@@ -3,7 +3,7 @@
 ##
 ## This file is part of HDF5.  The full HDF5 copyright notice, including
 ## terms governing use, modification, and redistribution, is contained in
-## the COPYING file, which can be found at the root of the source code
+## the LICENSE file, which can be found at the root of the source code
 ## distribution tree, or in https://www.hdfgroup.org/licenses.
 ## If you do not have access to either file, you may request a copy from
 ## help@hdfgroup.org.
@@ -59,11 +59,6 @@ STDOUT_FILTER() {
 # Remove them from the stderr result file.
 # $1 is the file name of the file to be filtered.
 # Cases of filter needed:
-# * MPE:
-# In parallel mode and if MPE library is used, it prints the following
-# two message lines whether the MPE tracing is used or not.
-#    Writing logfile.
-#    Finished writing logfile.
 # * LANL MPI:
 # The LANL MPI will print some messages like the following,
 #    LA-MPI: *** mpirun (1.5.10)
@@ -89,12 +84,6 @@ STDERR_FILTER() {
     cp $result_file $tmp_file
     sed -e '/ BE_MPI (ERROR): /d' \
 	< $tmp_file > $result_file
-    # Filter MPE messages
-    if test -n "$pmode"; then
-	cp $result_file $tmp_file
-	sed -e '/^Writing logfile./d' -e '/^Finished writing logfile./d' \
-	    < $tmp_file > $result_file
-    fi
     # Filter LANL MPI messages
     # and LLNL srun messages
     # and AIX error messages
