@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -40,9 +40,6 @@ typedef struct complex_t {
  * Purpose      Tests various things about compound data types.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (using C version)
- *              January, 2007
  *-------------------------------------------------------------------------
  */
 static void
@@ -73,9 +70,6 @@ test_compound_1()
  *              elements.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
  *-------------------------------------------------------------------------
  */
 static void
@@ -100,11 +94,13 @@ test_compound_2()
     SUBTEST("Compound Element Reordering");
     try {
         // Sizes should be the same, but be careful just in case
-        buf  = static_cast<unsigned char *>(HDmalloc(nelmts * MAX(sizeof(src_typ_t), sizeof(dst_typ_t))));
-        bkg  = static_cast<unsigned char *>(HDmalloc(nelmts * sizeof(dst_typ_t)));
-        orig = static_cast<unsigned char *>(HDmalloc(nelmts * sizeof(src_typ_t)));
+        buf  = static_cast<unsigned char *>(malloc(nelmts * MAX(sizeof(src_typ_t), sizeof(dst_typ_t))));
+        bkg  = static_cast<unsigned char *>(malloc(nelmts * sizeof(dst_typ_t)));
+        orig = static_cast<unsigned char *>(malloc(nelmts * sizeof(src_typ_t)));
         for (i = 0; i < nelmts; i++) {
-            s_ptr       = (reinterpret_cast<src_typ_t *>(orig)) + i;
+            H5_WARN_CAST_ALIGNMENT_OFF
+            s_ptr = (reinterpret_cast<src_typ_t *>(orig)) + i;
+            H5_WARN_CAST_ALIGNMENT_ON
             s_ptr->a    = i * 8 + 0;
             s_ptr->b    = i * 8 + 1;
             s_ptr->c[0] = i * 8 + 2;
@@ -114,7 +110,7 @@ test_compound_2()
             s_ptr->d    = i * 8 + 6;
             s_ptr->e    = i * 8 + 7;
         }
-        HDmemcpy(buf, orig, nelmts * sizeof(src_typ_t));
+        memcpy(buf, orig, nelmts * sizeof(src_typ_t));
 
         // Build hdf5 datatypes
         array_dt = new ArrayType(PredType::NATIVE_INT, 1, &four);
@@ -145,8 +141,10 @@ test_compound_2()
 
         // Compare results
         for (i = 0; i < nelmts; i++) {
+            H5_WARN_CAST_ALIGNMENT_OFF
             s_ptr = (reinterpret_cast<src_typ_t *>(orig)) + i;
             d_ptr = (reinterpret_cast<dst_typ_t *>(buf)) + i;
+            H5_WARN_CAST_ALIGNMENT_ON
             if (s_ptr->a != d_ptr->a || s_ptr->b != d_ptr->b || s_ptr->c[0] != d_ptr->c[0] ||
                 s_ptr->c[1] != d_ptr->c[1] || s_ptr->c[2] != d_ptr->c[2] || s_ptr->c[3] != d_ptr->c[3] ||
                 s_ptr->d != d_ptr->d || s_ptr->e != d_ptr->e) {
@@ -161,9 +159,9 @@ test_compound_2()
             }
         }
         // Release resources
-        HDfree(buf);
-        HDfree(bkg);
-        HDfree(orig);
+        free(buf);
+        free(bkg);
+        free(orig);
         s_ptr = NULL;
         d_ptr = NULL;
         st.close();
@@ -186,9 +184,6 @@ test_compound_2()
  *              members which appear in the source.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
  *-------------------------------------------------------------------------
  */
 static void
@@ -213,11 +208,13 @@ test_compound_3()
     SUBTEST("Compound Datatype Subset Conversions");
     try {
         /* Initialize */
-        buf  = static_cast<unsigned char *>(HDmalloc(nelmts * MAX(sizeof(src_typ_t), sizeof(dst_typ_t))));
-        bkg  = static_cast<unsigned char *>(HDmalloc(nelmts * sizeof(dst_typ_t)));
-        orig = static_cast<unsigned char *>(HDmalloc(nelmts * sizeof(src_typ_t)));
+        buf  = static_cast<unsigned char *>(malloc(nelmts * MAX(sizeof(src_typ_t), sizeof(dst_typ_t))));
+        bkg  = static_cast<unsigned char *>(malloc(nelmts * sizeof(dst_typ_t)));
+        orig = static_cast<unsigned char *>(malloc(nelmts * sizeof(src_typ_t)));
         for (i = 0; i < nelmts; i++) {
-            s_ptr       = (reinterpret_cast<src_typ_t *>(orig)) + i;
+            H5_WARN_CAST_ALIGNMENT_OFF
+            s_ptr = (reinterpret_cast<src_typ_t *>(orig)) + i;
+            H5_WARN_CAST_ALIGNMENT_ON
             s_ptr->a    = i * 8 + 0;
             s_ptr->b    = i * 8 + 1;
             s_ptr->c[0] = i * 8 + 2;
@@ -256,8 +253,10 @@ test_compound_3()
 
         /* Compare results */
         for (i = 0; i < nelmts; i++) {
+            H5_WARN_CAST_ALIGNMENT_OFF
             s_ptr = (reinterpret_cast<src_typ_t *>(orig)) + i;
             d_ptr = (reinterpret_cast<dst_typ_t *>(buf)) + i;
+            H5_WARN_CAST_ALIGNMENT_ON
             if (s_ptr->a != d_ptr->a || s_ptr->c[0] != d_ptr->c[0] || s_ptr->c[1] != d_ptr->c[1] ||
                 s_ptr->c[2] != d_ptr->c[2] || s_ptr->c[3] != d_ptr->c[3] || s_ptr->e != d_ptr->e) {
                 H5_FAILED();
@@ -271,9 +270,9 @@ test_compound_3()
         }
 
         /* Release resources */
-        HDfree(buf);
-        HDfree(bkg);
-        HDfree(orig);
+        free(buf);
+        free(bkg);
+        free(orig);
         s_ptr = NULL;
         d_ptr = NULL;
         st.close();
@@ -296,9 +295,6 @@ test_compound_3()
  *              smaller.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
  *-------------------------------------------------------------------------
  */
 static void
@@ -328,11 +324,13 @@ test_compound_4()
     SUBTEST("Compound Element Shrinking & Reordering");
     try {
         /* Sizes should be the same, but be careful just in case */
-        buf  = static_cast<unsigned char *>(HDmalloc(nelmts * MAX(sizeof(src_typ_t), sizeof(dst_typ_t))));
-        bkg  = static_cast<unsigned char *>(HDmalloc(nelmts * sizeof(dst_typ_t)));
-        orig = static_cast<unsigned char *>(HDmalloc(nelmts * sizeof(src_typ_t)));
+        buf  = static_cast<unsigned char *>(malloc(nelmts * MAX(sizeof(src_typ_t), sizeof(dst_typ_t))));
+        bkg  = static_cast<unsigned char *>(malloc(nelmts * sizeof(dst_typ_t)));
+        orig = static_cast<unsigned char *>(malloc(nelmts * sizeof(src_typ_t)));
         for (i = 0; i < nelmts; i++) {
-            s_ptr       = (reinterpret_cast<src_typ_t *>(orig)) + i;
+            H5_WARN_CAST_ALIGNMENT_OFF
+            s_ptr = (reinterpret_cast<src_typ_t *>(orig)) + i;
+            H5_WARN_CAST_ALIGNMENT_ON
             s_ptr->a    = i * 8 + 0;
             s_ptr->b    = (i * 8 + 1) & 0x7fff;
             s_ptr->c[0] = i * 8 + 2;
@@ -373,8 +371,10 @@ test_compound_4()
 
         /* Compare results */
         for (i = 0; i < nelmts; i++) {
+            H5_WARN_CAST_ALIGNMENT_OFF
             s_ptr = (reinterpret_cast<src_typ_t *>(orig)) + i;
             d_ptr = (reinterpret_cast<dst_typ_t *>(buf)) + i;
+            H5_WARN_CAST_ALIGNMENT_ON
             if (s_ptr->a != d_ptr->a || s_ptr->b != d_ptr->b || s_ptr->c[0] != d_ptr->c[0] ||
                 s_ptr->c[1] != d_ptr->c[1] || s_ptr->c[2] != d_ptr->c[2] || s_ptr->c[3] != d_ptr->c[3] ||
                 s_ptr->d != d_ptr->d || s_ptr->e != d_ptr->e) {
@@ -390,9 +390,9 @@ test_compound_4()
         }     // for
 
         /* Release resources */
-        HDfree(buf);
-        HDfree(bkg);
-        HDfree(orig);
+        free(buf);
+        free(bkg);
+        free(orig);
         s_ptr = NULL;
         d_ptr = NULL;
         st.close();
@@ -416,9 +416,6 @@ test_compound_4()
  *              which must undergo a conversion.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
  *-------------------------------------------------------------------------
  */
 static void
@@ -439,8 +436,8 @@ test_compound_5()
     hsize_t    dims[1] = {4};
     src_typ_t  src[2]  = {{"one", 102, {104, 105, 106, 107}}, {"two", 202, {204, 205, 206, 207}}};
     dst_typ_t *dst;
-    void      *buf      = HDcalloc(2, sizeof(dst_typ_t));
-    void      *bkg      = HDcalloc(2, sizeof(dst_typ_t));
+    void      *buf      = calloc(2, sizeof(dst_typ_t));
+    void      *bkg      = calloc(2, sizeof(dst_typ_t));
     ArrayType *array_dt = NULL;
 
     // Output message about test being performed
@@ -490,8 +487,8 @@ test_compound_5()
         }
 
         /* Free memory buffers */
-        HDfree(buf);
-        HDfree(bkg);
+        free(buf);
+        free(bkg);
         dst = NULL;
         PASSED();
     } // end of try block
@@ -511,9 +508,6 @@ test_compound_5()
  *              larger.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
  *-------------------------------------------------------------------------
  */
 static void
@@ -539,11 +533,13 @@ test_compound_6()
     SUBTEST("Compound Element Growing");
     try {
         /* Sizes should be the same, but be careful just in case */
-        buf  = static_cast<unsigned char *>(HDmalloc(nelmts * MAX(sizeof(src_typ_t), sizeof(dst_typ_t))));
-        bkg  = static_cast<unsigned char *>(HDmalloc(nelmts * sizeof(dst_typ_t)));
-        orig = static_cast<unsigned char *>(HDmalloc(nelmts * sizeof(src_typ_t)));
+        buf  = static_cast<unsigned char *>(malloc(nelmts * MAX(sizeof(src_typ_t), sizeof(dst_typ_t))));
+        bkg  = static_cast<unsigned char *>(malloc(nelmts * sizeof(dst_typ_t)));
+        orig = static_cast<unsigned char *>(malloc(nelmts * sizeof(src_typ_t)));
         for (i = 0; i < nelmts; i++) {
-            s_ptr    = (reinterpret_cast<src_typ_t *>(orig)) + i;
+            H5_WARN_CAST_ALIGNMENT_OFF
+            s_ptr = (reinterpret_cast<src_typ_t *>(orig)) + i;
+            H5_WARN_CAST_ALIGNMENT_ON
             s_ptr->b = (i * 8 + 1) & 0x7fff;
             s_ptr->d = (i * 8 + 6) & 0x7fff;
         }
@@ -563,8 +559,10 @@ test_compound_6()
 
         /* Compare results */
         for (i = 0; i < nelmts; i++) {
+            H5_WARN_CAST_ALIGNMENT_OFF
             s_ptr = (reinterpret_cast<src_typ_t *>(orig)) + i;
             d_ptr = (reinterpret_cast<dst_typ_t *>(buf)) + i;
+            H5_WARN_CAST_ALIGNMENT_ON
             if (s_ptr->b != d_ptr->b || s_ptr->d != d_ptr->d) {
                 H5_FAILED();
                 cerr << "    i=" << i << endl;
@@ -574,9 +572,9 @@ test_compound_6()
         }
 
         /* Release resources */
-        HDfree(buf);
-        HDfree(bkg);
-        HDfree(orig);
+        free(buf);
+        free(bkg);
+        free(orig);
         s_ptr = NULL;
         d_ptr = NULL;
         st.close();
@@ -596,9 +594,6 @@ test_compound_6()
  *              overlaps the end of the compound datatype.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2007
  *-------------------------------------------------------------------------
  */
 static void
@@ -662,9 +657,6 @@ test_compound_7()
  * Purpose      Tests member function setSize() on compound datatype
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use partial C version test_ooo_order)
- *              March, 2014
  *-------------------------------------------------------------------------
  */
 const H5std_string COMPFILE("tcompound_types.h5");
@@ -750,14 +742,13 @@ test_compound_set_size()
  * Purpose      Main compound datatype testing routine
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler
- *              January 2007
  *-------------------------------------------------------------------------
  */
 extern "C" void
-test_compound()
+test_compound(void *params)
 {
+    (void)params;
+
     // Output message about test being performed
     MESSAGE(5, ("Testing Compound Data Type operations\n"));
 
@@ -780,7 +771,11 @@ test_compound()
  *-------------------------------------------------------------------------
  */
 extern "C" void
-cleanup_compound()
+cleanup_compound(void *params)
 {
-    HDremove(COMPFILE.c_str());
+    (void)params;
+
+    if (GetTestCleanup()) {
+        HDremove(COMPFILE.c_str());
+    }
 } // cleanup_file
