@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -114,8 +114,10 @@ test_transfplist()
  *-------------------------------------------------------------------------
  */
 extern "C" void
-test_dsproplist()
+test_dsproplist(void *params)
 {
+    (void)params;
+
     // Output message about test being performed
     MESSAGE(5, ("Testing Generic Dataset Property Lists\n"));
 
@@ -132,7 +134,11 @@ test_dsproplist()
  *-------------------------------------------------------------------------
  */
 extern "C" void
-cleanup_dsproplist()
+cleanup_dsproplist(void *params)
 {
-    HDremove(FILENAME.c_str());
+    (void)params;
+
+    if (GetTestCleanup()) {
+        HDremove(FILENAME.c_str());
+    }
 }
