@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * the LICENSE file, which can be found at the root of the source code       *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -33,93 +32,86 @@
         PerformTests() -- Perform requested testing
         GetTestSummary() -- Retrieve Summary request value
         TestSummary() -- Display test summary
-        GetTestCleanup() -- Retrieve Cleanup request value
-        TestCleanup() -- Clean up files from testing
         GetTestNumErrs() -- Retrieve the number of testing errors
 
  ***************************************************************************/
-
-#ifdef OLD_HEADER_FILENAME
-#include <iostream.h>
-#else
 #include <iostream>
-#endif
 using std::cerr;
 using std::endl;
 
 #include <string>
-#include "H5Cpp.h"      // C++ API header file
+#include "H5Cpp.h" // C++ API header file
 using namespace H5;
 
-#include "h5cpputil.h"  // C++ utilility header file
+#include "h5test.h"
+#include "h5cpputil.h" // C++ utilility header file
 
 int
 main(int argc, char *argv[])
 {
-    try
-    {
+    try {
         // Turn of the auto-printing when failure occurs so that we can
         // handle the errors appropriately since sometime failures are
         // caused deliberately and expected.
         Exception::dontPrint();
         /* Initialize testing framework */
-        TestInit(argv[0], NULL, NULL);
+        TestInit(argv[0], NULL, NULL, NULL, NULL, 0);
 
         // testing file creation and opening in tfile.cpp
-        AddTest("tfile", test_file, cleanup_file, "File I/O Operations", NULL);
+        AddTest("tfile", test_file, NULL, cleanup_file, NULL, 0, "File I/O Operations");
         // testing dataset functionalities in dset.cpp
-        AddTest("dsets", test_dset, cleanup_dsets, "Dataset I/O Operations", NULL);
+        AddTest("dsets", test_dset, NULL, cleanup_dsets, NULL, 0, "Dataset I/O Operations");
         // testing dataspace functionalities in th5s.cpp
-        AddTest("th5s",  test_h5s,  cleanup_h5s,  "Dataspaces", NULL);
+        AddTest("th5s", test_h5s, NULL, cleanup_h5s, NULL, 0, "Dataspaces");
         // testing attribute functionalities in tattr.cpp
-        AddTest("tattr", test_attr, cleanup_attr,  "Attributes", NULL);
+        AddTest("tattr", test_attr, NULL, cleanup_attr, NULL, 0, "Attributes");
         // testing object functionalities in tobject.cpp
-        AddTest("tobject", test_object, cleanup_object,  "Objects", NULL);
+        AddTest("tobject", test_object, NULL, cleanup_object, NULL, 0, "Objects");
         // testing reference functionalities in trefer.cpp
-        AddTest("trefer", test_reference, cleanup_reference,  "References", NULL);
+        AddTest("trefer", test_reference, NULL, cleanup_reference, NULL, 0, "References");
         // testing variable-length strings in tvlstr.cpp
-        AddTest("tvlstr", test_vlstrings, cleanup_vlstrings,  "Variable-Length Strings", NULL);
-        AddTest("ttypes", test_types, cleanup_types,  "Generic Data Types", NULL);
-        AddTest("tarray", test_array, cleanup_array,  "Array Datatypes", NULL);
-        AddTest("tcompound", test_compound, cleanup_compound,  "Compound Data Types", NULL);
-        AddTest("tdspl", test_dsproplist, cleanup_dsproplist,  "Dataset Property List", NULL);
-        AddTest("tfilter", test_filters, cleanup_filters,  "Various Filters", NULL);
-        AddTest("tlinks", test_links, cleanup_links,  "Various Links", NULL);
-/* Comment out tests that are not done yet. - BMR, Feb 2001
-        AddTest("select", test_select, cleanup_select,  "Selections", NULL);
-        AddTest("time", test_time, cleanup_time,  "Time Datatypes", NULL);
-        AddTest("vltypes", test_vltypes, cleanup_vltypes,  "Variable-Length Datatypes", NULL);
-        AddTest("iterate", test_iterate, cleanup_iterate,  "Group & Attribute Iteration", NULL);
-        AddTest("genprop", test_genprop, cleanup_genprop,  "Generic Properties", NULL);
-        AddTest("id", test_ids, NULL,  "User-Created Identifiers", NULL);
+        AddTest("tvlstr", test_vlstrings, NULL, cleanup_vlstrings, NULL, 0, "Variable-Length Strings");
+        AddTest("ttypes", test_types, NULL, cleanup_types, NULL, 0, "Generic Data Types");
+        AddTest("tarray", test_array, NULL, cleanup_array, NULL, 0, "Array Datatypes");
+        AddTest("tcompound", test_compound, NULL, cleanup_compound, NULL, 0, "Compound Data Types");
+        AddTest("tdspl", test_dsproplist, NULL, cleanup_dsproplist, NULL, 0, "Dataset Property List");
+        AddTest("tfilter", test_filters, NULL, cleanup_filters, NULL, 0, "Various Filters");
+        AddTest("tlinks", test_links, NULL, cleanup_links, NULL, 0, "Various Links");
+        /* Comment out tests that are not done yet. - BMR, Feb 2001
+                AddTest("select", test_select, NULL, cleanup_select, NULL, 0, "Selections");
+                AddTest("time", test_time, NULL, cleanup_time, NULL, 0, "Time Datatypes");
+                AddTest("vltypes", test_vltypes, NULL, cleanup_vltypes, NULL, 0, "Variable-Length Datatypes");
+        */
+        AddTest("iterate", test_iterate, NULL, cleanup_iterate, NULL, 0, "Group & Attribute Iteration");
+        /*
+                AddTest("genprop", test_genprop, NULL, cleanup_genprop, NULL, 0, "Generic Properties");
+                AddTest("id", test_ids, NULL, NULL, NULL, 0, "User-Created Identifiers");
 
-Comment out tests that are not done yet */
+        Comment out tests that are not done yet */
 
-/* Tentative - BMR 2007/1/12
-        AddTest("enum", test_enum, cleanup_enum,  "Enum Data Types", NULL);
-*/
+        /* Tentative - BMR 2007/1/12
+                AddTest("enum", test_enum, NULL, cleanup_enum, NULL, 0, "Enum Data Types");
+        */
     }
-    catch (Exception& E)
-    {
+    catch (Exception &E) {
         issue_fail_msg("Tests failed", __LINE__, __FILE__, E.getCDetailMsg());
     }
 
     /* Display testing information */
-    TestInfo(argv[0]);
+    TestInfo(stdout);
 
     /* Parse command line arguments */
-    TestParseCmdLine(argc,argv);
+    TestParseCmdLine(argc, argv);
 
     /* Perform requested testing */
     PerformTests();
 
     /* Display test summary, if requested */
     if (GetTestSummary())
-        TestSummary();
+        TestSummary(stdout);
 
-    /* Clean up test files, if allowed */
-    if (GetTestCleanup() && !getenv("HDF5_NOCLEANUP"))
-        TestCleanup();
+    /* Release test infrastructure */
+    TestShutdown();
 
     return (GetTestNumErrs());
 }
