@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -61,17 +61,6 @@ const H5std_string FILE4("tfile4.h5");
  * Purpose      Test file and template creations
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2001
- *
- * Modifications:
- *        January, 2005: C tests' macro VERIFY casts values to 'long' for all
- *                     cases.  Since there are no operator<< for 'long long'
- *                     or int64 in VS C++ ostream, I casted the hsize_t values
- *                     passed to verify_val to 'long' as well.  If problems
- *                     arises later, this will have to be specifically handled
- *                     with a special routine.
  *-------------------------------------------------------------------------
  */
 static void
@@ -91,7 +80,7 @@ test_file_create()
     H5File *file1 = NULL;
     try {
         // Create file FILE1
-        file1 = new H5File(FILE1, H5F_ACC_EXCL);
+        file1 = new H5File(FILE1, H5F_ACC_TRUNC);
 
         // Try to create the same file with H5F_ACC_TRUNC. This should fail
         // because file1 is the same file and is currently open.
@@ -270,17 +259,6 @@ test_file_create()
  * Purpose      Test file accesses
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January, 2001
- *
- * Modifications:
- *        January, 2005: C tests' macro VERIFY casts values to 'long' for all
- *                     cases.  Since there are no operator<< for 'long long'
- *                     or int64 in VS C++ ostream, I casted the hsize_t values
- *                     passed to verify_val to 'long' as well.  If problems
- *                     arises later, this will have to be specifically handled
- *                     with a special routine.
  *-------------------------------------------------------------------------
  */
 static void
@@ -353,9 +331,6 @@ test_file_open()
  * Purpose      Test file size.
  *
  * Return       None
- *
- * Programmer   Raymond Lu
- *              June, 2004
  *-------------------------------------------------------------------------
  */
 static void
@@ -416,9 +391,6 @@ test_file_size()
  * Purpose      Test file number.
  *
  * Return       None
- *
- * Programmer   Quincey Koziol
- *              April, 2019
  *-------------------------------------------------------------------------
  */
 static void
@@ -473,9 +445,6 @@ test_file_num()
  * Purpose      Test getting file's name.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler
- *              July, 2004
  *-------------------------------------------------------------------------
  */
 const int          RANK = 2;
@@ -657,7 +626,7 @@ test_file_attribute()
         verify_val(n_attrs, 1, "DataSet::getNumAttrs()", __LINE__, __FILE__);
 
         // Read back attribute's data
-        HDmemset(rdata, 0, sizeof(rdata));
+        memset(rdata, 0, sizeof(rdata));
         dattr.read(PredType::NATIVE_INT, rdata);
         /* Check results */
         for (i = 0; i < ATTR1_DIM1; i++) {
@@ -684,9 +653,6 @@ test_file_attribute()
  *              versions for the right objects.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              March, 2015
  *-------------------------------------------------------------------------
  */
 const H5std_string FILE6("tfile5.h5");
@@ -716,7 +682,7 @@ test_libver_bounds_real(H5F_libver_t libver_create, unsigned oh_vers_create, H5F
 
         // Verify object header version another way
         H5O_native_info_t ninfo;
-        HDmemset(&ninfo, 0, sizeof(ninfo));
+        memset(&ninfo, 0, sizeof(ninfo));
         file.getNativeObjinfo(ninfo, H5O_NATIVE_INFO_HDR);
         verify_val(ninfo.hdr.version, oh_vers_create, "H5File::getNativeObjinfo", __LINE__, __FILE__);
 
@@ -743,7 +709,7 @@ test_libver_bounds_real(H5F_libver_t libver_create, unsigned oh_vers_create, H5F
         verify_val(obj_version, oh_vers_mod, "Group::objVersion", __LINE__, __FILE__);
 
         // Verify object header version another way
-        HDmemset(&ninfo, 0, sizeof(ninfo));
+        memset(&ninfo, 0, sizeof(ninfo));
         group.getNativeObjinfo(ninfo, H5O_NATIVE_INFO_HDR);
         verify_val(ninfo.hdr.version, oh_vers_mod, "Group::getNativeObjinfo", __LINE__, __FILE__);
 
@@ -783,9 +749,6 @@ test_libver_bounds_real(H5F_libver_t libver_create, unsigned oh_vers_create, H5F
  *              libver bounds is handled correctly.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              March 2015
  *-------------------------------------------------------------------------
  */
 static void
@@ -796,7 +759,7 @@ test_libver_bounds()
 
     /* Run the tests */
     test_libver_bounds_real(H5F_LIBVER_EARLIEST, H5O_VERSION_1, H5F_LIBVER_LATEST, H5O_VERSION_2);
-    test_libver_bounds_real(H5F_LIBVER_LATEST, H5O_VERSION_2, H5F_LIBVER_EARLIEST, H5O_VERSION_2);
+    test_libver_bounds_real(H5F_LIBVER_LATEST, H5O_VERSION_2, H5F_LIBVER_EARLIEST, H5O_VERSION_1);
     PASSED();
 } /* end test_libver_bounds() */
 
@@ -806,9 +769,6 @@ test_libver_bounds()
  * Purpose      Verify that H5File works as a root group.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              March, 2015
  *-------------------------------------------------------------------------
  */
 static void
@@ -869,9 +829,6 @@ test_commonfg()
  *              when the file is re-opened.
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler
- *              February, 2017
  *-------------------------------------------------------------------------
  */
 const H5std_string FILE7("tfile7.h5");
@@ -885,13 +842,15 @@ test_file_info()
     SUBTEST("File general information");
 
     hsize_t out_threshold = 0;     // Free space section threshold to get
-    hbool_t out_persist   = FALSE; // Persist free-space read
+    bool    out_persist   = false; // Persist free-space read
     // File space handling strategy
     H5F_fspace_strategy_t out_strategy = H5F_FSPACE_STRATEGY_FSM_AGGR;
 
     try {
-        // Create a file using default properties.
-        H5File tempfile(FILE7, H5F_ACC_TRUNC);
+        // Create a file using the earliest format.
+        FileAccPropList fapl;
+        fapl.setLibverBounds(H5F_LIBVER_EARLIEST, H5F_LIBVER_LATEST);
+        H5File tempfile(FILE7, H5F_ACC_TRUNC, FileCreatPropList::DEFAULT, fapl);
 
         // Get the file's version information.
         H5F_info2_t finfo;
@@ -912,7 +871,7 @@ test_file_info()
         // Verify file space information.
         verify_val(static_cast<long>(out_strategy), static_cast<long>(H5F_FSPACE_STRATEGY_FSM_AGGR),
                    "H5File::getFileInfo", __LINE__, __FILE__);
-        verify_val(out_persist, FALSE, "H5File::getFileInfo", __LINE__, __FILE__);
+        verify_val(out_persist, false, "H5File::getFileInfo", __LINE__, __FILE__);
         verify_val(static_cast<long>(out_threshold), 1, "H5File::getFileInfo", __LINE__, __FILE__);
 
         /* Retrieve file space page size */
@@ -927,7 +886,7 @@ test_file_info()
         fcpl.setIstorek(F2_ISTORE);
 
         hsize_t               threshold = 5;    // Free space section threshold to set
-        hbool_t               persist   = TRUE; // Persist free-space to set
+        bool                  persist   = true; // Persist free-space to set
         H5F_fspace_strategy_t strategy  = H5F_FSPACE_STRATEGY_PAGE;
 
         fcpl.setFileSpaceStrategy(strategy, persist, threshold);
@@ -1008,14 +967,13 @@ test_file_info()
  * Purpose      Main file testing routine
  *
  * Return       None
- *
- * Programmer   Binh-Minh Ribler (use C version)
- *              January 2001
  *-------------------------------------------------------------------------
  */
 extern "C" void
-test_file()
+test_file(void *params)
 {
+    (void)params;
+
     // Output message about test being performed
     MESSAGE(5, ("Testing File I/O Operations\n"));
 
@@ -1038,17 +996,18 @@ test_file()
  * Return       none
  *-------------------------------------------------------------------------
  */
-#ifdef __cplusplus
-extern "C"
-#endif
-    void
-    cleanup_file()
+extern "C" void
+cleanup_file(void *params)
 {
-    HDremove(FILE1.c_str());
-    HDremove(FILE2.c_str());
-    HDremove(FILE3.c_str());
-    HDremove(FILE4.c_str());
-    HDremove(FILE5.c_str());
-    HDremove(FILE6.c_str());
-    HDremove(FILE7.c_str());
+    (void)params;
+
+    if (GetTestCleanup()) {
+        HDremove(FILE1.c_str());
+        HDremove(FILE2.c_str());
+        HDremove(FILE3.c_str());
+        HDremove(FILE4.c_str());
+        HDremove(FILE5.c_str());
+        HDremove(FILE6.c_str());
+        HDremove(FILE7.c_str());
+    }
 } // cleanup_file
