@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -25,10 +25,8 @@ typedef struct {
 static hsize_t    H5PT_ptable_count   = 0;
 static H5I_type_t H5PT_ptable_id_type = H5I_UNINIT;
 
-#define H5PT_HASH_TABLE_SIZE 64
-
 /* Packet Table private functions */
-static herr_t H5PT_free_id(void *id);
+static herr_t H5PT_free_id(void *id, void **_ctx);
 static herr_t H5PT_close(htbl_t *table);
 static herr_t H5PT_create_index(htbl_t *table_id);
 static herr_t H5PT_set_index(htbl_t *table_id, hsize_t pt_index);
@@ -42,29 +40,16 @@ static herr_t H5PT_get_index(htbl_t *table_id, hsize_t *pt_index);
  */
 
 /*-------------------------------------------------------------------------
- * Function: H5PTcreate
+ * Function:    H5PTcreate
  *
- * Purpose: Creates a dataset containing a table and returns the Identifier
- *          of the table. (Copied mostly from H5PTcreate_fl)
+ * Purpose:     Creates a dataset containing a table and returns the Identifier
+ *              of the table. (Copied mostly from H5PTcreate_fl)
  *
- * Return: Success: table ID, Failure: FAIL
- *
- * Programmer: Nat Furrer (Author of H5PTcreate_fl)
- *             James Laird (Author of H5PTcreate_fl)
- *
- * Date: March 12, 2004
- *
- * Comments: This function does not handle fill data
- *           currently.  Fill data is not necessary because the
- *           table is initially of size 0.
- *
- * Modifications:
- *	Mar 1, 2016
- *		This function is added to replace H5PTcreate_fl and it differs
- *		from H5PTcreate_fl only because its last argument is plist_id
- *		instead of compression; this is to allow flexible compression.
- *		-BMR
+ *              This function does not handle fill data
+ *              currently.  Fill data is not necessary because the
+ *              table is initially of size 0.
  *
+ * Return:      Success: table ID, Failure: FAIL
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -86,11 +71,11 @@ H5PTcreate(hid_t loc_id, const char *dset_name, hid_t dtype_id, hsize_t chunk_si
 
     /* Register the packet table ID type if this is the first table created */
     if (H5PT_ptable_id_type < 0)
-        if ((H5PT_ptable_id_type = H5Iregister_type((size_t)H5PT_HASH_TABLE_SIZE, 0, H5PT_free_id)) < 0)
+        if ((H5PT_ptable_id_type = H5Iregister_type2(0, (H5I_free_t)H5PT_free_id)) < 0)
             goto error;
 
     /* Get memory for the table identifier */
-    table = (htbl_t *)HDmalloc(sizeof(htbl_t));
+    table = (htbl_t *)malloc(sizeof(htbl_t));
     if (table == NULL) {
         goto error;
     }
@@ -159,30 +144,23 @@ error:
     if (table) {
         if (table->type_id != H5I_INVALID_HID)
             H5Tclose(table->type_id);
-        HDfree(table);
+        free(table);
     }
 
     return ret_value;
 } /* H5PTcreate */
 
 /*-------------------------------------------------------------------------
- * Function: H5PTcreate_fl
+ * Function:    H5PTcreate_fl
  *
- * Purpose: Creates a dataset containing a table and returns the Identifier
- *          of the table.
+ * Purpose:     Creates a dataset containing a table and returns the
+ *              identifier of the table.
  *
- * Return: Success: table ID, Failure: Negative
+ *              This function does not handle fill data
+ *              currently.  Fill data is not necessary because the
+ *              table is initially of size 0.
  *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: March 12, 2004
- *
- * Comments: This function does not handle fill data
- *           currently.  Fill data is not necessary because the
- *           table is initially of size 0.
- *
- * Modifications:
+ * Return:      Success: table ID, Failure: Negative
  *
  *-------------------------------------------------------------------------
  */
@@ -206,11 +184,11 @@ H5PTcreate_fl(hid_t loc_id, const char *dset_name, hid_t dtype_id, hsize_t chunk
 
     /* Register the packet table ID type if this is the first table created */
     if (H5PT_ptable_id_type < 0)
-        if ((H5PT_ptable_id_type = H5Iregister_type((size_t)H5PT_HASH_TABLE_SIZE, 0, H5PT_free_id)) < 0)
+        if ((H5PT_ptable_id_type = H5Iregister_type2(0, (H5I_free_t)H5PT_free_id)) < 0)
             goto error;
 
     /* Get memory for the table identifier */
-    table = (htbl_t *)HDmalloc(sizeof(htbl_t));
+    table = (htbl_t *)malloc(sizeof(htbl_t));
     if (table == NULL) {
         goto error;
     }
@@ -274,7 +252,7 @@ error:
     if (table) {
         if (table->type_id != H5I_INVALID_HID)
             H5Tclose(table->type_id);
-        HDfree(table);
+        free(table);
     }
 
     return ret_value;
@@ -287,21 +265,6 @@ error:
  *          of the table.
  *
  * Return: Success: table ID, Failure: Negative
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: March 10, 2004
- *
- * Comments:
- *
- * Modifications:
- *
- * 		John Mainzer -- 4/23/08
- * 		Added error check on malloc of table, initialized fields
- * 		in table to keep lower level code from choking on bogus
- * 		data in error cases.
- *
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -320,10 +283,10 @@ H5PTopen(hid_t loc_id, const char *dset_name)
 
     /* Register the packet table ID type if this is the first table created */
     if (H5PT_ptable_id_type < 0)
-        if ((H5PT_ptable_id_type = H5Iregister_type((size_t)H5PT_HASH_TABLE_SIZE, 0, H5PT_free_id)) < 0)
+        if ((H5PT_ptable_id_type = H5Iregister_type2(0, (H5I_free_t)H5PT_free_id)) < 0)
             goto error;
 
-    table = (htbl_t *)HDmalloc(sizeof(htbl_t));
+    table = (htbl_t *)malloc(sizeof(htbl_t));
     if (table == NULL) {
         goto error;
     }
@@ -383,7 +346,7 @@ error:
             H5Tclose(table->type_id);
         if (table->dset_id != H5I_INVALID_HID)
             H5Dclose(table->dset_id);
-        HDfree(table);
+        free(table);
     }
 
     return ret_value;
@@ -398,9 +361,9 @@ error:
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5PT_free_id(void *id)
+H5PT_free_id(void *id, void H5_ATTR_UNUSED **_ctx)
 {
-    HDfree(id);
+    free(id);
     return SUCCEED;
 }
 
@@ -411,16 +374,6 @@ H5PT_free_id(void *id)
  *          table).
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: March 10, 2004
- *
- * Comments:
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -437,7 +390,7 @@ H5PT_close(htbl_t *table)
     if (H5Tclose(table->type_id) < 0)
         goto error;
 
-    HDfree(table);
+    free(table);
 
     return SUCCEED;
 
@@ -447,7 +400,7 @@ error:
         H5Dclose(table->dset_id);
         H5Tclose(table->type_id);
         H5E_END_TRY
-        HDfree(table);
+        free(table);
     }
     return FAIL;
 }
@@ -459,16 +412,6 @@ error:
  *          table).
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: April 21, 2004
- *
- * Comments:
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -513,16 +456,6 @@ error:
  * Purpose: Appends packets to the end of a packet table
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: March 12, 2004
- *
- * Comments:
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -563,17 +496,6 @@ error:
  *          that index
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: March 10, 2004
- *
- * Comments:
- *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -607,17 +529,6 @@ error:
  * Purpose: Reads packets from anywhere in a packet table
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: March 12, 2004
- *
- * Comments:
- *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -656,16 +567,6 @@ error:
  * Purpose: Resets, sets, and gets the current record index for a packet table
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *  		   James Laird
- *
- * Date: March 12, 2004
- *
- * Comments:
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -709,16 +610,6 @@ H5PT_get_index(htbl_t *table, hsize_t *pt_index)
  * Purpose: Resets, sets, and gets the current record index for a packet table
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: April 23, 2004
- *
- * Comments:
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -770,17 +661,6 @@ H5PTget_index(hid_t table_id, hsize_t *pt_index)
  * Purpose: Returns by reference the number of packets in the packet table
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: March 12, 2004
- *
- * Comments:
- *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -807,17 +687,6 @@ error:
  * Purpose: Validates a table identifier
  *
  * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: March 12, 2004
- *
- * Comments:
- *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -837,17 +706,6 @@ H5PTis_valid(hid_t table_id)
  *          length records or 0 for fixed-length records.
  *
  * Return: True: 1, False: 0, Failure: FAIL
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: April 14, 2004
- *
- * Comments:
- *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -887,17 +745,6 @@ error:
  *
  * Return: Success: SUCCEED, Failure: FAIL
  *          -2 if memory was reclaimed but another error occurred
- *
- * Programmer: Nat Furrer
- *             James Laird
- *
- * Date: April 12, 2004
- *
- * Comments:
- *
- * Modifications:
- *
- *
  *-------------------------------------------------------------------------
  */
 
@@ -941,21 +788,11 @@ error:
  *-------------------------------------------------------------------------
  */
 /*-------------------------------------------------------------------------
- * Function: H5PTget_dataset
- *
- * Purpose: Returns the backend dataset of this packet table
- *
- * Return: Success: SUCCEED, Failure: FAIL
- *
- * Programmer: User's patch 0003, HDFFV-8623. -BMR
- *
- * Date: Feb 10, 2016
- *
- * Comments:
- *
- * Modifications:
+ * Function:    H5PTget_dataset
  *
+ * Purpose:     Returns the backend dataset of this packet table
  *
+ * Return:      SUCCEED/FAIL
  *-------------------------------------------------------------------------
  */
 hid_t
@@ -976,21 +813,11 @@ error:
 }
 
 /*-------------------------------------------------------------------------
- * Function: H5PTget_type
- *
- * Purpose: Returns the backend type of this packet table
- *
- * Return: Success: datatype ID, Failure: H5I_INVALID_HID
- *
- * Programmer: User's patch 0003, HDFFV-8623. -BMR
- *
- * Date: Feb 10, 2016
- *
- * Comments:
- *
- * Modifications:
+ * Function:    H5PTget_type
  *
+ * Purpose:     Returns the backend type of this packet table
  *
+ * Return:      Success: datatype ID, Failure: H5I_INVALID_HID
  *-------------------------------------------------------------------------
  */
 hid_t
