@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -52,8 +52,12 @@
 static int
 test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
 {
-    hid_t  *file_id = NULL, *dset_id = NULL, file_space, plist; /* HDF5 ids */
-    hsize_t dims1[RANK]    = {2, 3};                            /* original dimension of datasets */
+    hid_t  *file_id        = NULL;            /* Array of file IDs */
+    hid_t  *dset_id        = NULL;            /* Array of dataset IDs */
+    hid_t   file_space_id  = H5I_INVALID_HID; /* Dataspace ID */
+    hid_t   dcpl_id        = H5I_INVALID_HID; /* DCPL ID */
+    hid_t   fapl_id        = H5I_INVALID_HID; /* FAPL ID */
+    hsize_t dims1[RANK]    = {2, 3};          /* original dimension of datasets */
     hsize_t max_dims[RANK] = {H5S_UNLIMITED, H5S_UNLIMITED};
     int     data1[6]       = {1, 2, 3, 4, 5, 6};    /* original contents of dataset */
     int     data2[6]       = {7, 8, 9, 10, 11, 12}; /* "wrong" contents of dataset */
@@ -76,29 +80,36 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
     VERIFY(nflags > 0, "The number of flag combinations  must be greater than 0");
 
     /* allocate array of flags for open images */
-    if (NULL == (input_flags = (unsigned *)HDmalloc(sizeof(unsigned) * open_images)))
+    if (NULL == (input_flags = (unsigned *)malloc(sizeof(unsigned) * open_images)))
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array of pointers for each of the open images */
-    if (NULL == (buf_ptr = (void **)HDmalloc(sizeof(void *) * open_images)))
+    if (NULL == (buf_ptr = (void **)malloc(sizeof(void *) * open_images)))
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array to store the name of each of the open images */
-    if (NULL == (filename = (char **)HDcalloc(1, sizeof(char *) * open_images)))
+    if (NULL == (filename = (char **)calloc(1, sizeof(char *) * open_images)))
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array to store the size of each of the open images */
-    if (NULL == (buf_size = (ssize_t *)HDmalloc(sizeof(ssize_t) * open_images)))
+    if (NULL == (buf_size = (ssize_t *)malloc(sizeof(ssize_t) * open_images)))
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array for each of the file identifiers */
-    if (NULL == (file_id = (hid_t *)HDmalloc(sizeof(hid_t) * open_images)))
+    if (NULL == (file_id = (hid_t *)malloc(sizeof(hid_t) * open_images)))
         FAIL_PUTS_ERROR("malloc() failed");
 
     /* allocate array for each of the dataset identifiers */
-    if (NULL == (dset_id = (hid_t *)HDmalloc(sizeof(hid_t) * open_images)))
+    if (NULL == (dset_id = (hid_t *)malloc(sizeof(hid_t) * open_images)))
         FAIL_PUTS_ERROR("malloc() failed");
 
+    /* Create FAPL and set earliest format */
+    /* TODO: run this test with all different formats */
+    if ((fapl_id = H5Pcreate(H5P_FILE_ACCESS)) < 0)
+        FAIL_PUTS_ERROR("H5Pcreate() failed");
+    if (H5Pset_libver_bounds(fapl_id, H5F_LIBVER_EARLIEST, H5F_LIBVER_LATEST) < 0)
+        FAIL_PUTS_ERROR("H5Pset_libver_bounds() failed");
+
     HL_TESTING2("get file images");
 
     /* create several file images */
@@ -109,32 +120,32 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
 
         /* allocate name buffer for image i */
         size_t filenamelength = sizeof(char) * 32;
-        filename[i]           = (char *)HDmalloc(filenamelength);
+        filename[i]           = (char *)malloc(filenamelength);
         if (!filename[i])
-            FAIL_PUTS_ERROR("HDmalloc() failed");
+            FAIL_PUTS_ERROR("malloc() failed");
 
         /* create file name */
-        HDsnprintf(filename[i], filenamelength, "image_file%d.h5", (int)i);
+        snprintf(filename[i], filenamelength, "image_file%d.h5", (int)i);
 
         /* create file */
-        if ((file_id[i] = H5Fcreate(filename[i], H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT)) < 0)
+        if ((file_id[i] = H5Fcreate(filename[i], H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id)) < 0)
             FAIL_PUTS_ERROR("H5Fcreate() failed");
 
         /* define dataspace for the dataset */
-        if ((file_space = H5Screate_simple(RANK, dims1, max_dims)) < 0)
+        if ((file_space_id = H5Screate_simple(RANK, dims1, max_dims)) < 0)
             FAIL_PUTS_ERROR("H5Screate_simple() failed");
 
         /* create dataset property list */
-        if ((plist = H5Pcreate(H5P_DATASET_CREATE)) < 0)
+        if ((dcpl_id = H5Pcreate(H5P_DATASET_CREATE)) < 0)
             FAIL_PUTS_ERROR("H5Pcreate() failed");
 
         /* set property list to create chunked dataset */
-        if (H5Pset_chunk(plist, RANK, dims1) < 0)
+        if (H5Pset_chunk(dcpl_id, RANK, dims1) < 0)
             FAIL_PUTS_ERROR("H5Pset_chunk() failed");
 
         /* create and write an integer type dataset named "dset" */
-        if ((dset_id[i] = H5Dcreate2(file_id[i], DSET_NAME, H5T_NATIVE_INT, file_space, H5P_DEFAULT, plist,
-                                     H5P_DEFAULT)) < 0)
+        if ((dset_id[i] = H5Dcreate2(file_id[i], DSET_NAME, H5T_NATIVE_INT, file_space_id, H5P_DEFAULT,
+                                     dcpl_id, H5P_DEFAULT)) < 0)
             FAIL_PUTS_ERROR("H5Dcreate() failed");
 
         /* dataset in open image 1 is written with "wrong" data */
@@ -153,11 +164,11 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
             FAIL_PUTS_ERROR("H5Fflush() failed");
 
         /* close dataset property list */
-        if (H5Pclose(plist) < 0)
+        if (H5Pclose(dcpl_id) < 0)
             FAIL_PUTS_ERROR("H5Pclose() failed");
 
         /* close dataspace */
-        if (H5Sclose(file_space) < 0)
+        if (H5Sclose(file_space_id) < 0)
             FAIL_PUTS_ERROR("H5Sclose() failed");
 
         /* close dataset */
@@ -169,7 +180,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
             FAIL_PUTS_ERROR("H5Fget_file_image() failed");
 
         /* allocate buffer for the file image i */
-        if (NULL == (buf_ptr[i] = (void *)HDmalloc((size_t)buf_size[i])))
+        if (NULL == (buf_ptr[i] = (void *)malloc((size_t)buf_size[i])))
             FAIL_PUTS_ERROR("malloc() failed");
 
         /* buffer for file image 2 is filled with counter data (non-valid image) */
@@ -233,28 +244,28 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
              */
             if (input_flags[i] & H5LT_FILE_IMAGE_OPEN_RW && !(input_flags[i] & H5LT_FILE_IMAGE_DONT_COPY)) {
 
-                void *tmp_ptr = HDmalloc((size_t)buf_size[i]);
+                void *tmp_ptr = malloc((size_t)buf_size[i]);
                 if (!tmp_ptr)
                     FAIL_PUTS_ERROR("buffer allocation failed");
 
                 /* Copy vfd buffer to a temporary buffer */
-                HDmemcpy(tmp_ptr, (void *)*core_buf_ptr_ptr, (size_t)buf_size[i]);
+                memcpy(tmp_ptr, (void *)*core_buf_ptr_ptr, (size_t)buf_size[i]);
                 /* Clear status_flags in the superblock for the vfd buffer: file locking is using status_flags
                  */
-                HDmemset((uint8_t *)tmp_ptr + SUPER_STATUS_FLAGS_OFF_V0_V1, (int)0,
-                         (size_t)SUPER_STATUS_FLAGS_SIZE_V0_V1);
+                memset((uint8_t *)tmp_ptr + SUPER_STATUS_FLAGS_OFF_V0_V1, (int)0,
+                       (size_t)SUPER_STATUS_FLAGS_SIZE_V0_V1);
                 /* Does the comparison */
-                if (HDmemcmp(tmp_ptr, buf_ptr[i], (size_t)buf_size[i]) != 0)
+                if (memcmp(tmp_ptr, buf_ptr[i], (size_t)buf_size[i]) != 0)
                     FAIL_PUTS_ERROR("comparison of TMP vfd and user buffer failed");
                 /* Free the temporary buffer */
                 if (tmp_ptr)
-                    HDfree(tmp_ptr);
+                    free(tmp_ptr);
             }
             else {
 
                 /* test whether the contents of the user buffer and driver buffer */
                 /* are equal.                                                     */
-                if (HDmemcmp(*core_buf_ptr_ptr, buf_ptr[i], (size_t)buf_size[i]) != 0)
+                if (memcmp(*core_buf_ptr_ptr, buf_ptr[i], (size_t)buf_size[i]) != 0)
                     FAIL_PUTS_ERROR("comparison of vfd and user buffer failed");
             }
         } /* end else */
@@ -268,7 +279,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
     for (i = 0; i < open_images; i++) {
         /* if opening the file image failed, continue next iteration */
         if (file_id[i] < 0) {
-            HDassert(i == 2);
+            assert(i == 2);
             continue;
         } /* end if */
 
@@ -277,11 +288,11 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
             FAIL_PUTS_ERROR("H5Dopen() failed");
 
         /* get dataspace for the dataset */
-        if ((file_space = H5Dget_space(dset_id[i])) < 0)
+        if ((file_space_id = H5Dget_space(dset_id[i])) < 0)
             FAIL_PUTS_ERROR("H5Dget_space() failed");
 
         /* get dimensions for the dataset */
-        if (H5Sget_simple_extent_dims(file_space, dims3, NULL) < 0)
+        if (H5Sget_simple_extent_dims(file_space_id, dims3, NULL) < 0)
             FAIL_PUTS_ERROR("H5Sget_simple_extent_dims() failed");
 
         /* read dataset */
@@ -312,7 +323,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
         } /* end else */
 
         /* close dataspace */
-        if (H5Sclose(file_space) < 0)
+        if (H5Sclose(file_space_id) < 0)
             FAIL_PUTS_ERROR("H5Sclose() failed");
     } /* end for */
 
@@ -324,7 +335,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
     for (i = 0; i < open_images; i++) {
         /* if opening the file image failed, continue next iteration */
         if (file_id[i] < 0) {
-            HDassert(i == 2);
+            assert(i == 2);
             continue;
         } /* end if */
 
@@ -335,7 +346,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
             {
                 status1 = H5Dwrite(dset_id[i], H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, data1);
             }
-            H5E_END_TRY;
+            H5E_END_TRY
 
             VERIFY(status1 < 0, "H5Dwrite() should have failed");
 
@@ -344,7 +355,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
             {
                 status1 = H5Dset_extent(dset_id[i], dims4);
             }
-            H5E_END_TRY;
+            H5E_END_TRY
 
             VERIFY(status1 < 0, "H5Dset_extent() should have failed");
 
@@ -353,7 +364,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
             {
                 status1 = H5Dwrite(dset_id[i], H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, data4);
             }
-            H5E_END_TRY;
+            H5E_END_TRY
 
             VERIFY(status1 < 0, "H5Dwrite() should have failed");
 
@@ -408,13 +419,13 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
                         status2 = H5Fflush(file_id[i], H5F_SCOPE_GLOBAL);
 
                     VERIFY(status1 < 0 || status2 < 0, "writing and flushing attr should have failed");
-                } H5E_END_TRY;
+                } H5E_END_TRY
 
                 /* close attr and attr_space -- expect errors on close */
                 H5E_BEGIN_TRY {
                     H5Sclose(attr_space_id);
                     H5Aclose(attr_id);
-                } H5E_END_TRY;
+                } H5E_END_TRY
 #endif
                 if (H5Dclose(dset_id[i]) < 0)
                     FAIL_PUTS_ERROR("H5Dclose() failed");
@@ -455,11 +466,11 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
             FAIL_PUTS_ERROR("H5Dopen() failed");
 
         /* get dataspace for the dataset */
-        if ((file_space = H5Dget_space(dset_id[i])) < 0)
+        if ((file_space_id = H5Dget_space(dset_id[i])) < 0)
             FAIL_PUTS_ERROR("H5Dget_space() failed");
 
         /* get dimensions for the dataset */
-        if (H5Sget_simple_extent_dims(file_space, dims3, NULL) < 0)
+        if (H5Sget_simple_extent_dims(file_space_id, dims3, NULL) < 0)
             FAIL_PUTS_ERROR("H5Sget_simple_extent_dims() failed");
 
         /* read dataset */
@@ -479,7 +490,7 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
                     FAIL_PUTS_ERROR("comparison of image values with original data failed");
 
         /* close dataspace */
-        if (H5Sclose(file_space) < 0)
+        if (H5Sclose(file_space_id) < 0)
             FAIL_PUTS_ERROR("H5Sclose() failed");
 
         /* close dataset */
@@ -508,20 +519,24 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
         if (!(input_flags[i] & H5LT_FILE_IMAGE_DONT_COPY) ||
             (input_flags[i] & H5LT_FILE_IMAGE_DONT_RELEASE)) {
             VERIFY(buf_ptr[i] != NULL, "buffer pointer must be non NULL");
-            HDfree(buf_ptr[i]);
+            free(buf_ptr[i]);
         } /* end if */
 
     } /* end for */
 
+    /* close file access property list */
+    if (H5Pclose(fapl_id) < 0)
+        FAIL_PUTS_ERROR("H5Pclose() failed");
+
     /* release temporary working buffers */
     for (i = 0; i < open_images; i++)
-        HDfree(filename[i]);
-    HDfree(filename);
-    HDfree(file_id);
-    HDfree(dset_id);
-    HDfree(buf_ptr);
-    HDfree(buf_size);
-    HDfree(input_flags);
+        free(filename[i]);
+    free(filename);
+    free(file_id);
+    free(dset_id);
+    free(buf_ptr);
+    free(buf_size);
+    free(input_flags);
 
     PASSED();
 
@@ -532,14 +547,14 @@ test_file_image(size_t open_images, size_t nflags, const unsigned *flags)
 error:
     if (filename) {
         for (i = 0; i < open_images; i++)
-            HDfree(filename[i]);
-        HDfree(filename);
+            free(filename[i]);
+        free(filename);
     }
-    HDfree(file_id);
-    HDfree(dset_id);
-    HDfree(buf_ptr);
-    HDfree(buf_size);
-    HDfree(input_flags);
+    free(file_id);
+    free(dset_id);
+    free(buf_ptr);
+    free(buf_size);
+    free(input_flags);
 
     H5_FAILED();
     return -1;
@@ -572,10 +587,10 @@ main(void)
 
     if (nerrors)
         goto error;
-    HDprintf("File image tests passed.\n");
+    printf("File image tests passed.\n");
     return 0;
 
 error:
-    HDprintf("***** %d IMAGE TEST%s FAILED! *****\n", nerrors, 1 == nerrors ? "" : "S");
+    printf("***** %d IMAGE TEST%s FAILED! *****\n", nerrors, 1 == nerrors ? "" : "S");
     return 1;
 }
