@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -84,7 +84,7 @@ error:
         H5Sclose(sid);
         H5Pclose(dcpl_id);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     return H5I_INVALID_HID;
 
@@ -192,7 +192,7 @@ test_direct_chunk_read(hid_t did)
             TEST_ERROR;
 
         /* Read the raw chunk back */
-        HDmemset(chunk_data, 0, CHUNK_NX * sizeof(int));
+        memset(chunk_data, 0, CHUNK_NX * sizeof(int));
         filter_mask = UINT_MAX;
         offset[0]   = (hsize_t)i * CHUNK_NX;
         if (H5DOread_chunk(did, H5P_DEFAULT, offset, &filter_mask, chunk_data) < 0)
@@ -223,7 +223,7 @@ error:
         H5Sclose(mem_sid);
         H5Sclose(file_sid);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     H5_FAILED();
     return 1;
@@ -247,8 +247,8 @@ main(void)
 {
 #ifdef H5_NO_DEPRECATED_SYMBOLS
 
-    HDputs("Direct chunk read/write wrapper tests SKIPPED.");
-    HDputs("(Backward compatibility not configured)");
+    puts("Direct chunk read/write wrapper tests SKIPPED.");
+    puts("(Backward compatibility not configured)");
     return EXIT_SUCCESS;
 
 #else
@@ -275,11 +275,11 @@ main(void)
     if (nerrors)
         goto error;
 
-    HDputs("All direct chunk read/write wrapper tests passed.");
+    puts("All direct chunk read/write wrapper tests passed.");
     return EXIT_SUCCESS;
 
 error:
-    HDputs("*** TESTS FAILED ***");
+    puts("*** TESTS FAILED ***");
     return EXIT_FAILURE;
 #endif /* H5_NO_DEPRECATED_SYMBOLS */
 } /* end main() */
