@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -15,25 +15,29 @@ package test;
 import static org.junit.Assert.assertFalse;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
+
 import hdf.hdf5lib.H5;
 import hdf.hdf5lib.HDF5Constants;
+import hdf.hdf5lib.exceptions.HDF5FunctionArgumentException;
 import hdf.hdf5lib.exceptions.HDF5LibraryException;
 
 import org.junit.After;
 import org.junit.Before;
+import org.junit.Ignore;
 import org.junit.Rule;
 import org.junit.Test;
-import org.junit.Ignore;
 import org.junit.rules.TestName;
 
 public class TestH5Edefault {
-    @Rule public TestName testname = new TestName();
+    @Rule
+    public TestName testname = new TestName();
 
     public static final int ERRSTACK_CNT = 6;
 
     @Before
-    public void H5Eset_default_stack() {
-        assertTrue("H5 open ids is 0",H5.getOpenIDCount()==0);
+    public void H5Eset_default_stack()
+    {
+        assertTrue("H5 open ids is 0", H5.getOpenIDCount() == 0);
         System.out.print(testname.getMethodName());
 
         try {
@@ -46,23 +50,26 @@ public class TestH5Edefault {
         }
     }
     @After
-    public void nextTestName() {
+    public void nextTestName()
+    {
         System.out.println();
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eprint2_invalid_classid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eprint2_invalid_classid() throws Throwable
+    {
         H5.H5Eprint2(-1, null);
     }
 
     @Ignore
-    public void testH5Eprint() {
+    public void testH5Eprint()
+    {
         /*
-        * If HDF5_VOL_CONNECTOR is set, this might not be the
-        * native connector and the error stack might be different.
-        * Only check for the specific error stack if the native
-        * connector is being used.
-        */
+         * If HDF5_VOL_CONNECTOR is set, this might not be the
+         * native connector and the error stack might be different.
+         * Only check for the specific error stack if the native
+         * connector is being used.
+         */
         String connector = System.getenv("HDF5_VOL_CONNECTOR");
         if (connector == null) {
             try {
@@ -81,19 +88,20 @@ public class TestH5Edefault {
     }
 
     @Test
-    public void testH5Eget_current_stack() {
-        long num_msg = -1;
-        long num_msg_default = -1;
-        long saved_num_msg = -1;
-        long stack_id = -1;
+    public void testH5Eget_current_stack()
+    {
+        long num_msg          = -1;
+        long num_msg_default  = -1;
+        long saved_num_msg    = -1;
+        long stack_id         = -1;
         long stack_id_default = HDF5Constants.H5E_DEFAULT;
         try {
             H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
-            //default stack id will be different after exception
+            // default stack id will be different after exception
             stack_id_default = HDF5Constants.H5E_DEFAULT;
-            //err.printStackTrace(); //This will clear the error stack
+            // err.printStackTrace(); //This will clear the error stack
         }
         // Verify we have messages on the error stack
         try {
@@ -147,16 +155,17 @@ public class TestH5Edefault {
     }
 
     @Test
-    public void testH5Eget_current_stack_pop() {
-        long num_msg = -1;
+    public void testH5Eget_current_stack_pop()
+    {
+        long num_msg         = -1;
         long num_msg_default = -1;
-        long saved_num_msg = -1;
-        long stack_id = -1;
+        long saved_num_msg   = -1;
+        long stack_id        = -1;
         try {
             H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
-            //err.printStackTrace(); //This will clear the error stack
+            // err.printStackTrace(); //This will clear the error stack
         }
 
         // Verify there are error messages on the stack and save it
@@ -179,7 +188,8 @@ public class TestH5Edefault {
             fail("H5.H5Eget_current_stack: " + err);
         }
         assertFalse("H5.H5Eget_current_stack: get_current_stack - " + stack_id, stack_id < 0);
-        assertFalse("H5.H5Eget_current_stack: get_current_stack - " + stack_id, stack_id == HDF5Constants.H5E_DEFAULT);
+        assertFalse("H5.H5Eget_current_stack: get_current_stack - " + stack_id,
+                    stack_id == HDF5Constants.H5E_DEFAULT);
 
         // Verify the stack is empty
         try {
@@ -206,7 +216,7 @@ public class TestH5Edefault {
             H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
-            //err.printStackTrace(); //This will clear the error stack
+            // err.printStackTrace(); //This will clear the error stack
         }
 
         // Verify we have a nonzero number of messages and save it
@@ -242,38 +252,46 @@ public class TestH5Edefault {
         assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg, num_msg == saved_num_msg);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eclose_stack_invalid_stackid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eclose_stack_invalid_stackid() throws Throwable
+    {
         H5.H5Eclose_stack(-1);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eget_class_name_invalid_classid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eget_class_name_invalid_classid() throws Throwable
+    {
         H5.H5Eget_class_name(-1);
     }
 
     @Test(expected = HDF5LibraryException.class)
-    public void testH5Eget_class_name_invalid_classname() throws Throwable {
+    public void testH5Eget_class_name_invalid_classname() throws Throwable
+    {
         H5.H5Eget_class_name(HDF5Constants.H5E_DEFAULT);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eclose_msg_invalid_errid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eclose_msg_invalid_errid() throws Throwable
+    {
         H5.H5Eclose_msg(-1);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Ecreate_msg_invalid_errid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Ecreate_msg_invalid_errid() throws Throwable
+    {
         H5.H5Ecreate_msg(-1, HDF5Constants.H5E_MAJOR, "null");
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eget_msg_invalid_msgid() throws Throwable {
-        H5.H5Eget_msg(-1, null);
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eget_msg_invalid_msgid() throws Throwable
+    {
+        int[] error_msg_type = {HDF5Constants.H5E_MAJOR};
+        H5.H5Eget_msg(-1, error_msg_type);
     }
 
     @Test
-    public void testH5Ecreate_stack() {
+    public void testH5Ecreate_stack()
+    {
         try {
             long stack_id = H5.H5Ecreate_stack();
             assertTrue("H5.H5Ecreate_stack", stack_id > 0);
@@ -285,15 +303,17 @@ public class TestH5Edefault {
         }
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eset_current_stack_invalid_stkid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eset_current_stack_invalid_stkid() throws Throwable
+    {
         H5.H5Eset_current_stack(-1);
     }
 
     @Test
-    public void testH5Eset_current_stack() {
-        long num_msg = -1;
-        long stack_id = -1;
+    public void testH5Eset_current_stack()
+    {
+        long num_msg       = -1;
+        long stack_id      = -1;
         long saved_num_msg = -1;
 
         // Generate errors on the default stack
@@ -301,7 +321,7 @@ public class TestH5Edefault {
             H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
-            //err.printStackTrace(); //This will clear the error stack
+            // err.printStackTrace(); //This will clear the error stack
         }
 
         // Verify we have a nonzero number of messages and save it
@@ -324,7 +344,8 @@ public class TestH5Edefault {
             fail("H5.H5Eset_current_stack: " + err);
         }
         assertFalse("H5.H5Eset_current_stack: get_current_stack - " + stack_id, stack_id < 0);
-        assertFalse("H5.H5Eset_current_stack: get_current_stack - " + stack_id, stack_id == HDF5Constants.H5E_DEFAULT);
+        assertFalse("H5.H5Eset_current_stack: get_current_stack - " + stack_id,
+                    stack_id == HDF5Constants.H5E_DEFAULT);
 
         // Verify the copy has the same number of messages as the original stack
         try {
@@ -341,7 +362,7 @@ public class TestH5Edefault {
             H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
-            //err.printStackTrace(); //This will clear the error stack
+            // err.printStackTrace(); //This will clear the error stack
         }
 
         // Verify we have the same number of messages as before
@@ -387,14 +408,16 @@ public class TestH5Edefault {
         assertTrue("H5.H5Eset_current_stack: get_num - " + num_msg, num_msg == saved_num_msg);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Epop_invalid_stkid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Epop_invalid_stkid() throws Throwable
+    {
         H5.H5Epop(-1, 0);
     }
 
     @Test
-    public void testH5Epop() throws Throwable {
-        long num_msg = -1;
+    public void testH5Epop() throws Throwable
+    {
+        long num_msg       = -1;
         long saved_num_msg = -1;
         try {
             H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
@@ -421,29 +444,34 @@ public class TestH5Edefault {
         assertTrue("H5.H5Epop after #:" + num_msg, num_msg == saved_num_msg - 1);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Epush_invalid_stkid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Epush_invalid_stkid() throws Throwable
+    {
         H5.H5Epush(-1, "Invalid", "Invalid", 0, -1, -1, -1, "Invalid message");
     }
 
     @Test(expected = NullPointerException.class)
-    public void testH5Epush_null_name() throws Throwable {
-        H5.H5Epush(HDF5Constants.H5E_DEFAULT, null, "Invalid", 0, HDF5Constants.H5E_DEFAULT, HDF5Constants.H5E_DEFAULT, HDF5Constants.H5E_DEFAULT, "Invalid message");
+    public void testH5Epush_null_name() throws Throwable
+    {
+        H5.H5Epush(HDF5Constants.H5E_DEFAULT, null, "Invalid", 0, HDF5Constants.H5E_DEFAULT,
+                   HDF5Constants.H5E_DEFAULT, HDF5Constants.H5E_DEFAULT, "Invalid message");
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5EprintInt_invalid_classid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5EprintInt_invalid_classid() throws Throwable
+    {
         H5.H5Eprint2(-1, null);
     }
 
     @Ignore
-    public void testH5EprintInt() {
+    public void testH5EprintInt()
+    {
         /*
-        * If HDF5_VOL_CONNECTOR is set, this might not be the
-        * native connector and the error stack might be different.
-        * Only check for the specific error stack if the native
-        * connector is being used.
-        */
+         * If HDF5_VOL_CONNECTOR is set, this might not be the
+         * native connector and the error stack might be different.
+         * Only check for the specific error stack if the native
+         * connector is being used.
+         */
         String connector = System.getenv("HDF5_VOL_CONNECTOR");
         if (connector == null) {
             try {
@@ -462,7 +490,8 @@ public class TestH5Edefault {
     }
 
     @Test
-    public void testH5EclearInt() {
+    public void testH5EclearInt()
+    {
         try {
             H5.H5Eclear(HDF5Constants.H5E_DEFAULT);
         }
@@ -472,13 +501,15 @@ public class TestH5Edefault {
         }
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eclear2_invalid_stkid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eclear2_invalid_stkid() throws Throwable
+    {
         H5.H5Eclear2(-1);
     }
 
     @Test
-    public void testH5Eclear() {
+    public void testH5Eclear()
+    {
         try {
             H5.H5Eclear2(HDF5Constants.H5E_DEFAULT);
         }
@@ -489,7 +520,8 @@ public class TestH5Edefault {
     }
 
     @Test
-    public void testH5Eclear2_with_msg() {
+    public void testH5Eclear2_with_msg()
+    {
         long num_msg = -1;
         try {
             H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
@@ -515,13 +547,15 @@ public class TestH5Edefault {
         assertTrue("H5.H5Eclear2_with_msg after #:" + num_msg, num_msg == 0);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eauto_is_v2_invalid_stkid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eauto_is_v2_invalid_stkid() throws Throwable
+    {
         H5.H5Eauto_is_v2(-1);
     }
 
     @Test
-    public void testH5Eauto_is_v2() {
+    public void testH5Eauto_is_v2()
+    {
         boolean is_v2 = false;
         try {
             is_v2 = H5.H5Eauto_is_v2(HDF5Constants.H5E_DEFAULT);
@@ -533,13 +567,15 @@ public class TestH5Edefault {
         assertTrue("H5.H5Eauto_is_v2: ", is_v2);
     }
 
-    @Test(expected = IllegalArgumentException.class)
-    public void testH5Eget_num_invalid_stkid() throws Throwable {
+    @Test(expected = HDF5FunctionArgumentException.class)
+    public void testH5Eget_num_invalid_stkid() throws Throwable
+    {
         H5.H5Eget_num(-1);
     }
 
     @Test
-    public void testH5Eget_num() {
+    public void testH5Eget_num()
+    {
         long num_msg = -1;
         try {
             num_msg = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
@@ -552,7 +588,8 @@ public class TestH5Edefault {
     }
 
     @Test
-    public void testH5Eget_num_with_msg() {
+    public void testH5Eget_num_with_msg()
+    {
         long num_msg = -1;
         try {
             H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
@@ -568,6 +605,4 @@ public class TestH5Edefault {
         }
         assertTrue("H5.H5Eget_num_with_msg #:" + num_msg, num_msg > 0);
     }
-
 }
-
