@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -22,7 +22,8 @@
  *      reporting macros.
  */
 #define H5B2_MODULE
-#define H5_MY_PKG     H5B2
-#define H5_MY_PKG_ERR H5E_BTREE
+#define H5_MY_PKG      H5B2
+#define H5_MY_PKG_ERR  H5E_BTREE
+#define H5_MY_PKG_INIT NO
 
 #endif /* H5B2module_H */
