@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5FA.c
- *              April 2009
- *              Vailin Choi
  *
  * Purpose:     Implements a Fixed Array for storing elements
  *              of datasets with fixed dimensions.
@@ -57,14 +55,14 @@
 /********************/
 /* Local Prototypes */
 /********************/
-static H5FA_t *H5FA__new(H5F_t *f, haddr_t fa_addr, hbool_t from_open, void *ctx_udata);
+static H5FA_t *H5FA__new(H5F_t *f, haddr_t fa_addr, bool from_open, void *ctx_udata);
 
 /*********************/
 /* Package Variables */
 /*********************/
 
 /* Package initialization variable */
-hbool_t H5_PKG_INIT_VAR = FALSE;
+bool H5_PKG_INIT_VAR = false;
 
 /* Fixed array client ID to class mapping */
 
@@ -99,45 +97,42 @@ H5FL_BLK_DEFINE(fa_native_elmt);
  * Return:	Pointer to farray wrapper success
  *              NULL on failure
  *
- * Programmer:	Quincey Koziol
- *		Oct 17 2016
- *
  *-------------------------------------------------------------------------
  */
 static H5FA_t *
-H5FA__new(H5F_t *f, haddr_t fa_addr, hbool_t from_open, void *ctx_udata)
+H5FA__new(H5F_t *f, haddr_t fa_addr, bool from_open, void *ctx_udata)
 {
     H5FA_t     *fa        = NULL; /* Pointer to new fixed array */
     H5FA_hdr_t *hdr       = NULL; /* The fixed array header information */
     H5FA_t     *ret_value = NULL;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(fa_addr));
+    assert(f);
+    assert(H5_addr_defined(fa_addr));
 
     /* Allocate fixed array wrapper */
     if (NULL == (fa = H5FL_CALLOC(H5FA_t)))
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTALLOC, NULL, "memory allocation failed for fixed array info")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTALLOC, NULL, "memory allocation failed for fixed array info");
 
     /* Lock the array header into memory */
     if (NULL == (hdr = H5FA__hdr_protect(f, fa_addr, ctx_udata, H5AC__READ_ONLY_FLAG)))
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, NULL, "unable to load fixed array header")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, NULL, "unable to load fixed array header");
 
     /* Check for pending array deletion */
     if (from_open && hdr->pending_delete)
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTOPENOBJ, NULL, "can't open fixed array pending deletion")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTOPENOBJ, NULL, "can't open fixed array pending deletion");
 
     /* Point fixed array wrapper at header and bump it's ref count */
     fa->hdr = hdr;
     if (H5FA__hdr_incr(fa->hdr) < 0)
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTINC, NULL, "can't increment reference count on shared array header")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTINC, NULL, "can't increment reference count on shared array header");
 
     /* Increment # of files using this array header */
     if (H5FA__hdr_fuse_incr(fa->hdr) < 0)
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTINC, NULL,
-                    "can't increment file reference count on shared array header")
+                    "can't increment file reference count on shared array header");
 
     /* Set file pointer for this array open context */
     fa->f = f;
@@ -147,10 +142,10 @@ H5FA__new(H5F_t *f, haddr_t fa_addr, hbool_t from_open, void *ctx_udata)
 
 done:
     if (hdr && H5FA__hdr_unprotect(hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, NULL, "unable to release fixed array header")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, NULL, "unable to release fixed array header");
     if (!ret_value)
         if (fa && H5FA_close(fa) < 0)
-            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array")
+            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA__new() */
@@ -163,9 +158,6 @@ done:
  * Return:      Pointer to fixed array wrapper on success
  *              NULL on failure
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 H5FA_t *
@@ -178,20 +170,20 @@ H5FA_create(H5F_t *f, const H5FA_create_t *cparam, void *ctx_udata)
     FUNC_ENTER_NOAPI(NULL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(cparam);
+    assert(f);
+    assert(cparam);
 
     /* H5FA interface sanity check */
     HDcompile_assert(H5FA_NUM_CLS_ID == NELMTS(H5FA_client_class_g));
 
     /* Create fixed array header */
     if (HADDR_UNDEF == (fa_addr = H5FA__hdr_create(f, cparam, ctx_udata)))
-        HGOTO_ERROR(H5E_FARRAY, H5E_CANTINIT, NULL, "can't create fixed array header")
+        HGOTO_ERROR(H5E_FARRAY, H5E_CANTINIT, NULL, "can't create fixed array header");
 
     /* Allocate and initialize new fixed array wrapper */
-    if (NULL == (fa = H5FA__new(f, fa_addr, FALSE, ctx_udata)))
+    if (NULL == (fa = H5FA__new(f, fa_addr, false, ctx_udata)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTINIT, NULL,
-                    "allocation and/or initialization failed for fixed array wrapper")
+                    "allocation and/or initialization failed for fixed array wrapper");
 
     /* Set the return value */
     ret_value = fa;
@@ -199,7 +191,7 @@ H5FA_create(H5F_t *f, const H5FA_create_t *cparam, void *ctx_udata)
 done:
     if (!ret_value)
         if (fa && H5FA_close(fa) < 0)
-            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array")
+            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_create() */
@@ -212,9 +204,6 @@ done:
  * Return:      Pointer to array wrapper on success
  *              NULL on failure
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 H5FA_t *
@@ -226,13 +215,13 @@ H5FA_open(H5F_t *f, haddr_t fa_addr, void *ctx_udata)
     FUNC_ENTER_NOAPI(NULL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(fa_addr));
+    assert(f);
+    assert(H5_addr_defined(fa_addr));
 
     /* Allocate and initialize new fixed array wrapper */
-    if (NULL == (fa = H5FA__new(f, fa_addr, TRUE, ctx_udata)))
+    if (NULL == (fa = H5FA__new(f, fa_addr, true, ctx_udata)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTINIT, NULL,
-                    "allocation and/or initialization failed for fixed array wrapper")
+                    "allocation and/or initialization failed for fixed array wrapper");
 
     /* Set the return value */
     ret_value = fa;
@@ -240,7 +229,7 @@ H5FA_open(H5F_t *f, haddr_t fa_addr, void *ctx_udata)
 done:
     if (!ret_value)
         if (fa && H5FA_close(fa) < 0)
-            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array")
+            HDONE_ERROR(H5E_FARRAY, H5E_CLOSEERROR, NULL, "unable to close fixed array");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_open() */
@@ -252,9 +241,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -263,8 +249,8 @@ H5FA_get_nelmts(const H5FA_t *fa, hsize_t *nelmts)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(nelmts);
+    assert(fa);
+    assert(nelmts);
 
     /* Retrieve the current number of elements in the fixed array */
     *nelmts = fa->hdr->stats.nelmts;
@@ -279,9 +265,6 @@ H5FA_get_nelmts(const H5FA_t *fa, hsize_t *nelmts)
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -290,9 +273,9 @@ H5FA_get_addr(const H5FA_t *fa, haddr_t *addr)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(fa->hdr);
-    HDassert(addr);
+    assert(fa);
+    assert(fa->hdr);
+    assert(addr);
 
     /* Retrieve the address of the fixed array's header */
     *addr = fa->hdr->addr;
@@ -307,9 +290,6 @@ H5FA_get_addr(const H5FA_t *fa, haddr_t *addr)
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -320,34 +300,34 @@ H5FA_set(const H5FA_t *fa, hsize_t idx, const void *elmt)
     H5FA_dblk_page_t *dblk_page = NULL;               /* Pointer to fixed array Data block page */
     unsigned dblock_cache_flags = H5AC__NO_FLAGS_SET; /* Flags to unprotecting fixed array Data block */
     unsigned dblk_page_cache_flags =
-        H5AC__NO_FLAGS_SET;    /* Flags to unprotecting FIxed Array Data block page */
-    hbool_t hdr_dirty = FALSE; /* Whether header information changed */
-    herr_t  ret_value = SUCCEED;
+        H5AC__NO_FLAGS_SET;   /* Flags to unprotecting FIxed Array Data block page */
+    bool   hdr_dirty = false; /* Whether header information changed */
+    herr_t ret_value = SUCCEED;
 
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(fa->hdr);
+    assert(fa);
+    assert(fa->hdr);
 
     /* Set the shared array header's file context for this operation */
     hdr->f = fa->f;
 
     /* Check if we need to create the fixed array data block */
-    if (!H5F_addr_defined(hdr->dblk_addr)) {
+    if (!H5_addr_defined(hdr->dblk_addr)) {
         /* Create the data block */
         hdr->dblk_addr = H5FA__dblock_create(hdr, &hdr_dirty);
-        if (!H5F_addr_defined(hdr->dblk_addr))
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTCREATE, FAIL, "unable to create fixed array data block")
+        if (!H5_addr_defined(hdr->dblk_addr))
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTCREATE, FAIL, "unable to create fixed array data block");
     }
 
-    HDassert(idx < hdr->cparam.nelmts);
+    assert(idx < hdr->cparam.nelmts);
 
     /* Protect data block */
     if (NULL == (dblock = H5FA__dblock_protect(hdr, hdr->dblk_addr, H5AC__NO_FLAGS_SET)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL,
                     "unable to protect fixed array data block, address = %llu",
-                    (unsigned long long)hdr->dblk_addr)
+                    (unsigned long long)hdr->dblk_addr);
 
     /* Check for paging data block */
     if (!dblock->npages) {
@@ -380,10 +360,10 @@ H5FA_set(const H5FA_t *fa, hsize_t idx, const void *elmt)
         if (!H5VM_bit_get(dblock->dblk_page_init, page_idx)) {
             /* Create the data block page */
             if (H5FA__dblk_page_create(hdr, dblk_page_addr, dblk_page_nelmts) < 0)
-                HGOTO_ERROR(H5E_FARRAY, H5E_CANTCREATE, FAIL, "unable to create data block page")
+                HGOTO_ERROR(H5E_FARRAY, H5E_CANTCREATE, FAIL, "unable to create data block page");
 
             /* Mark data block page as initialized in data block */
-            H5VM_bit_set(dblock->dblk_page_init, page_idx, TRUE);
+            H5VM_bit_set(dblock->dblk_page_init, page_idx, true);
             dblock_cache_flags |= H5AC__DIRTIED_FLAG;
         } /* end if */
 
@@ -392,7 +372,7 @@ H5FA_set(const H5FA_t *fa, hsize_t idx, const void *elmt)
             (dblk_page = H5FA__dblk_page_protect(hdr, dblk_page_addr, dblk_page_nelmts, H5AC__NO_FLAGS_SET)))
             HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL,
                         "unable to protect fixed array data block page, address = %llu",
-                        (unsigned long long)dblk_page_addr)
+                        (unsigned long long)dblk_page_addr);
 
         /* Set the element in the data block page */
         H5MM_memcpy(((uint8_t *)dblk_page->elmts) + (hdr->cparam.cls->nat_elmt_size * elmt_idx), elmt,
@@ -404,13 +384,13 @@ done:
     /* Check for header modified */
     if (hdr_dirty)
         if (H5FA__hdr_modified(hdr) < 0)
-            HDONE_ERROR(H5E_FARRAY, H5E_CANTMARKDIRTY, FAIL, "unable to mark fixed array header as modified")
+            HDONE_ERROR(H5E_FARRAY, H5E_CANTMARKDIRTY, FAIL, "unable to mark fixed array header as modified");
 
     /* Release resources */
     if (dblock && H5FA__dblock_unprotect(dblock, dblock_cache_flags) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block");
     if (dblk_page && H5FA__dblk_page_unprotect(dblk_page, dblk_page_cache_flags) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block page")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block page");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_set() */
@@ -422,9 +402,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -438,25 +415,25 @@ H5FA_get(const H5FA_t *fa, hsize_t idx, void *elmt)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(fa->hdr);
+    assert(fa);
+    assert(fa->hdr);
 
     /* Set the shared array header's file context for this operation */
     hdr->f = fa->f;
 
     /* Check if the fixed array data block has been allocated on disk yet */
-    if (!H5F_addr_defined(hdr->dblk_addr)) {
+    if (!H5_addr_defined(hdr->dblk_addr)) {
         /* Call the class's 'fill' callback */
         if ((hdr->cparam.cls->fill)(elmt, (size_t)1) < 0)
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value")
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value");
     } /* end if */
     else {
         /* Get the data block */
-        HDassert(H5F_addr_defined(hdr->dblk_addr));
+        assert(H5_addr_defined(hdr->dblk_addr));
         if (NULL == (dblock = H5FA__dblock_protect(hdr, hdr->dblk_addr, H5AC__READ_ONLY_FLAG)))
             HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL,
                         "unable to protect fixed array data block, address = %llu",
-                        (unsigned long long)hdr->dblk_addr)
+                        (unsigned long long)hdr->dblk_addr);
 
         /* Check for paged data block */
         if (!dblock->npages)
@@ -473,10 +450,10 @@ H5FA_get(const H5FA_t *fa, hsize_t idx, void *elmt)
             if (!H5VM_bit_get(dblock->dblk_page_init, page_idx)) {
                 /* Call the class's 'fill' callback */
                 if ((hdr->cparam.cls->fill)(elmt, (size_t)1) < 0)
-                    HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value")
+                    HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "can't set element to class's fill value");
 
                 /* We've retrieved the value, leave now */
-                HGOTO_DONE(SUCCEED)
+                HGOTO_DONE(SUCCEED);
             }                             /* end if */
             else {                        /* get the page */
                 size_t  dblk_page_nelmts; /* # of elements in a data block page */
@@ -501,7 +478,7 @@ H5FA_get(const H5FA_t *fa, hsize_t idx, void *elmt)
                                                                  H5AC__READ_ONLY_FLAG)))
                     HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL,
                                 "unable to protect fixed array data block page, address = %llu",
-                                (unsigned long long)dblk_page_addr)
+                                (unsigned long long)dblk_page_addr);
 
                 /* Retrieve element from data block */
                 H5MM_memcpy(elmt, ((uint8_t *)dblk_page->elmts) + (hdr->cparam.cls->nat_elmt_size * elmt_idx),
@@ -512,9 +489,9 @@ H5FA_get(const H5FA_t *fa, hsize_t idx, void *elmt)
 
 done:
     if (dblock && H5FA__dblock_unprotect(dblock, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block");
     if (dblk_page && H5FA__dblk_page_unprotect(dblk_page, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block page")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array data block page");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_get() */
@@ -526,22 +503,19 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
 H5FA_close(H5FA_t *fa)
 {
-    hbool_t pending_delete = FALSE;       /* Whether the array is pending deletion */
+    bool    pending_delete = false;       /* Whether the array is pending deletion */
     haddr_t fa_addr        = HADDR_UNDEF; /* Address of array (for deletion) */
     herr_t  ret_value      = SUCCEED;
 
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(fa);
+    assert(fa);
 
     /* Close the header if it was set */
     if (fa->hdr) {
@@ -558,7 +532,7 @@ H5FA_close(H5FA_t *fa)
                 /* Set local info, so array deletion can occur after decrementing the
                  *  header's ref count
                  */
-                pending_delete = TRUE;
+                pending_delete = true;
                 fa_addr        = fa->hdr->addr;
             } /* end if */
         }     /* end if */
@@ -574,19 +548,19 @@ H5FA_close(H5FA_t *fa)
                 /* Check the header's status in the metadata cache */
                 if (H5AC_get_entry_status(fa->f, fa_addr, &hdr_status) < 0)
                     HGOTO_ERROR(H5E_FARRAY, H5E_CANTGET, FAIL,
-                                "unable to check metadata cache status for fixed array header")
+                                "unable to check metadata cache status for fixed array header");
 
                 /* Sanity checks on header */
-                HDassert(hdr_status & H5AC_ES__IN_CACHE);
-                HDassert(hdr_status & H5AC_ES__IS_PINNED);
-                HDassert(!(hdr_status & H5AC_ES__IS_PROTECTED));
+                assert(hdr_status & H5AC_ES__IN_CACHE);
+                assert(hdr_status & H5AC_ES__IS_PINNED);
+                assert(!(hdr_status & H5AC_ES__IS_PROTECTED));
             }
 #endif /* NDEBUG */
 
             /* Lock the array header into memory */
             /* (OK to pass in NULL for callback context, since we know the header must be in the cache) */
             if (NULL == (hdr = H5FA__hdr_protect(fa->f, fa_addr, NULL, H5AC__NO_FLAGS_SET)))
-                HGOTO_ERROR(H5E_FARRAY, H5E_CANTLOAD, FAIL, "unable to load fixed array header")
+                HGOTO_ERROR(H5E_FARRAY, H5E_CANTLOAD, FAIL, "unable to load fixed array header");
 
             /* Set the shared array header's file context for this operation */
             hdr->f = fa->f;
@@ -597,11 +571,11 @@ H5FA_close(H5FA_t *fa)
              */
             if (H5FA__hdr_decr(fa->hdr) < 0)
                 HGOTO_ERROR(H5E_FARRAY, H5E_CANTDEC, FAIL,
-                            "can't decrement reference count on shared array header")
+                            "can't decrement reference count on shared array header");
 
             /* Delete array, starting with header (unprotects header) */
             if (H5FA__hdr_delete(hdr) < 0)
-                HGOTO_ERROR(H5E_FARRAY, H5E_CANTDELETE, FAIL, "unable to delete fixed array")
+                HGOTO_ERROR(H5E_FARRAY, H5E_CANTDELETE, FAIL, "unable to delete fixed array");
         } /* end if */
         else {
             /* Decrement the reference count on the array header */
@@ -610,7 +584,7 @@ H5FA_close(H5FA_t *fa)
              */
             if (H5FA__hdr_decr(fa->hdr) < 0)
                 HGOTO_ERROR(H5E_FARRAY, H5E_CANTDEC, FAIL,
-                            "can't decrement reference count on shared array header")
+                            "can't decrement reference count on shared array header");
         } /* end else */
     }     /* end if */
 
@@ -628,9 +602,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -642,31 +613,31 @@ H5FA_delete(H5F_t *f, haddr_t fa_addr, void *ctx_udata)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(f);
-    HDassert(H5F_addr_defined(fa_addr));
+    assert(f);
+    assert(H5_addr_defined(fa_addr));
 
     /* Lock the array header into memory */
     if (NULL == (hdr = H5FA__hdr_protect(f, fa_addr, ctx_udata, H5AC__NO_FLAGS_SET)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTPROTECT, FAIL, "unable to protect fixed array header, address = %llu",
-                    (unsigned long long)fa_addr)
+                    (unsigned long long)fa_addr);
 
     /* Check for files using shared array header */
     if (hdr->file_rc)
-        hdr->pending_delete = TRUE;
+        hdr->pending_delete = true;
     else {
         /* Set the shared array header's file context for this operation */
         hdr->f = f;
 
         /* Delete array now, starting with header (unprotects header) */
         if (H5FA__hdr_delete(hdr) < 0)
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTDELETE, FAIL, "unable to delete fixed array")
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTDELETE, FAIL, "unable to delete fixed array");
         hdr = NULL;
     }
 
 done:
     /* Unprotect the header if an error occurred */
     if (hdr && H5FA__hdr_unprotect(hdr, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array header")
+        HDONE_ERROR(H5E_FARRAY, H5E_CANTUNPROTECT, FAIL, "unable to release fixed array header");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5FA_delete() */
@@ -681,9 +652,6 @@ done:
  *
  * Return:      H5_ITER_CONT/H5_ITER_ERROR
  *
- * Programmer:  Vailin Choi
- *              Thursday, April 30, 2009
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -696,20 +664,20 @@ H5FA_iterate(H5FA_t *fa, H5FA_operator_t op, void *udata)
     FUNC_ENTER_NOAPI(H5_ITER_ERROR)
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(op);
-    HDassert(udata);
+    assert(fa);
+    assert(op);
+    assert(udata);
 
     /* Allocate space for a native array element */
     if (NULL == (elmt = H5FL_BLK_MALLOC(fa_native_elmt, fa->hdr->cparam.cls->nat_elmt_size)))
         HGOTO_ERROR(H5E_FARRAY, H5E_CANTALLOC, H5_ITER_ERROR,
-                    "memory allocation failed for fixed array element")
+                    "memory allocation failed for fixed array element");
 
     /* Iterate over all elements in array */
     for (u = 0; u < fa->hdr->stats.nelmts && ret_value == H5_ITER_CONT; u++) {
         /* Get array element */
         if (H5FA_get(fa, u, elmt) < 0)
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTGET, H5_ITER_ERROR, "unable to delete fixed array")
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTGET, H5_ITER_ERROR, "unable to delete fixed array");
 
         /* Invoke callback */
         if ((ret_value = (*op)(u, elmt, udata)) < 0) {
@@ -733,9 +701,6 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer:  Dana Robinson
- *              Fall 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -747,9 +712,9 @@ H5FA_depend(H5FA_t *fa, H5AC_proxy_entry_t *parent)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(hdr);
-    HDassert(parent);
+    assert(fa);
+    assert(hdr);
+    assert(parent);
 
     /*
      * Check to see if a flush dependency between the fixed array
@@ -758,14 +723,14 @@ H5FA_depend(H5FA_t *fa, H5AC_proxy_entry_t *parent)
      */
     if (NULL == hdr->parent) {
         /* Sanity check */
-        HDassert(hdr->top_proxy);
+        assert(hdr->top_proxy);
 
         /* Set the shared array header's file context for this operation */
         hdr->f = fa->f;
 
         /* Add the fixed array as a child of the parent (proxy) */
         if (H5AC_proxy_entry_add_child(parent, hdr->f, hdr->top_proxy) < 0)
-            HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "unable to add fixed array as child of proxy")
+            HGOTO_ERROR(H5E_FARRAY, H5E_CANTSET, FAIL, "unable to add fixed array as child of proxy");
         hdr->parent = parent;
     }
 
@@ -791,8 +756,8 @@ H5FA_patch_file(H5FA_t *fa, H5F_t *f)
     FUNC_ENTER_NOAPI_NOERR
 
     /* Check arguments */
-    HDassert(fa);
-    HDassert(f);
+    assert(fa);
+    assert(f);
 
     if (fa->f != f || fa->hdr->f != f)
         fa->f = fa->hdr->f = f;
