@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:             H5Fmpi.c
- *                      Jan 10 2008
- *                      Quincey Koziol
  *
  * Purpose:             MPI-related routines.
  *
@@ -77,9 +75,6 @@
  *
  *              Failure:    Negative
  *
- * Programmer:  Quincey Koziol
- *              Friday, January 30, 2004
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -89,11 +84,11 @@ H5F_mpi_get_rank(const H5F_t *f)
 
     FUNC_ENTER_NOAPI((-1))
 
-    HDassert(f && f->shared);
+    assert(f && f->shared);
 
     /* Dispatch to driver */
     if ((ret_value = H5FD_mpi_get_rank(f->shared->lf)) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, (-1), "driver get_rank request failed")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, (-1), "driver get_rank request failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -102,14 +97,10 @@ done:
 /*-------------------------------------------------------------------------
  * Function:    H5F_mpi_get_comm
  *
- * Purpose:     Retrieves the file's communicator
+ * Purpose:     Retrieves the file's MPI_Comm communicator object
  *
- * Return:      Success:    The communicator (non-negative)
- *
- *              Failure:    Negative
- *
- * Programmer:  Quincey Koziol
- *              Friday, January 30, 2004
+ * Return:      Success:    The communicator object
+ *              Failure:    MPI_COMM_NULL
  *
  *-------------------------------------------------------------------------
  */
@@ -120,16 +111,43 @@ H5F_mpi_get_comm(const H5F_t *f)
 
     FUNC_ENTER_NOAPI(MPI_COMM_NULL)
 
-    HDassert(f && f->shared);
+    assert(f && f->shared);
 
     /* Dispatch to driver */
     if ((ret_value = H5FD_mpi_get_comm(f->shared->lf)) == MPI_COMM_NULL)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, MPI_COMM_NULL, "driver get_comm request failed")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, MPI_COMM_NULL, "driver get_comm request failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_mpi_get_comm() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5F_mpi_get_info
+ *
+ * Purpose:     Retrieves the file's MPI_Info info object
+ *
+ * Return:      Success:    The info object
+ *              Failure:    MPI_INFO_NULL
+ *
+ *-------------------------------------------------------------------------
+ */
+MPI_Info
+H5F_mpi_get_info(const H5F_t *f)
+{
+    MPI_Info ret_value = MPI_INFO_NULL;
+
+    FUNC_ENTER_NOAPI(MPI_INFO_NULL)
+
+    assert(f && f->shared);
+
+    /* Dispatch to driver */
+    if ((ret_value = H5FD_mpi_get_info(f->shared->lf)) == MPI_INFO_NULL)
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, MPI_INFO_NULL, "driver get_info request failed");
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5F_mpi_get_info() */
+
 /*-------------------------------------------------------------------------
  * Function:    H5F_shared_mpi_get_size
  *
@@ -139,9 +157,6 @@ done:
  *
  *              Failure:        Negative
  *
- * Programmer:  John Mainzer
- *              Friday, May 6, 2005
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -151,11 +166,11 @@ H5F_shared_mpi_get_size(const H5F_shared_t *f_sh)
 
     FUNC_ENTER_NOAPI((-1))
 
-    HDassert(f_sh);
+    assert(f_sh);
 
     /* Dispatch to driver */
     if ((ret_value = H5FD_mpi_get_size(f_sh->lf)) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, (-1), "driver get_size request failed")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, (-1), "driver get_size request failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -170,9 +185,6 @@ done:
  *
  *              Failure:        Negative
  *
- * Programmer:  John Mainzer
- *              Friday, May 6, 2005
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -182,18 +194,18 @@ H5F_mpi_get_size(const H5F_t *f)
 
     FUNC_ENTER_NOAPI((-1))
 
-    HDassert(f && f->shared);
+    assert(f && f->shared);
 
     /* Dispatch to driver */
     if ((ret_value = H5FD_mpi_get_size(f->shared->lf)) < 0)
-        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, (-1), "driver get_size request failed")
+        HGOTO_ERROR(H5E_FILE, H5E_CANTGET, (-1), "driver get_size request failed");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_mpi_get_size() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5F_set_mpi_atomicity
+ * Function:    H5F__set_mpi_atomicity
  *
  * Purpose:     Private call to set the atomicity mode
  *
@@ -202,14 +214,14 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F_set_mpi_atomicity(H5F_t *file, hbool_t flag)
+H5F__set_mpi_atomicity(H5F_t *file, bool flag)
 {
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI(FAIL);
+    FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(file);
+    assert(file);
 
     /* Check VFD */
     if (!H5F_HAS_FEATURE(file, H5FD_FEAT_HAS_MPI))
@@ -221,8 +233,8 @@ H5F_set_mpi_atomicity(H5F_t *file, hbool_t flag)
         HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "can't set atomicity flag");
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
-} /* end H5F_set_mpi_atomicity() */
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5F__set_mpi_atomicity() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5Fset_mpi_atomicity
@@ -232,36 +244,37 @@ done:
  * Return:      Success:    Non-negative
  *              Failure:    Negative
  *
- * Programmer:  Mohamad Chaarawi
- *              Feb 14, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Fset_mpi_atomicity(hid_t file_id, hbool_t flag)
+H5Fset_mpi_atomicity(hid_t file_id, bool flag)
 {
-    H5VL_object_t *vol_obj   = NULL;
-    int            va_flag   = (int)flag; /* C is grumpy about passing hbool_t via va_arg */
-    herr_t         ret_value = SUCCEED;
+    H5VL_object_t                   *vol_obj;             /* File info */
+    H5VL_optional_args_t             vol_cb_args;         /* Arguments to VOL callback */
+    H5VL_native_file_optional_args_t file_opt_args;       /* Arguments for optional operation */
+    herr_t                           ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_API(FAIL);
-    H5TRACE2("e", "ib", file_id, flag);
+    FUNC_ENTER_API(FAIL)
 
     /* Get the file object */
     if (NULL == (vol_obj = (H5VL_object_t *)H5I_object_verify(file_id, H5I_FILE)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid file identifier");
 
+    /* Set up VOL callback arguments */
+    file_opt_args.set_mpi_atomicity.flag = flag;
+    vol_cb_args.op_type                  = H5VL_NATIVE_FILE_SET_MPI_ATOMICITY;
+    vol_cb_args.args                     = &file_opt_args;
+
     /* Set atomicity value */
-    if (H5VL_file_optional(vol_obj, H5VL_NATIVE_FILE_SET_MPI_ATOMICITY, H5P_DATASET_XFER_DEFAULT,
-                           H5_REQUEST_NULL, va_flag) < 0)
+    if (H5VL_file_optional(vol_obj, &vol_cb_args, H5P_DATASET_XFER_DEFAULT, H5_REQUEST_NULL) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTSET, FAIL, "unable to set MPI atomicity");
 
 done:
-    FUNC_LEAVE_API(ret_value);
+    FUNC_LEAVE_API(ret_value)
 } /* end H5Fset_mpi_atomicity() */
 
 /*-------------------------------------------------------------------------
- * Function:    H5F_get_mpi_atomicity
+ * Function:    H5F__get_mpi_atomicity
  *
  * Purpose:     Private call to get the atomicity mode
  *
@@ -270,15 +283,15 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F_get_mpi_atomicity(H5F_t *file, hbool_t *flag)
+H5F__get_mpi_atomicity(const H5F_t *file, bool *flag)
 {
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_NOAPI(FAIL);
+    FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(file);
-    HDassert(flag);
+    assert(file);
+    assert(flag);
 
     /* Check VFD */
     if (!H5F_HAS_FEATURE(file, H5FD_FEAT_HAS_MPI))
@@ -290,8 +303,8 @@ H5F_get_mpi_atomicity(H5F_t *file, hbool_t *flag)
         HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get atomicity flag");
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
-} /* end H5F_get_mpi_atomicity() */
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5F__get_mpi_atomicity() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5Fget_mpi_atomicity
@@ -301,31 +314,33 @@ done:
  * Return:      Success:    Non-negative
  *              Failure:    Negative
  *
- * Programmer:  Mohamad Chaarawi
- *              Feb 14, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5Fget_mpi_atomicity(hid_t file_id, hbool_t *flag)
+H5Fget_mpi_atomicity(hid_t file_id, bool *flag /*out*/)
 {
-    H5VL_object_t *vol_obj   = NULL;
-    herr_t         ret_value = SUCCEED;
+    H5VL_object_t                   *vol_obj;             /* File info */
+    H5VL_optional_args_t             vol_cb_args;         /* Arguments to VOL callback */
+    H5VL_native_file_optional_args_t file_opt_args;       /* Arguments for optional operation */
+    herr_t                           ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_API(FAIL);
-    H5TRACE2("e", "i*b", file_id, flag);
+    FUNC_ENTER_API(FAIL)
 
     /* Get the file object */
     if (NULL == (vol_obj = (H5VL_object_t *)H5I_object_verify(file_id, H5I_FILE)))
         HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid file identifier");
 
+    /* Set up VOL callback arguments */
+    file_opt_args.get_mpi_atomicity.flag = flag;
+    vol_cb_args.op_type                  = H5VL_NATIVE_FILE_GET_MPI_ATOMICITY;
+    vol_cb_args.args                     = &file_opt_args;
+
     /* Get atomicity value */
-    if (H5VL_file_optional(vol_obj, H5VL_NATIVE_FILE_GET_MPI_ATOMICITY, H5P_DATASET_XFER_DEFAULT,
-                           H5_REQUEST_NULL, flag) < 0)
+    if (H5VL_file_optional(vol_obj, &vol_cb_args, H5P_DATASET_XFER_DEFAULT, H5_REQUEST_NULL) < 0)
         HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "unable to get MPI atomicity");
 
 done:
-    FUNC_LEAVE_API(ret_value);
+    FUNC_LEAVE_API(ret_value)
 } /* end H5Fget_mpi_atomicity() */
 
 /*-------------------------------------------------------------------------
@@ -339,9 +354,6 @@ done:
  *
  *              Failure:    Negative
  *
- * Programmer:  Mohamad Chaarawi
- *              Feb 14, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -352,7 +364,7 @@ H5F_mpi_retrieve_comm(hid_t loc_id, hid_t acspl_id, MPI_Comm *mpi_comm)
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(mpi_comm);
+    assert(mpi_comm);
 
     /* Set value to return to invalid MPI comm */
     *mpi_comm = MPI_COMM_NULL;
@@ -365,27 +377,39 @@ H5F_mpi_retrieve_comm(hid_t loc_id, hid_t acspl_id, MPI_Comm *mpi_comm)
 
         /* Retrieve the file structure */
         if (H5G_loc(loc_id, &loc) < 0)
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location")
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a location");
         f = loc.oloc->file;
-        HDassert(f);
+        assert(f);
 
         /* Check if MPIO driver is used */
         if (H5F_HAS_FEATURE(f, H5FD_FEAT_HAS_MPI)) {
             /* retrieve the file communicator */
             if (MPI_COMM_NULL == (*mpi_comm = H5F_mpi_get_comm(f)))
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get MPI communicator")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get MPI communicator");
         }
     }
     /* otherwise, this is from H5Fopen or H5Fcreate and has to be collective */
     else {
-        H5P_genplist_t *plist; /* Property list pointer */
+        H5FD_driver_prop_t driver_prop; /* Property for driver ID & info */
+        H5P_genplist_t    *plist;       /* Property list pointer */
+        unsigned long      driver_feat_flags;
+        H5FD_class_t      *driver_class = NULL;
 
-        if (NULL == (plist = H5P_object_verify(acspl_id, H5P_FILE_ACCESS)))
-            HGOTO_ERROR(H5E_FILE, H5E_BADTYPE, FAIL, "not a file access list")
+        if (NULL == (plist = H5P_object_verify(acspl_id, H5P_FILE_ACCESS, true)))
+            HGOTO_ERROR(H5E_FILE, H5E_BADTYPE, FAIL, "not a file access list");
 
-        if (H5FD_MPIO == H5P_peek_driver(plist))
+        if (H5P_peek(plist, H5F_ACS_FILE_DRV_NAME, &driver_prop) < 0)
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTGET, FAIL, "can't get driver ID & info");
+
+        if (NULL == (driver_class = H5FD_get_class(driver_prop.driver_id)))
+            HGOTO_ERROR(H5E_VFL, H5E_CANTGET, FAIL, "can't get driver class structure");
+
+        if (H5FD_driver_query(driver_class, &driver_feat_flags) < 0)
+            HGOTO_ERROR(H5E_VFL, H5E_CANTGET, FAIL, "can't get driver feature flags");
+
+        if (driver_feat_flags & H5FD_FEAT_HAS_MPI)
             if (H5P_peek(plist, H5F_ACS_MPI_PARAMS_COMM_NAME, mpi_comm) < 0)
-                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get MPI communicator")
+                HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't get MPI communicator");
     }
 
 done:
@@ -401,29 +425,52 @@ done:
  *              coordinates between the file-global flag and the flag set
  *              for the current operation in the current API context.
  *
- * Return:      TRUE/FALSE (can't fail)
+ * Return:      true/false (can't fail)
  *
  *-------------------------------------------------------------------------
  */
-hbool_t
+bool
 H5F_get_coll_metadata_reads(const H5F_t *file)
+{
+    FUNC_ENTER_NOAPI_NOINIT_NOERR
+
+    assert(file && file->shared);
+
+    FUNC_LEAVE_NOAPI(H5F_shared_get_coll_metadata_reads(file->shared));
+} /* end H5F_get_coll_metadata_reads() */
+
+/*-------------------------------------------------------------------------
+ * Function:    H5F_shared_get_coll_metadata_reads
+ *
+ * Purpose:     Determines whether collective metadata reads should be
+ *              performed. This routine is meant to be the single source of
+ *              truth for the collective metadata reads status, as it
+ *              coordinates between the file-global flag and the flag set
+ *              for the current operation in the current API context.
+ *
+ * Return:      true/false (can't fail)
+ *
+ *-------------------------------------------------------------------------
+ */
+bool
+H5F_shared_get_coll_metadata_reads(const H5F_shared_t *f_sh)
 {
     H5P_coll_md_read_flag_t file_flag = H5P_USER_FALSE;
-    hbool_t                 ret_value = FALSE;
+    bool                    ret_value = false;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(file && file->shared);
+    assert(f_sh);
 
     /* Retrieve the file-global flag */
-    file_flag = H5F_COLL_MD_READ(file);
+    file_flag = H5F_SHARED_COLL_MD_READ(f_sh);
 
     /* If file flag is set to H5P_FORCE_FALSE, exit early
-     * with FALSE, since collective metadata reads have
+     * with false, since collective metadata reads have
      * been explicitly disabled somewhere in the library.
      */
     if (H5P_FORCE_FALSE == file_flag)
-        ret_value = FALSE;
+        ret_value = false;
     else {
         /* If file flag is set to H5P_USER_TRUE, ignore
          * any settings in the API context. A file-global
@@ -432,7 +479,7 @@ H5F_get_coll_metadata_reads(const H5F_t *file)
          * Property List for an individual operation.
          */
         if (H5P_USER_TRUE == file_flag)
-            ret_value = TRUE;
+            ret_value = true;
         else {
             /* Get the collective metadata reads flag from
              * the current API context.
@@ -442,7 +489,7 @@ H5F_get_coll_metadata_reads(const H5F_t *file)
     }
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5F_get_coll_metadata_reads() */
+} /* end H5F_shared_get_coll_metadata_reads() */
 
 /*-------------------------------------------------------------------------
  * Function:    H5F_set_coll_metadata_reads
@@ -484,16 +531,16 @@ H5F_get_coll_metadata_reads(const H5F_t *file)
  *-------------------------------------------------------------------------
  */
 void
-H5F_set_coll_metadata_reads(H5F_t *file, H5P_coll_md_read_flag_t *file_flag, hbool_t *context_flag)
+H5F_set_coll_metadata_reads(H5F_t *file, H5P_coll_md_read_flag_t *file_flag, bool *context_flag)
 {
     H5P_coll_md_read_flag_t prev_file_flag    = H5P_USER_FALSE;
-    hbool_t                 prev_context_flag = FALSE;
+    bool                    prev_context_flag = false;
 
     FUNC_ENTER_NOAPI_NOINIT_NOERR
 
-    HDassert(file && file->shared);
-    HDassert(file_flag);
-    HDassert(context_flag);
+    assert(file && file->shared);
+    assert(file_flag);
+    assert(context_flag);
 
     /* Save old state */
     prev_file_flag    = H5F_COLL_MD_READ(file);
@@ -516,12 +563,12 @@ H5F_set_coll_metadata_reads(H5F_t *file, H5P_coll_md_read_flag_t *file_flag, hbo
  * Function:    H5F_mpi_get_file_block_type
  *
  * Purpose:     Creates an MPI derived datatype for communicating an
- *              H5F_block_t structure. If `commit` is specified as TRUE,
+ *              H5F_block_t structure. If `commit` is specified as true,
  *              the resulting datatype will be committed and ready for
  *              use in communication. Otherwise, the type is only suitable
  *              for building other derived types.
  *
- *              If TRUE is returned through `new_type_derived`, this lets
+ *              If true is returned through `new_type_derived`, this lets
  *              the caller know that the datatype has been derived and
  *              should be freed with MPI_Type_free once it is no longer
  *              needed.
@@ -531,7 +578,7 @@ H5F_set_coll_metadata_reads(H5F_t *file, H5P_coll_md_read_flag_t *file_flag, hbo
  *-------------------------------------------------------------------------
  */
 herr_t
-H5F_mpi_get_file_block_type(hbool_t commit, MPI_Datatype *new_type, hbool_t *new_type_derived)
+H5F_mpi_get_file_block_type(bool commit, MPI_Datatype *new_type, bool *new_type_derived)
 {
     MPI_Datatype types[2];
     MPI_Aint     displacements[2];
@@ -542,13 +589,13 @@ H5F_mpi_get_file_block_type(hbool_t commit, MPI_Datatype *new_type, hbool_t *new
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(new_type);
-    HDassert(new_type_derived);
+    assert(new_type);
+    assert(new_type_derived);
 
-    *new_type_derived = FALSE;
+    *new_type_derived = false;
 
     field_count = 2;
-    HDassert(field_count == sizeof(types) / sizeof(MPI_Datatype));
+    assert(field_count == sizeof(types) / sizeof(MPI_Datatype));
 
     block_lengths[0] = 1;
     block_lengths[1] = 1;
@@ -559,7 +606,7 @@ H5F_mpi_get_file_block_type(hbool_t commit, MPI_Datatype *new_type, hbool_t *new
     if (MPI_SUCCESS !=
         (mpi_code = MPI_Type_create_struct(field_count, block_lengths, displacements, types, new_type)))
         HMPI_GOTO_ERROR(FAIL, "MPI_Type_create_struct failed", mpi_code)
-    *new_type_derived = TRUE;
+    *new_type_derived = true;
 
     if (commit && MPI_SUCCESS != (mpi_code = MPI_Type_commit(new_type)))
         HMPI_GOTO_ERROR(FAIL, "MPI_Type_commit failed", mpi_code)
@@ -569,11 +616,10 @@ done:
         if (*new_type_derived) {
             if (MPI_SUCCESS != (mpi_code = MPI_Type_free(new_type)))
                 HMPI_DONE_ERROR(FAIL, "MPI_Type_free failed", mpi_code)
-            *new_type_derived = FALSE;
+            *new_type_derived = false;
         }
     }
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5F_mpi_get_file_block_type() */
-
 #endif /* H5_HAVE_PARALLEL */
