@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -13,8 +13,6 @@
 /*-------------------------------------------------------------------------
  *
  * Created:     H5Oflush.c
- *              Aug 19, 2010
- *              Mike McGreevy
  *
  * Purpose:     Object flush/refresh routines.
  *
@@ -46,55 +44,12 @@
 /* Local Prototypes */
 /********************/
 static herr_t H5O__oh_tag(const H5O_loc_t *oloc, haddr_t *tag);
-static herr_t H5O__refresh_metadata_close(hid_t oid, H5O_loc_t oloc, H5G_loc_t *obj_loc);
+static herr_t H5O__refresh_metadata_close(H5O_loc_t *oloc, H5G_loc_t *obj_loc, hid_t oid);
 
 /*************/
 /* Functions */
 /*************/
 
-/*-------------------------------------------------------------------------
- * Function:    H5Oflush
- *
- * Purpose:     Flushes all buffers associated with an object to disk.
- *
- * Return:      Non-negative on success, negative on failure
- *
- * Programmer:  Mike McGreevy
- *              May 19, 2010
- *
- *-------------------------------------------------------------------------
- */
-herr_t
-H5Oflush(hid_t obj_id)
-{
-    H5VL_object_t    *vol_obj = NULL; /* Object of obj_id     */
-    H5VL_loc_params_t loc_params;
-    herr_t            ret_value = SUCCEED; /* Return value     */
-
-    FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "i", obj_id);
-
-    /* Check args */
-    if (NULL == (vol_obj = H5VL_vol_object(obj_id)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier")
-
-    /* Set up collective metadata if appropriate */
-    if (H5CX_set_loc(obj_id) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set access property list info")
-
-    /* Set location parameters */
-    loc_params.type     = H5VL_OBJECT_BY_SELF;
-    loc_params.obj_type = H5I_get_type(obj_id);
-
-    /* Flush the object */
-    if (H5VL_object_specific(vol_obj, &loc_params, H5VL_OBJECT_FLUSH, H5P_DATASET_XFER_DEFAULT,
-                             H5_REQUEST_NULL, obj_id) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object")
-
-done:
-    FUNC_LEAVE_API(ret_value)
-} /* end H5Oflush() */
-
 /*-------------------------------------------------------------------------
  * Function:    H5O_flush
  *
@@ -103,9 +58,6 @@ done:
  * Return:	Success:	Non-negative
  *		Failure:	Negative
  *
- * Programmer:	Quincey Koziol
- *		December 29, 2017
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -117,21 +69,26 @@ H5O_flush(H5O_loc_t *oloc, hid_t obj_id)
 
     FUNC_ENTER_NOAPI(FAIL)
 
+    /* Currently, H5Oflush causes H5Fclose to trigger an assertion failure in metadata cache.
+     * Leave this situation for the future solution */
+    if (H5F_HAS_FEATURE(oloc->file, H5FD_FEAT_HAS_MPI))
+        HGOTO_ERROR(H5E_ARGS, H5E_UNSUPPORTED, FAIL, "H5Oflush isn't supported for parallel");
+
     /* Get the object pointer */
     if (NULL == (obj_ptr = H5VL_object(obj_id)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier");
 
     /* Get the object class */
     if (NULL == (obj_class = H5O__obj_class(oloc)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to determine object class")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to determine object class");
 
     /* Flush the object of this class */
     if (obj_class->flush && obj_class->flush(obj_ptr) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object");
 
     /* Flush the object metadata and invoke flush callback */
     if (H5O_flush_common(oloc, obj_id) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object and object flush callback")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object and object flush callback");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -145,8 +102,6 @@ done:
  *
  * Return:  	Non-negative on success, negative on failure
  *
- * Programmer:  Vailin Choi; Dec 2013
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -159,15 +114,15 @@ H5O_flush_common(H5O_loc_t *oloc, hid_t obj_id)
 
     /* Retrieve tag for object */
     if (H5O__oh_tag(oloc, &tag) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object metadata")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush object metadata");
 
     /* Flush metadata based on tag value of the object */
     if (H5F_flush_tagged_metadata(oloc->file, tag) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush tagged metadata")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush tagged metadata");
 
     /* Check to invoke callback */
     if (H5F_object_flush_cb(oloc->file, obj_id) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to do object flush callback")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to do object flush callback");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -181,9 +136,6 @@ done:
  * Return:  	Success:    Non-negative
  *          	Failure:    Negative
  *
- * Programmer: Mike McGreevy
- *             May 19, 2010
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -192,70 +144,27 @@ H5O__oh_tag(const H5O_loc_t *oloc, haddr_t *tag)
     H5O_t *oh        = NULL;    /* Object header */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check args */
-    HDassert(oloc);
+    assert(oloc);
 
     /* Get object header for object */
-    if (NULL == (oh = H5O_protect(oloc, H5AC__READ_ONLY_FLAG, FALSE)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object's object header")
+    if (NULL == (oh = H5O_protect(oloc, H5AC__READ_ONLY_FLAG, false)))
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTPROTECT, FAIL, "unable to protect object's object header");
 
     /* Get object header's address (i.e. the tag value for this object) */
     if (HADDR_UNDEF == (*tag = H5O_OH_GET_ADDR(oh)))
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "unable to get address of object header")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTGET, FAIL, "unable to get address of object header");
 
 done:
     /* Unprotect object header on failure */
     if (oh && H5O_unprotect(oloc, oh, H5AC__NO_FLAGS_SET) < 0)
-        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header")
+        HDONE_ERROR(H5E_OHDR, H5E_CANTUNPROTECT, FAIL, "unable to release object header");
 
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__oh_tag() */
 
-/*-------------------------------------------------------------------------
- * Function:    H5Orefresh
- *
- * Purpose:     Refreshes all buffers associated with an object.
- *
- * Return:      Non-negative on success, negative on failure
- *
- * Programmer:  Mike McGreevy
- *              July 28, 2010
- *
- *-------------------------------------------------------------------------
- */
-herr_t
-H5Orefresh(hid_t oid)
-{
-    H5VL_object_t    *vol_obj = NULL; /* Object of oid     */
-    H5VL_loc_params_t loc_params;
-    herr_t            ret_value = SUCCEED; /* Return value     */
-
-    FUNC_ENTER_API(FAIL)
-    H5TRACE1("e", "i", oid);
-
-    /* Check args */
-    if (NULL == (vol_obj = H5VL_vol_object(oid)))
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier")
-
-    /* Set up collective metadata if appropriate */
-    if (H5CX_set_loc(oid) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set access property list info")
-
-    /* Set location parameters */
-    loc_params.type     = H5VL_OBJECT_BY_SELF;
-    loc_params.obj_type = H5I_get_type(oid);
-
-    /* Refresh the object */
-    if (H5VL_object_specific(vol_obj, &loc_params, H5VL_OBJECT_REFRESH, H5P_DATASET_XFER_DEFAULT,
-                             H5_REQUEST_NULL, oid) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object")
-
-done:
-    FUNC_LEAVE_API(ret_value)
-} /* end H5Orefresh() */
-
 /*-------------------------------------------------------------------------
  * Function:    H5O_refresh_metadata
  *
@@ -271,33 +180,30 @@ done:
  *
  * Return:    	Non-negative on success, negative on failure
  *
- * Programmer: Mike McGreevy/Vailin Choi
- *             July 28, 2010/Feb 2014
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5O_refresh_metadata(hid_t oid, H5O_loc_t oloc)
+H5O_refresh_metadata(H5O_loc_t *oloc, hid_t oid)
 {
     H5VL_object_t *vol_obj   = NULL;  /* VOL object associated with the ID */
-    hbool_t        objs_incr = FALSE; /* Whether the object count in the file was incremented */
+    bool           objs_incr = false; /* Whether the object count in the file was incremented */
     H5F_t         *file      = NULL;
     herr_t         ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_NOAPI(FAIL)
 
     /* If the file is opened with write access, no need to perform refresh actions. */
-    if (!(H5F_INTENT(oloc.file) & H5F_ACC_RDWR)) {
-        H5G_loc_t    obj_loc;
-        H5O_loc_t    obj_oloc;
-        H5G_name_t   obj_path;
-        H5O_shared_t cached_H5O_shared;
-        H5VL_t      *connector = NULL;
+    if (!(H5F_INTENT(oloc->file) & H5F_ACC_RDWR)) {
+        H5G_loc_t         obj_loc;
+        H5O_loc_t         obj_oloc;
+        H5G_name_t        obj_path;
+        H5O_shared_t      cached_H5O_shared;
+        H5VL_connector_t *connector = NULL;
 
         /* Hold a copy of the object's file pointer, since closing the object will
          * invalidate the file pointer in the oloc.
          */
-        file = oloc.file;
+        file = oloc->file;
 
         /* Create empty object location */
         obj_loc.oloc = &obj_oloc;
@@ -307,42 +213,47 @@ H5O_refresh_metadata(hid_t oid, H5O_loc_t oloc)
         /* "Fake" another open object in the file, so that it doesn't get closed
          *  if this object is the only thing holding the file open.
          */
-        H5F_incr_nopen_objs(oloc.file);
-        objs_incr = TRUE;
+        H5F_incr_nopen_objs(oloc->file);
+        objs_incr = true;
 
         /* Save important datatype state */
         if (H5I_get_type(oid) == H5I_DATATYPE)
             if (H5T_save_refresh_state(oid, &cached_H5O_shared) < 0)
-                HGOTO_ERROR(H5E_DATATYPE, H5E_CANTOPENOBJ, FAIL, "unable to save datatype state")
+                HGOTO_ERROR(H5E_DATATYPE, H5E_CANTOPENOBJ, FAIL, "unable to save datatype state");
 
         /* Get the VOL object from the ID and cache a pointer to the connector.
          * The vol_obj will disappear when the underlying object is closed, so
          * we can't use that directly.
          */
         if (NULL == (vol_obj = H5VL_vol_object(oid)))
-            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier")
-        connector = vol_obj->connector;
+            HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "invalid object identifier");
+        connector = H5VL_OBJ_CONNECTOR(vol_obj);
 
         /* Bump the number of references on the VOL connector.
          * If you don't do this, VDS refreshes can accidentally close the connector.
          */
-        connector->nrefs++;
+        H5VL_conn_inc_rc(connector);
 
         /* Close object & evict its metadata */
-        if ((H5O__refresh_metadata_close(oid, oloc, &obj_loc)) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object")
+        if (H5O__refresh_metadata_close(oloc, &obj_loc, oid) < 0) {
+            H5VL_conn_dec_rc(connector);
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object");
+        }
 
         /* Re-open the object, re-fetching its metadata */
-        if ((H5O_refresh_metadata_reopen(oid, H5P_DEFAULT, &obj_loc, connector, FALSE)) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object")
+        if (H5O_refresh_metadata_reopen(oid, H5P_DEFAULT, &obj_loc, connector, false) < 0) {
+            H5VL_conn_dec_rc(connector);
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTLOAD, FAIL, "unable to refresh object");
+        }
 
         /* Restore the number of references on the VOL connector */
-        connector->nrefs--;
+        if (H5VL_conn_dec_rc(connector) < 0)
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTDEC, FAIL, "can't decrement reference count for connector");
 
         /* Restore important datatype state */
         if (H5I_get_type(oid) == H5I_DATATYPE)
             if (H5T_restore_refresh_state(oid, &cached_H5O_shared) < 0)
-                HGOTO_ERROR(H5E_DATATYPE, H5E_CANTOPENOBJ, FAIL, "unable to restore datatype state")
+                HGOTO_ERROR(H5E_DATATYPE, H5E_CANTOPENOBJ, FAIL, "unable to restore datatype state");
 
     } /* end if */
 
@@ -350,7 +261,7 @@ done:
     if (objs_incr && file)
         H5F_decr_nopen_objs(file);
 
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_refresh_metadata() */
 
 /*-------------------------------------------------------------------------
@@ -367,19 +278,17 @@ done:
  * Return:  Success:    Non-negative
  *          Failure:    Negative
  *
- * Programmer: Mike McGreevy/Vailin Choi
- *             July 28, 2010/Feb 2014
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
-H5O__refresh_metadata_close(hid_t oid, H5O_loc_t oloc, H5G_loc_t *obj_loc)
+H5O__refresh_metadata_close(H5O_loc_t *oloc, H5G_loc_t *obj_loc, hid_t oid)
 {
+    H5F_t  *file;                /* Local copy of the object's file pointer */
     haddr_t tag       = 0;       /* Tag for object */
-    hbool_t corked    = FALSE;   /* Whether object's metadata is corked */
+    bool    corked    = false;   /* Whether object's metadata is corked */
     herr_t  ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Make deep local copy of object's location information */
     if (obj_loc) {
@@ -392,35 +301,39 @@ H5O__refresh_metadata_close(hid_t oid, H5O_loc_t oloc, H5G_loc_t *obj_loc)
     /* Handle close for multiple dataset opens */
     if (H5I_get_type(oid) == H5I_DATASET)
         if (H5D_mult_refresh_close(oid) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to prepare refresh for dataset")
+            HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to prepare refresh for dataset");
 
     /* Retrieve tag for object */
-    if (H5O__oh_tag(&oloc, &tag) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to get object header address")
+    if (H5O__oh_tag(oloc, &tag) < 0)
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to get object header address");
 
     /* Get cork status of the object with tag */
-    if (H5AC_cork(oloc.file, tag, H5AC__GET_CORKED, &corked) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_SYSTEM, FAIL, "unable to retrieve an object's cork status")
+    if (H5AC_cork(oloc->file, tag, H5AC__GET_CORKED, &corked) < 0)
+        HGOTO_ERROR(H5E_OHDR, H5E_SYSTEM, FAIL, "unable to retrieve an object's cork status");
 
+    /* Hold a copy of the object's file pointer, since closing the object will
+     * invalidate the file pointer in the oloc.
+     */
+    file = oloc->file;
     /* Close the object */
     if (H5I_dec_ref(oid) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to close object")
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTINIT, FAIL, "unable to close object");
 
     /* Flush metadata based on tag value of the object */
-    if (H5F_flush_tagged_metadata(oloc.file, tag) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush tagged metadata")
+    if (H5F_flush_tagged_metadata(file, tag) < 0)
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to flush tagged metadata");
 
     /* Evict the object's tagged metadata */
-    if (H5F_evict_tagged_metadata(oloc.file, tag) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to evict metadata")
+    if (H5AC_evict_tagged_metadata(file, tag, true) < 0)
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTFLUSH, FAIL, "unable to evict metadata");
 
     /* Re-cork object with tag */
     if (corked)
-        if (H5AC_cork(oloc.file, tag, H5AC__SET_CORK, &corked) < 0)
-            HGOTO_ERROR(H5E_OHDR, H5E_SYSTEM, FAIL, "unable to cork the object")
+        if (H5AC_cork(file, tag, H5AC__SET_CORK, &corked) < 0)
+            HGOTO_ERROR(H5E_OHDR, H5E_SYSTEM, FAIL, "unable to cork the object");
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O__refresh_metadata_close() */
 
 /*-------------------------------------------------------------------------
@@ -432,14 +345,11 @@ done:
  *
  * Return:      SUCCEED/FAIL
  *
- * Programmer: Mike McGreevy/Vailin Choi
- *             July 28, 2010/Feb 2014
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5O_refresh_metadata_reopen(hid_t oid, hid_t apl_id, H5G_loc_t *obj_loc, H5VL_t *vol_connector,
-                            hbool_t start_swmr)
+H5O_refresh_metadata_reopen(hid_t oid, hid_t apl_id, H5G_loc_t *obj_loc, H5VL_connector_t *vol_connector,
+                            bool start_swmr)
 {
     void      *object = NULL;       /* Object for this operation */
     H5I_type_t type;                /* Type of object for the ID */
@@ -448,8 +358,8 @@ H5O_refresh_metadata_reopen(hid_t oid, hid_t apl_id, H5G_loc_t *obj_loc, H5VL_t
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Sanity check */
-    HDassert(obj_loc);
-    HDassert(vol_connector);
+    assert(obj_loc);
+    assert(vol_connector);
 
     /* Get object's type */
     type = H5I_get_type(oid);
@@ -458,31 +368,31 @@ H5O_refresh_metadata_reopen(hid_t oid, hid_t apl_id, H5G_loc_t *obj_loc, H5VL_t
         case H5I_GROUP:
             /* Re-open the group */
             if (NULL == (object = H5G_open(obj_loc)))
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to open group")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to open group");
             break;
 
         case H5I_DATATYPE:
             /* Re-open the named datatype */
             if (NULL == (object = H5T_open(obj_loc)))
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to open named datatype")
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to open named datatype");
             break;
 
         case H5I_DATASET:
             /* Set dataset access property list in API context if appropriate */
-            if (H5CX_set_apl(&apl_id, H5P_CLS_DACC, oid, TRUE) < 0)
-                HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set access property list info")
+            if (H5CX_set_apl(&apl_id, H5P_CLS_DACC, oid, true) < 0)
+                HGOTO_ERROR(H5E_OHDR, H5E_CANTSET, FAIL, "can't set access property list info");
 
             /* Re-open the dataset */
             if (NULL ==
                 (object = H5D_open(obj_loc, apl_id == H5P_DEFAULT ? H5P_DATASET_ACCESS_DEFAULT : apl_id)))
-                HGOTO_ERROR(H5E_DATASET, H5E_CANTOPENOBJ, FAIL, "unable to open dataset")
+                HGOTO_ERROR(H5E_DATASET, H5E_CANTOPENOBJ, FAIL, "unable to open dataset");
             if (!start_swmr) /* No need to handle multiple opens when H5Fstart_swmr_write() */
                 if (H5D_mult_refresh_reopen((H5D_t *)object) < 0)
-                    HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to finish refresh for dataset")
+                    HGOTO_ERROR(H5E_OHDR, H5E_CANTOPENOBJ, FAIL, "unable to finish refresh for dataset");
             break;
 
         case H5I_MAP:
-            HGOTO_ERROR(H5E_OHDR, H5E_BADTYPE, FAIL, "maps not supported in native VOL connector")
+            HGOTO_ERROR(H5E_OHDR, H5E_BADTYPE, FAIL, "maps not supported in native VOL connector");
 
         case H5I_UNINIT:
         case H5I_BADID:
@@ -497,17 +407,18 @@ H5O_refresh_metadata_reopen(hid_t oid, hid_t apl_id, H5G_loc_t *obj_loc, H5VL_t
         case H5I_ERROR_MSG:
         case H5I_ERROR_STACK:
         case H5I_SPACE_SEL_ITER:
+        case H5I_EVENTSET:
         case H5I_NTYPES:
         default:
             HGOTO_ERROR(H5E_OHDR, H5E_BADTYPE, FAIL,
-                        "not a valid file object ID (dataset, group, or datatype)")
+                        "not a valid file object ID (dataset, group, or datatype)");
             break;
     } /* end switch */
 
     /* Re-register ID for the object */
-    if ((H5VL_register_using_existing_id(type, object, vol_connector, TRUE, oid)) < 0)
-        HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to re-register object ID after refresh")
+    if ((H5VL_register_using_existing_id(type, object, vol_connector, true, oid)) < 0)
+        HGOTO_ERROR(H5E_OHDR, H5E_CANTREGISTER, FAIL, "unable to re-register object ID after refresh");
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5O_refresh_metadata_reopen() */
