@@ -2,9 +2,9 @@
  * Copyright by The HDF Group.                                               *
  * All rights reserved.                                                      *
  *                                                                           *
- * This file is part of HDF5. The full HDF5 copyright notice, including      *
+ * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -64,7 +64,7 @@ static herr_t H5PL__replace_at(const char *path, unsigned int idx);
 static herr_t H5PL__expand_path_table(void);
 static herr_t H5PL__path_table_iterate_process_path(const char *plugin_path, H5PL_iterate_type_t iter_type,
                                                     H5PL_iterate_t iter_op, void *op_data);
-static herr_t H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *found,
+static herr_t H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, bool *found,
                                         const char *dir, const void **plugin_info);
 
 /*********************/
@@ -105,31 +105,31 @@ H5PL__insert_at(const char *path, unsigned int idx)
     char  *path_copy = NULL;    /* copy of path string (for storing) */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(path);
-    HDassert(HDstrlen(path));
+    assert(path);
+    assert(strlen(path));
 
     /* Expand the table if it is full */
     if (H5PL_num_paths_g == H5PL_path_capacity_g)
         if (H5PL__expand_path_table() < 0)
-            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't expand path table")
+            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't expand path table");
 
     /* Copy the path for storage so the caller can dispose of theirs */
     if (NULL == (path_copy = H5MM_strdup(path)))
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't make internal copy of path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't make internal copy of path");
 
 #ifdef H5_HAVE_WIN32_API
     /* Clean up Microsoft Windows environment variables in the path string */
     if (H5_expand_windows_env_vars(&path_copy))
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTCONVERT, FAIL, "can't expand environment variable string")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTCONVERT, FAIL, "can't expand environment variable string");
 #endif /* H5_HAVE_WIN32_API */
 
     /* If the table entry is in use, make some space */
     if (H5PL_paths_g[idx])
         if (H5PL__make_space_at(idx) < 0)
-            HGOTO_ERROR(H5E_PLUGIN, H5E_NOSPACE, FAIL, "unable to make space in the table for the new entry")
+            HGOTO_ERROR(H5E_PLUGIN, H5E_NOSPACE, FAIL, "unable to make space in the table for the new entry");
 
     /* Insert the copy of the search path into the table at the specified index */
     H5PL_paths_g[idx] = path_copy;
@@ -155,10 +155,10 @@ H5PL__make_space_at(unsigned int idx)
     unsigned u;                   /* iterator */
     herr_t   ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC_NOERR
+    FUNC_ENTER_PACKAGE_NOERR
 
     /* Check args - Just assert on package functions */
-    HDassert(idx < H5PL_path_capacity_g);
+    assert(idx < H5PL_path_capacity_g);
 
     /* Copy the paths back to make a space  */
     for (u = H5PL_num_paths_g; u > idx; u--)
@@ -186,24 +186,24 @@ H5PL__replace_at(const char *path, unsigned int idx)
     char  *path_copy = NULL;    /* copy of path string (for storing) */
     herr_t ret_value = SUCCEED; /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(path);
-    HDassert(HDstrlen(path));
+    assert(path);
+    assert(strlen(path));
 
     /* Check that the table entry is in use */
     if (!H5PL_paths_g[idx])
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, FAIL, "path entry at index %u in the table is NULL", idx)
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTFREE, FAIL, "path entry at index %u in the table is NULL", idx);
 
     /* Copy the path for storage so the caller can dispose of theirs */
     if (NULL == (path_copy = H5MM_strdup(path)))
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't make internal copy of path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't make internal copy of path");
 
 #ifdef H5_HAVE_WIN32_API
     /* Clean up Microsoft Windows environment variables in the path string */
     if (H5_expand_windows_env_vars(&path_copy))
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTCONVERT, FAIL, "can't expand environment variable string")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTCONVERT, FAIL, "can't expand environment variable string");
 #endif /* H5_HAVE_WIN32_API */
 
     /* Free the existing path entry */
@@ -243,19 +243,19 @@ H5PL__create_path_table(void)
     H5PL_num_paths_g     = 0;
     H5PL_path_capacity_g = H5PL_INITIAL_PATH_CAPACITY;
     if (NULL == (H5PL_paths_g = (char **)H5MM_calloc((size_t)H5PL_path_capacity_g * sizeof(char *))))
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't allocate memory for path table")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't allocate memory for path table");
 
     /* Retrieve paths from HDF5_PLUGIN_PATH if the user sets it
      * or from the default paths if it isn't set.
      */
-    env_var = HDgetenv("HDF5_PLUGIN_PATH");
+    env_var = getenv(HDF5_PLUGIN_PATH);
     if (NULL == env_var)
         paths = H5MM_strdup(H5PL_DEFAULT_PATH);
     else
         paths = H5MM_strdup(env_var);
 
     if (NULL == paths)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't allocate memory for path copy")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't allocate memory for path copy");
 
     /* Separate the paths and store them */
     next_path = HDstrtok_r(paths, H5PL_PATH_SEPARATOR, &lasts);
@@ -263,7 +263,7 @@ H5PL__create_path_table(void)
 
         /* Insert the path into the table */
         if (H5PL__append_path(next_path) < 0)
-            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't insert path: %s", next_path)
+            HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't insert path: %s", next_path);
 
         /* Get the next path from the environment string */
         next_path = HDstrtok_r(NULL, H5PL_PATH_SEPARATOR, &lasts);
@@ -348,7 +348,7 @@ H5PL__expand_path_table(void)
 {
     herr_t ret_value = SUCCEED;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Update the capacity */
     H5PL_path_capacity_g += H5PL_PATH_CAPACITY_ADD;
@@ -356,10 +356,10 @@ H5PL__expand_path_table(void)
     /* Resize the array */
     if (NULL ==
         (H5PL_paths_g = (char **)H5MM_realloc(H5PL_paths_g, (size_t)H5PL_path_capacity_g * sizeof(char *))))
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "allocating additional memory for path table failed")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "allocating additional memory for path table failed");
 
     /* Initialize the new memory */
-    HDmemset(H5PL_paths_g + H5PL_num_paths_g, 0, (size_t)H5PL_PATH_CAPACITY_ADD * sizeof(char *));
+    memset(H5PL_paths_g + H5PL_num_paths_g, 0, (size_t)H5PL_PATH_CAPACITY_ADD * sizeof(char *));
 
 done:
     /* Set the path capacity back if there were problems */
@@ -386,12 +386,12 @@ H5PL__append_path(const char *path)
     FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(path);
-    HDassert(HDstrlen(path));
+    assert(path);
+    assert(strlen(path));
 
     /* Insert the path at the end of the table */
     if (H5PL__insert_at(path, H5PL_num_paths_g) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to append search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to append search path");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -414,12 +414,12 @@ H5PL__prepend_path(const char *path)
     FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(path);
-    HDassert(HDstrlen(path));
+    assert(path);
+    assert(strlen(path));
 
     /* Insert the path at the beginning of the table */
     if (H5PL__insert_at(path, 0) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to prepend search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to prepend search path");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -442,13 +442,13 @@ H5PL__replace_path(const char *path, unsigned int idx)
     FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(path);
-    HDassert(HDstrlen(path));
-    HDassert(idx < H5PL_path_capacity_g);
+    assert(path);
+    assert(strlen(path));
+    assert(idx < H5PL_path_capacity_g);
 
     /* Insert the path at the requested index */
     if (H5PL__replace_at(path, idx) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to replace search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to replace search path");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -472,13 +472,13 @@ H5PL__insert_path(const char *path, unsigned int idx)
     FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(path);
-    HDassert(HDstrlen(path));
-    HDassert(idx < H5PL_path_capacity_g);
+    assert(path);
+    assert(strlen(path));
+    assert(idx < H5PL_path_capacity_g);
 
     /* Insert the path at the requested index */
     if (H5PL__insert_at(path, idx) < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to insert search path")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTINSERT, FAIL, "unable to insert search path");
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -503,11 +503,11 @@ H5PL__remove_path(unsigned int idx)
     FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(idx < H5PL_path_capacity_g);
+    assert(idx < H5PL_path_capacity_g);
 
     /* Check if the path at that index is set */
     if (!H5PL_paths_g[idx])
-        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTDELETE, FAIL, "search path at index %u is NULL", idx)
+        HGOTO_ERROR(H5E_PLUGIN, H5E_CANTDELETE, FAIL, "search path at index %u is NULL", idx);
 
     /* Delete the path */
     H5PL_num_paths_g--;
@@ -543,7 +543,7 @@ H5PL__get_path(unsigned int idx)
 
     /* Get the path at the requested index */
     if (idx >= H5PL_num_paths_g)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, NULL, "path index %u is out of range in table", idx)
+        HGOTO_ERROR(H5E_ARGS, H5E_BADRANGE, NULL, "path index %u is out of range in table", idx);
 
     return H5PL_paths_g[idx];
 done:
@@ -571,15 +571,15 @@ H5PL__path_table_iterate(H5PL_iterate_type_t iter_type, H5PL_iterate_t iter_op,
 
     FUNC_ENTER_PACKAGE
 
-    for (u = 0; (u < H5PL_num_paths_g) && (ret_value == H5_ITER_CONT); u++)
-        ret_value = H5PL__path_table_iterate_process_path(H5PL_paths_g[u], iter_type, iter_op, op_data);
-
-    if (ret_value < 0)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_BADITER, H5_ITER_ERROR, "can't iterate over plugins in plugin path '%s'",
-                    H5PL_paths_g[u]);
+    for (u = 0; (u < H5PL_num_paths_g) && (ret_value == H5_ITER_CONT); u++) {
+        if ((ret_value =
+                 H5PL__path_table_iterate_process_path(H5PL_paths_g[u], iter_type, iter_op, op_data)) < 0)
+            HGOTO_ERROR(H5E_PLUGIN, H5E_BADITER, H5_ITER_ERROR,
+                        "can't iterate over plugins in plugin path '%s'", H5PL_paths_g[u]);
+    }
 
 done:
-    FUNC_LEAVE_NOAPI(ret_value);
+    FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5PL__path_table_iterate() */
 
 /*-------------------------------------------------------------------------
@@ -604,16 +604,16 @@ H5PL__path_table_iterate_process_path(const char *plugin_path, H5PL_iterate_type
 {
     H5PL_type_t    plugin_type;
     const void    *plugin_info = NULL;
-    hbool_t        plugin_loaded;
+    bool           plugin_loaded;
     char          *path      = NULL;
     DIR           *dirp      = NULL; /* Directory stream */
     struct dirent *dp        = NULL; /* Directory entry */
     herr_t         ret_value = H5_ITER_CONT;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
-    HDassert(plugin_path);
-    HDassert(iter_op);
+    assert(plugin_path);
+    assert(iter_op);
 
     /* Open the directory - skip the path if the directory can't be opened */
     if (!(dirp = HDopendir(plugin_path)))
@@ -625,29 +625,30 @@ H5PL__path_table_iterate_process_path(const char *plugin_path, H5PL_iterate_type
          * or libxxx.xxx.dylib on Mac.
          */
 #ifndef __CYGWIN__
-        if (!HDstrncmp(dp->d_name, "lib", (size_t)3) &&
-            (HDstrstr(dp->d_name, ".so") || HDstrstr(dp->d_name, ".dylib"))) {
+        if (!strncmp(dp->d_name, "lib", (size_t)3) &&
+            (strstr(dp->d_name, ".so") || strstr(dp->d_name, ".dylib"))) {
 #else
-        if (!HDstrncmp(dp->d_name, "cyg", (size_t)3) && HDstrstr(dp->d_name, ".dll")) {
+        if (!strncmp(dp->d_name, "cyg", (size_t)3) && strstr(dp->d_name, ".dll")) {
 #endif
 
-            hbool_t   plugin_matches;
+            bool      plugin_matches;
             h5_stat_t my_stat;
             size_t    len;
 
             /* Allocate & initialize the path name */
-            len = HDstrlen(plugin_path) + HDstrlen(H5PL_PATH_SEPARATOR) + HDstrlen(dp->d_name) + 1 /*\0*/ +
+            len = strlen(plugin_path) + strlen(H5PL_PATH_SEPARATOR) + strlen(dp->d_name) + 1 /*\0*/ +
                   4; /* Extra "+4" to quiet GCC warning - 2019/07/05, QAK */
 
             if (NULL == (path = (char *)H5MM_calloc(len)))
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, H5_ITER_ERROR, "can't allocate memory for path")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, H5_ITER_ERROR, "can't allocate memory for path");
 
-            HDsnprintf(path, len, "%s/%s", plugin_path, dp->d_name);
+            snprintf(path, len, "%s/%s", plugin_path, dp->d_name);
 
             /* Get info for directory entry */
+            memset(&my_stat, 0, sizeof(h5_stat_t));
             if (HDstat(path, &my_stat) == -1)
                 HGOTO_ERROR(H5E_FILE, H5E_CANTGET, H5_ITER_ERROR, "can't stat file %s -- error was: %s", path,
-                            HDstrerror(errno))
+                            strerror(errno));
 
             /* If it is a directory, skip it */
             if (S_ISDIR(my_stat.st_mode))
@@ -656,14 +657,15 @@ H5PL__path_table_iterate_process_path(const char *plugin_path, H5PL_iterate_type
             /* Attempt to open the dynamic library */
             plugin_type   = H5PL_TYPE_ERROR;
             plugin_info   = NULL;
-            plugin_loaded = FALSE;
+            plugin_loaded = false;
             if (H5PL__open(path, H5PL_TYPE_NONE, NULL, &plugin_loaded, &plugin_type, &plugin_info) < 0)
                 HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, H5_ITER_ERROR, "failed to open plugin '%s'", path);
 
             /* Determine if we should process this plugin */
             plugin_matches = (iter_type == H5PL_ITER_TYPE_ALL) ||
                              ((iter_type == H5PL_ITER_TYPE_FILTER) && (plugin_type == H5PL_TYPE_FILTER)) ||
-                             ((iter_type == H5PL_ITER_TYPE_VOL) && (plugin_type == H5PL_TYPE_VOL));
+                             ((iter_type == H5PL_ITER_TYPE_VOL) && (plugin_type == H5PL_TYPE_VOL)) ||
+                             ((iter_type == H5PL_ITER_TYPE_VFD) && (plugin_type == H5PL_TYPE_VFD));
 
             /* If the plugin was successfully loaded, call supplied callback function on plugin */
             if (plugin_loaded && plugin_matches && (ret_value = iter_op(plugin_type, plugin_info, op_data)))
@@ -680,7 +682,7 @@ done:
     if (dirp)
         if (HDclosedir(dirp) < 0)
             HDONE_ERROR(H5E_FILE, H5E_CLOSEERROR, H5_ITER_ERROR, "can't close directory: %s",
-                        HDstrerror(errno))
+                        strerror(errno));
 
     path = (char *)H5MM_xfree(path);
 
@@ -695,37 +697,37 @@ H5PL__path_table_iterate_process_path(const char *plugin_path, H5PL_iterate_type
     HANDLE           hFind = INVALID_HANDLE_VALUE;
     H5PL_type_t      plugin_type;
     const void      *plugin_info = NULL;
-    hbool_t          plugin_loaded;
+    bool             plugin_loaded;
     char            *path = NULL;
     char             service[2048];
     herr_t           ret_value = H5_ITER_CONT;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(plugin_path);
-    HDassert(iter_op);
+    assert(plugin_path);
+    assert(iter_op);
 
     /* Specify a file mask. *.* = We want everything! -
      * skip the path if the directory can't be opened */
-    HDsnprintf(service, sizeof(service), "%s\\*.dll", plugin_path);
+    snprintf(service, sizeof(service), "%s\\*.dll", plugin_path);
     if ((hFind = FindFirstFileA(service, &fdFile)) == INVALID_HANDLE_VALUE)
         HGOTO_DONE(H5_ITER_CONT);
 
     /* Loop over all the files */
     do {
         /* Ignore '.' and '..' */
-        if (HDstrcmp(fdFile.cFileName, ".") != 0 && HDstrcmp(fdFile.cFileName, "..") != 0) {
-            hbool_t plugin_matches;
-            size_t  len;
+        if (strcmp(fdFile.cFileName, ".") != 0 && strcmp(fdFile.cFileName, "..") != 0) {
+            bool   plugin_matches;
+            size_t len;
 
             /* Allocate & initialize the path name */
-            len = HDstrlen(plugin_path) + HDstrlen(H5PL_PATH_SEPARATOR) + HDstrlen(fdFile.cFileName) + 1;
+            len = strlen(plugin_path) + strlen(H5PL_PATH_SEPARATOR) + strlen(fdFile.cFileName) + 1;
 
             if (NULL == (path = (char *)H5MM_calloc(len)))
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, H5_ITER_ERROR, "can't allocate memory for path")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, H5_ITER_ERROR, "can't allocate memory for path");
 
-            HDsnprintf(path, len, "%s\\%s", plugin_path, fdFile.cFileName);
+            snprintf(path, len, "%s\\%s", plugin_path, fdFile.cFileName);
 
             /* Ignore directories */
             if (fdFile.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
@@ -734,14 +736,15 @@ H5PL__path_table_iterate_process_path(const char *plugin_path, H5PL_iterate_type
             /* Attempt to open the dynamic library */
             plugin_type   = H5PL_TYPE_ERROR;
             plugin_info   = NULL;
-            plugin_loaded = FALSE;
+            plugin_loaded = false;
             if (H5PL__open(path, H5PL_TYPE_NONE, NULL, &plugin_loaded, &plugin_type, &plugin_info) < 0)
                 HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, H5_ITER_ERROR, "failed to open plugin '%s'", path);
 
             /* Determine if we should process this plugin */
             plugin_matches = (iter_type == H5PL_ITER_TYPE_ALL) ||
                              ((iter_type == H5PL_ITER_TYPE_FILTER) && (plugin_type == H5PL_TYPE_FILTER)) ||
-                             ((iter_type == H5PL_ITER_TYPE_VOL) && (plugin_type == H5PL_TYPE_VOL));
+                             ((iter_type == H5PL_ITER_TYPE_VOL) && (plugin_type == H5PL_TYPE_VOL)) ||
+                             ((iter_type == H5PL_ITER_TYPE_VFD) && (plugin_type == H5PL_TYPE_VFD));
 
             /* If the plugin was successfully loaded, call supplied callback function on plugin */
             if (plugin_loaded && plugin_matches && (ret_value = iter_op(plugin_type, plugin_info, op_data)))
@@ -777,7 +780,7 @@ done:
  *-------------------------------------------------------------------------
  */
 herr_t
-H5PL__find_plugin_in_path_table(const H5PL_search_params_t *search_params, hbool_t *found,
+H5PL__find_plugin_in_path_table(const H5PL_search_params_t *search_params, bool *found,
                                 const void **plugin_info)
 {
     unsigned int u; /* iterator */
@@ -786,12 +789,12 @@ H5PL__find_plugin_in_path_table(const H5PL_search_params_t *search_params, hbool
     FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(search_params);
-    HDassert(found);
-    HDassert(plugin_info);
+    assert(search_params);
+    assert(found);
+    assert(plugin_info);
 
     /* Initialize output parameters */
-    *found       = FALSE;
+    *found       = false;
     *plugin_info = NULL;
 
     /* Loop over the paths in the table, checking for an appropriate plugin */
@@ -804,7 +807,7 @@ H5PL__find_plugin_in_path_table(const H5PL_search_params_t *search_params, hbool
         /* Break out if found */
         if (*found) {
             if (!plugin_info)
-                HGOTO_ERROR(H5E_PLUGIN, H5E_BADVALUE, FAIL, "plugin info should not be NULL")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_BADVALUE, FAIL, "plugin info should not be NULL");
             break;
         }
     }
@@ -821,7 +824,7 @@ done:
  *              plugin library. Two function definitions are for Unix and
  *              Windows.
  *
- *              The found parameter will be set to TRUE and the info
+ *              The found parameter will be set to true and the info
  *              parameter will be filled in on success.
  *
  * Return:      SUCCEED/FAIL
@@ -830,7 +833,7 @@ done:
  */
 #ifndef H5_HAVE_WIN32_API
 static herr_t
-H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *found, const char *dir,
+H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, bool *found, const char *dir,
                           const void **plugin_info)
 {
     char          *path      = NULL;
@@ -838,21 +841,21 @@ H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *fo
     struct dirent *dp        = NULL; /* Directory entry */
     herr_t         ret_value = SUCCEED;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(search_params);
-    HDassert(found);
-    HDassert(dir);
-    HDassert(plugin_info);
+    assert(search_params);
+    assert(found);
+    assert(dir);
+    assert(plugin_info);
 
     /* Initialize the found parameter */
-    *found = FALSE;
+    *found = false;
 
     /* Open the directory */
     if (!(dirp = HDopendir(dir)))
         HGOTO_ERROR(H5E_PLUGIN, H5E_OPENERROR, FAIL, "can't open directory (%s). Please verify its existence",
-                    dir)
+                    dir);
 
     /* Iterate through all entries in the directory */
     while (NULL != (dp = HDreaddir(dirp))) {
@@ -861,28 +864,29 @@ H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *fo
          * or libxxx.xxx.dylib on Mac.
          */
 #ifndef __CYGWIN__
-        if (!HDstrncmp(dp->d_name, "lib", (size_t)3) &&
-            (HDstrstr(dp->d_name, ".so") || HDstrstr(dp->d_name, ".dylib"))) {
+        if (!strncmp(dp->d_name, "lib", (size_t)3) &&
+            (strstr(dp->d_name, ".so") || strstr(dp->d_name, ".dylib"))) {
 #else
-        if (!HDstrncmp(dp->d_name, "cyg", (size_t)3) && HDstrstr(dp->d_name, ".dll")) {
+        if (!strncmp(dp->d_name, "cyg", (size_t)3) && strstr(dp->d_name, ".dll")) {
 #endif
 
             h5_stat_t my_stat;
             size_t    len;
 
             /* Allocate & initialize the path name */
-            len = HDstrlen(dir) + HDstrlen(H5PL_PATH_SEPARATOR) + HDstrlen(dp->d_name) + 1 /*\0*/ +
+            len = strlen(dir) + strlen(H5PL_PATH_SEPARATOR) + strlen(dp->d_name) + 1 /*\0*/ +
                   4; /* Extra "+4" to quiet GCC warning - 2019/07/05, QAK */
 
             if (NULL == (path = (char *)H5MM_calloc(len)))
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't allocate memory for path")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't allocate memory for path");
 
-            HDsnprintf(path, len, "%s/%s", dir, dp->d_name);
+            snprintf(path, len, "%s/%s", dir, dp->d_name);
 
             /* Get info for directory entry */
+            memset(&my_stat, 0, sizeof(h5_stat_t));
             if (HDstat(path, &my_stat) == -1)
                 HGOTO_ERROR(H5E_FILE, H5E_CANTGET, FAIL, "can't stat file %s -- error was: %s", path,
-                            HDstrerror(errno))
+                            strerror(errno));
 
             /* If it is a directory, skip it */
             if (S_ISDIR(my_stat.st_mode)) {
@@ -892,9 +896,9 @@ H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *fo
 
             /* attempt to open the dynamic library */
             if (H5PL__open(path, search_params->type, search_params->key, found, NULL, plugin_info) < 0)
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "search in directory failed")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "search in directory failed");
             if (*found)
-                HGOTO_DONE(SUCCEED)
+                HGOTO_DONE(SUCCEED);
 
             path = (char *)H5MM_xfree(path);
         } /* end if */
@@ -903,7 +907,7 @@ H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *fo
 done:
     if (dirp)
         if (HDclosedir(dirp) < 0)
-            HDONE_ERROR(H5E_FILE, H5E_CLOSEERROR, FAIL, "can't close directory: %s", HDstrerror(errno))
+            HDONE_ERROR(H5E_FILE, H5E_CLOSEERROR, FAIL, "can't close directory: %s", strerror(errno));
 
     path = (char *)H5MM_xfree(path);
 
@@ -911,7 +915,7 @@ done:
 } /* end H5PL__find_plugin_in_path() */
 #else  /* H5_HAVE_WIN32_API */
 static herr_t
-H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *found, const char *dir,
+H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, bool *found, const char *dir,
                           const void **plugin_info)
 {
     WIN32_FIND_DATAA fdFile;
@@ -920,38 +924,38 @@ H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *fo
     char             service[2048];
     herr_t           ret_value = SUCCEED;
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Check args - Just assert on package functions */
-    HDassert(search_params);
-    HDassert(found);
-    HDassert(dir);
-    HDassert(plugin_info);
+    assert(search_params);
+    assert(found);
+    assert(dir);
+    assert(plugin_info);
 
     /* Initialize the found parameter */
-    *found = FALSE;
+    *found = false;
 
     /* Specify a file mask. *.* = We want everything! */
-    HDsnprintf(service, sizeof(service), "%s\\*.dll", dir);
+    snprintf(service, sizeof(service), "%s\\*.dll", dir);
     if ((hFind = FindFirstFileA(service, &fdFile)) == INVALID_HANDLE_VALUE)
-        HGOTO_ERROR(H5E_PLUGIN, H5E_OPENERROR, FAIL, "can't open directory")
+        HGOTO_ERROR(H5E_PLUGIN, H5E_OPENERROR, FAIL, "can't open directory");
 
     /* Loop over all the files */
     do {
         /* Ignore '.' and '..' */
-        if (HDstrcmp(fdFile.cFileName, ".") != 0 && HDstrcmp(fdFile.cFileName, "..") != 0) {
+        if (strcmp(fdFile.cFileName, ".") != 0 && strcmp(fdFile.cFileName, "..") != 0) {
 
             /* XXX: Probably just continue here and move the code below over one tab */
 
             size_t len;
 
             /* Allocate & initialize the path name */
-            len = HDstrlen(dir) + HDstrlen(H5PL_PATH_SEPARATOR) + HDstrlen(fdFile.cFileName) + 1;
+            len = strlen(dir) + strlen(H5PL_PATH_SEPARATOR) + strlen(fdFile.cFileName) + 1;
 
             if (NULL == (path = (char *)H5MM_calloc(len)))
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't allocate memory for path")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTALLOC, FAIL, "can't allocate memory for path");
 
-            HDsnprintf(path, len, "%s\\%s", dir, fdFile.cFileName);
+            snprintf(path, len, "%s\\%s", dir, fdFile.cFileName);
 
             /* Ignore directories */
             if (fdFile.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
@@ -959,9 +963,9 @@ H5PL__find_plugin_in_path(const H5PL_search_params_t *search_params, hbool_t *fo
 
             /* attempt to open the dynamic library */
             if (H5PL__open(path, search_params->type, search_params->key, found, NULL, plugin_info) < 0)
-                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "search in directory failed")
+                HGOTO_ERROR(H5E_PLUGIN, H5E_CANTGET, FAIL, "search in directory failed");
             if (*found)
-                HGOTO_DONE(SUCCEED)
+                HGOTO_DONE(SUCCEED);
 
             path = (char *)H5MM_xfree(path);
         }
