@@ -4,14 +4,13 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:  Quincey Koziol
- *
+/*
  * Purpose:	Generic Property Functions
  */
 
@@ -26,7 +25,6 @@
 /***********/
 #include "H5private.h"   /* Generic Functions			*/
 #include "H5Eprivate.h"  /* Error handling		  	*/
-#include "H5Fprivate.h"  /* Files		  	        */
 #include "H5Iprivate.h"  /* IDs			  		*/
 #include "H5MMprivate.h" /* Memory management			*/
 #include "H5Ppkg.h"      /* Property lists		  	*/
@@ -45,7 +43,7 @@
 
 /* Typedef for iterator when encoding a property list */
 typedef struct {
-    hbool_t encode;       /* Whether the property list should be encoded */
+    bool    encode;       /* Whether the property list should be encoded */
     size_t *enc_size_ptr; /* Pointer to size of encoded buffer */
     void  **pp;           /* Pointer to encoding buffer pointer */
 } H5P_enc_iter_ud_t;
@@ -74,9 +72,6 @@ typedef struct {
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Sunday, July 29, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -90,8 +85,8 @@ H5P__encode_size_t(const void *value, void **_pp, size_t *size)
 
     /* Sanity checks */
     HDcompile_assert(sizeof(size_t) <= sizeof(uint64_t));
-    HDassert(enc_size < 256);
-    HDassert(size);
+    assert(enc_size < 256);
+    assert(size);
 
     if (NULL != *pp) {
         /* Encode the size */
@@ -115,9 +110,6 @@ H5P__encode_size_t(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Mohamad Chaarawi
- *                 August 07, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -131,8 +123,8 @@ H5P__encode_hsize_t(const void *value, void **_pp, size_t *size)
 
     /* Sanity checks */
     HDcompile_assert(sizeof(hsize_t) <= sizeof(uint64_t));
-    HDassert(enc_size < 256);
-    HDassert(size);
+    assert(enc_size < 256);
+    assert(size);
 
     if (NULL != *pp) {
         *(*pp)++ = (uint8_t)enc_size;
@@ -155,9 +147,6 @@ H5P__encode_hsize_t(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Sunday, July 29, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -168,15 +157,15 @@ H5P__encode_unsigned(const void *value, void **_pp, size_t *size)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(value);
-    HDassert(size);
+    assert(value);
+    assert(size);
 
     if (NULL != *pp) {
         /* Encode the size */
         *(*pp)++ = (uint8_t)sizeof(unsigned);
 
         /* Encode the value */
-        H5_ENCODE_UNSIGNED(*pp, *(const unsigned *)value)
+        H5_ENCODE_UNSIGNED(*pp, *(const unsigned *)value);
     } /* end if */
 
     /* Set size needed for encoding */
@@ -193,9 +182,6 @@ H5P__encode_unsigned(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Mohamad Chaarawi
- *                 August 07, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -206,8 +192,8 @@ H5P__encode_uint8_t(const void *value, void **_pp, size_t *size)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(value);
-    HDassert(size);
+    assert(value);
+    assert(size);
 
     if (NULL != *pp) {
         /* Encode the value */
@@ -221,38 +207,35 @@ H5P__encode_uint8_t(const void *value, void **_pp, size_t *size)
 } /* end H5P__encode_uint8_t() */
 
 /*-------------------------------------------------------------------------
- * Function:       H5P__encode_hbool_t
+ * Function:       H5P__encode_bool
  *
- * Purpose:        Generic encoding callback routine for 'hbool_t' properties.
+ * Purpose:        Generic encoding callback routine for 'bool' properties.
  *
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 August 15, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5P__encode_hbool_t(const void *value, void **_pp, size_t *size)
+H5P__encode_bool(const void *value, void **_pp, size_t *size)
 {
     uint8_t **pp = (uint8_t **)_pp;
 
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(value);
-    HDassert(size);
+    assert(value);
+    assert(size);
 
     if (NULL != *pp)
         /* Encode the value */
-        *(*pp)++ = (uint8_t) * (const hbool_t *)value;
+        *(*pp)++ = (uint8_t) * (const bool *)value;
 
     /* Set size needed for encoding */
     *size += 1;
 
     FUNC_LEAVE_NOAPI(SUCCEED)
-} /* end H5P__encode_hbool_t() */
+} /* end H5P__encode_bool() */
 
 /*-------------------------------------------------------------------------
  * Function:       H5P__encode_double
@@ -262,9 +245,6 @@ H5P__encode_hbool_t(const void *value, void **_pp, size_t *size)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Sunday, July 29, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -275,15 +255,15 @@ H5P__encode_double(const void *value, void **_pp, size_t *size)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(value);
-    HDassert(size);
+    assert(value);
+    assert(size);
 
     if (NULL != *pp) {
         /* Encode the size */
         *(*pp)++ = (uint8_t)sizeof(double);
 
         /* Encode the value */
-        H5_ENCODE_DOUBLE(*pp, *(const double *)value)
+        H5_ENCODE_DOUBLE(*pp, *(const double *)value);
     } /* end if */
 
     /* Set size needed for encoding */
@@ -292,6 +272,41 @@ H5P__encode_double(const void *value, void **_pp, size_t *size)
     FUNC_LEAVE_NOAPI(SUCCEED)
 } /* end H5P__encode_double() */
 
+/*-------------------------------------------------------------------------
+ * Function:       H5P__encode_uint64_t
+ *
+ * Purpose:        Generic encoding callback routine for 'uint64_t' properties.
+ *
+ * Return:	   Success:	Non-negative
+ *		   Failure:	Negative
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5P__encode_uint64_t(const void *value, void **_pp, size_t *size)
+{
+    uint8_t **pp = (uint8_t **)_pp;
+
+    FUNC_ENTER_PACKAGE_NOERR
+
+    /* Sanity checks */
+    assert(value);
+    assert(size);
+
+    if (NULL != *pp) {
+        /* Encode the size */
+        *(*pp)++ = (uint8_t)sizeof(uint64_t);
+
+        /* Encode the value */
+        UINT64ENCODE(*pp, *(const unsigned *)value);
+    } /* end if */
+
+    /* Set size needed for encoding */
+    *size += (1 + sizeof(uint64_t));
+
+    FUNC_LEAVE_NOAPI(SUCCEED)
+} /* end H5P__encode_uint64_t() */
+
 /*--------------------------------------------------------------------------
  NAME
     H5P__encode_cb
@@ -318,11 +333,11 @@ H5P__encode_cb(H5P_genprop_t *prop, void *_udata)
     H5P_enc_iter_ud_t *udata     = (H5P_enc_iter_ud_t *)_udata; /* Pointer to user data */
     int                ret_value = H5_ITER_CONT;                /* Return value */
 
-    FUNC_ENTER_STATIC
+    FUNC_ENTER_PACKAGE
 
     /* Sanity check */
-    HDassert(prop);
-    HDassert(udata);
+    assert(prop);
+    assert(udata);
 
     /* Check if this property can be encoded */
     if (prop->encode) {
@@ -330,17 +345,23 @@ H5P__encode_cb(H5P_genprop_t *prop, void *_udata)
         size_t prop_value_len; /* Encoded size of property's value */
 
         /* Encode (or not, if the 'encode' flag is off) the property's name */
-        prop_name_len = HDstrlen(prop->name) + 1;
+        prop_name_len = strlen(prop->name) + 1;
         if (udata->encode) {
-            HDstrcpy((char *)*(udata->pp), prop->name);
+            strcpy((char *)*(udata->pp), prop->name);
             *(uint8_t **)(udata->pp) += prop_name_len;
         } /* end if */
         *(udata->enc_size_ptr) += prop_name_len;
 
-        /* Encode (or not, if *(udata->pp) is NULL) the property value */
-        prop_value_len = 0;
-        if ((prop->encode)(prop->value, udata->pp, &prop_value_len) < 0)
-            HGOTO_ERROR(H5E_PLIST, H5E_CANTENCODE, H5_ITER_ERROR, "property encoding routine failed")
+        /* Prepare & restore library for user callback */
+        H5_BEFORE_USER_CB(H5_ITER_ERROR)
+            {
+                /* Encode (or not, if *(udata->pp) is NULL) the property value */
+                prop_value_len = 0;
+                ret_value      = (prop->encode)(prop->value, udata->pp, &prop_value_len);
+            }
+        H5_AFTER_USER_CB(H5_ITER_ERROR)
+        if (ret_value < 0)
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTENCODE, H5_ITER_ERROR, "property encoding routine failed");
         *(udata->enc_size_ptr) += prop_value_len;
     } /* end if */
 
@@ -356,8 +377,8 @@ done:
  USAGE
     herr_t H5P__encode(plist, enc_all_prop, buf, nalloc)
         const H5P_genplist_t *plist;  IN: Property list to encode
-        hbool_t enc_all_prop;  IN: Whether to encode all properties (TRUE),
-                or just non-default (i.e. changed) properties (FALSE).
+        bool enc_all_prop;  IN: Whether to encode all properties (true),
+                or just non-default (i.e. changed) properties (false).
         uint8_t *buf;    OUT: buffer to hold the encoded plist
         size_t *nalloc;  IN/OUT: size of buffer needed to encode plist
  RETURNS
@@ -372,26 +393,26 @@ done:
  REVISION LOG
 --------------------------------------------------------------------------*/
 herr_t
-H5P__encode(const H5P_genplist_t *plist, hbool_t enc_all_prop, void *buf, size_t *nalloc)
+H5P__encode(const H5P_genplist_t *plist, bool enc_all_prop, void *buf, size_t *nalloc)
 {
     H5P_enc_iter_ud_t udata;                 /* User data for property iteration callback */
     uint8_t          *p = (uint8_t *)buf;    /* Temporary pointer to encoding buffer */
     int               idx;                   /* Index of property to start at */
     size_t            encode_size = 0;       /* Size of buffer needed to encode properties */
-    hbool_t           encode      = TRUE;    /* Whether the property list should be encoded */
+    bool              encode      = true;    /* Whether the property list should be encoded */
     herr_t            ret_value   = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE
 
     /* Sanity check */
     if (NULL == nalloc)
-        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "bad allocation size pointer")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "bad allocation size pointer");
 
     /* If the buffer is NULL, then this call to H5P__encode will return how much
      * space is needed to encode a property.
      */
     if (NULL == p)
-        encode = FALSE;
+        encode = false;
 
     /* Encode property list description info */
     if (encode) {
@@ -411,7 +432,7 @@ H5P__encode(const H5P_genplist_t *plist, hbool_t enc_all_prop, void *buf, size_t
     /* Iterate over all properties in property list, encoding them */
     idx = 0;
     if (H5P__iterate_plist(plist, enc_all_prop, &idx, H5P__encode_cb, &udata) < 0)
-        HGOTO_ERROR(H5E_PLIST, H5E_BADITER, FAIL, "can't iterate over properties")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADITER, FAIL, "can't iterate over properties");
 
     /* Encode a terminator for list of properties */
     if (encode)
@@ -433,9 +454,6 @@ done:
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Thursday, August 2, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -450,13 +468,13 @@ H5P__decode_size_t(const void **_pp, void *_value)
 
     /* Sanity check */
     HDcompile_assert(sizeof(size_t) <= sizeof(uint64_t));
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the size */
     enc_size = *(*pp)++;
-    HDassert(enc_size < 256);
+    assert(enc_size < 256);
 
     /* Decode the value */
     UINT64DECODE_VAR(*pp, enc_value, enc_size);
@@ -473,9 +491,6 @@ H5P__decode_size_t(const void **_pp, void *_value)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Mohamad Chaarawi
- *                 August 07, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -490,13 +505,13 @@ H5P__decode_hsize_t(const void **_pp, void *_value)
 
     /* Sanity check */
     HDcompile_assert(sizeof(hsize_t) <= sizeof(uint64_t));
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the size */
     enc_size = *(*pp)++;
-    HDassert(enc_size < 256);
+    assert(enc_size < 256);
 
     /* Decode the value */
     UINT64DECODE_VAR(*pp, enc_value, enc_size);
@@ -513,9 +528,6 @@ H5P__decode_hsize_t(const void **_pp, void *_value)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Thursday, August 2, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -529,16 +541,16 @@ H5P__decode_unsigned(const void **_pp, void *_value)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the size */
     enc_size = *(*pp)++;
     if (enc_size != sizeof(unsigned))
-        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "unsigned value can't be decoded")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "unsigned value can't be decoded");
 
-    H5_DECODE_UNSIGNED(*pp, *value)
+    H5_DECODE_UNSIGNED(*pp, *value);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
@@ -552,9 +564,6 @@ done:
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Thursday, August 2, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -567,9 +576,9 @@ H5P__decode_uint8_t(const void **_pp, void *_value)
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the value */
     *value = *(*pp)++;
@@ -578,37 +587,34 @@ H5P__decode_uint8_t(const void **_pp, void *_value)
 } /* end H5P__decode_uint8_t() */
 
 /*-------------------------------------------------------------------------
- * Function:       H5P__decode_hbool_t
+ * Function:       H5P__decode_bool
  *
- * Purpose:        Generic decoding callback routine for 'hbool_t' properties.
+ * Purpose:        Generic decoding callback routine for 'bool' properties.
  *
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Wednesday, August 15, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
-H5P__decode_hbool_t(const void **_pp, void *_value)
+H5P__decode_bool(const void **_pp, void *_value)
 {
-    hbool_t        *value     = (hbool_t *)_value; /* Property value to return */
+    bool           *value     = (bool *)_value; /* Property value to return */
     const uint8_t **pp        = (const uint8_t **)_pp;
     herr_t          ret_value = SUCCEED; /* Return value */
 
     FUNC_ENTER_PACKAGE_NOERR
 
     /* Sanity checks */
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the value */
-    *value = (hbool_t) * (*pp)++;
+    *value = (bool)*(*pp)++;
 
     FUNC_LEAVE_NOAPI(ret_value)
-} /* end H5P__decode_hbool_t() */
+} /* end H5P__decode_bool() */
 
 /*-------------------------------------------------------------------------
  * Function:       H5P__decode_double
@@ -618,9 +624,6 @@ H5P__decode_hbool_t(const void **_pp, void *_value)
  * Return:	   Success:	Non-negative
  *		   Failure:	Negative
  *
- * Programmer:     Quincey Koziol
- *                 Thursday, August 2, 2012
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -634,21 +637,57 @@ H5P__decode_double(const void **_pp, void *_value)
     FUNC_ENTER_PACKAGE
 
     /* Sanity checks */
-    HDassert(pp);
-    HDassert(*pp);
-    HDassert(value);
+    assert(pp);
+    assert(*pp);
+    assert(value);
 
     /* Decode the size */
     enc_size = *(*pp)++;
     if (enc_size != sizeof(double))
-        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "double value can't be decoded")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "double value can't be decoded");
 
-    H5_DECODE_DOUBLE(*pp, *value)
+    H5_DECODE_DOUBLE(*pp, *value);
 
 done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5P__decode_double() */
 
+/*-------------------------------------------------------------------------
+ * Function:       H5P__decode_uint64_t
+ *
+ * Purpose:        Generic decoding callback routine for 'uint64_t' properties.
+ *
+ * Return:	   Success:	Non-negative
+ *		   Failure:	Negative
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5P__decode_uint64_t(const void **_pp, void *_value)
+{
+    uint64_t       *value = (uint64_t *)_value; /* Property value to return */
+    const uint8_t **pp    = (const uint8_t **)_pp;
+    unsigned        enc_size;            /* Size of encoded property */
+    herr_t          ret_value = SUCCEED; /* Return value */
+
+    FUNC_ENTER_PACKAGE
+
+    /* Sanity checks */
+    assert(pp);
+    assert(*pp);
+    assert(value);
+
+    /* Decode the size */
+    enc_size = *(*pp)++;
+    if (enc_size != sizeof(uint64_t))
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "uint64_t value can't be decoded");
+
+    UINT64DECODE(*pp, *value);
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5P__decode_uint64_t() */
+
 /*-------------------------------------------------------------------------
  NAME
     H5P__decode
@@ -688,18 +727,18 @@ H5P__decode(const void *buf)
 
     /* Sanity check */
     if (NULL == p)
-        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "decode buffer is NULL")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADVALUE, FAIL, "decode buffer is NULL");
 
     /* Get the version number of the encoded property list */
     vers = (uint8_t)*p++;
     if ((uint8_t)H5P_ENCODE_VERS != vers)
         HGOTO_ERROR(H5E_PLIST, H5E_VERSION, FAIL, "bad version # of encoded information, expected %u, got %u",
-                    (unsigned)H5P_ENCODE_VERS, (unsigned)vers)
+                    (unsigned)H5P_ENCODE_VERS, (unsigned)vers);
 
     /* Get the type of the property list */
     type = (H5P_plist_type_t)*p++;
     if (type <= H5P_TYPE_USER || type >= H5P_TYPE_MAX_TYPE)
-        HGOTO_ERROR(H5E_PLIST, H5E_BADRANGE, FAIL, "bad type of encoded information: %u", (unsigned)type)
+        HGOTO_ERROR(H5E_PLIST, H5E_BADRANGE, FAIL, "bad type of encoded information: %u", (unsigned)type);
 
     /* Create new property list of the specified type */
     if ((plist_id = H5P__new_plist_of_type(type)) < 0)
@@ -707,7 +746,7 @@ H5P__decode(const void *buf)
 
     /* Get the property list object */
     if (NULL == (plist = (H5P_genplist_t *)H5I_object(plist_id)))
-        HGOTO_ERROR(H5E_PLIST, H5E_BADTYPE, FAIL, "not a property class")
+        HGOTO_ERROR(H5E_PLIST, H5E_BADTYPE, FAIL, "not a property class");
 
     /* Loop over encoded properties, deserializing their values */
     while (p) {
@@ -720,31 +759,37 @@ H5P__decode(const void *buf)
 
         /* Get property list name */
         name = (const char *)p;
-        p += HDstrlen(name) + 1;
+        p += strlen(name) + 1;
 
         /* Find property with name */
         if (NULL == (prop = H5P__find_prop_plist(plist, name)))
-            HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "property doesn't exist: '%s'", name)
+            HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "property doesn't exist: '%s'", name);
 
         /* Check if we should increase the size of the value buffer */
         if (prop->size > value_buf_size) {
             if (NULL == (value_buf = H5MM_realloc(value_buf, prop->size)))
-                HGOTO_ERROR(H5E_PLIST, H5E_CANTALLOC, FAIL, "decoding buffer allocation failed")
+                HGOTO_ERROR(H5E_PLIST, H5E_CANTALLOC, FAIL, "decoding buffer allocation failed");
             value_buf_size = prop->size;
         } /* end if */
 
         /* Decode serialized value */
         if (prop->decode) {
-            if ((prop->decode)((const void **)&p, value_buf) < 0)
+            /* Prepare & restore library for user callback */
+            H5_BEFORE_USER_CB(FAIL)
+                {
+                    ret_value = (prop->decode)((const void **)&p, value_buf);
+                }
+            H5_AFTER_USER_CB(FAIL)
+            if (ret_value < 0)
                 HGOTO_ERROR(H5E_PLIST, H5E_CANTDECODE, FAIL,
-                            "property decoding routine failed, property: '%s'", name)
+                            "property decoding routine failed, property: '%s'", name);
         } /* end if */
         else
-            HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "no decode callback for property: '%s'", name)
+            HGOTO_ERROR(H5E_PLIST, H5E_NOTFOUND, FAIL, "no decode callback for property: '%s'", name);
 
         /* Set the value for the property */
         if (H5P_poke(plist, name, value_buf) < 0)
-            HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "unable to set value for property: '%s'", name)
+            HGOTO_ERROR(H5E_PLIST, H5E_CANTSET, FAIL, "unable to set value for property: '%s'", name);
     } /* end while */
 
     /* Set return value */
@@ -759,7 +804,7 @@ done:
     if (ret_value < 0) {
         if (plist_id > 0 && H5I_dec_ref(plist_id) < 0)
             HDONE_ERROR(H5E_PLIST, H5E_CANTCLOSEOBJ, FAIL,
-                        "unable to close partially initialized property list")
+                        "unable to close partially initialized property list");
     } /* end if */
 
     FUNC_LEAVE_NOAPI(ret_value)
