@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -22,10 +22,14 @@
  *      reporting macros.
  */
 #define H5P_MODULE
-#define H5_MY_PKG     H5P
-#define H5_MY_PKG_ERR H5E_PLIST
+#define H5_MY_PKG      H5P
+#define H5_MY_PKG_ERR  H5E_PLIST
+#define H5_MY_PKG_INIT YES
 
 /** \page H5P_UG  Properties and Property Lists in HDF5
+ *
+ * Navigate back: \ref index "Main" / \ref UG
+ * <hr>
  *
  * \section sec_plist Properties and Property Lists in HDF5
  *
@@ -878,6 +882,11 @@
  *
  * Previous Chapter \ref sec_error - Next Chapter \ref sec_vol
  *
+ * <hr>
+ * Navigate back: \ref index "Main" / \ref UG
+ */
+
+/**
  * \defgroup H5P Property Lists (H5P)
  *
  * Use the functions in this module to manage HDF5 property lists and property
@@ -1050,7 +1059,7 @@
  * created.
  * <div>
  * \snippet{doc} tables/propertyLists.dox fcpl_table
-  * </div>
+ * </div>
  *
  * \defgroup GAPL Group Access Properties
  * \ingroup LAPL
