@@ -4,16 +4,13 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  James Laird
- *              Thursday, March 30, 2006
- *
  * Purpose:     This file contains declarations which are visible only within
  *              the H5SM shared object header messages package.  Source files
  *              outside the H5SM package should	include H5SMprivate.h instead.
@@ -32,6 +29,7 @@
 #include "H5ACprivate.h" /* Metadata Cache		  	*/
 #include "H5B2private.h" /* B-trees                              */
 #include "H5HFprivate.h" /* Fractal heaps		  	*/
+#include "H5FLprivate.h" /* Free Lists                           */
 
 /****************************/
 /* Package Macros           */
@@ -203,24 +201,6 @@ typedef struct {
                                 * heap ID, the heap ID will be 0. */
 } H5SM_mesg_key_t;
 
-/*
- * Data exchange structure to pass through the fractal heap layer for the
- * H5HF_op function when computing a hash value for a message.
- */
-typedef struct {
-    /* downward (internal) */
-    unsigned type_id; /* Message type */
-
-    /* upward */
-    uint32_t hash; /* Hash value */
-} H5SM_fh_ud_gh_t;
-
-/* Typedef to increment a reference count in the B-tree */
-typedef struct {
-    H5SM_mesg_key_t *key;      /* IN: key for message being incremented */
-    H5O_fheap_id_t   fheap_id; /* OUT: fheap ID of record */
-} H5SM_incr_ref_opdata;
-
 /* v2 B-tree client callback context */
 typedef struct H5SM_bt2_ctx_t {
     uint8_t sizeof_addr; /* Size of file addresses */
@@ -254,7 +234,7 @@ H5_DLLVAR const H5B2_class_t H5SM_INDEX[1];
 /****************************/
 
 /* General routines */
-H5_DLL ssize_t H5SM__get_index(const H5SM_master_table_t *table, unsigned type_id);
+H5_DLL herr_t H5SM__get_index(const H5SM_master_table_t *table, unsigned type_id, ssize_t *idx);
 
 /* Encode and decode routines, used for B-tree and cache encoding/decoding */
 H5_DLL herr_t H5SM__message_compare(const void *rec1, const void *rec2, int *result);
