@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -43,8 +43,6 @@ static hsize_t bigio_count_g = H5_MAX_MPI_COUNT;
  *
  * Return:    The current/previous value of bigio_count_g.
  *
- * Programmer: Richard Warren,  March 10, 2017
- *
  *-------------------------------------------------------------------------
  */
 hsize_t
@@ -66,11 +64,9 @@ H5_mpi_set_bigio_count(hsize_t new_count)
  *
  * Return:    The current/previous value of bigio_count_g.
  *
- * Programmer: Richard Warren,  October 7, 2019
- *
  *-------------------------------------------------------------------------
  */
-hsize_t
+H5_ATTR_PURE hsize_t
 H5_mpi_get_bigio_count(void)
 {
     return bigio_count_g;
@@ -101,7 +97,7 @@ H5_mpi_comm_dup(MPI_Comm comm, MPI_Comm *comm_new)
 
     /* Check arguments */
     if (!comm_new)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "comm_new cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "comm_new cannot be NULL");
 
     /* Handle MPI_COMM_NULL separately */
     if (MPI_COMM_NULL == comm) {
@@ -160,7 +156,7 @@ H5_mpi_info_dup(MPI_Info info, MPI_Info *info_new)
 
     /* Check arguments */
     if (!info_new)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "info_new cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "info_new cannot be NULL");
 
     /* Duplicate the MPI info */
     if (info == MPI_INFO_NULL) {
@@ -206,7 +202,7 @@ H5_mpi_comm_free(MPI_Comm *comm)
 
     /* Check arguments */
     if (!comm)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "comm pointer cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "comm pointer cannot be NULL");
 
     /* Free the communicator */
     if (MPI_COMM_WORLD != *comm && MPI_COMM_NULL != *comm)
@@ -238,7 +234,7 @@ H5_mpi_info_free(MPI_Info *info)
 
     /* Check arguments */
     if (!info)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "info pointer cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "info pointer cannot be NULL");
 
     /* Free the info */
     if (MPI_INFO_NULL != *info)
@@ -281,7 +277,7 @@ H5_mpi_comm_cmp(MPI_Comm comm1, MPI_Comm comm2, int *result)
 
     /* Check arguments */
     if (!result)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "result cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "result cannot be NULL");
 
     /* Set out parameter to something reasonable in case something goes wrong */
     *result = 0;
@@ -339,27 +335,27 @@ done:
 herr_t
 H5_mpi_info_cmp(MPI_Info info1, MPI_Info info2, int *result)
 {
-    hbool_t same      = FALSE;
-    char   *key       = NULL;
-    char   *value1    = NULL;
-    char   *value2    = NULL;
-    herr_t  ret_value = SUCCEED;
+    bool   same      = false;
+    char  *key       = NULL;
+    char  *value1    = NULL;
+    char  *value2    = NULL;
+    herr_t ret_value = SUCCEED;
 
     FUNC_ENTER_NOAPI(FAIL)
 
     /* Check arguments */
     if (!result)
-        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "result cannot be NULL")
+        HGOTO_ERROR(H5E_INTERNAL, H5E_BADVALUE, FAIL, "result cannot be NULL");
 
     /* Check for MPI_INFO_NULL */
     if (MPI_INFO_NULL == info1 && MPI_INFO_NULL == info2) {
         /* Special case of both info objects being MPI_INFO_NULL */
-        same = TRUE;
+        same = true;
     }
     else if (MPI_INFO_NULL == info1 || MPI_INFO_NULL == info2) {
 
         /* Special case of one info object being MPI_INFO_NULL */
-        same = FALSE;
+        same = false;
     }
     else {
         int mpi_code;
@@ -373,9 +369,9 @@ H5_mpi_info_cmp(MPI_Info info1, MPI_Info info2, int *result)
             HMPI_GOTO_ERROR(FAIL, "MPI_Info_get_nkeys failed", mpi_code)
 
         if (nkeys_1 != nkeys_2)
-            same = FALSE;
+            same = false;
         else if (0 == nkeys_1 && 0 == nkeys_2)
-            same = TRUE;
+            same = true;
         else {
             int i;
             int flag1 = -1;
@@ -383,21 +379,21 @@ H5_mpi_info_cmp(MPI_Info info1, MPI_Info info2, int *result)
 
             /* Allocate buffers for iteration */
             if (NULL == (key = (char *)H5MM_malloc(MPI_MAX_INFO_KEY * sizeof(char))))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
-            if (NULL == (value1 = (char *)H5MM_malloc(MPI_MAX_INFO_VAL * sizeof(char))))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
-            if (NULL == (value2 = (char *)H5MM_malloc(MPI_MAX_INFO_VAL * sizeof(char))))
-                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed")
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
+            if (NULL == (value1 = (char *)H5MM_malloc((MPI_MAX_INFO_VAL + 1) * sizeof(char))))
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
+            if (NULL == (value2 = (char *)H5MM_malloc((MPI_MAX_INFO_VAL + 1) * sizeof(char))))
+                HGOTO_ERROR(H5E_RESOURCE, H5E_NOSPACE, FAIL, "memory allocation failed");
 
             /* Iterate over the keys, comparing them */
             for (i = 0; i < nkeys_1; i++) {
 
-                same = TRUE;
+                same = true;
 
                 /* Memset the buffers to zero */
-                HDmemset(key, 0, MPI_MAX_INFO_KEY);
-                HDmemset(value1, 0, MPI_MAX_INFO_VAL);
-                HDmemset(value2, 0, MPI_MAX_INFO_VAL);
+                memset(key, 0, MPI_MAX_INFO_KEY);
+                memset(value1, 0, MPI_MAX_INFO_VAL);
+                memset(value2, 0, MPI_MAX_INFO_VAL);
 
                 /* Get the nth key */
                 if (MPI_SUCCESS != (mpi_code = MPI_Info_get_nthkey(info1, i, key)))
@@ -410,8 +406,8 @@ H5_mpi_info_cmp(MPI_Info info1, MPI_Info info2, int *result)
                     HMPI_GOTO_ERROR(FAIL, "MPI_Info_get failed", mpi_code)
 
                 /* Compare values and flags */
-                if (!flag1 || !flag2 || HDmemcmp(value1, value2, MPI_MAX_INFO_VAL)) {
-                    same = FALSE;
+                if (!flag1 || !flag2 || memcmp(value1, value2, MPI_MAX_INFO_VAL)) {
+                    same = false;
                     break;
                 }
 
@@ -450,8 +446,6 @@ done:
  *
  *              *new_type    the new datatype created
  *
- * Programmer:  Mohamad Chaarawi
- *
  *-------------------------------------------------------------------------
  */
 herr_t
@@ -582,8 +576,8 @@ done:
  *                            MPI_(All)gatherv's `recvtype` parameter.
  *
  *              `allgather` - Specifies whether the gather operation to be
- *                            performed should be MPI_Allgatherv (TRUE) or
- *                            MPI_Gatherv (FALSE).
+ *                            performed should be MPI_Allgatherv (true) or
+ *                            MPI_Gatherv (false).
  *
  *              `root` - For MPI_Gatherv operations, specifies the rank
  *                       that will receive the data sent by other ranks.
@@ -622,37 +616,28 @@ done:
  */
 herr_t
 H5_mpio_gatherv_alloc(void *send_buf, int send_count, MPI_Datatype send_type, const int recv_counts[],
-                      const int displacements[], MPI_Datatype recv_type, hbool_t allgather, int root,
+                      const int displacements[], MPI_Datatype recv_type, bool allgather, int root,
                       MPI_Comm comm, int mpi_rank, int mpi_size, void **out_buf, size_t *out_buf_num_entries)
 {
-    size_t recv_buf_num_entries = 0;
-    void  *recv_buf             = NULL;
-#if MPI_VERSION >= 3
+    size_t    recv_buf_num_entries = 0;
+    void     *recv_buf             = NULL;
     MPI_Count type_lb;
     MPI_Count type_extent;
-#else
-    MPI_Aint type_lb;
-    MPI_Aint type_extent;
-#endif
-    int    mpi_code;
-    herr_t ret_value = SUCCEED;
+    int       mpi_code;
+    herr_t    ret_value = SUCCEED;
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(send_buf || send_count == 0);
+    assert(send_buf || send_count == 0);
     if (allgather || (mpi_rank == root))
-        HDassert(out_buf && out_buf_num_entries);
+        assert(out_buf && out_buf_num_entries);
 
-        /* Retrieve the extent of the MPI Datatype being used */
-#if MPI_VERSION >= 3
+    /* Retrieve the extent of the MPI Datatype being used */
     if (MPI_SUCCESS != (mpi_code = MPI_Type_get_extent_x(recv_type, &type_lb, &type_extent)))
-#else
-    if (MPI_SUCCESS != (mpi_code = MPI_Type_get_extent(recv_type, &type_lb, &type_extent)))
-#endif
         HMPI_GOTO_ERROR(FAIL, "MPI_Type_get_extent(_x) failed", mpi_code)
 
     if (type_extent < 0)
-        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "MPI recv_type had a negative extent")
+        HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "MPI recv_type had a negative extent");
 
     /*
      * Calculate the total size of the buffer being
@@ -668,11 +653,11 @@ H5_mpio_gatherv_alloc(void *send_buf, int send_count, MPI_Datatype send_type, co
 
         /* If our buffer size is 0, there's nothing to do */
         if (buf_size == 0)
-            HGOTO_DONE(SUCCEED)
+            HGOTO_DONE(SUCCEED);
 
         if (NULL == (recv_buf = H5MM_malloc(buf_size)))
             /* Push an error, but still participate in collective gather operation */
-            HDONE_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "couldn't allocate receive buffer")
+            HDONE_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL, "couldn't allocate receive buffer");
     }
 
     /* Perform gather operation */
@@ -716,7 +701,7 @@ done:
  */
 herr_t
 H5_mpio_gatherv_alloc_simple(void *send_buf, int send_count, MPI_Datatype send_type, MPI_Datatype recv_type,
-                             hbool_t allgather, int root, MPI_Comm comm, int mpi_rank, int mpi_size,
+                             bool allgather, int root, MPI_Comm comm, int mpi_rank, int mpi_size,
                              void **out_buf, size_t *out_buf_num_entries)
 {
     int   *recv_counts_disps_array = NULL;
@@ -725,9 +710,9 @@ H5_mpio_gatherv_alloc_simple(void *send_buf, int send_count, MPI_Datatype send_t
 
     FUNC_ENTER_NOAPI(FAIL)
 
-    HDassert(send_buf || send_count == 0);
+    assert(send_buf || send_count == 0);
     if (allgather || (mpi_rank == root))
-        HDassert(out_buf && out_buf_num_entries);
+        assert(out_buf && out_buf_num_entries);
 
     /*
      * Allocate array to store the receive counts of each rank, as well as
@@ -741,7 +726,7 @@ H5_mpio_gatherv_alloc_simple(void *send_buf, int send_count, MPI_Datatype send_t
             (recv_counts_disps_array = H5MM_malloc(2 * (size_t)mpi_size * sizeof(*recv_counts_disps_array))))
             /* Push an error, but still participate in collective gather operation */
             HDONE_ERROR(H5E_RESOURCE, H5E_CANTALLOC, FAIL,
-                        "couldn't allocate receive counts and displacements array")
+                        "couldn't allocate receive counts and displacements array");
     }
 
     /* Collect each rank's send count to interested ranks */
@@ -772,7 +757,7 @@ H5_mpio_gatherv_alloc_simple(void *send_buf, int send_count, MPI_Datatype send_t
     if (H5_mpio_gatherv_alloc(send_buf, send_count, send_type, recv_counts_disps_array,
                               &recv_counts_disps_array[mpi_size], recv_type, allgather, root, comm, mpi_rank,
                               mpi_size, out_buf, out_buf_num_entries) < 0)
-        HGOTO_ERROR(H5E_LIB, H5E_CANTGATHER, FAIL, "can't gather data")
+        HGOTO_ERROR(H5E_LIB, H5E_CANTGATHER, FAIL, "can't gather data");
 
 done:
     if (recv_counts_disps_array)
@@ -781,4 +766,57 @@ done:
     FUNC_LEAVE_NOAPI(ret_value)
 } /* end H5_mpio_gatherv_alloc_simple() */
 
+/*-------------------------------------------------------------------------
+ * Function:    H5_mpio_get_file_sync_required
+ *
+ * Purpose:     Retrieve the MPI hint indicating whether the data written
+ *              by the MPI ROMIO driver is immediately visible to all MPI
+ *              ranks.
+ *
+ * Notes:       This routine is designed for supporting UnifyFS that needs
+ *              MPI_File_sync in order to make the written data available
+ *              to all ranks.
+ *
+ * Return:      Non-negative on success/Negative on failure
+ *
+ *-------------------------------------------------------------------------
+ */
+herr_t
+H5_mpio_get_file_sync_required(MPI_File fh, bool *file_sync_required)
+{
+    MPI_Info info_used;
+    int      flag;
+    char    *sync_env_var;
+    char     value[MPI_MAX_INFO_VAL];
+    herr_t   ret_value = SUCCEED;
+
+    FUNC_ENTER_NOAPI(FAIL)
+
+    assert(file_sync_required);
+
+    *file_sync_required = false;
+
+    if (MPI_SUCCESS != MPI_File_get_info(fh, &info_used))
+        HGOTO_ERROR(H5E_LIB, H5E_CANTGET, FAIL, "can't get MPI info");
+
+    if (MPI_SUCCESS !=
+        MPI_Info_get(info_used, "romio_visibility_immediate", MPI_MAX_INFO_VAL - 1, value, &flag))
+        HGOTO_ERROR(H5E_LIB, H5E_CANTGET, FAIL, "can't get MPI info");
+
+    if (flag && !strcmp(value, "false"))
+        *file_sync_required = true;
+
+    if (MPI_SUCCESS != MPI_Info_free(&info_used))
+        HGOTO_ERROR(H5E_LIB, H5E_CANTFREE, FAIL, "can't free MPI info");
+
+    /* Force setting the flag via env variable (temp solution before the flag is implemented in MPI) */
+    sync_env_var = getenv("HDF5_DO_MPI_FILE_SYNC");
+    if (sync_env_var && (!strcmp(sync_env_var, "TRUE") || !strcmp(sync_env_var, "1")))
+        *file_sync_required = true;
+    if (sync_env_var && (!strcmp(sync_env_var, "FALSE") || !strcmp(sync_env_var, "0")))
+        *file_sync_required = false;
+
+done:
+    FUNC_LEAVE_NOAPI(ret_value)
+} /* end H5_mpio_get_file_sync_required() */
 #endif /* H5_HAVE_PARALLEL */
