@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -36,11 +36,16 @@
  */
 #define H5D_FRIEND
 #define H5D_TESTING /* to use H5D__ functions */
-#include "H5Dpkg.h"
 
-#include "testhdf5.h"
+#include "h5test.h"
+#include "H5Dpkg.h"
 #ifdef H5_HAVE_FILTER_DEFLATE
-#include "zlib.h"
+#if defined(H5_HAVE_ZLIB_H) && !defined(H5_ZLIB_HEADER)
+#define H5_ZLIB_HEADER "zlib.h"
+#endif
+#if defined(H5_ZLIB_HEADER)
+#include H5_ZLIB_HEADER /* "zlib.h" */
+#endif
 #endif
 
 /* Test file names, using H5F_libver_t as indices */
@@ -49,7 +54,7 @@ static const char *FILENAME[] = {"tchunk_info_earliest",
                                  "tchunk_info_v110",
                                  "tchunk_info_v112",
                                  "tchunk_info_v114",
-                                 "tchunk_info_v116",
+                                 "tchunk_info_v200",
                                  NULL};
 
 /* File to be used in test_failed_attempts */
@@ -320,11 +325,18 @@ verify_selected_chunks(hid_t dset, hid_t plist, const hsize_t *start, const hsiz
     chk_index = 0;
     for (ii = start[0]; ii < end[0]; ii++)
         for (jj = start[1]; jj < end[1]; jj++, chk_index++) {
+            size_t tmp_buf_size;
+
             offset[0] = ii * CHUNK_NX;
             offset[1] = jj * CHUNK_NY;
 
             /* Read the current chunk */
-            if (H5Dread_chunk(dset, plist, offset, &read_flt_msk, read_buf) < 0)
+            tmp_buf_size = sizeof(read_buf);
+            if (H5Dread_chunk2(dset, plist, offset, &read_flt_msk, read_buf, &tmp_buf_size) < 0)
+                TEST_ERROR;
+
+            /* Check if buffer wasn't big enough */
+            if (tmp_buf_size > sizeof(read_buf))
                 TEST_ERROR;
 
             /* Verify that read chunk is the same as the corresponding written one */
@@ -534,7 +546,11 @@ test_get_chunk_info_highest_v18(hid_t fapl)
     z_dst = (Bytef *)inbuf;
 
     /* Perform compression from the source to the destination buffer */
+#if defined(H5_HAVE_ZLIBNG_H)
+    ret = zng_compress2(z_dst, &z_dst_nbytes, z_src, z_src_nbytes, aggression);
+#else
     ret = compress2(z_dst, &z_dst_nbytes, z_src, z_src_nbytes, aggression);
+#endif
 
     /* Set the chunk size to the compressed chunk size */
     chunk_size = (hsize_t)z_dst_nbytes;
@@ -2051,12 +2067,18 @@ test_flt_msk_with_skip_compress(hid_t fapl)
     if (read_buf_size != CHK_SIZE)
         TEST_ERROR;
 
-    /* Read the raw chunk back with H5Dread_chunk */
-    memset(&read_direct_buf, 0, sizeof(read_direct_buf));
-    if (H5Dread_chunk(dset, H5P_DEFAULT, offset, &read_flt_msk, read_direct_buf) < 0)
-        TEST_ERROR;
-    if (read_flt_msk != flt_msk)
-        TEST_ERROR;
+    /* Read the raw chunk back with H5Dread_chunk2 */
+    {
+        size_t tmp_buf_size = sizeof(read_direct_buf);
+
+        memset(&read_direct_buf, 0, sizeof(read_direct_buf));
+        if (H5Dread_chunk2(dset, H5P_DEFAULT, offset, &read_flt_msk, read_direct_buf, &tmp_buf_size) < 0)
+            TEST_ERROR;
+        if (tmp_buf_size > sizeof(read_direct_buf))
+            TEST_ERROR;
+        if (read_flt_msk != flt_msk)
+            TEST_ERROR;
+    }
 
     /* Check that the direct chunk read is the same as the chunk written */
     for (ii = 0; ii < CHUNK_NX; ii++)
