@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -48,36 +48,36 @@ main(void)
     int                       little_endian;
     int                       word_length;
     H5AC_cache_config_t       my_cache_config       = {H5AC__CURR_CACHE_CONFIG_VERSION,
-                                           1 /*TRUE*/,
-                                           0 /*FALSE*/,
-                                           0 /*FALSE*/,
-                                           "temp",
-                                           1 /*TRUE*/,
-                                           0 /*FALSE*/,
-                                           (2 * 2048 * 1024),
-                                           0.3,
-                                           (64 * 1024 * 1024),
-                                           (4 * 1024 * 1024),
-                                           60000,
-                                           H5C_incr__threshold,
-                                           0.8,
-                                           3.0,
-                                           1 /*TRUE*/,
-                                           (8 * 1024 * 1024),
-                                           H5C_flash_incr__add_space,
-                                           2.0,
-                                           0.25,
-                                           H5C_decr__age_out_with_threshold,
-                                           0.997,
-                                           0.8,
-                                           1 /*TRUE*/,
-                                           (3 * 1024 * 1024),
-                                           3,
-                                           0 /*FALSE*/,
-                                           0.2,
-                                           (256 * 2048),
-                                           H5AC_METADATA_WRITE_STRATEGY__PROCESS_0_ONLY};
-    H5AC_cache_image_config_t my_cache_image_config = {H5AC__CURR_CACHE_IMAGE_CONFIG_VERSION, TRUE, FALSE,
+                                                       1 /*true*/,
+                                                       0 /*false*/,
+                                                       0 /*false*/,
+                                                       "temp",
+                                                       1 /*true*/,
+                                                       0 /*false*/,
+                                                       (2 * 2048 * 1024),
+                                                       0.3,
+                                                       (64 * 1024 * 1024),
+                                                       (4 * 1024 * 1024),
+                                                       60000,
+                                                       H5C_incr__threshold,
+                                                       0.8,
+                                                       3.0,
+                                                       1 /*true*/,
+                                                       (8 * 1024 * 1024),
+                                                       H5C_flash_incr__add_space,
+                                                       2.0,
+                                                       0.25,
+                                                       H5C_decr__age_out_with_threshold,
+                                                       0.997,
+                                                       0.8,
+                                                       1 /*true*/,
+                                                       (3 * 1024 * 1024),
+                                                       3,
+                                                       0 /*false*/,
+                                                       0.2,
+                                                       (256 * 2048),
+                                                       H5AC_METADATA_WRITE_STRATEGY__PROCESS_0_ONLY};
+    H5AC_cache_image_config_t my_cache_image_config = {H5AC__CURR_CACHE_IMAGE_CONFIG_VERSION, true, false,
                                                        -1};
 
     /* check endianness */
@@ -105,7 +105,7 @@ main(void)
     if ((dcpl1 = H5Pcreate(H5P_DATASET_CREATE)) < 0)
         assert(dcpl1 > 0);
 
-    if ((ret = encode_plist(dcpl1, little_endian, word_length, "testfiles/plist_files/def_dcpl_")) < 0)
+    if ((ret = encode_plist(dcpl1, little_endian, word_length, "plist_files/def_dcpl_")) < 0)
         assert(ret > 0);
 
     if ((ret = H5Pset_chunk(dcpl1, 1, &chunk_size)) < 0)
@@ -119,20 +119,20 @@ main(void)
     if ((ret = H5Pset_fill_value(dcpl1, H5T_STD_I32BE, &fill)) < 0)
         assert(ret > 0);
 
-    if ((ret = H5Pset_dset_no_attrs_hint(dcpl1, FALSE)) < 0)
+    if ((ret = H5Pset_dset_no_attrs_hint(dcpl1, false)) < 0)
         assert(ret > 0);
 
     max_size[0] = 100;
-    if ((ret = H5Pset_external(dcpl1, "ext1.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) / 4))) < 0)
+    if ((ret = H5Pset_external(dcpl1, "ext1.data", 0, (hsize_t)(max_size[0] * sizeof(int) / 4))) < 0)
         assert(ret > 0);
-    if ((ret = H5Pset_external(dcpl1, "ext2.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) / 4))) < 0)
+    if ((ret = H5Pset_external(dcpl1, "ext2.data", 0, (hsize_t)(max_size[0] * sizeof(int) / 4))) < 0)
         assert(ret > 0);
-    if ((ret = H5Pset_external(dcpl1, "ext3.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) / 4))) < 0)
+    if ((ret = H5Pset_external(dcpl1, "ext3.data", 0, (hsize_t)(max_size[0] * sizeof(int) / 4))) < 0)
         assert(ret > 0);
-    if ((ret = H5Pset_external(dcpl1, "ext4.data", (off_t)0, (hsize_t)(max_size[0] * sizeof(int) / 4))) < 0)
+    if ((ret = H5Pset_external(dcpl1, "ext4.data", 0, (hsize_t)(max_size[0] * sizeof(int) / 4))) < 0)
         assert(ret > 0);
 
-    if ((ret = encode_plist(dcpl1, little_endian, word_length, "testfiles/plist_files/dcpl_")) < 0)
+    if ((ret = encode_plist(dcpl1, little_endian, word_length, "plist_files/dcpl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -143,13 +143,13 @@ main(void)
     if ((dapl1 = H5Pcreate(H5P_DATASET_ACCESS)) < 0)
         assert(dapl1 > 0);
 
-    if ((ret = encode_plist(dapl1, little_endian, word_length, "testfiles/plist_files/def_dapl_")) < 0)
+    if ((ret = encode_plist(dapl1, little_endian, word_length, "plist_files/def_dapl_")) < 0)
         assert(ret > 0);
 
     if ((ret = H5Pset_chunk_cache(dapl1, nslots, nbytes, w0)) < 0)
         assert(ret > 0);
 
-    if ((ret = encode_plist(dapl1, little_endian, word_length, "testfiles/plist_files/dapl_")) < 0)
+    if ((ret = encode_plist(dapl1, little_endian, word_length, "plist_files/dapl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -160,10 +160,10 @@ main(void)
     if ((dxpl1 = H5Pcreate(H5P_DATASET_XFER)) < 0)
         assert(dxpl1 > 0);
 
-    if ((ret = encode_plist(dxpl1, little_endian, word_length, "testfiles/plist_files/def_dxpl_")) < 0)
+    if ((ret = encode_plist(dxpl1, little_endian, word_length, "plist_files/def_dxpl_")) < 0)
         assert(ret > 0);
 
-    if ((ret = H5Pset_btree_ratios(dxpl1, 0.2f, 0.6f, 0.2f)) < 0)
+    if ((ret = H5Pset_btree_ratios(dxpl1, 0.2, 0.6, 0.2)) < 0)
         assert(ret > 0);
     if ((ret = H5Pset_hyper_vector_size(dxpl1, 5)) < 0)
         assert(ret > 0);
@@ -183,8 +183,13 @@ main(void)
         assert(ret > 0);
     if ((ret = H5Pset_data_transform(dxpl1, c_to_f)) < 0)
         assert(ret > 0);
+    if ((ret = H5Pset_selection_io(dxpl1, H5D_SELECTION_IO_MODE_ON)) < 0)
+        assert(ret > 0);
 
-    if ((ret = encode_plist(dxpl1, little_endian, word_length, "testfiles/plist_files/dxpl_")) < 0)
+    if ((ret = H5Pset_modify_write_buf(dxpl1, true)) < 0)
+        assert(ret > 0);
+
+    if ((ret = encode_plist(dxpl1, little_endian, word_length, "plist_files/dxpl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -195,7 +200,7 @@ main(void)
     if ((gcpl1 = H5Pcreate(H5P_GROUP_CREATE)) < 0)
         assert(gcpl1 > 0);
 
-    if ((ret = encode_plist(gcpl1, little_endian, word_length, "testfiles/plist_files/def_gcpl_")) < 0)
+    if ((ret = encode_plist(gcpl1, little_endian, word_length, "plist_files/def_gcpl_")) < 0)
         assert(ret > 0);
 
     if ((ret = H5Pset_local_heap_size_hint(gcpl1, 256)) < 0)
@@ -214,7 +219,7 @@ main(void)
     if ((ret = H5Pset_link_creation_order(gcpl1, (H5P_CRT_ORDER_TRACKED | H5P_CRT_ORDER_INDEXED))) < 0)
         assert(ret > 0);
 
-    if ((ret = encode_plist(gcpl1, little_endian, word_length, "testfiles/plist_files/gcpl_")) < 0)
+    if ((ret = encode_plist(gcpl1, little_endian, word_length, "plist_files/gcpl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -225,13 +230,13 @@ main(void)
     if ((lcpl1 = H5Pcreate(H5P_LINK_CREATE)) < 0)
         assert(lcpl1 > 0);
 
-    if ((ret = encode_plist(lcpl1, little_endian, word_length, "testfiles/plist_files/def_lcpl_")) < 0)
+    if ((ret = encode_plist(lcpl1, little_endian, word_length, "plist_files/def_lcpl_")) < 0)
         assert(ret > 0);
 
-    if ((ret = H5Pset_create_intermediate_group(lcpl1, 1 /*TRUE*/)) < 0)
+    if ((ret = H5Pset_create_intermediate_group(lcpl1, 1 /*true*/)) < 0)
         assert(ret > 0);
 
-    if ((ret = encode_plist(lcpl1, little_endian, word_length, "testfiles/plist_files/lcpl_")) < 0)
+    if ((ret = encode_plist(lcpl1, little_endian, word_length, "plist_files/lcpl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -242,7 +247,7 @@ main(void)
     if ((ocpypl1 = H5Pcreate(H5P_OBJECT_COPY)) < 0)
         assert(ocpypl1 > 0);
 
-    if ((ret = encode_plist(ocpypl1, little_endian, word_length, "testfiles/plist_files/def_ocpypl_")) < 0)
+    if ((ret = encode_plist(ocpypl1, little_endian, word_length, "plist_files/def_ocpypl_")) < 0)
         assert(ret > 0);
 
     ret = H5Pset_copy_object(ocpypl1, H5O_COPY_EXPAND_EXT_LINK_FLAG);
@@ -254,7 +259,7 @@ main(void)
     ret = H5Padd_merge_committed_dtype_path(ocpypl1, "bar");
     assert(ret >= 0);
 
-    if ((ret = encode_plist(ocpypl1, little_endian, word_length, "testfiles/plist_files/ocpypl_")) < 0)
+    if ((ret = encode_plist(ocpypl1, little_endian, word_length, "plist_files/ocpypl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -265,7 +270,7 @@ main(void)
     if ((ocpl1 = H5Pcreate(H5P_OBJECT_CREATE)) < 0)
         assert(ocpl1 > 0);
 
-    if ((ret = encode_plist(ocpl1, little_endian, word_length, "testfiles/plist_files/def_ocpl_")) < 0)
+    if ((ret = encode_plist(ocpl1, little_endian, word_length, "plist_files/def_ocpl_")) < 0)
         assert(ret > 0);
 
     if ((ret = H5Pset_attr_creation_order(ocpl1, (H5P_CRT_ORDER_TRACKED | H5P_CRT_ORDER_INDEXED))) < 0)
@@ -277,7 +282,7 @@ main(void)
     if ((ret = H5Pset_filter(ocpl1, H5Z_FILTER_FLETCHER32, 0, (size_t)0, NULL)) < 0)
         assert(ret > 0);
 
-    if ((ret = encode_plist(ocpl1, little_endian, word_length, "testfiles/plist_files/ocpl_")) < 0)
+    if ((ret = encode_plist(ocpl1, little_endian, word_length, "plist_files/ocpl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -288,7 +293,7 @@ main(void)
     if ((lapl1 = H5Pcreate(H5P_LINK_ACCESS)) < 0)
         assert(lapl1 > 0);
 
-    if ((ret = encode_plist(lapl1, little_endian, word_length, "testfiles/plist_files/def_lapl_")) < 0)
+    if ((ret = encode_plist(lapl1, little_endian, word_length, "plist_files/def_lapl_")) < 0)
         assert(ret > 0);
 
     if ((ret = H5Pset_nlinks(lapl1, (size_t)134)) < 0)
@@ -313,7 +318,7 @@ main(void)
     if ((ret = H5Pclose(fapl1)) < 0)
         assert(ret > 0);
 
-    if ((ret = encode_plist(lapl1, little_endian, word_length, "testfiles/plist_files/lapl_")) < 0)
+    if ((ret = encode_plist(lapl1, little_endian, word_length, "plist_files/lapl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -324,7 +329,7 @@ main(void)
     if ((fapl1 = H5Pcreate(H5P_FILE_ACCESS)) < 0)
         assert(fapl1 > 0);
 
-    if ((ret = encode_plist(fapl1, little_endian, word_length, "testfiles/plist_files/def_fapl_")) < 0)
+    if ((ret = encode_plist(fapl1, little_endian, word_length, "plist_files/def_fapl_")) < 0)
         assert(ret > 0);
 
     if ((ret = H5Pset_family_offset(fapl1, 1024)) < 0)
@@ -335,7 +340,7 @@ main(void)
         assert(ret > 0);
     if ((ret = H5Pset_alignment(fapl1, 2, 1024)) < 0)
         assert(ret > 0);
-    if ((ret = H5Pset_cache(fapl1, 1024, 128, 10485760, 0.3f)) < 0)
+    if ((ret = H5Pset_cache(fapl1, 1024, 128, 10485760, 0.3)) < 0)
         assert(ret > 0);
     if ((ret = H5Pset_elink_file_cache_size(fapl1, 10485760)) < 0)
         assert(ret > 0);
@@ -354,7 +359,7 @@ main(void)
     if ((ret = H5Pset_mdc_image_config(fapl1, &my_cache_image_config)) < 0)
         assert(ret > 0);
 
-    if ((ret = encode_plist(fapl1, little_endian, word_length, "testfiles/plist_files/fapl_")) < 0)
+    if ((ret = encode_plist(fapl1, little_endian, word_length, "plist_files/fapl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -365,7 +370,7 @@ main(void)
     if ((fcpl1 = H5Pcreate(H5P_FILE_CREATE)) < 0)
         assert(fcpl1 > 0);
 
-    if ((ret = encode_plist(fcpl1, little_endian, word_length, "testfiles/plist_files/def_fcpl_")) < 0)
+    if ((ret = encode_plist(fcpl1, little_endian, word_length, "plist_files/def_fcpl_")) < 0)
         assert(ret > 0);
 
     if ((ret = H5Pset_userblock(fcpl1, 1024) < 0))
@@ -389,13 +394,13 @@ main(void)
     if ((ret = H5Pset_sizes(fcpl1, 8, 4) < 0))
         assert(ret > 0);
 
-    if ((ret = H5Pset_file_space_strategy(fcpl1, H5F_FSPACE_STRATEGY_PAGE, TRUE, (hsize_t)1)) < 0)
+    if ((ret = H5Pset_file_space_strategy(fcpl1, H5F_FSPACE_STRATEGY_PAGE, true, (hsize_t)1)) < 0)
         assert(ret > 0);
 
     if ((ret = H5Pset_file_space_page_size(fcpl1, (hsize_t)4096)) < 0)
         assert(ret > 0);
 
-    if ((ret = encode_plist(fcpl1, little_endian, word_length, "testfiles/plist_files/fcpl_")) < 0)
+    if ((ret = encode_plist(fcpl1, little_endian, word_length, "plist_files/fcpl_")) < 0)
         assert(ret > 0);
 
     /* release resource */
@@ -406,13 +411,13 @@ main(void)
     strcpl1 = H5Pcreate(H5P_STRING_CREATE);
     assert(strcpl1 > 0);
 
-    ret = encode_plist(strcpl1, little_endian, word_length, "testfiles/plist_files/def_strcpl_");
+    ret = encode_plist(strcpl1, little_endian, word_length, "plist_files/def_strcpl_");
     assert(ret > 0);
 
     ret = H5Pset_char_encoding(strcpl1, H5T_CSET_UTF8);
     assert(ret >= 0);
 
-    ret = encode_plist(strcpl1, little_endian, word_length, "testfiles/plist_files/strcpl_");
+    ret = encode_plist(strcpl1, little_endian, word_length, "plist_files/strcpl_");
     assert(ret > 0);
 
     /* release resource */
@@ -423,13 +428,13 @@ main(void)
     acpl1 = H5Pcreate(H5P_ATTRIBUTE_CREATE);
     assert(acpl1 > 0);
 
-    ret = encode_plist(acpl1, little_endian, word_length, "testfiles/plist_files/def_acpl_");
+    ret = encode_plist(acpl1, little_endian, word_length, "plist_files/def_acpl_");
     assert(ret > 0);
 
     ret = H5Pset_char_encoding(acpl1, H5T_CSET_UTF8);
     assert(ret >= 0);
 
-    ret = encode_plist(acpl1, little_endian, word_length, "testfiles/plist_files/acpl_");
+    ret = encode_plist(acpl1, little_endian, word_length, "plist_files/acpl_");
     assert(ret > 0);
 
     /* release resource */
@@ -450,29 +455,29 @@ encode_plist(hid_t plist_id, int little_endian, int word_length, const char *fil
     char                          filename[1024];
 
     /* Generate filename */
-    if ((ret = HDsnprintf(filename, sizeof(filename), "%s%d%s", filename_prefix, word_length,
-                          little_endian ? "le" : "be")) < 0)
-        HDassert(ret > 0);
+    if ((ret = snprintf(filename, sizeof(filename), "%s%d%s", filename_prefix, word_length,
+                        little_endian ? "le" : "be")) < 0)
+        assert(ret > 0);
 
     /* first call to encode returns only the size of the buffer needed */
     if ((ret = H5Pencode2(plist_id, NULL, &temp_size, H5P_DEFAULT)) < 0)
-        HDassert(ret > 0);
+        assert(ret > 0);
 
-    temp_buf = (void *)HDmalloc(temp_size);
-    HDassert(temp_buf);
+    temp_buf = (void *)malloc(temp_size);
+    assert(temp_buf);
 
     if ((ret = H5Pencode2(plist_id, temp_buf, &temp_size, H5P_DEFAULT)) < 0)
-        HDassert(ret > 0);
+        assert(ret > 0);
 
     fd = HDopen(filename, O_RDWR | O_CREAT | O_TRUNC, H5_POSIX_CREATE_MODE_RW);
-    HDassert(fd >= 0);
+    assert(fd >= 0);
 
     write_size = HDwrite(fd, temp_buf, temp_size);
-    HDassert(write_size == (ssize_t)temp_size);
+    assert(write_size == (ssize_t)temp_size);
 
     HDclose(fd);
 
-    HDfree(temp_buf);
+    free(temp_buf);
 
     return 1;
 }
