@@ -1,24 +1,21 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
-/* Programmer:    Robb Matzke
- *        Friday, October 10, 1997
- *
- * Purpose:    Hyperslab operations are rather complex, so this file
- *        attempts to test them extensively so we can be relatively
- *        sure they really work.    We only test 1d, 2d, and 3d cases
- *        because testing general dimensionalities would require us to
- *        rewrite much of the hyperslab stuff.
+/*
+ * Purpose: Hyperslab operations are rather complex, so this file
+ *          attempts to test them extensively so we can be relatively
+ *          sure they really work.    We only test 1d, 2d, and 3d cases
+ *          because testing general dimensionalities would require us to
+ *          rewrite much of the hyperslab stuff.
  */
 #include "h5test.h"
 #include "H5VMprivate.h"
@@ -40,9 +37,6 @@
  *
  * Return:    void
  *
- * Programmer:    Robb Matzke
- *        Friday, October 10, 1997
- *
  *-------------------------------------------------------------------------
  */
 static unsigned
@@ -71,9 +65,6 @@ init_full(uint8_t *array, size_t nx, size_t ny, size_t nz)
  *
  * Return:    void
  *
- * Programmer:    Robb Matzke
- *        Friday, October 10, 1997
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -83,19 +74,19 @@ print_array(uint8_t *array, size_t nx, size_t ny, size_t nz)
 
     for (i = 0; i < nx; i++) {
         if (nz > 1)
-            HDprintf("i=%lu:\n", (unsigned long)i);
+            printf("i=%lu:\n", (unsigned long)i);
         else
-            HDprintf("%03lu:", (unsigned long)i);
+            printf("%03lu:", (unsigned long)i);
 
         for (j = 0; j < ny; j++) {
             if (nz > 1)
-                HDprintf("%03lu:", (unsigned long)j);
+                printf("%03lu:", (unsigned long)j);
             for (k = 0; k < nz; k++)
-                HDprintf(" %3d", *array++);
+                printf(" %3d", *array++);
             if (nz > 1)
-                HDprintf("\n");
+                printf("\n");
         } /* end for */
-        HDprintf("\n");
+        printf("\n");
     } /* end for */
 } /* end print_array() */
 
@@ -108,9 +99,6 @@ print_array(uint8_t *array, size_t nx, size_t ny, size_t nz)
  *
  *        Failure:
  *
- * Programmer:    Robb Matzke
- *        Friday, October 10, 1997
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -118,12 +106,12 @@ print_ref(size_t nx, size_t ny, size_t nz)
 {
     uint8_t *array;
 
-    if (NULL != (array = (uint8_t *)HDmalloc(nx * ny * nz))) {
-        HDprintf("Reference array:\n");
+    if (NULL != (array = (uint8_t *)malloc(nx * ny * nz))) {
+        printf("Reference array:\n");
         init_full(array, nx, ny, nz);
         print_array(array, nx, ny, nz);
-        HDfree(array);
-    } /* end if */
+        free(array);
+    }
 } /* end print_ref() */
 
 /*-------------------------------------------------------------------------
@@ -135,9 +123,6 @@ print_ref(size_t nx, size_t ny, size_t nz)
  *
  *        Failure:    FAIL
  *
- * Programmer:    Robb Matzke
- *        Saturday, October 11, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -163,25 +148,25 @@ test_fill(size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_t dk, size
         if (0 == ny) {
             ndims = 1;
             ny = nz = 1;
-            HDsprintf(dim, "%lu", (unsigned long)nx);
+            snprintf(dim, sizeof(dim), "%lu", (unsigned long)nx);
         } /* end if */
         else {
             ndims = 2;
             nz    = 1;
-            HDsprintf(dim, "%lux%lu", (unsigned long)nx, (unsigned long)ny);
+            snprintf(dim, sizeof(dim), "%lux%lu", (unsigned long)nx, (unsigned long)ny);
         } /* end else */
     }     /* end if */
     else {
         ndims = 3;
-        HDsprintf(dim, "%lux%lux%lu", (unsigned long)nx, (unsigned long)ny, (unsigned long)nz);
+        snprintf(dim, sizeof(dim), "%lux%lux%lu", (unsigned long)nx, (unsigned long)ny, (unsigned long)nz);
     } /* end else */
-    HDsprintf(s, "Testing hyperslab fill %-11s variable hyperslab", dim);
-    HDprintf("%-70s", s);
-    HDfflush(stdout);
+    snprintf(s, sizeof(s), "Testing hyperslab fill %-11s variable hyperslab", dim);
+    printf("%-70s", s);
+    fflush(stdout);
 
     /* Allocate array */
-    if (NULL == (dst = (uint8_t *)HDcalloc((size_t)1, nx * ny * nz)))
-        TEST_ERROR
+    if (NULL == (dst = (uint8_t *)calloc((size_t)1, nx * ny * nz)))
+        TEST_ERROR;
 
     init_full(dst, nx, ny, nz);
 
@@ -229,22 +214,22 @@ test_fill(size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_t dk, size
                                             acc += dst[u * ny * nz + v * nz + w];
 
                                 if (acc != ref_value) {
-                                    H5_FAILED()
+                                    H5_FAILED();
                                     if (!HDisatty(1)) {
                                         /*
                                          * Print debugging info unless output
                                          * is going directly to a terminal.
                                          */
                                         AT();
-                                        HDprintf("   acc != ref_value\n");
-                                        HDprintf("   i=%lu, j=%lu, k=%lu, "
-                                                 "dx=%lu, dy=%lu, dz=%lu, "
-                                                 "fill=%d\n",
-                                                 (unsigned long)i, (unsigned long)j, (unsigned long)k,
-                                                 (unsigned long)dx, (unsigned long)dy, (unsigned long)dz,
-                                                 fill_value);
+                                        printf("   acc != ref_value\n");
+                                        printf("   i=%lu, j=%lu, k=%lu, "
+                                               "dx=%lu, dy=%lu, dz=%lu, "
+                                               "fill=%d\n",
+                                               (unsigned long)i, (unsigned long)j, (unsigned long)k,
+                                               (unsigned long)dx, (unsigned long)dy, (unsigned long)dz,
+                                               fill_value);
                                         print_ref(nx, ny, nz);
-                                        HDprintf("\n   Result is:\n");
+                                        printf("\n   Result is:\n");
                                         print_array(dst, nx, ny, nz);
                                     } /* end if */
                                     goto error;
@@ -259,13 +244,13 @@ test_fill(size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_t dk, size
 
     PASSED();
 
-    HDfree(dst);
+    free(dst);
 
     return SUCCEED;
 
 error:
     if (dst)
-        HDfree(dst);
+        free(dst);
     return FAIL;
 } /* end test_fill() */
 
@@ -290,17 +275,14 @@ error:
  *
  *        Failure:    FAIL
  *
- * Programmer:    Robb Matzke
- *        Friday, October 10, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 test_copy(int mode, size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_t dk, size_t ddx, size_t ddy,
           size_t ddz)
 {
-    uint8_t *   src = NULL;          /*source array            */
-    uint8_t *   dst = NULL;          /*destination array        */
+    uint8_t    *src = NULL;          /*source array            */
+    uint8_t    *dst = NULL;          /*destination array        */
     hsize_t     hs_size[3];          /*hyperslab size        */
     hsize_t     dst_size[3];         /*destination total size    */
     hsize_t     src_size[3];         /*source total size        */
@@ -321,17 +303,17 @@ test_copy(int mode, size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_
         if (0 == ny) {
             ndims = 1;
             ny = nz = 1;
-            HDsprintf(dim, "%lu", (unsigned long)nx);
+            snprintf(dim, sizeof(dim), "%lu", (unsigned long)nx);
         } /* end if */
         else {
             ndims = 2;
             nz    = 1;
-            HDsprintf(dim, "%lux%lu", (unsigned long)nx, (unsigned long)ny);
+            snprintf(dim, sizeof(dim), "%lux%lu", (unsigned long)nx, (unsigned long)ny);
         } /* end else */
     }     /* end if */
     else {
         ndims = 3;
-        HDsprintf(dim, "%lux%lux%lu", (unsigned long)nx, (unsigned long)ny, (unsigned long)nz);
+        snprintf(dim, sizeof(dim), "%lux%lux%lu", (unsigned long)nx, (unsigned long)ny, (unsigned long)nz);
     } /* end else */
 
     switch (mode) {
@@ -361,20 +343,20 @@ test_copy(int mode, size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_
             break;
 
         default:
-            HDabort();
+            FAIL_PUTS_ERROR("Unhandled case");
     } /* end switch */
 
-    HDsprintf(s, "Testing hyperslab copy %-11s %s", dim, sub);
-    HDprintf("%-70s", s);
-    HDfflush(stdout);
+    snprintf(s, sizeof(s), "Testing hyperslab copy %-11s %s", dim, sub);
+    printf("%-70s", s);
+    fflush(stdout);
 
     /*
      * Allocate arrays
      */
-    if (NULL == (src = (uint8_t *)HDcalloc((size_t)1, nx * ny * nz)))
-        TEST_ERROR
-    if (NULL == (dst = (uint8_t *)HDcalloc((size_t)1, nx * ny * nz)))
-        TEST_ERROR
+    if (NULL == (src = (uint8_t *)calloc((size_t)1, nx * ny * nz)))
+        TEST_ERROR;
+    if (NULL == (dst = (uint8_t *)calloc((size_t)1, nx * ny * nz)))
+        TEST_ERROR;
 
     init_full(src, nx, ny, nz);
 
@@ -424,7 +406,7 @@ test_copy(int mode, size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_
                                     break;
 
                                 default:
-                                    HDabort();
+                                    FAIL_PUTS_ERROR("Unhandled case");
                             } /* end switch */
 
                             /*
@@ -463,20 +445,20 @@ test_copy(int mode, size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_
                                     for (w = dst_offset[2]; w < dst_offset[2] + dz; w++)
                                         acc += dst[u * ny * nz + v * nz + w];
                             if (acc != ref_value) {
-                                H5_FAILED()
+                                H5_FAILED();
                                 if (!HDisatty(1)) {
                                     /*
                                      * Print debugging info unless output is
                                      * going directly to a terminal.
                                      */
                                     AT();
-                                    HDprintf("   acc != ref_value\n");
-                                    HDprintf("   i=%lu, j=%lu, k=%lu, "
-                                             "dx=%lu, dy=%lu, dz=%lu\n",
-                                             (unsigned long)i, (unsigned long)j, (unsigned long)k,
-                                             (unsigned long)dx, (unsigned long)dy, (unsigned long)dz);
+                                    printf("   acc != ref_value\n");
+                                    printf("   i=%lu, j=%lu, k=%lu, "
+                                           "dx=%lu, dy=%lu, dz=%lu\n",
+                                           (unsigned long)i, (unsigned long)j, (unsigned long)k,
+                                           (unsigned long)dx, (unsigned long)dy, (unsigned long)dz);
                                     print_ref(nx, ny, nz);
-                                    HDprintf("\n     Destination array is:\n");
+                                    printf("\n     Destination array is:\n");
                                     print_array(dst, nx, ny, nz);
                                 } /* end if */
                                 goto error;
@@ -500,21 +482,21 @@ test_copy(int mode, size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_
                              */
                             if (acc + (unsigned)dx * (unsigned)dy * (unsigned)dz !=
                                 ref_value + nx * ny * nz) {
-                                H5_FAILED()
+                                H5_FAILED();
                                 if (!HDisatty(1)) {
                                     /*
                                      * Print debugging info unless output is
                                      * going directly to a terminal.
                                      */
                                     AT();
-                                    HDprintf("   acc != ref_value + nx*ny*nz - "
-                                             "dx*dy*dz\n");
-                                    HDprintf("   i=%lu, j=%lu, k=%lu, "
-                                             "dx=%lu, dy=%lu, dz=%lu\n",
-                                             (unsigned long)i, (unsigned long)j, (unsigned long)k,
-                                             (unsigned long)dx, (unsigned long)dy, (unsigned long)dz);
+                                    printf("   acc != ref_value + nx*ny*nz - "
+                                           "dx*dy*dz\n");
+                                    printf("   i=%lu, j=%lu, k=%lu, "
+                                           "dx=%lu, dy=%lu, dz=%lu\n",
+                                           (unsigned long)i, (unsigned long)j, (unsigned long)k,
+                                           (unsigned long)dx, (unsigned long)dy, (unsigned long)dz);
                                     print_ref(nx, ny, nz);
-                                    HDprintf("\n     Destination array is:\n");
+                                    printf("\n     Destination array is:\n");
                                     print_array(dst, nx, ny, nz);
                                 } /* end if */
                                 goto error;
@@ -528,16 +510,16 @@ test_copy(int mode, size_t nx, size_t ny, size_t nz, size_t di, size_t dj, size_
 
     PASSED();
 
-    HDfree(src);
-    HDfree(dst);
+    free(src);
+    free(dst);
 
     return SUCCEED;
 
 error:
     if (src)
-        HDfree(src);
+        free(src);
     if (dst)
-        HDfree(dst);
+        free(dst);
 
     return FAIL;
 } /* end test_copy() */
@@ -555,9 +537,6 @@ error:
  *
  *        Failure:    FAIL
  *
- * Programmer:    Robb Matzke
- *        Saturday, October 11, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -574,21 +553,21 @@ test_multifill(size_t nx)
     } fill, *src = NULL, *dst = NULL;
     hsize_t i, j;
 
-    HDprintf("%-70s", "Testing multi-byte fill value");
-    HDfflush(stdout);
+    printf("%-70s", "Testing multi-byte fill value");
+    fflush(stdout);
 
     /* Initialize the source and destination */
-    if (NULL == (src = (struct a_struct *)HDmalloc(nx * sizeof(*src))))
-        TEST_ERROR
-    if (NULL == (dst = (struct a_struct *)HDmalloc(nx * sizeof(*dst))))
-        TEST_ERROR
+    if (NULL == (src = (struct a_struct *)malloc(nx * sizeof(*src))))
+        TEST_ERROR;
+    if (NULL == (dst = (struct a_struct *)malloc(nx * sizeof(*dst))))
+        TEST_ERROR;
 
     for (i = 0; i < nx; i++) {
         src[i].left  = 1111111;
-        src[i].mid   = 12345.6789F;
+        src[i].mid   = 12345.6789;
         src[i].right = 2222222;
         dst[i].left  = 3333333;
-        dst[i].mid   = 98765.4321F;
+        dst[i].mid   = 98765.4321;
         dst[i].right = 4444444;
     } /* end for */
 
@@ -597,7 +576,7 @@ test_multifill(size_t nx)
      * over and over again.
      */
     fill.left  = 55555555;
-    fill.mid   = 3.1415927F;
+    fill.mid   = 3.1415927;
     fill.right = 66666666;
     src_stride = 0;
 
@@ -618,27 +597,27 @@ test_multifill(size_t nx)
     s[0] = '\0';
     for (i = 0; i < nx; i++) {
         if (dst[i].left != 3333333)
-            HDsprintf(s, "bad dst[%lu].left", (unsigned long)i);
+            snprintf(s, sizeof(s), "bad dst[%lu].left", (unsigned long)i);
         else if (!H5_DBL_ABS_EQUAL(dst[i].mid, fill.mid))
             /* Check if two DOUBLE values are equal.  If their difference
              * is smaller than the EPSILON value for double, they are
              * considered equal. See the definition in h5test.h.
              */
-            HDsprintf(s, "bad dst[%lu].mid", (unsigned long)i);
+            snprintf(s, sizeof(s), "bad dst[%lu].mid", (unsigned long)i);
         else if (dst[i].right != 4444444)
-            HDsprintf(s, "bad dst[%lu].right", (unsigned long)i);
+            snprintf(s, sizeof(s), "bad dst[%lu].right", (unsigned long)i);
         if (s[0]) {
-            H5_FAILED()
+            H5_FAILED();
             if (!HDisatty(1)) {
                 AT();
-                HDprintf("   fill={%d,%g,%d}\n   ", fill.left, fill.mid, fill.right);
+                printf("   fill={%d,%g,%d}\n   ", fill.left, fill.mid, fill.right);
                 for (j = 0; j < sizeof(fill); j++)
-                    HDprintf(" %02x", ((uint8_t *)&fill)[j]);
-                HDprintf("\n   dst[%lu]={%d,%g,%d}\n   ", (unsigned long)i, dst[i].left, dst[i].mid,
-                         dst[i].right);
+                    printf(" %02x", ((uint8_t *)&fill)[j]);
+                printf("\n   dst[%lu]={%d,%g,%d}\n   ", (unsigned long)i, dst[i].left, dst[i].mid,
+                       dst[i].right);
                 for (j = 0; j < sizeof(dst[i]); j++)
-                    HDprintf(" %02x", ((uint8_t *)(dst + i))[j]);
-                HDprintf("\n");
+                    printf(" %02x", ((uint8_t *)(dst + i))[j]);
+                printf("\n");
             } /* end if */
             goto error;
         } /* end if */
@@ -646,16 +625,16 @@ test_multifill(size_t nx)
 
     PASSED();
 
-    HDfree(src);
-    HDfree(dst);
+    free(src);
+    free(dst);
 
     return SUCCEED;
 
 error:
     if (src)
-        HDfree(src);
+        free(src);
     if (dst)
-        HDfree(dst);
+        free(dst);
 
     return FAIL;
 } /* end test_multifill() */
@@ -671,9 +650,6 @@ error:
  *
  *        Failure:    FAIL
  *
- * Programmer:    Robb Matzke
- *        Saturday, October 11, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -686,14 +662,14 @@ test_endian(size_t nx)
     hsize_t  size[2];       /*size vector            */
     hsize_t  i, j;
 
-    HDprintf("%-70s", "Testing endian conversion by stride");
-    HDfflush(stdout);
+    printf("%-70s", "Testing endian conversion by stride");
+    fflush(stdout);
 
     /* Initialize arrays */
-    if (NULL == (src = (uint8_t *)HDmalloc(nx * 4)))
-        TEST_ERROR
-    if (NULL == (dst = (uint8_t *)HDcalloc(nx, (size_t)4)))
-        TEST_ERROR
+    if (NULL == (src = (uint8_t *)malloc(nx * 4)))
+        TEST_ERROR;
+    if (NULL == (dst = (uint8_t *)calloc(nx, (size_t)4)))
+        TEST_ERROR;
 
     init_full(src, nx, (size_t)4, (size_t)1);
 
@@ -712,17 +688,17 @@ test_endian(size_t nx)
     for (i = 0; i < nx; i++) {
         for (j = 0; j < 4; j++) {
             if (src[i * 4 + j] != dst[i * 4 + 3 - j]) {
-                H5_FAILED()
+                H5_FAILED();
                 if (!HDisatty(1)) {
                     /*
                      * Print debugging info unless output is going directly
                      * to a terminal.
                      */
                     AT();
-                    HDprintf("   i=%lu, j=%lu\n", (unsigned long)i, (unsigned long)j);
-                    HDprintf("   Source array is:\n");
+                    printf("   i=%lu, j=%lu\n", (unsigned long)i, (unsigned long)j);
+                    printf("   Source array is:\n");
                     print_array(src, nx, (size_t)4, (size_t)1);
-                    HDprintf("\n     Result is:\n");
+                    printf("\n     Result is:\n");
                     print_array(dst, nx, (size_t)4, (size_t)1);
                 } /* end if */
                 goto error;
@@ -732,16 +708,16 @@ test_endian(size_t nx)
 
     PASSED();
 
-    HDfree(src);
-    HDfree(dst);
+    free(src);
+    free(dst);
 
     return SUCCEED;
 
 error:
     if (src)
-        HDfree(src);
+        free(src);
     if (dst)
-        HDfree(dst);
+        free(dst);
 
     return FAIL;
 } /* end test_endian() */
@@ -756,30 +732,27 @@ error:
  *
  *        Failure:    FAIL
  *
- * Programmer:    Robb Matzke
- *        Saturday, October 11, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 test_transpose(size_t nx, size_t ny)
 {
-    int *   src = NULL;
-    int *   dst = NULL;
+    int    *src = NULL;
+    int    *dst = NULL;
     hsize_t src_stride[2], dst_stride[2];
     hsize_t size[2];
     char    s[256];
     hsize_t i, j;
 
-    HDsprintf(s, "Testing 2d transpose by stride %4lux%-lud", (unsigned long)nx, (unsigned long)ny);
-    HDprintf("%-70s", s);
-    HDfflush(stdout);
+    snprintf(s, sizeof(s), "Testing 2d transpose by stride %4lux%-lud", (unsigned long)nx, (unsigned long)ny);
+    printf("%-70s", s);
+    fflush(stdout);
 
     /* Initialize */
-    if (NULL == (src = (int *)HDmalloc(nx * ny * sizeof(*src))))
-        TEST_ERROR
-    if (NULL == (dst = (int *)HDcalloc(nx * ny, sizeof(*dst))))
-        TEST_ERROR
+    if (NULL == (src = (int *)malloc(nx * ny * sizeof(*src))))
+        TEST_ERROR;
+    if (NULL == (dst = (int *)calloc(nx * ny, sizeof(*dst))))
+        TEST_ERROR;
 
     for (i = 0; i < nx; i++)
         for (j = 0; j < ny; j++)
@@ -800,23 +773,23 @@ test_transpose(size_t nx, size_t ny)
     for (i = 0; i < nx; i++) {
         for (j = 0; j < ny; j++) {
             if (src[i * ny + j] != dst[j * nx + i]) {
-                H5_FAILED()
+                H5_FAILED();
                 if (!HDisatty(1)) {
                     AT();
-                    HDprintf("   diff at i=%lu, j=%lu\n", (unsigned long)i, (unsigned long)j);
-                    HDprintf("   Source is:\n");
+                    printf("   diff at i=%lu, j=%lu\n", (unsigned long)i, (unsigned long)j);
+                    printf("   Source is:\n");
                     for (i = 0; i < nx; i++) {
-                        HDprintf("%3lu:", (unsigned long)i);
+                        printf("%3lu:", (unsigned long)i);
                         for (j = 0; j < ny; j++)
-                            HDprintf(" %6d", src[i * ny + j]);
-                        HDprintf("\n");
+                            printf(" %6d", src[i * ny + j]);
+                        printf("\n");
                     } /* end for */
-                    HDprintf("\n     Destination is:\n");
+                    printf("\n     Destination is:\n");
                     for (i = 0; i < ny; i++) {
-                        HDprintf("%3lu:", (unsigned long)i);
+                        printf("%3lu:", (unsigned long)i);
                         for (j = 0; j < nx; j++)
-                            HDprintf(" %6d", dst[i * nx + j]);
-                        HDprintf("\n");
+                            printf(" %6d", dst[i * nx + j]);
+                        printf("\n");
                     } /* end for */
                 }     /* end if */
                 goto error;
@@ -826,16 +799,16 @@ test_transpose(size_t nx, size_t ny)
 
     PASSED();
 
-    HDfree(src);
-    HDfree(dst);
+    free(src);
+    free(dst);
 
     return SUCCEED;
 
 error:
     if (src)
-        HDfree(src);
+        free(src);
     if (dst)
-        HDfree(dst);
+        free(dst);
 
     return FAIL;
 } /* end test_transpose() */
@@ -852,9 +825,6 @@ error:
  *
  *        Failure:    FAIL
  *
- * Programmer:    Robb Matzke
- *        Monday, October 13, 1997
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -869,18 +839,18 @@ test_sub_super(size_t nx, size_t ny)
     hsize_t  i, j;
     char     s[256];
 
-    HDsprintf(s, "Testing image sampling %4lux%-4lu to %4lux%-4lu ", (unsigned long)(2 * nx),
-              (unsigned long)(2 * ny), (unsigned long)nx, (unsigned long)ny);
-    HDprintf("%-70s", s);
-    HDfflush(stdout);
+    snprintf(s, sizeof(s), "Testing image sampling %4lux%-4lu to %4lux%-4lu ", (unsigned long)(2 * nx),
+             (unsigned long)(2 * ny), (unsigned long)nx, (unsigned long)ny);
+    printf("%-70s", s);
+    fflush(stdout);
 
     /* Initialize */
-    if (NULL == (full = (uint8_t *)HDmalloc(4 * nx * ny)))
-        TEST_ERROR
-    if (NULL == (half = (uint8_t *)HDcalloc((size_t)1, nx * ny)))
-        TEST_ERROR
-    if (NULL == (twice = (uint8_t *)HDcalloc((size_t)4, nx * ny)))
-        TEST_ERROR
+    if (NULL == (full = (uint8_t *)malloc(4 * nx * ny)))
+        TEST_ERROR;
+    if (NULL == (half = (uint8_t *)calloc((size_t)1, nx * ny)))
+        TEST_ERROR;
+    if (NULL == (twice = (uint8_t *)calloc((size_t)4, nx * ny)))
+        TEST_ERROR;
 
     init_full(full, 2 * nx, 2 * ny, (size_t)1);
 
@@ -899,14 +869,14 @@ test_sub_super(size_t nx, size_t ny)
     for (i = 0; i < nx; i++) {
         for (j = 0; j < ny; j++) {
             if (full[4 * i * ny + 2 * j] != half[i * ny + j]) {
-                H5_FAILED()
+                H5_FAILED();
                 if (!HDisatty(1)) {
                     AT();
-                    HDprintf("   full[%lu][%lu] != half[%lu][%lu]\n", (unsigned long)i * 2,
-                             (unsigned long)j * 2, (unsigned long)i, (unsigned long)j);
-                    HDprintf("   full is:\n");
+                    printf("   full[%lu][%lu] != half[%lu][%lu]\n", (unsigned long)i * 2,
+                           (unsigned long)j * 2, (unsigned long)i, (unsigned long)j);
+                    printf("   full is:\n");
                     print_array(full, 2 * nx, 2 * ny, (size_t)1);
-                    HDprintf("\n     half is:\n");
+                    printf("\n     half is:\n");
                     print_array(half, nx, ny, (size_t)1);
                 } /* end if */
                 goto error;
@@ -919,10 +889,10 @@ test_sub_super(size_t nx, size_t ny)
      * Test replicating pixels to produce an image twice as large in each
      * dimension.
      */
-    HDsprintf(s, "Testing image sampling %4lux%-4lu to %4lux%-4lu ", (unsigned long)nx, (unsigned long)ny,
-              (unsigned long)(2 * nx), (unsigned long)(2 * ny));
-    HDprintf("%-70s", s);
-    HDfflush(stdout);
+    snprintf(s, sizeof(s), "Testing image sampling %4lux%-4lu to %4lux%-4lu ", (unsigned long)nx,
+             (unsigned long)ny, (unsigned long)(2 * nx), (unsigned long)(2 * ny));
+    printf("%-70s", s);
+    fflush(stdout);
 
     /* Setup stride */
     size[0]       = nx;
@@ -946,24 +916,24 @@ test_sub_super(size_t nx, size_t ny)
     for (i = 0; i < nx; i++) {
         for (j = 0; j < ny; j++) {
             if (half[i * ny + j] != twice[4 * i * ny + 2 * j])
-                HDsprintf(s, "half[%lu][%lu] != twice[%lu][%lu]", (unsigned long)i, (unsigned long)j,
-                          (unsigned long)i * 2, (unsigned long)j * 2);
+                snprintf(s, sizeof(s), "half[%lu][%lu] != twice[%lu][%lu]", (unsigned long)i,
+                         (unsigned long)j, (unsigned long)i * 2, (unsigned long)j * 2);
             else if (half[i * ny + j] != twice[4 * i * ny + 2 * j + 1])
-                HDsprintf(s, "half[%lu][%lu] != twice[%lu][%lu]", (unsigned long)i, (unsigned long)j,
-                          (unsigned long)i * 2, (unsigned long)j * 2 + 1);
+                snprintf(s, sizeof(s), "half[%lu][%lu] != twice[%lu][%lu]", (unsigned long)i,
+                         (unsigned long)j, (unsigned long)i * 2, (unsigned long)j * 2 + 1);
             else if (half[i * ny + j] != twice[(2 * i + 1) * 2 * ny + 2 * j])
-                HDsprintf(s, "half[%lu][%lu] != twice[%lu][%lu]", (unsigned long)i, (unsigned long)j,
-                          (unsigned long)i * 2 + 1, (unsigned long)j * 2);
+                snprintf(s, sizeof(s), "half[%lu][%lu] != twice[%lu][%lu]", (unsigned long)i,
+                         (unsigned long)j, (unsigned long)i * 2 + 1, (unsigned long)j * 2);
             else if (half[i * ny + j] != twice[(2 * i + 1) * 2 * ny + 2 * j + 1])
-                HDsprintf(s, "half[%lu][%lu] != twice[%lu][%lu]", (unsigned long)i, (unsigned long)j,
-                          (unsigned long)i * 2 + 1, (unsigned long)j * 2 + 1);
+                snprintf(s, sizeof(s), "half[%lu][%lu] != twice[%lu][%lu]", (unsigned long)i,
+                         (unsigned long)j, (unsigned long)i * 2 + 1, (unsigned long)j * 2 + 1);
             if (s[0]) {
-                H5_FAILED()
+                H5_FAILED();
                 if (!HDisatty(1)) {
                     AT();
-                    HDprintf("   %s\n   Half is:\n", s);
+                    printf("   %s\n   Half is:\n", s);
                     print_array(half, nx, ny, (size_t)1);
-                    HDprintf("\n     Twice is:\n");
+                    printf("\n     Twice is:\n");
                     print_array(twice, 2 * nx, 2 * ny, (size_t)1);
                 } /* end if */
                 goto error;
@@ -973,19 +943,19 @@ test_sub_super(size_t nx, size_t ny)
 
     PASSED();
 
-    HDfree(full);
-    HDfree(half);
-    HDfree(twice);
+    free(full);
+    free(half);
+    free(twice);
 
     return SUCCEED;
 
 error:
     if (full)
-        HDfree(full);
+        free(full);
     if (half)
-        HDfree(half);
+        free(half);
     if (twice)
-        HDfree(twice);
+        free(twice);
 
     return FAIL;
 } /* test_sub_super() */
@@ -1001,25 +971,22 @@ error:
  *
  *        Failure:    FAIL
  *
- * Programmer:    Quincey Koziol
- *        Monday, April 21, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
 test_array_fill(size_t lo, size_t hi)
 {
-    int *  dst = NULL;           /* Destination                  */
+    int   *dst = NULL;           /* Destination                  */
     int    src[ARRAY_FILL_SIZE]; /* Source to duplicate    */
     size_t u, v, w;              /* Local index variables        */
     char   s[256];
 
-    HDsprintf(s, "array filling %4lu-%-4lu elements", (unsigned long)lo, (unsigned long)hi);
+    snprintf(s, sizeof(s), "array filling %4lu-%-4lu elements", (unsigned long)lo, (unsigned long)hi);
     TESTING(s);
 
     /* Initialize */
-    if (NULL == (dst = (int *)HDcalloc(sizeof(int), ARRAY_FILL_SIZE * hi)))
-        TEST_ERROR
+    if (NULL == (dst = (int *)calloc((ARRAY_FILL_SIZE * hi), sizeof(int))))
+        TEST_ERROR;
 
     /* Setup */
     for (u = 0; u < ARRAY_FILL_SIZE; u++)
@@ -1033,20 +1000,20 @@ test_array_fill(size_t lo, size_t hi)
         for (u = 0; u < w; u++)
             for (v = 0; v < ARRAY_FILL_SIZE; v++)
                 if (dst[(u * ARRAY_FILL_SIZE) + v] != src[v])
-                    TEST_ERROR
+                    TEST_ERROR;
 
-        HDmemset(dst, 0, sizeof(int) * ARRAY_FILL_SIZE * w);
+        memset(dst, 0, sizeof(int) * ARRAY_FILL_SIZE * w);
     } /* end for */
 
     PASSED();
 
-    HDfree(dst);
+    free(dst);
 
     return SUCCEED;
 
 error:
     if (dst)
-        HDfree(dst);
+        free(dst);
     return FAIL;
 } /* end test_array_fill() */
 
@@ -1061,9 +1028,6 @@ error:
  *
  *        Failure:    FAIL
  *
- * Programmer:    Quincey Koziol
- *        Monday, April 21, 2003
- *
  *-------------------------------------------------------------------------
  */
 static herr_t
@@ -1078,13 +1042,13 @@ test_array_offset_n_calc(size_t n, size_t x, size_t y, size_t z)
     hsize_t  new_coords[ARRAY_OFFSET_NDIMS]; /* X, Y & X coordinates of offset */
     char     s[256];
 
-    HDsprintf(s, "array offset %4lux%4lux%4lu elements", (unsigned long)z, (unsigned long)y,
-              (unsigned long)x);
+    snprintf(s, sizeof(s), "array offset %4lux%4lux%4lu elements", (unsigned long)z, (unsigned long)y,
+             (unsigned long)x);
     TESTING(s);
 
     /* Initialize */
-    if (NULL == (a = (hsize_t *)HDmalloc(sizeof(hsize_t) * x * y * z)))
-        TEST_ERROR
+    if (NULL == (a = (hsize_t *)malloc(sizeof(hsize_t) * x * y * z)))
+        TEST_ERROR;
 
     dims[0] = z;
     dims[1] = y;
@@ -1099,39 +1063,39 @@ test_array_offset_n_calc(size_t n, size_t x, size_t y, size_t z)
     /* Check offsets */
     for (u = 0; u < n; u++) {
         /* Get random coordinate */
-        coords[0] = (hsize_t)((size_t)HDrandom() % z);
-        coords[1] = (hsize_t)((size_t)HDrandom() % y);
-        coords[2] = (hsize_t)((size_t)HDrandom() % x);
+        coords[0] = (hsize_t)((size_t)rand() % z);
+        coords[1] = (hsize_t)((size_t)rand() % y);
+        coords[2] = (hsize_t)((size_t)rand() % x);
 
         /* Get offset of coordinate */
         off = H5VM_array_offset(ARRAY_OFFSET_NDIMS, dims, coords);
 
         /* Check offset of coordinate */
         if (a[off] != off)
-            TEST_ERROR
+            TEST_ERROR;
 
         /* Get coordinates of offset */
         if (H5VM_array_calc(off, ARRAY_OFFSET_NDIMS, dims, new_coords) < 0)
-            TEST_ERROR
+            TEST_ERROR;
 
         /* Check computed coordinates */
         for (v = 0; v < ARRAY_OFFSET_NDIMS; v++)
             if (coords[v] != new_coords[v]) {
-                HDfprintf(stderr, "coords[%zu]=%" PRIuHSIZE ", new_coords[%zu]=%" PRIuHSIZE "\n", v,
-                          coords[v], v, new_coords[v]);
+                fprintf(stderr, "coords[%zu]=%" PRIuHSIZE ", new_coords[%zu]=%" PRIuHSIZE "\n", v, coords[v],
+                        v, new_coords[v]);
                 TEST_ERROR;
             } /* end if */
     }         /* end for */
 
     PASSED();
 
-    HDfree(a);
+    free(a);
 
     return SUCCEED;
 
 error:
     if (a)
-        HDfree(a);
+        free(a);
 
     return FAIL;
 } /* end test_array_offset_n_calc() */
@@ -1145,9 +1109,6 @@ error:
  *
  * Return:      EXIT_SUCCESS/EXIT_FAILURE
  *
- * Programmer:    Robb Matzke
- *        Friday, October 10, 1997
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -1164,34 +1125,34 @@ main(int argc, char *argv[])
         int i;
 
         for (i = 1, size_of_test = 0; i < argc; i++) {
-            if (!HDstrcmp(argv[i], "small"))
+            if (!strcmp(argv[i], "small"))
                 size_of_test |= TEST_SMALL;
-            else if (!HDstrcmp(argv[i], "medium"))
+            else if (!strcmp(argv[i], "medium"))
                 size_of_test |= TEST_MEDIUM;
             else {
-                HDprintf("unrecognized argument: %s\n", argv[i]);
-                HDexit(EXIT_FAILURE);
+                printf("unrecognized argument: %s\n", argv[i]);
+                exit(EXIT_FAILURE);
             } /* end else */
         }     /* end for */
     }         /* end else */
 
-    HDprintf("Test sizes: ");
+    printf("Test sizes: ");
     if (size_of_test & TEST_SMALL)
-        HDprintf(" SMALL");
+        printf(" SMALL");
     if (size_of_test & TEST_MEDIUM)
-        HDprintf(" MEDIUM");
-    HDprintf("\n");
+        printf(" MEDIUM");
+    printf("\n");
 
     /* Set the random # seed */
-    HDsrandom((unsigned)HDtime(NULL));
+    srand((unsigned)time(NULL));
 
     /*
      * Open the library explicitly for thread-safe builds, so per-thread
      * things are initialized correctly.
      */
-#ifdef H5_HAVE_THREADSAFE
+#ifdef H5_HAVE_THREADSAFE_API
     H5open();
-#endif /* H5_HAVE_THREADSAFE */
+#endif /* H5_HAVE_THREADSAFE_API */
 
     /*
      *------------------------------
@@ -1384,17 +1345,17 @@ main(int argc, char *argv[])
     /*--- END OF TESTS ---*/
 
     if (nerrors) {
-        HDprintf("***** %d HYPERSLAB TEST%s FAILED! *****\n", nerrors, 1 == nerrors ? "" : "S");
+        printf("***** %d HYPERSLAB TEST%s FAILED! *****\n", nerrors, 1 == nerrors ? "" : "S");
         if (HDisatty(1))
-            HDprintf("(Redirect output to a pager or a file to see debug output)\n");
-        HDexit(EXIT_FAILURE);
+            printf("(Redirect output to a pager or a file to see debug output)\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
-    HDprintf("All hyperslab tests passed.\n");
+    printf("All hyperslab tests passed.\n");
 
-#ifdef H5_HAVE_THREADSAFE
+#ifdef H5_HAVE_THREADSAFE_API
     H5close();
-#endif /* H5_HAVE_THREADSAFE */
+#endif /* H5_HAVE_THREADSAFE_API */
 
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 }
