@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -2445,7 +2445,7 @@ main(int argc, char **argv)
     /* TESTS */
 
     if (nerrors == 0) {
-        H5FD_mirror_xmit_t xmit_mock; /* Re-used header in various xmit tests */
+        H5FD_mirror_xmit_t xmit_mock; /* Reused header in various xmit tests */
 
         /* Set bogus values matching expected; encoding doesn't care
          * Use sequential values to easily generate the expected buffer with a
