@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -75,7 +75,7 @@ open_skeleton(const char *filename, unsigned verbose, unsigned old)
     hsize_t  dim[2]; /* Dataspace dimensions */
     unsigned u, v;   /* Local index variable */
 
-    HDassert(filename);
+    assert(filename);
 
     /* Create file access property list */
     if ((fapl = h5_fileaccess()) < 0)
@@ -97,7 +97,7 @@ open_skeleton(const char *filename, unsigned verbose, unsigned old)
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Opening datasets\n");
+        fprintf(stderr, "Opening datasets\n");
 
     /* Open the datasets */
     for (u = 0; u < NLEVELS; u++)
@@ -146,7 +146,7 @@ remove_records(hid_t fid, unsigned verbose, unsigned long nshrinks, unsigned lon
     hsize_t       dim[2] = {1, 0}; /* Dataspace dimensions */
     unsigned long u, v;            /* Local index variables */
 
-    HDassert(fid >= 0);
+    assert(fid >= 0);
 
     /* Remove records from random datasets, according to frequency distribution */
     shrink_to_flush = flush_count;
@@ -158,7 +158,7 @@ remove_records(hid_t fid, unsigned verbose, unsigned long nshrinks, unsigned lon
         symbol = choose_dataset();
 
         /* Shrink the dataset's dataspace */
-        remove_size = (hsize_t)HDrandom() % MAX_REMOVE_SIZE + 1;
+        remove_size = (hsize_t)rand() % MAX_REMOVE_SIZE + 1;
         if (remove_size > symbol->nrecords)
             symbol->nrecords = 0;
         else
@@ -186,7 +186,7 @@ remove_records(hid_t fid, unsigned verbose, unsigned long nshrinks, unsigned lon
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Closing datasets\n");
+        fprintf(stderr, "Closing datasets\n");
 
     /* Close the datasets */
     for (u = 0; u < NLEVELS; u++)
@@ -200,19 +200,19 @@ remove_records(hid_t fid, unsigned verbose, unsigned long nshrinks, unsigned lon
 static void
 usage(void)
 {
-    HDprintf("\n");
-    HDprintf("Usage error!\n");
-    HDprintf("\n");
-    HDprintf("Usage: swmr_remove_writer [-q] [-o] [-f <# of shrinks between flushing\n");
-    HDprintf("    file contents>] [-r <random seed>] <# of shrinks>\n");
-    HDprintf("\n");
-    HDprintf("<# of shrinks between flushing file contents> should be 0 (for no\n");
-    HDprintf("flushing) or between 1 and (<# of shrinks> - 1)\n");
-    HDprintf("\n");
-    HDprintf("Defaults to verbose (no '-q' given), latest format when opening file (no '-o' given),\n");
-    HDprintf("flushing every 1000 shrinks ('-f 1000'), and will generate a random seed (no -r given).\n");
-    HDprintf("\n");
-    HDexit(EXIT_FAILURE);
+    printf("\n");
+    printf("Usage error!\n");
+    printf("\n");
+    printf("Usage: swmr_remove_writer [-q] [-o] [-f <# of shrinks between flushing\n");
+    printf("    file contents>] [-r <random seed>] <# of shrinks>\n");
+    printf("\n");
+    printf("<# of shrinks between flushing file contents> should be 0 (for no\n");
+    printf("flushing) or between 1 and (<# of shrinks> - 1)\n");
+    printf("\n");
+    printf("Defaults to verbose (no '-q' given), latest format when opening file (no '-o' given),\n");
+    printf("flushing every 1000 shrinks ('-f 1000'), and will generate a random seed (no -r given).\n");
+    printf("\n");
+    exit(EXIT_FAILURE);
 }
 
 int
@@ -238,7 +238,7 @@ main(int argc, char *argv[])
                 switch (argv[u][1]) {
                     /* # of records to write between flushing file */
                     case 'f':
-                        flush_count = HDatol(argv[u + 1]);
+                        flush_count = atol(argv[u + 1]);
                         if (flush_count < 0)
                             usage();
                         u += 2;
@@ -253,7 +253,7 @@ main(int argc, char *argv[])
                     /* Random # seed */
                     case 'r':
                         use_seed    = 1;
-                        temp        = HDatoi(argv[u + 1]);
+                        temp        = atoi(argv[u + 1]);
                         random_seed = (unsigned)temp;
                         u += 2;
                         break;
@@ -271,7 +271,7 @@ main(int argc, char *argv[])
             }     /* end if */
             else {
                 /* Get the number of records to append */
-                nshrinks = HDatol(argv[u]);
+                nshrinks = atol(argv[u]);
                 if (nshrinks <= 0)
                     usage();
 
@@ -286,9 +286,9 @@ main(int argc, char *argv[])
 
     /* Emit informational message */
     if (verbose) {
-        HDfprintf(stderr, "Parameters:\n");
-        HDfprintf(stderr, "\t# of shrinks between flushes = %ld\n", flush_count);
-        HDfprintf(stderr, "\t# of shrinks = %ld\n", nshrinks);
+        fprintf(stderr, "Parameters:\n");
+        fprintf(stderr, "\t# of shrinks between flushes = %ld\n", flush_count);
+        fprintf(stderr, "\t# of shrinks = %ld\n", nshrinks);
     } /* end if */
 
     /* Set the random seed */
@@ -297,13 +297,13 @@ main(int argc, char *argv[])
         HDgettimeofday(&t, NULL);
         random_seed = (unsigned)(t.tv_usec);
     } /* end if */
-    HDsrandom(random_seed);
+    srand(random_seed);
     /* ALWAYS emit the random seed for possible debugging */
-    HDfprintf(stderr, "Using writer random seed: %u\n", random_seed);
+    fprintf(stderr, "Using writer random seed: %u\n", random_seed);
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Generating symbol names\n");
+        fprintf(stderr, "Generating symbol names\n");
 
     /* Generate dataset names */
     if (generate_symbols() < 0)
@@ -311,12 +311,12 @@ main(int argc, char *argv[])
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Opening skeleton file: %s\n", FILENAME);
+        fprintf(stderr, "Opening skeleton file: %s\n", FILENAME);
 
     /* Open file skeleton */
     if ((fid = open_skeleton(FILENAME, verbose, old)) < 0) {
-        HDfprintf(stderr, "Error opening skeleton file!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error opening skeleton file!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Send a message to indicate "H5Fopen" is complete--releasing the file lock */
@@ -324,32 +324,32 @@ main(int argc, char *argv[])
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Removing records\n");
+        fprintf(stderr, "Removing records\n");
 
     /* Remove records from datasets */
     if (remove_records(fid, verbose, (unsigned long)nshrinks, (unsigned long)flush_count) < 0) {
-        HDfprintf(stderr, "Error removing records from datasets!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error removing records from datasets!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Releasing symbols\n");
+        fprintf(stderr, "Releasing symbols\n");
 
     /* Clean up the symbols */
     if (shutdown_symbols() < 0) {
-        HDfprintf(stderr, "Error releasing symbols!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error releasing symbols!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(stderr, "Closing objects\n");
+        fprintf(stderr, "Closing objects\n");
 
     /* Close objects opened */
     if (H5Fclose(fid) < 0) {
-        HDfprintf(stderr, "Error closing file!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error closing file!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     return 0;
