@@ -1,11 +1,10 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -36,10 +35,10 @@
 /* Local Prototypes */
 /********************/
 
-static hid_t create_file(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned random_seed);
-static int   create_datasets(hid_t fid, int comp_level, hbool_t verbose, FILE *verbose_file,
+static hid_t create_file(const char *filename, bool verbose, FILE *verbose_file, unsigned random_seed);
+static int   create_datasets(hid_t fid, int comp_level, bool verbose, FILE *verbose_file,
                              const char *index_type);
-static int   add_records(hid_t fid, hbool_t verbose, FILE *verbose_file, unsigned long nrecords,
+static int   add_records(hid_t fid, bool verbose, FILE *verbose_file, unsigned long nrecords,
                          unsigned long flush_count);
 static void  usage(void);
 
@@ -64,7 +63,7 @@ static void  usage(void);
  *-------------------------------------------------------------------------
  */
 static hid_t
-create_file(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned random_seed)
+create_file(const char *filename, bool verbose, FILE *verbose_file, unsigned random_seed)
 {
     hid_t fid;  /* File ID for new HDF5 file */
     hid_t fcpl; /* File creation property list */
@@ -72,7 +71,7 @@ create_file(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
     hid_t sid;  /* Dataspace ID */
     hid_t aid;  /* Attribute ID */
 
-    HDassert(filename);
+    assert(filename);
 
     /* Create file access property list */
     if ((fapl = h5_fileaccess()) < 0)
@@ -88,7 +87,7 @@ create_file(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Creating file without SWMR access\n");
+        fprintf(verbose_file, "Creating file without SWMR access\n");
 
     /* Create the file */
     if ((fid = H5Fcreate(filename, H5F_ACC_TRUNC, fcpl, fapl)) < 0)
@@ -136,7 +135,7 @@ create_file(const char *filename, hbool_t verbose, FILE *verbose_file, unsigned
  *-------------------------------------------------------------------------
  */
 static int
-create_datasets(hid_t fid, int comp_level, hbool_t verbose, FILE *verbose_file, const char *index_type)
+create_datasets(hid_t fid, int comp_level, bool verbose, FILE *verbose_file, const char *index_type)
 {
     hid_t    dcpl;                               /* Dataset creation property list */
     hid_t    tid;                                /* Datatype for dataset elements */
@@ -146,7 +145,7 @@ create_datasets(hid_t fid, int comp_level, hbool_t verbose, FILE *verbose_file,
     hsize_t  chunk_dims[2] = {1, CHUNK_SIZE};    /* Chunk dimensions */
     unsigned u, v;                               /* Local index variable */
 
-    HDassert(index_type);
+    assert(index_type);
 
     /* Create datatype for creating datasets */
     if ((tid = create_symbol_datatype()) < 0)
@@ -156,7 +155,7 @@ create_datasets(hid_t fid, int comp_level, hbool_t verbose, FILE *verbose_file,
      * With one unlimited dimension, we get the extensible array index
      * type, with two unlimited dimensions, we get a v-2 B-tree.
      */
-    if (!HDstrcmp(index_type, "b2"))
+    if (!strcmp(index_type, "b2"))
         max_dims[0] = H5S_UNLIMITED;
 
     /* Create dataspace for creating datasets */
@@ -175,7 +174,7 @@ create_datasets(hid_t fid, int comp_level, hbool_t verbose, FILE *verbose_file,
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Creating datasets\n");
+        fprintf(verbose_file, "Creating datasets\n");
 
     /* Create the datasets */
     for (u = 0; u < NLEVELS; u++)
@@ -210,7 +209,7 @@ create_datasets(hid_t fid, int comp_level, hbool_t verbose, FILE *verbose_file,
  *-------------------------------------------------------------------------
  */
 static int
-add_records(hid_t fid, hbool_t verbose, FILE *verbose_file, unsigned long nrecords, unsigned long flush_count)
+add_records(hid_t fid, bool verbose, FILE *verbose_file, unsigned long nrecords, unsigned long flush_count)
 {
     hid_t         tid;                                  /* Datatype ID for records */
     hid_t         mem_sid;                              /* Memory dataspace ID */
@@ -220,11 +219,11 @@ add_records(hid_t fid, hbool_t verbose, FILE *verbose_file, unsigned long nrecor
     unsigned long rec_to_flush;                         /* # of records left to write before flush */
     unsigned long u, v;                                 /* Local index variables */
 
-    HDassert(fid >= 0);
+    assert(fid >= 0);
 
     /* Reset the record */
     /* (record's 'info' field might need to change for each record written, also) */
-    HDmemset(&record, 0, sizeof(record));
+    memset(&record, 0, sizeof(record));
 
     /* Create a dataspace for the record to add */
     if ((mem_sid = H5Screate(H5S_SCALAR)) < 0)
@@ -307,7 +306,7 @@ add_records(hid_t fid, hbool_t verbose, FILE *verbose_file, unsigned long nrecor
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Closing datasets\n");
+        fprintf(verbose_file, "Closing datasets\n");
 
     /* Close the datasets */
     for (u = 0; u < NLEVELS; u++)
@@ -321,27 +320,27 @@ add_records(hid_t fid, hbool_t verbose, FILE *verbose_file, unsigned long nrecor
 static void
 usage(void)
 {
-    HDprintf("\n");
-    HDprintf("Usage error!\n");
-    HDprintf("\n");
-    HDprintf("Usage: swmr_start_write [-f <# of records to write between flushing file contents>]\n");
-    HDprintf("    [-i <index type>] [-c <deflate compression level>]\n");
-    HDprintf("    [-r <random seed>] [-q] <# of records>\n");
-    HDprintf("\n");
-    HDprintf("<# of records to write between flushing file contents> should be 0\n");
-    HDprintf("(for no flushing) or between 1 and (<# of records> - 1).\n");
-    HDprintf("\n");
-    HDprintf("<index type> should be b2 or ea\n");
-    HDprintf("\n");
-    HDprintf("<deflate compression level> should be -1 (for no compression) or 0-9\n");
-    HDprintf("\n");
-    HDprintf("<# of records> must be specified.\n");
-    HDprintf("\n");
-    HDprintf("Defaults to flushing every 10000 records ('-f 10000'),\n");
-    HDprintf("v1 b-tree indexing (-i b1), compression ('-c -1'),\n");
-    HDprintf("will generate a random seed (no -r given), and verbose (no '-q' given)\n");
-    HDprintf("\n");
-    HDexit(EXIT_FAILURE);
+    printf("\n");
+    printf("Usage error!\n");
+    printf("\n");
+    printf("Usage: swmr_start_write [-f <# of records to write between flushing file contents>]\n");
+    printf("    [-i <index type>] [-c <deflate compression level>]\n");
+    printf("    [-r <random seed>] [-q] <# of records>\n");
+    printf("\n");
+    printf("<# of records to write between flushing file contents> should be 0\n");
+    printf("(for no flushing) or between 1 and (<# of records> - 1).\n");
+    printf("\n");
+    printf("<index type> should be b2 or ea\n");
+    printf("\n");
+    printf("<deflate compression level> should be -1 (for no compression) or 0-9\n");
+    printf("\n");
+    printf("<# of records> must be specified.\n");
+    printf("\n");
+    printf("Defaults to flushing every 10000 records ('-f 10000'),\n");
+    printf("v1 b-tree indexing (-i b1), compression ('-c -1'),\n");
+    printf("will generate a random seed (no -r given), and verbose (no '-q' given)\n");
+    printf("\n");
+    exit(EXIT_FAILURE);
 } /* usage() */
 
 /*
@@ -357,9 +356,9 @@ main(int argc, char *argv[])
     hid_t       fid;                  /* File ID for file opened */
     long        nrecords     = 0;     /* # of records to append */
     long        flush_count  = 10000; /* # of records to write between flushing file */
-    hbool_t     verbose      = TRUE;  /* Whether to emit some informational messages */
-    FILE *      verbose_file = NULL;  /* File handle for verbose output */
-    hbool_t     use_seed     = FALSE; /* Set to TRUE if a seed was set on the command line */
+    bool        verbose      = true;  /* Whether to emit some informational messages */
+    FILE       *verbose_file = NULL;  /* File handle for verbose output */
+    bool        use_seed     = false; /* Set to true if a seed was set on the command line */
     unsigned    random_seed  = 0;     /* Random # seed */
     int         comp_level   = -1;    /* Compression level (-1 is no compression) */
     const char *index_type   = "b1";  /* Chunk index type */
@@ -376,7 +375,7 @@ main(int argc, char *argv[])
                 switch (argv[u][1]) {
                     /* Compress dataset chunks */
                     case 'c':
-                        comp_level = HDatoi(argv[u + 1]);
+                        comp_level = atoi(argv[u + 1]);
                         if (comp_level < -1 || comp_level > 9)
                             usage();
                         u += 2;
@@ -385,14 +384,14 @@ main(int argc, char *argv[])
                     /* Chunk index type */
                     case 'i':
                         index_type = argv[u + 1];
-                        if (HDstrcmp(index_type, "ea") != 0 && HDstrcmp(index_type, "b2") != 0)
+                        if (strcmp(index_type, "ea") != 0 && strcmp(index_type, "b2") != 0)
                             usage();
                         u += 2;
                         break;
 
                     /* # of records to write between flushing file */
                     case 'f':
-                        flush_count = HDatol(argv[u + 1]);
+                        flush_count = atol(argv[u + 1]);
                         if (flush_count < 0)
                             usage();
                         u += 2;
@@ -400,14 +399,14 @@ main(int argc, char *argv[])
 
                     /* Be quiet */
                     case 'q':
-                        verbose = FALSE;
+                        verbose = false;
                         u++;
                         break;
 
                     /* Random # seed */
                     case 'r':
-                        use_seed = TRUE;
-                        temp     = HDatoi(argv[u + 1]);
+                        use_seed = true;
+                        temp     = atoi(argv[u + 1]);
                         if (temp < 0)
                             usage();
                         else
@@ -422,7 +421,7 @@ main(int argc, char *argv[])
             }     /* end if */
             else {
                 /* Get the number of records to append */
-                nrecords = HDatol(argv[u]);
+                nrecords = atol(argv[u]);
                 if (nrecords <= 0)
                     usage();
 
@@ -443,40 +442,40 @@ main(int argc, char *argv[])
         HDgettimeofday(&t, NULL);
         random_seed = (unsigned)(t.tv_usec);
     } /* end if */
-    HDsrandom(random_seed);
+    srand(random_seed);
 
     /* Open output file */
     if (verbose) {
         char verbose_name[1024];
 
-        HDsnprintf(verbose_name, sizeof(verbose_name), "swmr_writer.out.%u", random_seed);
-        if (NULL == (verbose_file = HDfopen(verbose_name, "w"))) {
-            HDfprintf(stderr, "Can't open verbose output file!\n");
-            HDexit(EXIT_FAILURE);
+        snprintf(verbose_name, sizeof(verbose_name), "swmr_writer.out.%u", random_seed);
+        if (NULL == (verbose_file = fopen(verbose_name, "w"))) {
+            fprintf(stderr, "Can't open verbose output file!\n");
+            exit(EXIT_FAILURE);
         }
     } /* end if */
 
     /* Emit informational message */
     if (verbose) {
-        HDfprintf(verbose_file, "Parameters:\n");
-        HDfprintf(verbose_file, "\tindex type = %s\n", index_type);
-        HDfprintf(verbose_file, "\tcompression level = %d\n", comp_level);
-        HDfprintf(verbose_file, "\t# of records between flushes = %ld\n", flush_count);
-        HDfprintf(verbose_file, "\t# of records to write = %ld\n", nrecords);
+        fprintf(verbose_file, "Parameters:\n");
+        fprintf(verbose_file, "\tindex type = %s\n", index_type);
+        fprintf(verbose_file, "\tcompression level = %d\n", comp_level);
+        fprintf(verbose_file, "\t# of records between flushes = %ld\n", flush_count);
+        fprintf(verbose_file, "\t# of records to write = %ld\n", nrecords);
     } /* end if */
 
     /* ALWAYS emit the random seed for possible debugging */
-    HDfprintf(stdout, "Using writer random seed: %u\n", random_seed);
+    fprintf(stdout, "Using writer random seed: %u\n", random_seed);
 
     /* Create the test file */
     if ((fid = create_file(FILENAME, verbose, verbose_file, random_seed)) < 0) {
-        HDfprintf(stderr, "Error creating the file...\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error creating the file...\n");
+        exit(EXIT_FAILURE);
     }
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Generating symbol names\n");
+        fprintf(verbose_file, "Generating symbol names\n");
 
     /* Generate dataset names */
     if (generate_symbols() < 0)
@@ -484,14 +483,14 @@ main(int argc, char *argv[])
 
     /* Create the datasets in the file */
     if (create_datasets(fid, comp_level, verbose, verbose_file, index_type) < 0) {
-        HDfprintf(stderr, "Error creating datasets...\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error creating datasets...\n");
+        exit(EXIT_FAILURE);
     }
 
     /* Enable SWMR writing mode */
     if (H5Fstart_swmr_write(fid) < 0) {
-        HDfprintf(stderr, "Error starting SWMR writing mode...\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error starting SWMR writing mode...\n");
+        exit(EXIT_FAILURE);
     }
 
     /* Send a message to indicate "H5Fopen" is complete--releasing the file lock */
@@ -499,32 +498,32 @@ main(int argc, char *argv[])
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Adding records\n");
+        fprintf(verbose_file, "Adding records\n");
 
     /* Append records to datasets */
     if (add_records(fid, verbose, verbose_file, (unsigned long)nrecords, (unsigned long)flush_count) < 0) {
-        HDfprintf(stderr, "Error appending records to datasets!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error appending records to datasets!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Releasing symbols\n");
+        fprintf(verbose_file, "Releasing symbols\n");
 
     /* Clean up the symbols */
     if (shutdown_symbols() < 0) {
-        HDfprintf(stderr, "Error releasing symbols!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error releasing symbols!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     /* Emit informational message */
     if (verbose)
-        HDfprintf(verbose_file, "Closing the file\n");
+        fprintf(verbose_file, "Closing the file\n");
 
     /* Close objects opened */
     if (H5Fclose(fid) < 0) {
-        HDfprintf(stderr, "Error closing file!\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "Error closing file!\n");
+        exit(EXIT_FAILURE);
     } /* end if */
 
     return 0;
