@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -42,14 +42,20 @@ test_h5o_open(void)
 {
     hid_t       fid;                      /* HDF5 File ID      */
     hid_t       grp, dset, dtype, dspace; /* Object identifiers */
+    char        filename[1024];
     hsize_t     dims[RANK];
     H5I_type_t  id_type;    /* Type of IDs returned from H5Oopen */
     H5G_info_t  ginfo;      /* Group info struct */
     H5T_class_t type_class; /* Class of the datatype */
     herr_t      ret;        /* Value returned from API calls */
 
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing H5Oopen\n"));
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
     /* Create a group, dataset, and committed datatype within the file */
@@ -154,11 +160,17 @@ test_h5o_close(void)
 {
     hid_t   fid;                      /* HDF5 File ID      */
     hid_t   grp, dset, dtype, dspace; /* Object identifiers */
+    char    filename[1024];
     hsize_t dims[RANK];
     herr_t  ret; /* Value returned from API calls */
 
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing H5Oclose\n"));
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
     /* Create a group, dataset, and committed datatype within the file */
@@ -246,20 +258,31 @@ test_h5o_open_by_addr(void)
 {
     hid_t       fid;                      /* HDF5 File ID      */
     hid_t       grp, dset, dtype, dspace; /* Object identifiers */
-    H5L_info2_t li;                       /* Buffer for H5Lget_info2 */
-    haddr_t     grp_addr;                 /* Addresses for objects */
+    char        filename[1024];
+    H5L_info2_t li;       /* Buffer for H5Lget_info2 */
+    haddr_t     grp_addr; /* Addresses for objects */
     haddr_t     dset_addr;
     haddr_t     dtype_addr;
     hsize_t     dims[RANK];
     H5I_type_t  id_type;    /* Type of IDs returned from H5Oopen */
     H5G_info_t  ginfo;      /* Group info struct */
     H5T_class_t type_class; /* Class of the datatype */
-    herr_t      ret;        /* Value returned from API calls */
+    bool        vol_is_native;
+    herr_t      ret; /* Value returned from API calls */
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
 
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(H5P_DEFAULT, fid, &vol_is_native), FAIL, "h5_using_native_vol");
+    if (!vol_is_native) {
+        CHECK(H5Fclose(fid), FAIL, "H5Fclose");
+        return;
+    }
+
     /* Create a group, dataset, and committed datatype within the file */
     /* Create the group */
     grp = H5Gcreate2(fid, "group", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
@@ -396,15 +419,21 @@ test_h5o_open_by_token(void)
 {
     hid_t       fid;                      /* HDF5 File ID      */
     hid_t       grp, dset, dtype, dspace; /* Object identifiers */
-    H5L_info2_t li;                       /* Buffer for H5Lget_info */
+    char        filename[1024];
+    H5L_info2_t li; /* Buffer for H5Lget_info */
     hsize_t     dims[RANK];
     H5I_type_t  id_type;    /* Type of IDs returned from H5Oopen */
     H5G_info_t  ginfo;      /* Group info struct */
     H5T_class_t type_class; /* Class of the datatype */
     herr_t      ret;        /* Value returned from API calls */
 
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing H5Oopen_by_token\n"));
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
     /* Create a group, dataset, and committed datatype within the file */
@@ -514,12 +543,19 @@ test_h5o_refcount(void)
 {
     hid_t       fid;                      /* HDF5 File ID      */
     hid_t       grp, dset, dtype, dspace; /* Object identifiers */
-    H5O_info2_t oinfo;                    /* Object info struct */
+    char        filename[1024];
+    H5O_info2_t oinfo; /* Object info struct */
+    H5L_info2_t linfo; /* Buffer for H5Lget_info */
     hsize_t     dims[RANK];
     herr_t      ret; /* Value returned from API calls */
 
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing retrieval of object reference count with H5Oget_info\n"));
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
     /* Create a group, dataset, and committed datatype within the file */
@@ -533,6 +569,10 @@ test_h5o_refcount(void)
     ret = H5Tcommit2(fid, "datatype", dtype, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(ret, FAIL, "H5Tcommit2");
 
+    /* Test passing a datatype ID to H5Lget_info2, it should not fail */
+    ret = H5Lget_info2(dtype, "/datatype", &linfo, H5P_DEFAULT);
+    CHECK(ret, FAIL, "H5Lget_info2");
+
     /* Create the data space for the dataset. */
     dims[0] = DIM0;
     dims[1] = DIM1;
@@ -611,7 +651,7 @@ test_h5o_refcount(void)
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Re-open the file and check that the reference counts were really incremented */
-    fid = H5Fopen(TEST_FILENAME, H5F_ACC_RDWR, H5P_DEFAULT);
+    fid = H5Fopen(filename, H5F_ACC_RDWR, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fopen");
 
     grp = H5Gopen2(fid, "group", H5P_DEFAULT);
@@ -649,7 +689,7 @@ test_h5o_refcount(void)
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Re-open the file and check that the reference counts were really decremented */
-    fid = H5Fopen(TEST_FILENAME, H5F_ACC_RDWR, H5P_DEFAULT);
+    fid = H5Fopen(filename, H5F_ACC_RDWR, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fopen");
 
     grp = H5Gopen2(fid, "group", H5P_DEFAULT);
@@ -708,14 +748,19 @@ test_h5o_refcount(void)
 static void
 test_h5o_plist(void)
 {
-    hid_t    fid;                            /* HDF5 File ID      */
-    hid_t    grp, dset, dtype, dspace;       /* Object identifiers */
-    hid_t    fapl;                           /* File access property list */
-    hid_t    gcpl, dcpl, tcpl;               /* Object creation properties */
+    hid_t    fid;                      /* HDF5 File ID      */
+    hid_t    grp, dset, dtype, dspace; /* Object identifiers */
+    hid_t    fapl;                     /* File access property list */
+    hid_t    gcpl, dcpl, tcpl;         /* Object creation properties */
+    hid_t    bad_pl = H5I_INVALID_HID; /* Invalid property list dues to invalid arg */
+    char     filename[1024];
     unsigned def_max_compact, def_min_dense; /* Default phase change parameters */
     unsigned max_compact, min_dense;         /* Actual phase change parameters */
     herr_t   ret;                            /* Value returned from API calls */
 
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing Object creation properties\n"));
+
     /* Make a FAPL that uses the "use the latest version of the format" flag */
     fapl = H5Pcreate(H5P_FILE_ACCESS);
     CHECK(fapl, FAIL, "H5Pcreate");
@@ -724,8 +769,10 @@ test_h5o_plist(void)
     ret = H5Pset_libver_bounds(fapl, H5F_LIBVER_LATEST, H5F_LIBVER_LATEST);
     CHECK(ret, FAIL, "H5Pset_libver_bounds");
 
+    h5_fixname(TEST_FILENAME, fapl, filename, sizeof filename);
+
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, fapl);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl);
     CHECK(fid, FAIL, "H5Fcreate");
 
     /* Create group, dataset & named datatype creation property lists */
@@ -808,6 +855,14 @@ test_h5o_plist(void)
     dcpl = H5Dget_create_plist(dset);
     CHECK(dcpl, FAIL, "H5Dget_create_plist");
 
+    /* Test passing in a non-group identifier to the H5G API */
+    H5E_BEGIN_TRY
+    {
+        bad_pl = H5Gget_create_plist(dtype);
+    }
+    H5E_END_TRY
+    VERIFY(bad_pl, H5I_INVALID_HID, "H5Gget_create_plist");
+
     /* Retrieve attribute phase change values on each creation property list and verify */
     ret = H5Pget_attr_phase_change(gcpl, &max_compact, &min_dense);
     CHECK(ret, FAIL, "H5Pget_attr_phase_change");
@@ -839,7 +894,7 @@ test_h5o_plist(void)
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Re-open the file and check that the object creation properties persist */
-    fid = H5Fopen(TEST_FILENAME, H5F_ACC_RDONLY, fapl);
+    fid = H5Fopen(filename, H5F_ACC_RDONLY, fapl);
     CHECK(fid, FAIL, "H5Fopen");
 
     /* Re-open objects */
@@ -901,14 +956,15 @@ test_h5o_plist(void)
 static void
 test_h5o_link(void)
 {
-    hid_t        file_id  = -1;
-    hid_t        group_id = -1;
-    hid_t        space_id = -1;
-    hid_t        dset_id  = -1;
-    hid_t        type_id  = -1;
-    hid_t        fapl_id  = -1;
-    hid_t        lcpl_id  = -1;
-    hsize_t      dims[2]  = {TEST6_DIM1, TEST6_DIM2};
+    hid_t        file_id  = H5I_INVALID_HID;
+    hid_t        group_id = H5I_INVALID_HID;
+    hid_t        space_id = H5I_INVALID_HID;
+    hid_t        dset_id  = H5I_INVALID_HID;
+    hid_t        type_id  = H5I_INVALID_HID;
+    hid_t        fapl_id  = H5I_INVALID_HID;
+    hid_t        lcpl_id  = H5I_INVALID_HID;
+    char         filename[1024];
+    hsize_t      dims[2] = {TEST6_DIM1, TEST6_DIM2};
     htri_t       committed; /* Whether the named datatype is committed */
     H5F_libver_t low, high; /* File format bounds */
     int         *wdata;
@@ -916,12 +972,17 @@ test_h5o_link(void)
     int          i, n;
     herr_t       ret; /* Value returned from API calls */
 
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing H5Olink\n"));
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
     /* Allocate memory buffers */
     /* (These are treated as 2-D buffers) */
-    wdata = (int *)HDmalloc((size_t)(TEST6_DIM1 * TEST6_DIM2) * sizeof(int));
-    CHECK_PTR(wdata, "HDmalloc");
-    rdata = (int *)HDmalloc((size_t)(TEST6_DIM1 * TEST6_DIM2) * sizeof(int));
-    CHECK_PTR(rdata, "HDmalloc");
+    wdata = (int *)malloc((size_t)(TEST6_DIM1 * TEST6_DIM2) * sizeof(int));
+    CHECK_PTR(wdata, "malloc");
+    rdata = (int *)malloc((size_t)(TEST6_DIM1 * TEST6_DIM2) * sizeof(int));
+    CHECK_PTR(rdata, "malloc");
 
     /* Initialize the raw data */
     for (i = n = 0; i < (TEST6_DIM1 * TEST6_DIM2); i++)
@@ -934,7 +995,7 @@ test_h5o_link(void)
     /* Create LCPL with intermediate group creation flag set */
     lcpl_id = H5Pcreate(H5P_LINK_CREATE);
     CHECK(lcpl_id, FAIL, "H5Pcreate");
-    ret = H5Pset_create_intermediate_group(lcpl_id, TRUE);
+    ret = H5Pset_create_intermediate_group(lcpl_id, true);
     CHECK(ret, FAIL, "H5Pset_create_intermediate_group");
 
     /* Create a file access property list */
@@ -950,13 +1011,13 @@ test_h5o_link(void)
             {
                 ret = H5Pset_libver_bounds(fapl_id, low, high);
             }
-            H5E_END_TRY;
+            H5E_END_TRY
 
             if (ret < 0) /* Invalid low/high combinations */
                 continue;
 
             /* Create a new HDF5 file */
-            file_id = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
+            file_id = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
             CHECK(file_id, FAIL, "H5Fcreate");
 
             /* Close the FAPL */
@@ -969,7 +1030,7 @@ test_h5o_link(void)
             ret = H5Tcommit_anon(file_id, type_id, H5P_DEFAULT, H5P_DEFAULT);
             CHECK(ret, FAIL, "H5Tcommit_anon");
             committed = H5Tcommitted(type_id);
-            VERIFY(committed, TRUE, "H5Tcommitted");
+            VERIFY(committed, true, "H5Tcommitted");
 
             /* Create a dataset with no name using the committed datatype*/
             dset_id = H5Dcreate_anon(file_id, type_id, space_id, H5P_DEFAULT, H5P_DEFAULT);
@@ -1044,8 +1105,8 @@ test_h5o_link(void)
     CHECK(ret, FAIL, "H5Pclose");
 
     /* Release buffers */
-    HDfree(wdata);
-    HDfree(rdata);
+    free(wdata);
+    free(rdata);
 } /* end test_h5o_link() */
 
 /****************************************************************
@@ -1059,6 +1120,7 @@ test_h5o_comment(void)
     hid_t       fid;                      /* HDF5 File ID      */
     hid_t       grp, dset, dtype, dspace; /* Object identifiers */
     hid_t       attr_space, attr_id;
+    char        filename[1024];
     hsize_t     dims[RANK];
     hsize_t     attr_dims     = 1;
     int         attr_value    = 5;
@@ -1069,13 +1131,23 @@ test_h5o_comment(void)
     char        check_comment[64];
     ssize_t     comment_len = 0;
     ssize_t     len;
+    bool        vol_is_native;
     herr_t      ret; /* Value returned from API calls */
     int         ret_value;
 
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(H5P_DEFAULT, fid, &vol_is_native), FAIL, "h5_using_native_vol");
+    if (!vol_is_native) {
+        CHECK(H5Fclose(fid), FAIL, "H5Fclose");
+        return;
+    }
+
     /* Create an attribute for the file */
     attr_space = H5Screate_simple(1, &attr_dims, NULL);
     CHECK(attr_space, FAIL, "H5Screate_simple");
@@ -1138,7 +1210,7 @@ test_h5o_comment(void)
     {
         ret = H5Oset_comment(dspace, "dataspace comment");
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Oset_comment");
 
     /* Close the file */
@@ -1151,17 +1223,18 @@ test_h5o_comment(void)
 
     /* Now make sure that the comments are correct all 4 types of objects */
     /* Open file */
-    fid = H5Fopen(TEST_FILENAME, H5F_ACC_RDONLY, H5P_DEFAULT);
+    fid = H5Fopen(filename, H5F_ACC_RDONLY, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fopen");
 
     /* Getting the comment on the file and verify it */
     comment_len = H5Oget_comment(fid, NULL, (size_t)0);
     CHECK(comment_len, FAIL, "H5Oget_comment");
+    VERIFY(comment_len, strlen(file_comment), "H5Oget_comment");
 
     len = H5Oget_comment(fid, check_comment, (size_t)comment_len + 1);
     CHECK(len, FAIL, "H5Oget_comment");
 
-    ret_value = HDstrcmp(file_comment, check_comment);
+    ret_value = strcmp(file_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment");
 
     /* Open the group */
@@ -1174,8 +1247,9 @@ test_h5o_comment(void)
 
     len = H5Oget_comment(grp, check_comment, (size_t)comment_len + 1);
     CHECK(len, FAIL, "H5Oget_comment");
+    VERIFY(len, strlen(grp_comment), "H5Oget_comment");
 
-    ret_value = HDstrcmp(grp_comment, check_comment);
+    ret_value = strcmp(grp_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment");
 
     /* Open the datatype */
@@ -1185,11 +1259,12 @@ test_h5o_comment(void)
     /* Getting the comment on the datatype and verify it */
     comment_len = H5Oget_comment(dtype, NULL, (size_t)0);
     CHECK(comment_len, FAIL, "H5Oget_comment");
+    VERIFY(comment_len, strlen(dtype_comment), "H5Oget_comment");
 
     len = H5Oget_comment(dtype, check_comment, (size_t)comment_len + 1);
     CHECK(len, FAIL, "H5Oget_comment");
 
-    ret_value = HDstrcmp(dtype_comment, check_comment);
+    ret_value = strcmp(dtype_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment");
 
     /* Open the dataset */
@@ -1202,8 +1277,9 @@ test_h5o_comment(void)
 
     len = H5Oget_comment(dset, check_comment, (size_t)comment_len + 1);
     CHECK(ret, len, "H5Oget_comment");
+    VERIFY(len, strlen(dset_comment), "H5Oget_comment");
 
-    ret_value = HDstrcmp(dset_comment, check_comment);
+    ret_value = strcmp(dset_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment");
 
     /* Close the IDs */
@@ -1231,6 +1307,7 @@ test_h5o_comment_by_name(void)
     hid_t       fid;                      /* HDF5 File ID      */
     hid_t       grp, dset, dtype, dspace; /* Object identifiers */
     hid_t       attr_space, attr_id;
+    char        filename[1024];
     hsize_t     dims[RANK];
     hsize_t     attr_dims     = 1;
     int         attr_value    = 5;
@@ -1241,13 +1318,23 @@ test_h5o_comment_by_name(void)
     char        check_comment[64];
     ssize_t     comment_len = 0;
     ssize_t     len;
+    bool        vol_is_native;
     herr_t      ret; /* Value returned from API calls */
     int         ret_value;
 
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(H5P_DEFAULT, fid, &vol_is_native), FAIL, "h5_using_native_vol");
+    if (!vol_is_native) {
+        CHECK(H5Fclose(fid), FAIL, "H5Fclose");
+        return;
+    }
+
     /* Create an attribute for the file */
     attr_space = H5Screate_simple(1, &attr_dims, NULL);
     CHECK(attr_space, FAIL, "H5Screate_simple");
@@ -1310,7 +1397,7 @@ test_h5o_comment_by_name(void)
     {
         ret = H5Oset_comment_by_name(dspace, ".", "dataspace comment", H5P_DEFAULT);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VERIFY(ret, FAIL, "H5Oset_comment");
 
     /* Close the file */
@@ -1323,7 +1410,7 @@ test_h5o_comment_by_name(void)
 
     /* Now make sure that the comments are correct all 4 types of objects */
     /* Open file */
-    fid = H5Fopen(TEST_FILENAME, H5F_ACC_RDONLY, H5P_DEFAULT);
+    fid = H5Fopen(filename, H5F_ACC_RDONLY, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fopen");
 
     /* Getting the comment on the file and verify it */
@@ -1332,8 +1419,9 @@ test_h5o_comment_by_name(void)
 
     len = H5Oget_comment_by_name(fid, ".", check_comment, (size_t)comment_len + 1, H5P_DEFAULT);
     CHECK(len, FAIL, "H5Oget_comment_by_name");
+    VERIFY(len, strlen(file_comment), "H5Oget_comment");
 
-    ret_value = HDstrcmp(file_comment, check_comment);
+    ret_value = strcmp(file_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment_by_name");
 
     /* Open the group */
@@ -1347,7 +1435,7 @@ test_h5o_comment_by_name(void)
     len = H5Oget_comment_by_name(fid, "group", check_comment, (size_t)comment_len + 1, H5P_DEFAULT);
     CHECK(len, FAIL, "H5Oget_comment_by_name");
 
-    ret_value = HDstrcmp(grp_comment, check_comment);
+    ret_value = strcmp(grp_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment_by_name");
 
     /* Getting the comment on the datatype and verify it */
@@ -1357,7 +1445,7 @@ test_h5o_comment_by_name(void)
     len = H5Oget_comment_by_name(grp, "datatype", check_comment, (size_t)comment_len + 1, H5P_DEFAULT);
     CHECK(len, FAIL, "H5Oget_comment");
 
-    ret_value = HDstrcmp(dtype_comment, check_comment);
+    ret_value = strcmp(dtype_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment_by_name");
 
     /* Getting the comment on the dataset and verify it */
@@ -1367,7 +1455,7 @@ test_h5o_comment_by_name(void)
     len = H5Oget_comment_by_name(fid, "dataset", check_comment, (size_t)comment_len + 1, H5P_DEFAULT);
     CHECK(len, FAIL, "H5Oget_comment_by_name");
 
-    ret_value = HDstrcmp(dset_comment, check_comment);
+    ret_value = strcmp(dset_comment, check_comment);
     VERIFY(ret_value, 0, "H5Oget_comment_by_name");
 
     /* Close the IDs */
@@ -1389,13 +1477,19 @@ test_h5o_comment_by_name(void)
 static void
 test_h5o_getinfo_same_file(void)
 {
-    hid_t       fid1, fid2;     /* HDF5 File ID */
-    hid_t       gid1, gid2;     /* Group IDs */
+    hid_t       fid1, fid2; /* HDF5 File ID */
+    hid_t       gid1, gid2; /* Group IDs */
+    char        filename[1024];
     H5O_info2_t oinfo1, oinfo2; /* Object info structs */
     herr_t      ret;            /* Value returned from API calls */
 
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing H5Oget_info on objects in same file\n"));
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
     /* Create a new HDF5 file */
-    fid1 = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid1 = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid1, FAIL, "H5Fcreate");
 
     /* Create two groups in the file */
@@ -1405,8 +1499,8 @@ test_h5o_getinfo_same_file(void)
     CHECK(gid2, FAIL, "H5Gcreate2");
 
     /* Reset object info */
-    HDmemset(&oinfo1, 0, sizeof(oinfo1));
-    HDmemset(&oinfo2, 0, sizeof(oinfo2));
+    memset(&oinfo1, 0, sizeof(oinfo1));
+    memset(&oinfo2, 0, sizeof(oinfo2));
 
     /* Query the object info for each object, through group IDs */
     ret = H5Oget_info3(gid1, &oinfo1, H5O_INFO_BASIC);
@@ -1417,8 +1511,8 @@ test_h5o_getinfo_same_file(void)
     VERIFY(oinfo1.fileno, oinfo2.fileno, "file number from H5Oget_info3");
 
     /* Reset object info */
-    HDmemset(&oinfo1, 0, sizeof(oinfo1));
-    HDmemset(&oinfo2, 0, sizeof(oinfo2));
+    memset(&oinfo1, 0, sizeof(oinfo1));
+    memset(&oinfo2, 0, sizeof(oinfo2));
 
     /* Query the object info for each object, by name */
     ret = H5Oget_info_by_name3(fid1, "group1", &oinfo1, H5O_INFO_BASIC, H5P_DEFAULT);
@@ -1437,9 +1531,9 @@ test_h5o_getinfo_same_file(void)
     CHECK(ret, FAIL, "H5Fclose");
 
     /* Open file twice */
-    fid1 = H5Fopen(TEST_FILENAME, H5F_ACC_RDWR, H5P_DEFAULT);
+    fid1 = H5Fopen(filename, H5F_ACC_RDWR, H5P_DEFAULT);
     CHECK(fid1, FAIL, "H5Fopen");
-    fid2 = H5Fopen(TEST_FILENAME, H5F_ACC_RDWR, H5P_DEFAULT);
+    fid2 = H5Fopen(filename, H5F_ACC_RDWR, H5P_DEFAULT);
     CHECK(fid2, FAIL, "H5Fopen");
 
     /* Open the two groups in the file */
@@ -1449,8 +1543,8 @@ test_h5o_getinfo_same_file(void)
     CHECK(gid2, FAIL, "H5Gopen2");
 
     /* Reset object info */
-    HDmemset(&oinfo1, 0, sizeof(oinfo1));
-    HDmemset(&oinfo2, 0, sizeof(oinfo2));
+    memset(&oinfo1, 0, sizeof(oinfo1));
+    memset(&oinfo2, 0, sizeof(oinfo2));
 
     /* Query the object info for each object, through group IDs */
     ret = H5Oget_info3(gid1, &oinfo1, H5O_INFO_BASIC);
@@ -1461,8 +1555,8 @@ test_h5o_getinfo_same_file(void)
     VERIFY(oinfo1.fileno, oinfo2.fileno, "file number from H5Oget_info3");
 
     /* Reset object info */
-    HDmemset(&oinfo1, 0, sizeof(oinfo1));
-    HDmemset(&oinfo2, 0, sizeof(oinfo2));
+    memset(&oinfo1, 0, sizeof(oinfo1));
+    memset(&oinfo2, 0, sizeof(oinfo2));
 
     /* Query the object info for each object, by name */
     ret = H5Oget_info_by_name3(fid1, "group1", &oinfo1, H5O_INFO_BASIC, H5P_DEFAULT);
@@ -1496,20 +1590,31 @@ test_h5o_open_by_addr_deprec(void)
 {
     hid_t       fid;                      /* HDF5 File ID      */
     hid_t       grp, dset, dtype, dspace; /* Object identifiers */
-    H5L_info1_t li;                       /* Buffer for H5Lget_info1 */
-    haddr_t     grp_addr;                 /* Addresses for objects */
+    char        filename[1024];
+    H5L_info1_t li;       /* Buffer for H5Lget_info1 */
+    haddr_t     grp_addr; /* Addresses for objects */
     haddr_t     dset_addr;
     haddr_t     dtype_addr;
     hsize_t     dims[RANK];
     H5I_type_t  id_type;    /* Type of IDs returned from H5Oopen */
     H5G_info_t  ginfo;      /* Group info struct */
     H5T_class_t type_class; /* Class of the datatype */
-    herr_t      ret;        /* Value returned from API calls */
+    bool        vol_is_native;
+    herr_t      ret; /* Value returned from API calls */
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
 
     /* Create a new HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(H5P_DEFAULT, fid, &vol_is_native), FAIL, "h5_using_native_vol");
+    if (!vol_is_native) {
+        CHECK(H5Fclose(fid), FAIL, "H5Fclose");
+        return;
+    }
+
     /* Create a group, dataset, and committed datatype within the file */
     /* Create the group */
     grp = H5Gcreate2(fid, "group", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
@@ -1645,16 +1750,16 @@ visit_obj_cb(hid_t group_id, const char *name, const H5O_info1_t *oinfo1, void H
     H5O_info1_t oinfo2; /* Object info structs */
 
     /* Verify the object info for "group1", "group2" and the root group */
-    if (!(HDstrcmp(name, "group1"))) {
+    if (!(strcmp(name, "group1"))) {
         H5Oget_info_by_name2(group_id, name, &oinfo2, H5O_INFO_NUM_ATTRS, H5P_DEFAULT);
         VERIFY(oinfo1->num_attrs, oinfo2.num_attrs, "obj info from H5Ovisit1");
     }
-    else if (!(HDstrcmp(name, "group2"))) {
+    else if (!(strcmp(name, "group2"))) {
         H5Oget_info_by_name2(group_id, name, &oinfo2, H5O_INFO_HDR, H5P_DEFAULT);
         VERIFY(oinfo1->hdr.nmesgs, oinfo2.hdr.nmesgs, "obj info from H5Ovisit1/H5Oget_info2");
         VERIFY(oinfo1->hdr.nchunks, oinfo2.hdr.nchunks, "obj info from H5Ovisit1/H5Oget_info2");
     }
-    else if (!(HDstrcmp(name, "."))) {
+    else if (!(strcmp(name, "."))) {
         H5Oget_info_by_name2(group_id, name, &oinfo2, H5O_INFO_META_SIZE, H5P_DEFAULT);
         VERIFY(oinfo1->meta_size.obj.index_size, oinfo2.meta_size.obj.index_size,
                "obj info from H5Ovisit1/H5Oget_info2");
@@ -1677,19 +1782,34 @@ visit_obj_cb(hid_t group_id, const char *name, const H5O_info1_t *oinfo1, void H
 static void
 test_h5o_getinfo_visit(void)
 {
-    hid_t       fid  = -1;            /* HDF5 File ID */
-    hid_t       gid1 = -1, gid2 = -1; /* Group IDs */
-    hid_t       sid = -1;             /* Dataspace ID */
-    hid_t       aid = -1;             /* Attribute ID */
-    H5O_info1_t oinfo1, oinfo2;       /* Object info structs */
-    char        attrname[25];         /* Attribute name */
-    int         j;                    /* Local index variable */
-    herr_t      ret;                  /* Value returned from API calls */
+    hid_t       fid  = H5I_INVALID_HID;                         /* HDF5 File ID */
+    hid_t       gid1 = H5I_INVALID_HID, gid2 = H5I_INVALID_HID; /* Group IDs */
+    hid_t       sid = H5I_INVALID_HID;                          /* Dataspace ID */
+    hid_t       aid = H5I_INVALID_HID;                          /* Attribute ID */
+    char        filename[1024];
+    H5O_info1_t oinfo1, oinfo2; /* Object info structs */
+    char        attrname[25];   /* Attribute name */
+    int         j;              /* Local index variable */
+    bool        vol_is_native;
+    herr_t      ret; /* Value returned from API calls */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing info returned by H5Oget_info vs H5Ovisit\n"));
+
+    h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
 
     /* Create an HDF5 file */
-    fid = H5Fcreate(TEST_FILENAME, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(fid, FAIL, "H5Fcreate");
 
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(H5P_DEFAULT, fid, &vol_is_native), FAIL, "h5_using_native_vol");
+    if (!vol_is_native) {
+        CHECK(H5Fclose(fid), FAIL, "H5Fclose");
+        MESSAGE(5, (" -- SKIPPED --\n"));
+        return;
+    }
+
     /* Create "group1" in the file */
     gid1 = H5Gcreate2(fid, "group1", H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
     CHECK(gid1, FAIL, "H5Gcreate2");
@@ -1701,7 +1821,7 @@ test_h5o_getinfo_visit(void)
     /* Attach 10 attributes to "group1" */
     for (j = 0; j < 10; j++) {
         /* Create the attribute name */
-        HDsprintf(attrname, "attr%u", j);
+        snprintf(attrname, sizeof(attrname), "attr%u", j);
         /* Create the attribute */
         aid = H5Acreate2(gid1, attrname, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT);
         CHECK(aid, FAIL, "H5Acreate2");
@@ -1715,8 +1835,8 @@ test_h5o_getinfo_visit(void)
     CHECK(gid2, FAIL, "H5Gcreate2");
 
     /* Reset object info */
-    HDmemset(&oinfo1, 0, sizeof(oinfo1));
-    HDmemset(&oinfo2, 0, sizeof(oinfo2));
+    memset(&oinfo1, 0, sizeof(oinfo1));
+    memset(&oinfo2, 0, sizeof(oinfo2));
 
     /* Query the object info for "group1" via H5Oget_info1 and H5Oget_info2 */
     ret = H5Oget_info1(gid1, &oinfo1);
@@ -1729,8 +1849,8 @@ test_h5o_getinfo_visit(void)
     VERIFY(oinfo1.num_attrs, oinfo2.num_attrs, "obj info from H5Oget_info1/2");
 
     /* Reset object info */
-    HDmemset(&oinfo1, 0, sizeof(oinfo1));
-    HDmemset(&oinfo2, 0, sizeof(oinfo2));
+    memset(&oinfo1, 0, sizeof(oinfo1));
+    memset(&oinfo2, 0, sizeof(oinfo2));
 
     /* Query the object info for "group2" via H5Oget_info1 and H5Oget_info2 */
     ret = H5Oget_info_by_name1(fid, "group2", &oinfo1, H5P_DEFAULT);
@@ -1759,6 +1879,164 @@ test_h5o_getinfo_visit(void)
 
 } /* test_h5o_getinfo_visit() */
 
+#define G1              "g1"           /* Group /g1 */
+#define G1G2            "g1/g2"        /* Group /g1/g2 */
+#define ATTR1           "Attr1"        /* Attribute Attr1 */
+#define D1G1G2          "/g1/g2/dset1" /* Dataset /g1/g2/dset1 */
+#define NUM_OBJS        4              /* Number of objects including root group */
+#define NUM_ATTRS       1              /* Number of attributes belong to root group */
+#define VISIT2_FILENAME "th5o_visit2"
+
+typedef struct {
+    unsigned idx;    /* Index in object visit structure */
+    unsigned fields; /* Fields to verify number of attributes in callback */
+} ovisit2_ud_t;
+
+/* Names of objects being visited, in this order */
+static const char *visited_objs[] = {".", "g1", "g1/g2", "g1/g2/dset1"};
+
+/****************************************************************
+**
+**  visit_obj_cb():
+**      This is the callback function invoked by H5Ovisit1() in
+**      test_h5o_getinfo_visit():
+**      --Verify that the object info returned to the callback
+**        function is the same as H5Oget_info2().
+**
+****************************************************************/
+static int
+visit2_obj_cb(hid_t obj_id, const char *name, const H5O_info1_t H5_ATTR_UNUSED *info, void *_op_data)
+{
+    H5O_info1_t oinfo;
+
+    memset(&oinfo, 0, sizeof(oinfo));
+    ovisit2_ud_t *op_data = (ovisit2_ud_t *)_op_data;
+
+    if (strcmp(visited_objs[op_data->idx], name) != 0)
+        return H5_ITER_ERROR;
+
+    if (H5Oget_info2(obj_id, &oinfo, op_data->fields) < 0)
+        return H5_ITER_ERROR;
+
+    if (op_data->fields == H5O_INFO_NUM_ATTRS)
+        if (oinfo.num_attrs != NUM_ATTRS)
+            return H5_ITER_ERROR;
+
+    /* Advance to next location in expected output */
+    op_data->idx++;
+
+    return H5_ITER_CONT;
+}
+
+/****************************************************************
+**
+**  test_h5o_visit2():
+**    Verify that H5Ovisit2 visits the nested groups and objects
+**    instead of only root group.
+**
+****************************************************************/
+static void
+test_h5o_visit2(void)
+{
+    hid_t           fid  = H5I_INVALID_HID;                         /* HDF5 File ID */
+    hid_t           gid1 = H5I_INVALID_HID, gid2 = H5I_INVALID_HID; /* Group IDs */
+    hid_t           sid   = H5I_INVALID_HID;                        /* Dataspace ID */
+    hid_t           did   = H5I_INVALID_HID;                        /* Dataset ID */
+    hid_t           attid = H5I_INVALID_HID;                        /* Attribute ID */
+    hid_t           obj_id;                                         /* Object ID for root group */
+    char            filename[1024];                                 /* File used in this test */
+    ovisit2_ud_t    udata;                                          /* User-data for visiting */
+    unsigned        fields;                                         /* Fields to return */
+    H5_index_t      idx_type = H5_INDEX_NAME;
+    H5_iter_order_t order    = H5_ITER_DEC;
+    bool            vol_is_native;
+    herr_t          ret; /* Value returned from API calls */
+
+    /* Output message about test being performed */
+    MESSAGE(5, ("Testing H5Ovisit2 visits all nested groups and objects\n"));
+
+    h5_fixname(VISIT2_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+
+    /* Create an HDF5 file */
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(fid, FAIL, "H5Fcreate");
+
+    /* Check if native VOL is being used */
+    CHECK(h5_using_native_vol(H5P_DEFAULT, fid, &vol_is_native), FAIL, "h5_using_native_vol");
+    if (!vol_is_native) {
+        CHECK(H5Fclose(fid), FAIL, "H5Fclose");
+        MESSAGE(5, (" -- SKIPPED --\n"));
+        return;
+    }
+
+    /* Create group G1 in the file */
+    gid1 = H5Gcreate2(fid, G1, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(gid1, FAIL, "H5Gcreate2");
+
+    /* Create group G1G2 in the file */
+    gid2 = H5Gcreate2(fid, G1G2, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(gid2, FAIL, "H5Gcreate2");
+
+    /* Create dataspace */
+    sid = H5Screate(H5S_SCALAR);
+    CHECK(sid, FAIL, "H5Screate");
+
+    did = H5Dcreate2(gid2, D1G1G2, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(did, FAIL, "H5Dcreate2");
+
+    /* Add an attribute to verify H5O_get_info with H5O_INFO_NUM_ATTRS works */
+    attid = H5Acreate2(fid, ATTR1, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT);
+    CHECK(attid, FAIL, "H5Acreate2");
+
+    H5Aclose(attid);
+    H5Dclose(did);
+    H5Gclose(gid2);
+    H5Gclose(gid1);
+
+    /* Open root object */
+    obj_id = H5Oopen(fid, "/", H5P_DEFAULT);
+    CHECK(obj_id, FAIL, "H5Oopen");
+
+    /* Visit root with H5O_INFO_META_SIZE */
+    udata.idx = 0; /* first object, i.e., root group */
+    fields = udata.fields = H5O_INFO_META_SIZE;
+    ret                   = H5Ovisit2(obj_id, idx_type, order, visit2_obj_cb, &udata, fields);
+    CHECK(ret, FAIL, "H5Ovisit2");
+
+    /* Verify that all objects were visitted */
+    VERIFY(udata.idx, NUM_OBJS, "idx should be the same as NUM_OBJS");
+
+    /* Visit root with H5O_INFO_BASIC */
+    udata.idx = 0; /* first object, i.e., root group */
+    fields = udata.fields = H5O_INFO_BASIC;
+    ret                   = H5Ovisit2(obj_id, idx_type, order, visit2_obj_cb, &udata, fields);
+    CHECK(ret, FAIL, "H5Ovisit2");
+
+    /* Verify that all objects were visitted */
+    VERIFY(udata.idx, NUM_OBJS, "idx should be the same as NUM_OBJS");
+
+    /* Visit root with H5O_INFO_ALL */
+    udata.idx = 0; /* first object, i.e., root group */
+    fields = udata.fields = H5O_INFO_ALL;
+    ret                   = H5Ovisit2(obj_id, idx_type, order, visit2_obj_cb, &udata, fields);
+    CHECK(ret, FAIL, "H5Ovisit2");
+
+    /* Visit root with H5O_INFO_NUM_ATTRS */
+    udata.idx = 0; /* first object, i.e., root group */
+    fields = udata.fields = H5O_INFO_NUM_ATTRS;
+    ret                   = H5Ovisit2(obj_id, idx_type, order, visit2_obj_cb, &udata, fields);
+    CHECK(ret, FAIL, "H5Ovisit2");
+
+    /* Verify that all objects were visitted */
+    VERIFY(udata.idx, NUM_OBJS, "idx should be the same as NUM_OBJS");
+
+    /* Close object and file */
+    ret = H5Oclose(obj_id);
+    CHECK(ret, FAIL, "H5Oclose");
+    ret = H5Fclose(fid);
+    CHECK(ret, FAIL, "H5Fclose");
+}
+
 #endif /* H5_NO_DEPRECATED_SYMBOLS */
 
 /****************************************************************
@@ -1767,7 +2045,7 @@ test_h5o_getinfo_visit(void)
 **
 ****************************************************************/
 void
-test_h5o(void)
+test_h5o(void H5_ATTR_UNUSED *params)
 {
     /* Output message about test being performed */
     MESSAGE(5, ("Testing Objects\n"));
@@ -1787,6 +2065,7 @@ test_h5o(void)
 #ifndef H5_NO_DEPRECATED_SYMBOLS
     test_h5o_open_by_addr_deprec(); /* Test opening objects by address with H5Lget_info1 */
     test_h5o_getinfo_visit();       /* Test object info for H5Oget_info1/2 and H5Ovisit1 */
+    test_h5o_visit2();              /* Test behavior of H5Ovisit2 */
 #endif                              /* H5_NO_DEPRECATED_SYMBOLS */
 } /* test_h5o() */
 
@@ -1797,13 +2076,23 @@ test_h5o(void)
  *
  * Return:    none
  *
- * Programmer:    James Laird
- *              June 3, 2006
- *
  *-------------------------------------------------------------------------
  */
 void
-cleanup_h5o(void)
+cleanup_h5o(void H5_ATTR_UNUSED *params)
 {
-    HDremove(TEST_FILENAME);
+    if (GetTestCleanup()) {
+        char filename[1024];
+
+        H5E_BEGIN_TRY
+        {
+            h5_fixname(TEST_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+            H5Fdelete(filename, H5P_DEFAULT);
+#ifndef H5_NO_DEPRECATED_SYMBOLS
+            h5_fixname(VISIT2_FILENAME, H5P_DEFAULT, filename, sizeof filename);
+            H5Fdelete(filename, H5P_DEFAULT);
+#endif /* H5_NO_DEPRECATED_SYMBOLS */
+        }
+        H5E_END_TRY
+    }
 }
