@@ -1,11 +1,10 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -22,31 +21,31 @@
 #include "testhdf5.h"
 #include "H5Fprivate.h"
 
-#define TEST_INT16_VALUE  -7641
+#define TEST_INT16_VALUE  (-7641)
 #define TEST_UINT16_VALUE 45002
-#define TEST_INT32_VALUE  -981236
+#define TEST_INT32_VALUE  (-981236)
 #define TEST_UINT32_VALUE 3476589
 
-uint8_t compar_buffer[] = {
+static uint8_t compar_buffer[] = {
     /* Little-endian encoded version of the 16-bit signed integer */
-    (uint8_t)((TEST_INT16_VALUE)&0xff),
+    (uint8_t)((TEST_INT16_VALUE) & 0xff),
     (uint8_t)((TEST_INT16_VALUE >> 8) & 0xff),
     /* Little-endian encoded version of the 16-bit unsigned integer */
-    (uint8_t)((TEST_UINT16_VALUE)&0xff),
+    (uint8_t)((TEST_UINT16_VALUE) & 0xff),
     (uint8_t)((TEST_UINT16_VALUE >> 8) & 0xff),
     /* Little-endian encoded version of the 32-bit signed integer */
-    (uint8_t)((TEST_INT32_VALUE)&0xff),
+    (uint8_t)((TEST_INT32_VALUE) & 0xff),
     (uint8_t)((TEST_INT32_VALUE >> 8) & 0xff),
     (uint8_t)((TEST_INT32_VALUE >> 16) & 0xff),
     (uint8_t)((TEST_INT32_VALUE >> 24) & 0xff),
     /* Little-endian encoded version of the 32-bit unsigned integer */
-    (uint8_t)((TEST_UINT32_VALUE)&0xff),
+    (uint8_t)((TEST_UINT32_VALUE) & 0xff),
     (uint8_t)((TEST_UINT32_VALUE >> 8) & 0xff),
     (uint8_t)((TEST_UINT32_VALUE >> 16) & 0xff),
     (uint8_t)((TEST_UINT32_VALUE >> 24) & 0xff),
 };
 
-uint8_t encode_buffer[sizeof(compar_buffer)];
+static uint8_t encode_buffer[sizeof(compar_buffer)];
 
 /****************************************************************
 **
@@ -54,7 +53,7 @@ uint8_t encode_buffer[sizeof(compar_buffer)];
 **
 ****************************************************************/
 void
-test_metadata(void)
+test_metadata(void H5_ATTR_UNUSED *params)
 {
     int16_t  ei16 = TEST_INT16_VALUE; /* variables to hold the values to encode */
     uint16_t eu16 = TEST_UINT16_VALUE;
@@ -77,7 +76,7 @@ test_metadata(void)
     UINT32ENCODE(p, eu32); /* Encode the uint32 value */
 
     /* Check if we got what we asked for */
-    if (HDmemcmp(encode_buffer, compar_buffer, sizeof(compar_buffer)) != 0) {
+    if (memcmp(encode_buffer, compar_buffer, sizeof(compar_buffer)) != 0) {
         unsigned u; /* local counting variable */
 
         for (u = 0; u < sizeof(compar_buffer); u++) {
@@ -119,15 +118,10 @@ test_metadata(void)
  *
  * Return:	none
  *
- * Programmer:	Albert Cheng
- *              July 2, 1998
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 void
-cleanup_metadata(void)
+cleanup_metadata(void H5_ATTR_UNUSED *params)
 {
     /* no file to clean */
 }
