@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -33,13 +33,17 @@
 #define H5MF_FRIEND /*suppress error about including H5MFpkg      */
 #include "H5MFpkg.h"
 
+#ifdef PB_OUT
 #define NUM_DSETS 5
+#endif
 
 int mpi_size, mpi_rank;
 
+#ifdef PB_OUT
 static int create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_strategy);
 static int open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t page_size,
                      size_t page_buffer_size);
+#endif
 
 /*
  * test file access by communicator besides COMM_WORLD.
@@ -53,7 +57,7 @@ static int open_file(const char *filename, hid_t fapl, int metadata_write_strate
  * sooner or later due to barrier mixed up.
  */
 void
-test_split_comm_access(void)
+test_split_comm_access(void *params)
 {
     MPI_Comm    comm;
     MPI_Info    info = MPI_INFO_NULL;
@@ -64,13 +68,25 @@ test_split_comm_access(void)
     herr_t      ret;     /* generic return value */
     const char *filename;
 
-    filename = (const char *)GetTestParameters();
+    filename = ((const H5Ptest_param_t *)params)->name;
     if (VERBOSE_MED)
-        HDprintf("Split Communicator access test on file %s\n", filename);
+        printf("Split Communicator access test on file %s\n", filename);
 
     /* set up MPI parameters */
     MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
     MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
+
+    /* Make sure the connector supports the API functions being tested */
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC)) {
+        if (MAINPROCESS) {
+            puts("SKIPPED");
+            printf("    API functions for basic file aren't supported with this connector\n");
+            fflush(stdout);
+        }
+
+        return;
+    }
+
     is_old = mpi_rank % 2;
     mrc    = MPI_Comm_split(MPI_COMM_WORLD, is_old, mpi_rank, &comm);
     VRFY((mrc == MPI_SUCCESS), "");
@@ -95,19 +111,21 @@ test_split_comm_access(void)
         fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, acc_tpl);
         VRFY((fid >= 0), "H5Fcreate succeeded");
 
-        /* Release file-access template */
-        ret = H5Pclose(acc_tpl);
-        VRFY((ret >= 0), "");
-
         /* close the file */
         ret = H5Fclose(fid);
         VRFY((ret >= 0), "");
 
         /* delete the test file */
-        if (sub_mpi_rank == 0) {
-            mrc = MPI_File_delete(filename, info);
-            /*VRFY((mrc==MPI_SUCCESS), ""); */
+        H5E_BEGIN_TRY
+        {
+            ret = H5Fdelete(filename, acc_tpl);
         }
+        H5E_END_TRY
+        VRFY((ret >= 0), "H5Fdelete succeeded");
+
+        /* Release file-access template */
+        ret = H5Pclose(acc_tpl);
+        VRFY((ret >= 0), "");
     }
     mrc = MPI_Comm_free(&comm);
     VRFY((mrc == MPI_SUCCESS), "MPI_Comm_free succeeded");
@@ -116,26 +134,34 @@ test_split_comm_access(void)
 }
 
 void
-test_page_buffer_access(void)
+test_page_buffer_access(void *params)
 {
-    hid_t       file_id = -1; /* File ID */
+    const char *filename;
+    hid_t       file_id = H5I_INVALID_HID; /* File ID */
     hid_t       fcpl, fapl;
+    herr_t      ret; /* generic return value */
+#ifdef PB_OUT
     size_t      page_count = 0;
     int         i, num_elements = 200;
     haddr_t     raw_addr, meta_addr;
     int        *data;
-    H5F_t      *f = NULL;
-    herr_t      ret; /* generic return value */
-    const char *filename;
-    hbool_t     api_ctx_pushed = FALSE; /* Whether API context pushed */
+    H5F_t      *f              = NULL;
+    H5CX_node_t api_ctx        = {{0}, NULL}; /* API context node to push */
+    bool        api_ctx_pushed = false;       /* Whether API context pushed */
+#endif
 
     MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
     MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
 
-    filename = (const char *)GetTestParameters();
+    filename = ((const H5Ptest_param_t *)params)->name;
 
+    /* Until page buffering is supported in parallel in some form (even if
+     * just for a single MPI process), this test just will just check to
+     * make sure that an error is thrown when page buffering is enabled
+     * with parallel access.
+     */
     if (VERBOSE_MED)
-        HDprintf("Page Buffer Usage in Parallel %s\n", filename);
+        printf("Page Buffer Usage in Parallel %s\n", filename);
 
     fapl = create_faccess_plist(MPI_COMM_WORLD, MPI_INFO_NULL, facc_type);
     VRFY((fapl >= 0), "create_faccess_plist succeeded");
@@ -154,13 +180,22 @@ test_page_buffer_access(void)
     {
         file_id = H5Fcreate(filename, H5F_ACC_TRUNC, fcpl, fapl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     VRFY((file_id < 0), "H5Fcreate failed");
 
     /* disable collective metadata writes for page buffering to work */
-    ret = H5Pset_coll_metadata_write(fapl, FALSE);
+    ret = H5Pset_coll_metadata_write(fapl, false);
     VRFY((ret >= 0), "");
 
+    /* This should fail due to page buffering not being supported in parallel */
+    H5E_BEGIN_TRY
+    {
+        file_id = H5Fcreate(filename, H5F_ACC_TRUNC, fcpl, fapl);
+    }
+    H5E_END_TRY
+    VRFY((file_id < 0), "H5Fcreate failed");
+
+#ifdef PB_OUT
     ret = create_file(filename, fcpl, fapl, H5AC_METADATA_WRITE_STRATEGY__DISTRIBUTED);
     VRFY((ret == 0), "");
     ret = open_file(filename, fapl, H5AC_METADATA_WRITE_STRATEGY__DISTRIBUTED, sizeof(int) * 100,
@@ -176,7 +211,7 @@ test_page_buffer_access(void)
     ret = H5Pset_file_space_page_size(fcpl, sizeof(int) * 100);
     VRFY((ret == 0), "");
 
-    data = (int *)HDmalloc(sizeof(int) * (size_t)num_elements);
+    data = (int *)malloc(sizeof(int) * (size_t)num_elements);
 
     /* initialize all the elements to have a value of -1 */
     for (i = 0; i < num_elements; i++)
@@ -188,16 +223,16 @@ test_page_buffer_access(void)
         ret = H5Pset_page_buffer_size(fapl_self, sizeof(int) * 1000, 0, 0);
         VRFY((ret == 0), "");
         /* collective metadata writes do not work with page buffering */
-        ret = H5Pset_coll_metadata_write(fapl_self, FALSE);
+        ret = H5Pset_coll_metadata_write(fapl_self, false);
         VRFY((ret >= 0), "");
 
         file_id = H5Fcreate(filename, H5F_ACC_TRUNC, fcpl, fapl_self);
         VRFY((file_id >= 0), "");
 
         /* Push API context */
-        ret = H5CX_push();
+        ret = H5CX_push(&api_ctx);
         VRFY((ret == 0), "H5CX_push()");
-        api_ctx_pushed = TRUE;
+        api_ctx_pushed = true;
 
         /* Get a pointer to the internal file object */
         f = (H5F_t *)H5I_object(file_id);
@@ -286,9 +321,9 @@ test_page_buffer_access(void)
 
         /* Pop API context */
         if (api_ctx_pushed) {
-            ret = H5CX_pop();
+            ret = H5CX_pop(false);
             VRFY((ret == 0), "H5CX_pop()");
-            api_ctx_pushed = FALSE;
+            api_ctx_pushed = false;
         }
     }
 
@@ -298,16 +333,16 @@ test_page_buffer_access(void)
         ret = H5Pset_page_buffer_size(fapl, sizeof(int) * 1000, 0, 0);
         VRFY((ret == 0), "");
         /* collective metadata writes do not work with page buffering */
-        ret = H5Pset_coll_metadata_write(fapl, FALSE);
+        ret = H5Pset_coll_metadata_write(fapl, false);
         VRFY((ret >= 0), "");
 
         file_id = H5Fcreate(filename, H5F_ACC_TRUNC, fcpl, fapl);
         VRFY((file_id >= 0), "");
 
         /* Push API context */
-        ret = H5CX_push();
+        ret = H5CX_push(&api_ctx);
         VRFY((ret == 0), "H5CX_push()");
-        api_ctx_pushed = TRUE;
+        api_ctx_pushed = true;
 
         /* Get a pointer to the internal file object */
         f = (H5F_t *)H5I_object(file_id);
@@ -420,16 +455,18 @@ test_page_buffer_access(void)
 
     /* Pop API context */
     if (api_ctx_pushed) {
-        ret = H5CX_pop();
+        ret = H5CX_pop(false);
         VRFY((ret == 0), "H5CX_pop()");
-        api_ctx_pushed = FALSE;
+        api_ctx_pushed = false;
     }
 
-    HDfree(data);
+    free(data);
     data = NULL;
     MPI_Barrier(MPI_COMM_WORLD);
+#endif
 }
 
+#ifdef PB_OUT
 static int
 create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_strategy)
 {
@@ -447,7 +484,8 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
     H5F_t              *f         = NULL;
     H5C_t              *cache_ptr = NULL;
     H5AC_cache_config_t config;
-    hbool_t             api_ctx_pushed = FALSE; /* Whether API context pushed */
+    H5CX_node_t         api_ctx        = {{0}, NULL}; /* API context node to push */
+    bool                api_ctx_pushed = false;       /* Whether API context pushed */
     herr_t              ret;
 
     file_id = H5Fcreate(filename, H5F_ACC_TRUNC, fcpl, fapl);
@@ -457,17 +495,16 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
     VRFY((ret == 0), "");
 
     /* Push API context */
-    ret = H5CX_push();
+    ret = H5CX_push(&api_ctx);
     VRFY((ret == 0), "H5CX_push()");
-    api_ctx_pushed = TRUE;
+    api_ctx_pushed = true;
 
     f = (H5F_t *)H5I_object(file_id);
     VRFY((f != NULL), "");
 
     cache_ptr = f->shared->cache;
-    VRFY((cache_ptr->magic == H5C__H5C_T_MAGIC), "");
 
-    cache_ptr->ignore_tags = TRUE;
+    cache_ptr->ignore_tags = true;
     H5C_stats__reset(cache_ptr);
     config.version = H5AC__CURR_CACHE_CONFIG_VERSION;
 
@@ -499,8 +536,8 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
 
     num_elements = block[0] * block[1];
     /* allocate memory for data buffer */
-    data_array = (DATATYPE *)HDmalloc(num_elements * sizeof(DATATYPE));
-    VRFY((data_array != NULL), "data_array HDmalloc succeeded");
+    data_array = (DATATYPE *)malloc(num_elements * sizeof(DATATYPE));
+    VRFY((data_array != NULL), "data_array malloc succeeded");
     /* put some trivial data in the data_array */
     for (i = 0; i < num_elements; i++)
         data_array[i] = mpi_rank + 1;
@@ -513,25 +550,25 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
     VRFY((mem_dataspace >= 0), "");
 
     for (k = 0; k < NUM_DSETS; k++) {
-        HDsnprintf(dset_name, sizeof(dset_name), "D1dset%d", k);
+        snprintf(dset_name, sizeof(dset_name), "D1dset%d", k);
         dset_id = H5Dcreate2(grp_id, dset_name, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
         VRFY((dset_id >= 0), "");
         ret = H5Dclose(dset_id);
         VRFY((ret == 0), "");
 
-        HDsnprintf(dset_name, sizeof(dset_name), "D2dset%d", k);
+        snprintf(dset_name, sizeof(dset_name), "D2dset%d", k);
         dset_id = H5Dcreate2(grp_id, dset_name, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
         VRFY((dset_id >= 0), "");
         ret = H5Dclose(dset_id);
         VRFY((ret == 0), "");
 
-        HDsnprintf(dset_name, sizeof(dset_name), "D3dset%d", k);
+        snprintf(dset_name, sizeof(dset_name), "D3dset%d", k);
         dset_id = H5Dcreate2(grp_id, dset_name, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
         VRFY((dset_id >= 0), "");
         ret = H5Dclose(dset_id);
         VRFY((ret == 0), "");
 
-        HDsnprintf(dset_name, sizeof(dset_name), "dset%d", k);
+        snprintf(dset_name, sizeof(dset_name), "dset%d", k);
         dset_id = H5Dcreate2(grp_id, dset_name, H5T_NATIVE_INT, sid, H5P_DEFAULT, H5P_DEFAULT, H5P_DEFAULT);
         VRFY((dset_id >= 0), "");
 
@@ -541,7 +578,7 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
         ret = H5Dclose(dset_id);
         VRFY((ret == 0), "");
 
-        HDmemset(data_array, 0, num_elements * sizeof(DATATYPE));
+        memset(data_array, 0, num_elements * sizeof(DATATYPE));
         dset_id = H5Dopen2(grp_id, dset_name, H5P_DEFAULT);
         VRFY((dset_id >= 0), "");
 
@@ -554,13 +591,13 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
         for (i = 0; i < num_elements; i++)
             VRFY((data_array[i] == mpi_rank + 1), "Dataset Verify failed");
 
-        HDsnprintf(dset_name, sizeof(dset_name), "D1dset%d", k);
+        snprintf(dset_name, sizeof(dset_name), "D1dset%d", k);
         ret = H5Ldelete(grp_id, dset_name, H5P_DEFAULT);
         VRFY((ret == 0), "");
-        HDsnprintf(dset_name, sizeof(dset_name), "D2dset%d", k);
+        snprintf(dset_name, sizeof(dset_name), "D2dset%d", k);
         ret = H5Ldelete(grp_id, dset_name, H5P_DEFAULT);
         VRFY((ret == 0), "");
-        HDsnprintf(dset_name, sizeof(dset_name), "D3dset%d", k);
+        snprintf(dset_name, sizeof(dset_name), "D3dset%d", k);
         ret = H5Ldelete(grp_id, dset_name, H5P_DEFAULT);
         VRFY((ret == 0), "");
     }
@@ -576,13 +613,13 @@ create_file(const char *filename, hid_t fcpl, hid_t fapl, int metadata_write_str
 
     /* Pop API context */
     if (api_ctx_pushed) {
-        ret = H5CX_pop();
+        ret = H5CX_pop(false);
         VRFY((ret == 0), "H5CX_pop()");
-        api_ctx_pushed = FALSE;
+        api_ctx_pushed = false;
     }
 
     MPI_Barrier(MPI_COMM_WORLD);
-    HDfree(data_array);
+    free(data_array);
     return 0;
 } /* create_file */
 
@@ -604,7 +641,8 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
     H5F_t              *f         = NULL;
     H5C_t              *cache_ptr = NULL;
     H5AC_cache_config_t config;
-    hbool_t             api_ctx_pushed = FALSE; /* Whether API context pushed */
+    H5CX_node_t         api_ctx        = {{0}, NULL}; /* API context node to push */
+    bool                api_ctx_pushed = false;       /* Whether API context pushed */
     herr_t              ret;
 
     config.version = H5AC__CURR_CACHE_CONFIG_VERSION;
@@ -621,9 +659,9 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
     VRFY((file_id >= 0), "");
 
     /* Push API context */
-    ret = H5CX_push();
+    ret = H5CX_push(&api_ctx);
     VRFY((ret == 0), "H5CX_push()");
-    api_ctx_pushed = TRUE;
+    api_ctx_pushed = true;
 
     ret = H5Fflush(file_id, H5F_SCOPE_GLOBAL);
     VRFY((ret == 0), "");
@@ -632,7 +670,6 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
     VRFY((f != NULL), "");
 
     cache_ptr = f->shared->cache;
-    VRFY((cache_ptr->magic == H5C__H5C_T_MAGIC), "");
 
     MPI_Barrier(MPI_COMM_WORLD);
 
@@ -658,15 +695,15 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
 
     num_elements = block[0] * block[1];
     /* allocate memory for data buffer */
-    data_array = (DATATYPE *)HDmalloc(num_elements * sizeof(DATATYPE));
-    VRFY((data_array != NULL), "data_array HDmalloc succeeded");
+    data_array = (DATATYPE *)malloc(num_elements * sizeof(DATATYPE));
+    VRFY((data_array != NULL), "data_array malloc succeeded");
 
     /* create a memory dataspace independently */
     mem_dataspace = H5Screate_simple(1, &num_elements, NULL);
     VRFY((mem_dataspace >= 0), "");
 
     for (k = 0; k < NUM_DSETS; k++) {
-        HDsnprintf(dset_name, sizeof(dset_name), "dset%d", k);
+        snprintf(dset_name, sizeof(dset_name), "dset%d", k);
         dset_id = H5Dopen2(grp_id, dset_name, H5P_DEFAULT);
         VRFY((dset_id >= 0), "");
 
@@ -711,8 +748,7 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
         entry_ptr = cache_ptr->index[i];
 
         while (entry_ptr != NULL) {
-            HDassert(entry_ptr->magic == H5C__H5C_CACHE_ENTRY_T_MAGIC);
-            HDassert(entry_ptr->is_dirty == FALSE);
+            assert(entry_ptr->is_dirty == false);
 
             if (!entry_ptr->is_pinned && !entry_ptr->is_protected) {
                 ret = H5AC_expunge_entry(f, entry_ptr->type, entry_ptr->addr, 0);
@@ -740,15 +776,16 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
 
     /* Pop API context */
     if (api_ctx_pushed) {
-        ret = H5CX_pop();
+        ret = H5CX_pop(false);
         VRFY((ret == 0), "H5CX_pop()");
-        api_ctx_pushed = FALSE;
+        api_ctx_pushed = false;
     }
 
-    HDfree(data_array);
+    free(data_array);
 
     return nerrors;
 }
+#endif
 
 /*
  * NOTE:  See HDFFV-10894 and add tests later to verify MPI-specific properties in the
@@ -756,12 +793,12 @@ open_file(const char *filename, hid_t fapl, int metadata_write_strategy, hsize_t
  *        multiple opens of the same file.
  */
 void
-test_file_properties(void)
+test_file_properties(void *params)
 {
     hid_t       fid          = H5I_INVALID_HID; /* HDF5 file ID */
     hid_t       fapl_id      = H5I_INVALID_HID; /* File access plist */
     hid_t       fapl_copy_id = H5I_INVALID_HID; /* File access plist */
-    hbool_t     is_coll;
+    bool        is_coll;
     htri_t      are_equal;
     const char *filename;
     MPI_Comm    comm     = MPI_COMM_WORLD;
@@ -772,17 +809,29 @@ test_file_properties(void)
     int         mpi_ret; /* MPI return value */
     int         cmp;     /* Compare value */
 
-    filename = (const char *)GetTestParameters();
-
     /* set up MPI parameters */
     mpi_ret = MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
     VRFY((mpi_ret >= 0), "MPI_Comm_size succeeded");
     mpi_ret = MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
     VRFY((mpi_ret >= 0), "MPI_Comm_rank succeeded");
+
+    /* Make sure the connector supports the API functions being tested */
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC)) {
+        if (MAINPROCESS) {
+            puts("SKIPPED");
+            printf("    API functions for basic file aren't supported with this connector\n");
+            fflush(stdout);
+        }
+
+        return;
+    }
+
+    filename = ((const H5Ptest_param_t *)params)->name;
+
     mpi_ret = MPI_Info_create(&info);
     VRFY((mpi_ret >= 0), "MPI_Info_create succeeded");
     mpi_ret = MPI_Info_set(info, "hdf_info_prop1", "xyz");
-    VRFY((mpi_ret == MPI_SUCCESS), "MPI_Info_set");
+    VRFY((mpi_ret == MPI_SUCCESS), "MPI_Info_set succeeded");
 
     /* setup file access plist */
     fapl_id = H5Pcreate(H5P_FILE_ACCESS);
@@ -818,7 +867,7 @@ test_file_properties(void)
     fapl_copy_id = H5Pcopy(fapl_id);
     VRFY((fapl_copy_id != H5I_INVALID_HID), "H5Pcopy");
     are_equal = H5Pequal(fapl_id, fapl_copy_id);
-    VRFY((TRUE == are_equal), "H5Pequal");
+    VRFY((true == are_equal), "H5Pequal");
 
     /* Add a property to the copy and ensure it's different now */
     mpi_ret = MPI_Info_set(info, "hdf_info_prop2", "abc");
@@ -826,7 +875,7 @@ test_file_properties(void)
     ret = H5Pset_mpi_params(fapl_copy_id, comm, info);
     VRFY((ret >= 0), "H5Pset_mpi_params succeeded");
     are_equal = H5Pequal(fapl_id, fapl_copy_id);
-    VRFY((FALSE == are_equal), "H5Pequal");
+    VRFY((false == are_equal), "H5Pequal");
 
     /* Add a property with the same key but a different value to the original
      * and ensure they are still different.
@@ -836,7 +885,7 @@ test_file_properties(void)
     ret = H5Pset_mpi_params(fapl_id, comm, info);
     VRFY((ret >= 0), "H5Pset_mpi_params succeeded");
     are_equal = H5Pequal(fapl_id, fapl_copy_id);
-    VRFY((FALSE == are_equal), "H5Pequal");
+    VRFY((false == are_equal), "H5Pequal");
 
     /* Set the second property in the original to the same
      * value as the copy and ensure they are the same now.
@@ -846,7 +895,7 @@ test_file_properties(void)
     ret = H5Pset_mpi_params(fapl_id, comm, info);
     VRFY((ret >= 0), "H5Pset_mpi_params succeeded");
     are_equal = H5Pequal(fapl_id, fapl_copy_id);
-    VRFY((TRUE == are_equal), "H5Pequal");
+    VRFY((true == are_equal), "H5Pequal");
 
     /* create the file */
     fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
@@ -857,12 +906,12 @@ test_file_properties(void)
     /* Collective metadata writes */
     ret = H5Pget_coll_metadata_write(fapl_id, &is_coll);
     VRFY((ret >= 0), "H5Pget_coll_metadata_write succeeded");
-    VRFY((is_coll == FALSE), "Incorrect property setting for coll metadata writes");
+    VRFY((is_coll == false), "Incorrect property setting for coll metadata writes");
 
     /* Collective metadata read API calling requirement */
     ret = H5Pget_all_coll_metadata_ops(fapl_id, &is_coll);
     VRFY((ret >= 0), "H5Pget_all_coll_metadata_ops succeeded");
-    VRFY((is_coll == FALSE), "Incorrect property setting for coll metadata API calls requirement");
+    VRFY((is_coll == false), "Incorrect property setting for coll metadata API calls requirement");
 
     ret = H5Fclose(fid);
     VRFY((ret >= 0), "H5Fclose succeeded");
@@ -871,19 +920,19 @@ test_file_properties(void)
     ret = H5Pset_fapl_mpio(fapl_id, comm, info);
     VRFY((ret >= 0), "H5Pset_fapl_mpio failed");
     fid = H5Fopen(filename, H5F_ACC_RDWR, fapl_id);
-    VRFY((fid != H5I_INVALID_HID), "H5Fcreate succeeded");
+    VRFY((fid != H5I_INVALID_HID), "H5Fopen succeeded");
 
     /* verify settings for file access properties */
 
     /* Collective metadata writes */
     ret = H5Pget_coll_metadata_write(fapl_id, &is_coll);
     VRFY((ret >= 0), "H5Pget_coll_metadata_write succeeded");
-    VRFY((is_coll == FALSE), "Incorrect property setting for coll metadata writes");
+    VRFY((is_coll == false), "Incorrect property setting for coll metadata writes");
 
     /* Collective metadata read API calling requirement */
     ret = H5Pget_all_coll_metadata_ops(fapl_id, &is_coll);
     VRFY((ret >= 0), "H5Pget_all_coll_metadata_ops succeeded");
-    VRFY((is_coll == FALSE), "Incorrect property setting for coll metadata API calls requirement");
+    VRFY((is_coll == false), "Incorrect property setting for coll metadata API calls requirement");
 
     ret = H5Fclose(fid);
     VRFY((ret >= 0), "H5Fclose succeeded");
@@ -892,25 +941,25 @@ test_file_properties(void)
     ret = H5Pset_fapl_mpio(fapl_id, comm, info);
     VRFY((ret >= 0), "H5Pset_fapl_mpio failed");
     /* Collective metadata writes */
-    ret = H5Pset_coll_metadata_write(fapl_id, TRUE);
+    ret = H5Pset_coll_metadata_write(fapl_id, true);
     VRFY((ret >= 0), "H5Pget_coll_metadata_write succeeded");
     /* Collective metadata read API calling requirement */
-    ret = H5Pset_all_coll_metadata_ops(fapl_id, TRUE);
+    ret = H5Pset_all_coll_metadata_ops(fapl_id, true);
     VRFY((ret >= 0), "H5Pget_all_coll_metadata_ops succeeded");
     fid = H5Fopen(filename, H5F_ACC_RDWR, fapl_id);
-    VRFY((fid != H5I_INVALID_HID), "H5Fcreate succeeded");
+    VRFY((fid != H5I_INVALID_HID), "H5Fopen succeeded");
 
     /* verify settings for file access properties */
 
     /* Collective metadata writes */
     ret = H5Pget_coll_metadata_write(fapl_id, &is_coll);
     VRFY((ret >= 0), "H5Pget_coll_metadata_write succeeded");
-    VRFY((is_coll == TRUE), "Incorrect property setting for coll metadata writes");
+    VRFY((is_coll == true), "Incorrect property setting for coll metadata writes");
 
     /* Collective metadata read API calling requirement */
     ret = H5Pget_all_coll_metadata_ops(fapl_id, &is_coll);
     VRFY((ret >= 0), "H5Pget_all_coll_metadata_ops succeeded");
-    VRFY((is_coll == TRUE), "Incorrect property setting for coll metadata API calls requirement");
+    VRFY((is_coll == true), "Incorrect property setting for coll metadata API calls requirement");
 
     /* close fapl and retrieve it from file */
     ret = H5Pclose(fapl_id);
@@ -925,12 +974,12 @@ test_file_properties(void)
     /* Collective metadata writes */
     ret = H5Pget_coll_metadata_write(fapl_id, &is_coll);
     VRFY((ret >= 0), "H5Pget_coll_metadata_write succeeded");
-    VRFY((is_coll == TRUE), "Incorrect property setting for coll metadata writes");
+    VRFY((is_coll == true), "Incorrect property setting for coll metadata writes");
 
     /* Collective metadata read API calling requirement */
     ret = H5Pget_all_coll_metadata_ops(fapl_id, &is_coll);
     VRFY((ret >= 0), "H5Pget_all_coll_metadata_ops succeeded");
-    VRFY((is_coll == TRUE), "Incorrect property setting for coll metadata API calls requirement");
+    VRFY((is_coll == true), "Incorrect property setting for coll metadata API calls requirement");
 
     /* close file */
     ret = H5Fclose(fid);
@@ -948,13 +997,88 @@ test_file_properties(void)
 
 } /* end test_file_properties() */
 
+void
+test_delete(void *params)
+{
+    hid_t       fid           = H5I_INVALID_HID; /* HDF5 file ID */
+    hid_t       fapl_id       = H5I_INVALID_HID; /* File access plist */
+    const char *filename      = NULL;
+    MPI_Comm    comm          = MPI_COMM_WORLD;
+    MPI_Info    info          = MPI_INFO_NULL;
+    htri_t      is_accessible = FAIL; /* Whether a file is accessible */
+    herr_t      ret;                  /* Generic return value */
+
+    filename = ((const H5Ptest_param_t *)params)->name;
+
+    /* set up MPI parameters */
+    MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
+    MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
+
+    /* Make sure the connector supports the API functions being tested */
+    if (!(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_BASIC) || !(vol_cap_flags_g & H5VL_CAP_FLAG_FILE_MORE)) {
+        if (MAINPROCESS) {
+            puts("SKIPPED");
+            printf("    API functions for basic file or file more aren't supported with this "
+                   "connector\n");
+            fflush(stdout);
+        }
+
+        return;
+    }
+
+    /* setup file access plist */
+    fapl_id = H5Pcreate(H5P_FILE_ACCESS);
+    VRFY((fapl_id != H5I_INVALID_HID), "H5Pcreate");
+    ret = H5Pset_fapl_mpio(fapl_id, comm, info);
+    VRFY((SUCCEED == ret), "H5Pset_fapl_mpio");
+
+    /* create the file */
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
+    VRFY((fid != H5I_INVALID_HID), "H5Fcreate");
+
+    /* close the file */
+    ret = H5Fclose(fid);
+    VRFY((SUCCEED == ret), "H5Fclose");
+
+    /* Verify that the file is an HDF5 file */
+    is_accessible = H5Fis_accessible(filename, fapl_id);
+    VRFY((true == is_accessible), "H5Fis_accessible");
+
+    /* Delete the file */
+    ret = H5Fdelete(filename, fapl_id);
+    VRFY((SUCCEED == ret), "H5Fdelete");
+
+    /*
+     * Work around a Cray MPICH bug that causes
+     * H5Fis_accessible to re-create the just-deleted
+     * file as a 0-byte file with strange Unix
+     * permissions, causing the routine to return
+     * false here instead of FAIL.
+     */
+    H5Pset_fapl_mpio(fapl_id, comm, info);
+
+    /* Verify that the file is NO LONGER an HDF5 file */
+    /* This should fail since there is no file */
+    H5E_BEGIN_TRY
+    {
+        is_accessible = H5Fis_accessible(filename, fapl_id);
+    }
+    H5E_END_TRY
+    VRFY((FAIL == is_accessible), "H5Fis_accessible failed as expected");
+
+    /* Release file-access plist */
+    ret = H5Pclose(fapl_id);
+    VRFY((SUCCEED == ret), "H5Pclose");
+
+} /* end test_delete() */
+
 /*
  * Tests for an assertion failure during file close that used
  * to occur when the library fails to create a file in parallel
  * due to an invalid library version bounds setting
  */
 void
-test_invalid_libver_bounds_file_close_assert(void)
+test_invalid_libver_bounds_file_close_assert(void *params)
 {
     const char *filename = NULL;
     MPI_Comm    comm     = MPI_COMM_WORLD;
@@ -964,7 +1088,7 @@ test_invalid_libver_bounds_file_close_assert(void)
     hid_t       fapl_id = H5I_INVALID_HID;
     hid_t       fcpl_id = H5I_INVALID_HID;
 
-    filename = (const char *)GetTestParameters();
+    filename = ((const H5Ptest_param_t *)params)->name;
 
     /* set up MPI parameters */
     MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
@@ -982,7 +1106,7 @@ test_invalid_libver_bounds_file_close_assert(void)
     fcpl_id = H5Pcreate(H5P_FILE_CREATE);
     VRFY((fcpl_id != H5I_INVALID_HID), "H5Pcreate");
 
-    ret = H5Pset_file_space_strategy(fcpl_id, H5F_FSPACE_STRATEGY_PAGE, TRUE, 1);
+    ret = H5Pset_file_space_strategy(fcpl_id, H5F_FSPACE_STRATEGY_PAGE, true, 1);
     VRFY((SUCCEED == ret), "H5Pset_file_space_strategy");
 
     /* create the file */
@@ -998,3 +1122,164 @@ test_invalid_libver_bounds_file_close_assert(void)
     ret = H5Pclose(fcpl_id);
     VRFY((SUCCEED == ret), "H5Pclose");
 }
+
+/*
+ * Tests that H5Pevict_on_close properly succeeds in serial/one rank and fails when
+ * called by multiple ranks.
+ */
+void
+test_evict_on_close_parallel_unsupp(void *params)
+{
+    const char *filename = NULL;
+    MPI_Comm    comm     = MPI_COMM_WORLD;
+    MPI_Info    info     = MPI_INFO_NULL;
+    hid_t       fid      = H5I_INVALID_HID;
+    hid_t       fapl_id  = H5I_INVALID_HID;
+    herr_t      ret;
+
+    filename = ((const H5Ptest_param_t *)params)->name;
+
+    /* set up MPI parameters */
+    MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
+    MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
+
+    /* setup file access plist */
+    fapl_id = H5Pcreate(H5P_FILE_ACCESS);
+    VRFY((fapl_id != H5I_INVALID_HID), "H5Pcreate");
+    ret = H5Pset_libver_bounds(fapl_id, H5F_LIBVER_EARLIEST, H5F_LIBVER_V18);
+    VRFY((SUCCEED == ret), "H5Pset_libver_bounds");
+
+    ret = H5Pset_evict_on_close(fapl_id, true);
+    VRFY((SUCCEED == ret), "H5Pset_evict_on_close");
+
+    /* test on 1 rank */
+    ret = H5Pset_fapl_mpio(fapl_id, MPI_COMM_SELF, info);
+    VRFY((SUCCEED == ret), "H5Pset_fapl_mpio");
+
+    if (mpi_rank == 0) {
+        fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
+        VRFY((SUCCEED == ret), "H5Fcreate");
+        ret = H5Fclose(fid);
+        VRFY((SUCCEED == ret), "H5Fclose");
+    }
+
+    VRFY((MPI_SUCCESS == MPI_Barrier(MPI_COMM_WORLD)), "MPI_Barrier");
+
+    /* test on multiple ranks if we have them */
+    if (mpi_size > 1) {
+        ret = H5Pset_fapl_mpio(fapl_id, comm, info);
+        VRFY((SUCCEED == ret), "H5Pset_fapl_mpio");
+
+        H5E_BEGIN_TRY
+        {
+            fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
+        }
+        H5E_END_TRY
+        VRFY((fid == H5I_INVALID_HID), "H5Fcreate");
+    }
+
+    ret = H5Pclose(fapl_id);
+    VRFY((SUCCEED == ret), "H5Pclose");
+}
+
+/*
+ * Verify that MPI I/O hints are preserved after closing the file access property list
+ * as described in issue #3025
+ * This is a test program from the user.
+ */
+void
+test_fapl_preserve_hints(void *params)
+{
+    const char *filename;
+    const char *key       = "hdf_info_fapl";
+    const char *value     = "xyz";
+    MPI_Info    info_used = MPI_INFO_NULL;
+    MPI_Info    info      = MPI_INFO_NULL;
+    hid_t       fid       = H5I_INVALID_HID; /* HDF5 file ID */
+    hid_t       fapl_id   = H5I_INVALID_HID; /* File access plist */
+    char        key_used[MPI_MAX_INFO_KEY + 1];
+    char       *value_used = NULL;
+    bool        same       = false;
+    int         flag       = -1;
+    int         nkeys_used;
+    int         i;
+    int         mpi_ret; /* MPI return value */
+    herr_t      ret;     /* Generic return value */
+
+    filename = ((const H5Ptest_param_t *)params)->name;
+
+    value_used = malloc(MPI_MAX_INFO_VAL + 1);
+    VRFY(value_used, "malloc succeeded");
+
+    /* set up MPI parameters */
+    mpi_ret = MPI_Info_create(&info);
+    VRFY((mpi_ret >= 0), "MPI_Info_create succeeded");
+
+    mpi_ret = MPI_Info_set(info, key, value);
+    VRFY((mpi_ret == MPI_SUCCESS), "MPI_Info_set succeeded");
+
+    fapl_id = H5Pcreate(H5P_FILE_ACCESS);
+    VRFY((fapl_id != H5I_INVALID_HID), "H5Pcreate");
+
+    ret = H5Pset_fapl_mpio(fapl_id, MPI_COMM_WORLD, info);
+    VRFY((ret >= 0), "H5Pset_fapl_mpio");
+
+    fid = H5Fcreate(filename, H5F_ACC_TRUNC, H5P_DEFAULT, fapl_id);
+    VRFY((fid != H5I_INVALID_HID), "H5Fcreate succeeded");
+
+    ret = H5Pclose(fapl_id);
+    VRFY((ret >= 0), "H5Pclose succeeded");
+
+    fapl_id = H5Fget_access_plist(fid);
+    VRFY((fapl_id != H5I_INVALID_HID), "H5Fget_access_plist succeeded");
+
+    ret = H5Pget_fapl_mpio(fapl_id, NULL, &info_used);
+    VRFY((ret >= 0), "H5Pget_fapl_mpio succeeded");
+
+    VRFY((info_used != MPI_INFO_NULL), "H5Pget_fapl_mpio");
+
+    mpi_ret = MPI_Info_get_nkeys(info_used, &nkeys_used);
+    VRFY((mpi_ret == MPI_SUCCESS), "MPI_Info_get_nkeys succeeded");
+
+    /* Loop over the # of keys */
+    for (i = 0; i < nkeys_used; i++) {
+
+        /* Memset the buffers to zero */
+        memset(key_used, 0, MPI_MAX_INFO_KEY + 1);
+        memset(value_used, 0, MPI_MAX_INFO_VAL + 1);
+
+        /* Get the nth key */
+        mpi_ret = MPI_Info_get_nthkey(info_used, i, key_used);
+        VRFY((mpi_ret == MPI_SUCCESS), "MPI_Info_get_nthkey succeeded");
+
+        if (!strcmp(key_used, key)) {
+            mpi_ret = MPI_Info_get(info_used, key_used, MPI_MAX_INFO_VAL, value_used, &flag);
+            VRFY((mpi_ret == MPI_SUCCESS), "MPI_Info_get succeeded");
+
+            if (!strcmp(value_used, value)) {
+
+                /* Both key_used and value_used are the same */
+                same = true;
+                break;
+            }
+        }
+    } /* end for */
+
+    VRFY((same == true), "key_used and value_used are the same");
+
+    ret = H5Pclose(fapl_id);
+    VRFY((ret >= 0), "H5Pclose succeeded");
+
+    ret = H5Fclose(fid);
+    VRFY((ret >= 0), "H5Fclose succeeded");
+
+    /* Free the MPI info object */
+    mpi_ret = MPI_Info_free(&info);
+    VRFY((mpi_ret >= 0), "MPI_Info_free succeeded");
+
+    mpi_ret = MPI_Info_free(&info_used);
+    VRFY((mpi_ret >= 0), "MPI_Info_free succeeded");
+
+    free(value_used);
+
+} /* end test_fapl_preserve_hints() */
