@@ -1,11 +1,10 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -27,6 +26,9 @@
 
 #include "testpar.h"
 
+/* Include testing framework functionality */
+#include "testframe.h"
+
 /* FILENAME and filenames must have the same number of names */
 const char *FILENAME[2] = {"MPItest", NULL};
 char        filenames[2][200];
@@ -41,35 +43,42 @@ static int errors_sum(int nerrs);
 static int
 test_mpio_overlap_writes(char *filename)
 {
-    int           mpi_size, mpi_rank;
-    MPI_Comm      comm;
-    MPI_Info      info = MPI_INFO_NULL;
-    int           color, mrc;
-    MPI_File      fh;
-    int           i;
-    int           vrfyerrs, nerrs;
-    unsigned char buf[4093]; /* use some prime number for size */
-    int           bufsize = sizeof(buf);
-    MPI_Offset    stride;
-    MPI_Offset    mpi_off;
-    MPI_Status    mpi_stat;
-
-    if (VERBOSE_MED)
-        HDprintf("MPIO independent overlapping writes test on file %s\n", filename);
+    int            mpi_size, mpi_rank;
+    MPI_Comm       comm;
+    MPI_Info       info = MPI_INFO_NULL;
+    int            color, mrc;
+    MPI_File       fh;
+    int            i;
+    int            vrfyerrs, nerrs;
+    unsigned char *buf = NULL;
+    int            bufsize;
+    MPI_Offset     stride;
+    MPI_Offset     mpi_off;
+    MPI_Status     mpi_stat;
 
     nerrs = 0;
     /* set up MPI parameters */
     MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
     MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
 
+    if (VERBOSE_MED && MAINPROCESS)
+        printf("MPIO independent overlapping writes test on file %s\n", filename);
+
     /* Need at least 2 processes */
     if (mpi_size < 2) {
         if (MAINPROCESS)
-            HDprintf("Need at least 2 processes to run MPIO test.\n");
-        HDprintf(" -SKIP- \n");
+            printf("Need at least 2 processes to run MPIO test.\n");
+        printf(" -SKIP- \n");
         return 0;
     }
 
+    bufsize = 4093; /* use some prime number for size */
+    if (NULL == (buf = malloc((size_t)bufsize))) {
+        if (MAINPROCESS)
+            printf("couldn't allocate buffer\n");
+        return 1;
+    }
+
     /* splits processes 0 to n-2 into one comm. and the last one into another */
     color = ((mpi_rank < (mpi_size - 1)) ? 0 : 1);
     mrc   = MPI_Comm_split(MPI_COMM_WORLD, color, mpi_rank, &comm);
@@ -136,12 +145,12 @@ test_mpio_overlap_writes(char *filename)
                 unsigned char expected;
                 expected = (unsigned char)(mpi_off + i);
                 if ((expected != buf[i]) && (vrfyerrs++ < MAX_ERR_REPORT || VERBOSE_MED)) {
-                    HDprintf("proc %d: found data error at [%ld], expect %u, got %u\n", mpi_rank,
-                             (long)(mpi_off + i), expected, buf[i]);
+                    printf("proc %d: found data error at [%ld], expect %u, got %u\n", mpi_rank,
+                           (long)(mpi_off + i), expected, buf[i]);
                 }
             }
             if (vrfyerrs > MAX_ERR_REPORT && !VERBOSE_MED)
-                HDprintf("proc %d: [more errors ...]\n", mpi_rank);
+                printf("proc %d: [more errors ...]\n", mpi_rank);
 
             nerrs += vrfyerrs;
         }
@@ -159,6 +168,9 @@ test_mpio_overlap_writes(char *filename)
      */
     mrc = MPI_Barrier(MPI_COMM_WORLD);
     VRFY((mrc == MPI_SUCCESS), "Sync before leaving test");
+
+    free(buf);
+
     return (nerrs);
 }
 
@@ -166,6 +178,8 @@ test_mpio_overlap_writes(char *filename)
 #define GB            1073741824  /* 1024**3 == 2**30 */
 #define TWO_GB_LESS1  2147483647  /* 2**31 - 1 */
 #define FOUR_GB_LESS1 4294967295L /* 2**32 - 1 */
+
+#ifndef H5_HAVE_WIN32_API
 /*
  * Verify that MPI_Offset exceeding 2**31 can be computed correctly.
  * Print any failure as information only, not as an error so that this
@@ -189,7 +203,7 @@ test_mpio_gb_file(char *filename)
     int        writerrs; /* write errors */
     int        nerrs;
     int        ntimes; /* how many times */
-    char *     buf = NULL;
+    char      *buf = NULL;
     char       expected;
     MPI_Offset size;
     MPI_Offset mpi_off;
@@ -202,8 +216,8 @@ test_mpio_gb_file(char *filename)
     MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
     MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
 
-    if (VERBOSE_MED)
-        HDprintf("MPI_Offset range test\n");
+    if (VERBOSE_MED && MAINPROCESS)
+        printf("MPI_Offset range test\n");
 
     /* figure out the signness and sizeof MPI_Offset */
     mpi_off           = 0;
@@ -215,11 +229,11 @@ test_mpio_gb_file(char *filename)
      * sizes.
      */
     if (MAINPROCESS) { /* only process 0 needs to check it*/
-        HDprintf("MPI_Offset is %s %d bytes integral type\n", is_signed ? "signed" : "unsigned",
-                 (int)sizeof(MPI_Offset));
+        printf("MPI_Offset is %s %d bytes integral type\n", is_signed ? "signed" : "unsigned",
+               (int)sizeof(MPI_Offset));
         if (sizeof_mpi_offset <= 4 && is_signed) {
-            HDprintf("Skipped 2GB range test "
-                     "because MPI_Offset cannot support it\n");
+            printf("Skipped 2GB range test "
+                   "because MPI_Offset cannot support it\n");
         }
         else {
             /* verify correctness of assigning 2GB sizes */
@@ -240,8 +254,8 @@ test_mpio_gb_file(char *filename)
         }
 
         if (sizeof_mpi_offset <= 4) {
-            HDprintf("Skipped 4GB range test "
-                     "because MPI_Offset cannot support it\n");
+            printf("Skipped 4GB range test "
+                   "because MPI_Offset cannot support it\n");
         }
         else {
             /* verify correctness of assigning 4GB sizes */
@@ -265,15 +279,16 @@ test_mpio_gb_file(char *filename)
     /*
      * Verify if we can write to a file of multiple GB sizes.
      */
-    if (VERBOSE_MED)
-        HDprintf("MPIO GB file test %s\n", filename);
+    if (VERBOSE_MED && MAINPROCESS)
+        printf("MPIO GB file test %s\n", filename);
 
     if (sizeof_mpi_offset <= 4) {
-        HDprintf("Skipped GB file range test "
-                 "because MPI_Offset cannot support it\n");
+        if (MAINPROCESS)
+            printf("Skipped GB file range test "
+                   "because MPI_Offset cannot support it\n");
     }
     else {
-        buf = (char *)HDmalloc(MB);
+        buf = (char *)malloc(MB);
         VRFY((buf != NULL), "malloc succeed");
 
         /* open a new file. Remove it first in case it exists. */
@@ -285,7 +300,8 @@ test_mpio_gb_file(char *filename)
         mrc = MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_CREATE | MPI_MODE_RDWR, info, &fh);
         VRFY((mrc == MPI_SUCCESS), "MPI_FILE_OPEN");
 
-        HDprintf("MPIO GB file write test %s\n", filename);
+        if (MAINPROCESS)
+            printf("MPIO GB file write test %s\n", filename);
 
         /* instead of writing every bytes of the file, we will just write
          * some data around the 2 and 4 GB boundaries.  That should cover
@@ -297,13 +313,14 @@ test_mpio_gb_file(char *filename)
             for (i = ntimes - 2; i <= ntimes; i++) {
                 mpi_off = (i * mpi_size + mpi_rank) * (MPI_Offset)MB;
                 if (VERBOSE_MED)
-                    HDfprintf(stdout, "proc %d: write to mpi_off=%016llx, %lld\n", mpi_rank, mpi_off,
-                              mpi_off);
+                    fprintf(stdout, "proc %d: write to mpi_off=%016llx, %lld\n", mpi_rank, (long long)mpi_off,
+                            (long long)mpi_off);
                 /* set data to some trivial pattern for easy verification */
                 for (j = 0; j < MB; j++)
                     *(buf + j) = (int8_t)(i * mpi_size + mpi_rank);
                 if (VERBOSE_MED)
-                    HDfprintf(stdout, "proc %d: writing %d bytes at offset %lld\n", mpi_rank, MB, mpi_off);
+                    fprintf(stdout, "proc %d: writing %d bytes at offset %lld\n", mpi_rank, MB,
+                            (long long)mpi_off);
                 mrc = MPI_File_write_at(fh, mpi_off, buf, MB, MPI_BYTE, &mpi_stat);
                 INFO((mrc == MPI_SUCCESS), "GB size file write");
                 if (mrc != MPI_SUCCESS)
@@ -323,9 +340,10 @@ test_mpio_gb_file(char *filename)
          */
         /* open it again to verify the data written */
         /* but only if there was no write errors */
-        HDprintf("MPIO GB file read test %s\n", filename);
+        if (MAINPROCESS)
+            printf("MPIO GB file read test %s\n", filename);
         if (errors_sum(writerrs) > 0) {
-            HDprintf("proc %d: Skip read test due to previous write errors\n", mpi_rank);
+            printf("proc %d: Skip read test due to previous write errors\n", mpi_rank);
             goto finish;
         }
         mrc = MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_RDONLY, info, &fh);
@@ -337,20 +355,20 @@ test_mpio_gb_file(char *filename)
             for (i = ntimes - 2; i <= ntimes; i++) {
                 mpi_off = (i * mpi_size + (mpi_size - mpi_rank - 1)) * (MPI_Offset)MB;
                 if (VERBOSE_MED)
-                    HDfprintf(stdout, "proc %d: read from mpi_off=%016llx, %lld\n", mpi_rank, mpi_off,
-                              mpi_off);
+                    fprintf(stdout, "proc %d: read from mpi_off=%016llx, %lld\n", mpi_rank,
+                            (long long)mpi_off, (long long)mpi_off);
                 mrc = MPI_File_read_at(fh, mpi_off, buf, MB, MPI_BYTE, &mpi_stat);
                 INFO((mrc == MPI_SUCCESS), "GB size file read");
                 expected = (int8_t)(i * mpi_size + (mpi_size - mpi_rank - 1));
                 vrfyerrs = 0;
                 for (j = 0; j < MB; j++) {
                     if ((*(buf + j) != expected) && (vrfyerrs++ < MAX_ERR_REPORT || VERBOSE_MED)) {
-                        HDprintf("proc %d: found data error at [%ld+%d], expect %d, got %d\n", mpi_rank,
-                                 (long)mpi_off, j, expected, *(buf + j));
+                        printf("proc %d: found data error at [%ld+%d], expect %d, got %d\n", mpi_rank,
+                               (long)mpi_off, j, expected, *(buf + j));
                     }
                 }
                 if (vrfyerrs > MAX_ERR_REPORT && !VERBOSE_MED)
-                    HDprintf("proc %d: [more errors ...]\n", mpi_rank);
+                    printf("proc %d: [more errors ...]\n", mpi_rank);
 
                 nerrs += vrfyerrs;
             }
@@ -367,7 +385,8 @@ test_mpio_gb_file(char *filename)
         mrc = MPI_Barrier(MPI_COMM_WORLD);
         VRFY((mrc == MPI_SUCCESS), "Sync before leaving test");
 
-        HDprintf("Test if MPI_File_get_size works correctly with %s\n", filename);
+        if (MAINPROCESS)
+            printf("Test if MPI_File_get_size works correctly with %s\n", filename);
 
         mrc = MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_RDONLY, info, &fh);
         VRFY((mrc == MPI_SUCCESS), "");
@@ -392,9 +411,10 @@ test_mpio_gb_file(char *filename)
 
 finish:
     if (buf)
-        HDfree(buf);
+        free(buf);
     return (nerrs);
 }
+#endif
 
 /*
  * MPI-IO Test: One writes, Many reads.
@@ -414,7 +434,7 @@ finish:
  */
 
 #define DIMSIZE  32 /* Dimension size. */
-#define PRINTID  HDprintf("Proc %d: ", mpi_rank)
+#define PRINTID  printf("Proc %d: ", mpi_rank)
 #define USENONE  0
 #define USEATOM  1 /* request atomic I/O */
 #define USEFSYNC 2 /* request file_sync */
@@ -422,7 +442,6 @@ finish:
 static int
 test_mpio_1wMr(char *filename, int special_request)
 {
-    char          hostname[128];
     int           mpi_size, mpi_rank;
     MPI_File      fh;
     char          mpi_err_str[MPI_MAX_ERROR_STRING];
@@ -440,25 +459,14 @@ test_mpio_1wMr(char *filename, int special_request)
     MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
 
     if (MAINPROCESS && VERBOSE_MED) {
-        HDprintf("Testing one process writes, all processes read.\n");
-        HDprintf("Using %d processes accessing file %s\n", mpi_size, filename);
-        HDprintf("    (Filename can be specified via program argument)\n");
+        printf("Testing one process writes, all processes read.\n");
+        printf("Using %d processes accessing file %s\n", mpi_size, filename);
+        printf("    (Filename can be specified via program argument)\n");
     }
 
     /* show the hostname so that we can tell where the processes are running */
-    if (VERBOSE_DEF) {
-#ifdef H5_HAVE_GETHOSTNAME
-        if (HDgethostname(hostname, sizeof(hostname)) < 0) {
-            HDprintf("gethostname failed\n");
-            hostname[0] = '\0';
-        }
-#else
-        HDprintf("gethostname unavailable\n");
-        hostname[0] = '\0';
-#endif
-        PRINTID;
-        HDprintf("hostname=%s\n", hostname);
-    }
+    if (VERBOSE_DEF)
+        h5_show_hostname();
 
     /* Delete any old file in order to start anew. */
     /* Must delete because MPI_File_open does not have a Truncate mode. */
@@ -470,7 +478,7 @@ test_mpio_1wMr(char *filename, int special_request)
                                  &fh)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
         PRINTID;
-        HDprintf("MPI_File_open failed (%s)\n", mpi_err_str);
+        printf("MPI_File_open failed (%s)\n", mpi_err_str);
         return 1;
     }
 
@@ -482,29 +490,29 @@ test_mpio_1wMr(char *filename, int special_request)
         if ((mpi_err = MPI_File_get_atomicity(fh, &atomicity)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
             PRINTID;
-            HDprintf("MPI_File_get_atomicity failed (%s)\n", mpi_err_str);
+            printf("MPI_File_get_atomicity failed (%s)\n", mpi_err_str);
         }
         if (VERBOSE_HI)
-            HDprintf("Initial atomicity = %d\n", atomicity);
+            printf("Initial atomicity = %d\n", atomicity);
         if ((mpi_err = MPI_File_set_atomicity(fh, 1)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
             PRINTID;
-            HDprintf("MPI_File_set_atomicity failed (%s)\n", mpi_err_str);
+            printf("MPI_File_set_atomicity failed (%s)\n", mpi_err_str);
         }
         if ((mpi_err = MPI_File_get_atomicity(fh, &atomicity)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
             PRINTID;
-            HDprintf("MPI_File_get_atomicity failed (%s)\n", mpi_err_str);
+            printf("MPI_File_get_atomicity failed (%s)\n", mpi_err_str);
         }
         if (VERBOSE_HI)
-            HDprintf("After set_atomicity atomicity = %d\n", atomicity);
+            printf("After set_atomicity atomicity = %d\n", atomicity);
     }
 
     /* This barrier is not necessary but do it anyway. */
     MPI_Barrier(MPI_COMM_WORLD);
     if (VERBOSE_HI) {
         PRINTID;
-        HDprintf("between MPI_Barrier and MPI_File_write_at\n");
+        printf("between MPI_Barrier and MPI_File_write_at\n");
     }
 
     /* ==================================================
@@ -520,14 +528,14 @@ test_mpio_1wMr(char *filename, int special_request)
     if (mpi_rank == irank) {
         if (VERBOSE_HI) {
             PRINTID;
-            HDprintf("wrote %d bytes at %ld\n", DIMSIZE, (long)mpi_off);
+            printf("wrote %d bytes at %ld\n", DIMSIZE, (long)mpi_off);
         }
         if ((mpi_err = MPI_File_write_at(fh, mpi_off, writedata, DIMSIZE, MPI_BYTE, &mpi_stat)) !=
             MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
             PRINTID;
-            HDprintf("MPI_File_write_at offset(%ld), bytes (%d), failed (%s)\n", (long)mpi_off, DIMSIZE,
-                     mpi_err_str);
+            printf("MPI_File_write_at offset(%ld), bytes (%d), failed (%s)\n", (long)mpi_off, DIMSIZE,
+                   mpi_err_str);
             return 1;
         };
     };
@@ -537,7 +545,7 @@ test_mpio_1wMr(char *filename, int special_request)
     MPI_Bcast(&mpi_err, 1, MPI_INT, irank, MPI_COMM_WORLD);
     if (VERBOSE_HI) {
         PRINTID;
-        HDprintf("MPI_Bcast: mpi_err = %d\n", mpi_err);
+        printf("MPI_Bcast: mpi_err = %d\n", mpi_err);
     }
 
     if (special_request & USEFSYNC) {
@@ -546,19 +554,19 @@ test_mpio_1wMr(char *filename, int special_request)
          * should not need this.
          * ==================================================*/
         if (VERBOSE_HI)
-            HDprintf("Apply MPI_File_sync\n");
+            printf("Apply MPI_File_sync\n");
         /* call file_sync to force the write out */
         if ((mpi_err = MPI_File_sync(fh)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
             PRINTID;
-            HDprintf("MPI_File_sync failed (%s)\n", mpi_err_str);
+            printf("MPI_File_sync failed (%s)\n", mpi_err_str);
         }
         MPI_Barrier(MPI_COMM_WORLD);
         /* call file_sync to force the write out */
         if ((mpi_err = MPI_File_sync(fh)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
             PRINTID;
-            HDprintf("MPI_File_sync failed (%s)\n", mpi_err_str);
+            printf("MPI_File_sync failed (%s)\n", mpi_err_str);
         }
     }
 
@@ -567,7 +575,7 @@ test_mpio_1wMr(char *filename, int special_request)
     MPI_Barrier(MPI_COMM_WORLD);
     if (VERBOSE_HI) {
         PRINTID;
-        HDprintf("after MPI_Barrier\n");
+        printf("after MPI_Barrier\n");
     }
 
     /* ==================================================
@@ -578,15 +586,15 @@ test_mpio_1wMr(char *filename, int special_request)
     if ((mpi_err = MPI_File_read_at(fh, mpi_off, readdata, DIMSIZE, MPI_BYTE, &mpi_stat)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
         PRINTID;
-        HDprintf("MPI_File_read_at offset(%ld), bytes (%d), failed (%s)\n", (long)mpi_off, DIMSIZE,
-                 mpi_err_str);
+        printf("MPI_File_read_at offset(%ld), bytes (%d), failed (%s)\n", (long)mpi_off, DIMSIZE,
+               mpi_err_str);
         return 1;
     };
     for (i = 0; i < DIMSIZE; i++) {
         expect_val = (uint8_t)(irank * DIMSIZE + i);
         if (readdata[i] != expect_val) {
             PRINTID;
-            HDprintf("read data[%d:%d] got %02x, expect %02x\n", irank, i, readdata[i], expect_val);
+            printf("read data[%d:%d] got %02x, expect %02x\n", irank, i, readdata[i], expect_val);
             nerrs++;
         }
     }
@@ -595,7 +603,7 @@ test_mpio_1wMr(char *filename, int special_request)
 
     if (VERBOSE_HI) {
         PRINTID;
-        HDprintf("%d data errors detected\n", nerrs);
+        printf("%d data errors detected\n", nerrs);
     }
 
     mpi_err = MPI_Barrier(MPI_COMM_WORLD);
@@ -649,7 +657,7 @@ test_mpio_1wMr(char *filename, int special_request)
  2. This test will verify whether the complicated derived datatype is working on
  the current platform.
 
- If this bug has been fixed in the previous not-working package, this test will issue a HDprintf message to
+ If this bug has been fixed in the previous not-working package, this test will issue a printf message to
  tell the developer to change the configuration specific file of HDF5 so that we can change our
  configurationsetting to support collective IO for irregular selections.
 
@@ -690,7 +698,7 @@ test_mpio_derived_dtype(char *filename)
     if ((mpi_err = MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_RDWR | MPI_MODE_CREATE, MPI_INFO_NULL,
                                  &fh)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_open failed (%s)\n", mpi_err_str);
+        printf("MPI_File_open failed (%s)\n", mpi_err_str);
         return 1;
     }
 
@@ -703,13 +711,13 @@ test_mpio_derived_dtype(char *filename)
 
     if ((mpi_err = MPI_Type_create_hindexed(count, blocklens, offsets, MPI_BYTE, &filetype)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_Type_contiguous failed (%s)\n", mpi_err_str);
+        printf("MPI_Type_contiguous failed (%s)\n", mpi_err_str);
         return 1;
     }
 
     if ((mpi_err = MPI_Type_commit(&filetype)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_Type_commit failed (%s)\n", mpi_err_str);
+        printf("MPI_Type_commit failed (%s)\n", mpi_err_str);
         return 1;
     }
 
@@ -719,13 +727,13 @@ test_mpio_derived_dtype(char *filename)
     if ((mpi_err = MPI_Type_create_hindexed(count, blocklens, offsets, MPI_BYTE, &filetypenew)) !=
         MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_Type_contiguous failed (%s)\n", mpi_err_str);
+        printf("MPI_Type_contiguous failed (%s)\n", mpi_err_str);
         return 1;
     }
 
     if ((mpi_err = MPI_Type_commit(&filetypenew)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_Type_commit failed (%s)\n", mpi_err_str);
+        printf("MPI_Type_commit failed (%s)\n", mpi_err_str);
         return 1;
     }
 
@@ -740,49 +748,67 @@ test_mpio_derived_dtype(char *filename)
     if ((mpi_err = MPI_Type_create_struct(outcount, adv_blocklens, adv_disp, bas_filetype, &adv_filetype)) !=
         MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_Type_create_struct failed (%s)\n", mpi_err_str);
+        printf("MPI_Type_create_struct failed (%s)\n", mpi_err_str);
         return 1;
     }
     if ((mpi_err = MPI_Type_commit(&adv_filetype)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_Type_commit failed (%s)\n", mpi_err_str);
+        printf("MPI_Type_commit failed (%s)\n", mpi_err_str);
         return 1;
     }
 
     if ((mpi_err = MPI_File_set_view(fh, disp, etype, adv_filetype, "native", MPI_INFO_NULL)) !=
         MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_set_view failed (%s)\n", mpi_err_str);
+        printf("MPI_File_set_view failed (%s)\n", mpi_err_str);
         return 1;
     }
 
     if ((mpi_err = MPI_File_write(fh, buf, 3, MPI_BYTE, &Status)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_write failed (%s)\n", mpi_err_str);
+        printf("MPI_File_write failed (%s)\n", mpi_err_str);
         return 1;
     }
 
     if ((mpi_err = MPI_File_close(&fh)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_close failed (%s)\n", mpi_err_str);
+        printf("MPI_File_close failed (%s)\n", mpi_err_str);
+        return 1;
+    }
+
+    if ((mpi_err = MPI_Type_free(&filetype)) != MPI_SUCCESS) {
+        MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
+        printf("MPI_Type_free failed (%s)\n", mpi_err_str);
+        return 1;
+    }
+
+    if ((mpi_err = MPI_Type_free(&adv_filetype)) != MPI_SUCCESS) {
+        MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
+        printf("MPI_Type_free failed (%s)\n", mpi_err_str);
+        return 1;
+    }
+
+    if ((mpi_err = MPI_Type_free(&filetypenew)) != MPI_SUCCESS) {
+        MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
+        printf("MPI_Type_free failed (%s)\n", mpi_err_str);
         return 1;
     }
 
     if ((mpi_err = MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_RDONLY, MPI_INFO_NULL, &fh)) !=
         MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_open failed (%s)\n", mpi_err_str);
+        printf("MPI_File_open failed (%s)\n", mpi_err_str);
         return 1;
     }
 
     if ((mpi_err = MPI_File_set_view(fh, 0, MPI_BYTE, MPI_BYTE, "native", MPI_INFO_NULL)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_set_view failed (%s)\n", mpi_err_str);
+        printf("MPI_File_set_view failed (%s)\n", mpi_err_str);
         return 1;
     }
     if ((mpi_err = MPI_File_read(fh, outbuf, 3, MPI_BYTE, &Status)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_read failed (%s)\n", mpi_err_str);
+        printf("MPI_File_read failed (%s)\n", mpi_err_str);
         return 1;
     }
 
@@ -791,9 +817,9 @@ test_mpio_derived_dtype(char *filename)
     }
     else {
         /*      if(mpi_rank == 0) {
-        HDprintf("complicated derived datatype is NOT working at this platform\n");
-        HDprintf("go back to hdf5/config and find the corresponding\n");
-        HDprintf("configure-specific file and change ?????\n");
+        printf("complicated derived datatype is NOT working at this platform\n");
+        printf("go back to hdf5/config and find the corresponding\n");
+        printf("configure-specific file and change ?????\n");
         }
         */
         retcode = -1;
@@ -801,15 +827,15 @@ test_mpio_derived_dtype(char *filename)
 
     if ((mpi_err = MPI_File_close(&fh)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_close failed (%s)\n", mpi_err_str);
+        printf("MPI_File_close failed (%s)\n", mpi_err_str);
         return 1;
     }
 
     mpi_err = MPI_Barrier(MPI_COMM_WORLD);
     if (retcode == -1) {
         if (mpi_rank == 0) {
-            HDprintf("Complicated derived datatype is NOT working at this platform\n");
-            HDprintf(" Please report to help@hdfgroup.org about this problem.\n");
+            printf("Complicated derived datatype is NOT working at this platform\n");
+            printf(" Please report to help@hdfgroup.org about this problem.\n");
         }
         retcode = 1;
     }
@@ -834,7 +860,7 @@ test_mpio_derived_dtype(char *filename)
  2. This test will fail with the MPI-IO package that doesn't support this. For example,
  mpich 1.2.6.
 
- If this bug has been fixed in the previous not-working package, this test will issue a HDprintf message to
+ If this bug has been fixed in the previous not-working package, this test will issue a printf message to
  tell the developer to change the configuration specific file of HDF5 so that we can change our
  configurationsetting to support special collective IO; currently only special collective IO.
 
@@ -848,7 +874,9 @@ test_mpio_special_collective(char *filename)
 {
     int          mpi_size, mpi_rank;
     MPI_File     fh;
-    MPI_Datatype etype, buftype, filetype;
+    MPI_Datatype etype;
+    MPI_Datatype filetype = MPI_BYTE;
+    MPI_Datatype buftype  = MPI_BYTE;
     char         mpi_err_str[MPI_MAX_ERROR_STRING];
     int          mpi_err_strlen;
     int          mpi_err;
@@ -884,38 +912,34 @@ test_mpio_special_collective(char *filename)
     if (count != 0) {
         if ((mpi_err = MPI_Type_create_hindexed(2, blocklens, offsets, etype, &filetype)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-            HDprintf("MPI_Type_contiguous failed (%s)\n", mpi_err_str);
+            printf("MPI_Type_contiguous failed (%s)\n", mpi_err_str);
             return 1;
         } /* end if */
 
         if ((mpi_err = MPI_Type_commit(&filetype)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-            HDprintf("MPI_Type_commit failed (%s)\n", mpi_err_str);
+            printf("MPI_Type_commit failed (%s)\n", mpi_err_str);
             return 1;
         } /* end if */
 
         if ((mpi_err = MPI_Type_create_hindexed(2, blocklens, offsets, etype, &buftype)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-            HDprintf("MPI_Type_contiguous failed (%s)\n", mpi_err_str);
+            printf("MPI_Type_contiguous failed (%s)\n", mpi_err_str);
             return 1;
         } /* end if */
 
         if ((mpi_err = MPI_Type_commit(&buftype)) != MPI_SUCCESS) {
             MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-            HDprintf("MPI_Type_commit failed (%s)\n", mpi_err_str);
+            printf("MPI_Type_commit failed (%s)\n", mpi_err_str);
             return 1;
         } /* end if */
     }     /* end if */
-    else {
-        filetype = MPI_BYTE;
-        buftype  = MPI_BYTE;
-    } /* end else */
 
     /* Open a file */
     if ((mpi_err = MPI_File_open(MPI_COMM_WORLD, filename, MPI_MODE_RDWR | MPI_MODE_CREATE, MPI_INFO_NULL,
                                  &fh)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_open failed (%s)\n", mpi_err_str);
+        printf("MPI_File_open failed (%s)\n", mpi_err_str);
         return 1;
     } /* end if */
 
@@ -927,23 +951,35 @@ test_mpio_special_collective(char *filename)
     if ((mpi_err = MPI_File_set_view(fh, mpi_off, MPI_BYTE, filetype, filerep, MPI_INFO_NULL)) !=
         MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_set_view failed (%s)\n", mpi_err_str);
+        printf("MPI_File_set_view failed (%s)\n", mpi_err_str);
         return 1;
     } /* end if */
 
+    if (filetype != MPI_BYTE && (mpi_err = MPI_Type_free(&filetype)) != MPI_SUCCESS) {
+        MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
+        printf("MPI_Type_free failed (%s)\n", mpi_err_str);
+        return 1;
+    }
+
     /* Collectively write into the file */
     if ((mpi_err = MPI_File_write_at_all(fh, mpi_off, writedata, bufcount, buftype, &mpi_stat)) !=
         MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_write_at offset(%ld), bytes (%d), failed (%s)\n", (long)mpi_off, bufcount,
-                 mpi_err_str);
+        printf("MPI_File_write_at offset(%ld), bytes (%d), failed (%s)\n", (long)mpi_off, bufcount,
+               mpi_err_str);
         return 1;
     } /* end if */
 
+    if (buftype != MPI_BYTE && (mpi_err = MPI_Type_free(&buftype)) != MPI_SUCCESS) {
+        MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
+        printf("MPI_Type_free failed (%s)\n", mpi_err_str);
+        return 1;
+    }
+
     /* Close the file */
     if ((mpi_err = MPI_File_close(&fh)) != MPI_SUCCESS) {
         MPI_Error_string(mpi_err, mpi_err_str, &mpi_err_strlen);
-        HDprintf("MPI_File_close failed. \n");
+        printf("MPI_File_close failed. \n");
         return 1;
     } /* end if */
 
@@ -951,8 +987,8 @@ test_mpio_special_collective(char *filename)
     mpi_err = MPI_Barrier(MPI_COMM_WORLD);
     if (retcode != 0) {
         if (mpi_rank == 0) {
-            HDprintf("special collective IO is NOT working at this platform\n");
-            HDprintf(" Please report to help@hdfgroup.org about this problem.\n");
+            printf("special collective IO is NOT working at this platform\n");
+            printf(" Please report to help@hdfgroup.org about this problem.\n");
         } /* end if */
         retcode = 1;
     } /* end if */
@@ -967,6 +1003,10 @@ test_mpio_special_collective(char *filename)
 static int
 parse_options(int argc, char **argv)
 {
+    int mpi_rank;
+
+    MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
+
     while (--argc) {
         if (**(++argv) != '-') {
             break;
@@ -974,8 +1014,10 @@ parse_options(int argc, char **argv)
         else {
             switch (*(*argv + 1)) {
                 case 'v':
-                    if (*((*argv + 1) + 1))
-                        ParseTestVerbosity((*argv + 1) + 1);
+                    if (*((*argv + 1) + 1)) {
+                        if (ParseTestVerbosity((*argv + 1) + 1) < 0)
+                            return 1;
+                    }
                     else
                         SetTestVerbosity(VERBO_MED);
                     break;
@@ -1010,15 +1052,15 @@ parse_options(int argc, char **argv)
 
         for (i = 0; i < n; i++)
             if (h5_fixname(FILENAME[i], plist, filenames[i], sizeof(filenames[i])) == NULL) {
-                HDprintf("h5_fixname failed\n");
+                printf("h5_fixname failed\n");
                 nerrors++;
                 return (1);
             }
         H5Pclose(plist);
-        if (VERBOSE_MED) {
-            HDprintf("Test filenames are:\n");
+        if (VERBOSE_MED && MAINPROCESS) {
+            printf("Test filenames are:\n");
             for (i = 0; i < n; i++)
-                HDprintf("    %s\n", filenames[i]);
+                printf("    %s\n", filenames[i]);
         }
     }
 
@@ -1031,10 +1073,10 @@ parse_options(int argc, char **argv)
 static void
 usage(void)
 {
-    HDprintf("Usage: t_mpi [-v<verbosity>] [-f <prefix>]\n");
-    HDprintf("\t-v<verbosity>\tset verbose level (0-9,l,m,h)\n");
-    HDprintf("\t-f <prefix>\tfilename prefix\n");
-    HDprintf("\n");
+    printf("Usage: t_mpi [-v<verbosity>] [-f <prefix>]\n");
+    printf("\t-v<verbosity>\tset verbose level (0-9,l,m,h)\n");
+    printf("\t-f <prefix>\tfilename prefix\n");
+    printf("\n");
 }
 
 /*
@@ -1064,7 +1106,7 @@ main(int argc, char **argv)
      * calls.  By then, MPI calls may not work.
      */
     if (H5dont_atexit() < 0) {
-        HDprintf("Failed to turn off atexit processing. Continue.\n");
+        printf("Failed to turn off atexit processing. Continue.\n");
     };
     H5open();
     if (parse_options(argc, argv) != 0) {
@@ -1074,9 +1116,9 @@ main(int argc, char **argv)
     }
 
     if (MAINPROCESS) {
-        HDprintf("===================================\n");
-        HDprintf("MPI functionality tests\n");
-        HDprintf("===================================\n");
+        printf("===================================\n");
+        printf("MPI functionality tests\n");
+        printf("===================================\n");
     }
 
     if (VERBOSE_MED)
@@ -1086,7 +1128,12 @@ main(int argc, char **argv)
     H5Pset_fapl_mpio(fapl, MPI_COMM_WORLD, MPI_INFO_NULL);
 
     /* set alarm. */
-    TestAlarmOn();
+    if (TestAlarmOn() < 0) {
+        if (MAINPROCESS)
+            fprintf(stderr, "couldn't enable test timer\n");
+        fflush(stderr);
+        MPI_Abort(MPI_COMM_WORLD, -1);
+    }
 
     /*=======================================
      * MPIO 1 write Many read test
@@ -1095,7 +1142,7 @@ main(int argc, char **argv)
     ret_code = test_mpio_1wMr(filenames[0], USENONE);
     ret_code = errors_sum(ret_code);
     if (mpi_rank == 0 && ret_code > 0) {
-        HDprintf("***FAILED with %d total errors\n", ret_code);
+        printf("***FAILED with %d total errors\n", ret_code);
         nerrors += ret_code;
     }
 
@@ -1106,7 +1153,7 @@ main(int argc, char **argv)
         ret_code = test_mpio_1wMr(filenames[0], USEATOM);
         ret_code = errors_sum(ret_code);
         if (mpi_rank == 0 && ret_code > 0) {
-            HDprintf("***FAILED with %d total errors\n", ret_code);
+            printf("***FAILED with %d total errors\n", ret_code);
             nerrors += ret_code;
         }
 
@@ -1114,7 +1161,7 @@ main(int argc, char **argv)
         ret_code = test_mpio_1wMr(filenames[0], USEFSYNC);
         ret_code = errors_sum(ret_code);
         if (mpi_rank == 0 && ret_code > 0) {
-            HDprintf("***FAILED with %d total errors\n", ret_code);
+            printf("***FAILED with %d total errors\n", ret_code);
             nerrors += ret_code;
         }
     }
@@ -1127,12 +1174,12 @@ main(int argc, char **argv)
     ret_code = test_mpio_gb_file(filenames[0]);
     ret_code = errors_sum(ret_code);
     if (mpi_rank == 0 && ret_code > 0) {
-        HDprintf("***FAILED with %d total errors\n", ret_code);
+        printf("***FAILED with %d total errors\n", ret_code);
         nerrors += ret_code;
     }
 #else
     if (mpi_rank == 0)
-        HDprintf(" will be skipped on Windows (JIRA HDDFV-8064)\n");
+        printf(" will be skipped on Windows (JIRA HDDFV-8064)\n");
 #endif
 
     /*=======================================
@@ -1142,7 +1189,7 @@ main(int argc, char **argv)
     ret_code = test_mpio_overlap_writes(filenames[0]);
     ret_code = errors_sum(ret_code);
     if (mpi_rank == 0 && ret_code > 0) {
-        HDprintf("***FAILED with %d total errors\n", ret_code);
+        printf("***FAILED with %d total errors\n", ret_code);
         nerrors += ret_code;
     }
 
@@ -1153,7 +1200,7 @@ main(int argc, char **argv)
     ret_code = test_mpio_derived_dtype(filenames[0]);
     ret_code = errors_sum(ret_code);
     if (mpi_rank == 0 && ret_code > 0) {
-        HDprintf("***FAILED with %d total errors\n", ret_code);
+        printf("***FAILED with %d total errors\n", ret_code);
         nerrors += ret_code;
     }
 
@@ -1163,7 +1210,7 @@ main(int argc, char **argv)
     if (mpi_size < 4) {
         MPI_BANNER("MPIO special collective io test SKIPPED.");
         if (mpi_rank == 0)
-            HDprintf("This test needs at least four processes to run.\n");
+            printf("This test needs at least four processes to run.\n");
         ret_code = 0;
         goto sc_finish;
     } /* end if */
@@ -1174,7 +1221,7 @@ main(int argc, char **argv)
 sc_finish:
     ret_code = errors_sum(ret_code);
     if (mpi_rank == 0 && ret_code > 0) {
-        HDprintf("***FAILED with %d total errors\n", ret_code);
+        printf("***FAILED with %d total errors\n", ret_code);
         nerrors += ret_code;
     }
 
@@ -1184,20 +1231,21 @@ finish:
      */
     MPI_Barrier(MPI_COMM_WORLD);
     if (MAINPROCESS) { /* only process 0 reports */
-        HDprintf("===================================\n");
+        printf("===================================\n");
         if (nerrors) {
-            HDprintf("***MPI tests detected %d errors***\n", nerrors);
+            printf("***MPI tests detected %d errors***\n", nerrors);
         }
         else {
-            HDprintf("MPI tests finished with no errors\n");
+            printf("MPI tests finished with no errors\n");
         }
-        HDprintf("===================================\n");
+        printf("===================================\n");
     }
 
     /* turn off alarm */
     TestAlarmOff();
 
-    h5_clean_files(FILENAME, fapl);
+    h5_delete_all_test_files(FILENAME, fapl);
+    H5Pclose(fapl);
     H5close();
 
     /* MPI_Finalize must be called AFTER H5close which may use MPI calls */
