@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -28,10 +28,6 @@
 unsigned           h5tools_nCols    = 80;
 static int         h5tools_d_status = 0;
 static const char *h5tools_progname = "h5tools";
-/* ``get_option'' variables */
-int         opt_err = 1; /*get_option prints errors if this is on */
-int         opt_ind = 1; /*token pointer                          */
-const char *opt_arg;     /*flag argument (or value)               */
 
 /*
  * The output functions need a temporary buffer to hold a piece of the
@@ -55,7 +51,7 @@ static void init_table(hid_t fid, table_t **tbl);
 #ifdef H5DUMP_DEBUG
 static void dump_table(hid_t fid, char *tablename, table_t *table);
 #endif /* H5DUMP_DEBUG */
-static void add_obj(table_t *table, const H5O_token_t *obj_token, const char *objname, hbool_t recorded);
+static void add_obj(table_t *table, const H5O_token_t *obj_token, const char *objname, bool recorded);
 
 /*-------------------------------------------------------------------------
  * Function: parallel_print
@@ -69,41 +65,41 @@ parallel_print(const char *format, ...)
     int     bytes_written;
     va_list ap;
 
-    HDva_start(ap, format);
+    va_start(ap, format);
 
     if (!g_Parallel)
-        HDvprintf(format, ap);
+        vprintf(format, ap);
     else {
         if (overflow_file == NULL) /*no overflow has occurred yet */ {
-            bytes_written = HDvsnprintf(outBuff + outBuffOffset, OUTBUFF_SIZE - outBuffOffset, format, ap);
-            HDva_end(ap);
-            HDva_start(ap, format);
+            bytes_written = vsnprintf(outBuff + outBuffOffset, OUTBUFF_SIZE - outBuffOffset, format, ap);
+            va_end(ap);
+            va_start(ap, format);
 
             if ((bytes_written < 0) || ((unsigned)bytes_written >= (OUTBUFF_SIZE - outBuffOffset))) {
                 /* Terminate the outbuff at the end of the previous output */
                 outBuff[outBuffOffset] = '\0';
 
-                overflow_file = HDtmpfile();
+                overflow_file = tmpfile();
                 if (overflow_file == NULL)
-                    HDfprintf(rawerrorstream,
-                              "warning: could not create overflow file.  Output may be truncated.\n");
+                    fprintf(rawerrorstream,
+                            "warning: could not create overflow file.  Output may be truncated.\n");
                 else
-                    bytes_written = HDvfprintf(overflow_file, format, ap);
+                    bytes_written = vfprintf(overflow_file, format, ap);
             }
             else
                 outBuffOffset += (unsigned)bytes_written;
         }
         else
-            bytes_written = HDvfprintf(overflow_file, format, ap);
+            bytes_written = vfprintf(overflow_file, format, ap);
     }
-    HDva_end(ap);
+    va_end(ap);
 }
 
 /*-------------------------------------------------------------------------
  * Function: error_msg
  *
- * Purpose:  Print a nicely formatted error message to stderr flushing the
- *              stdout stream first.
+ * Purpose:  Print a nicely formatted error message to stderr stream flushing
+ *           the stdout stream first.
  *
  * Return:   Nothing
  *-------------------------------------------------------------------------
@@ -113,20 +109,20 @@ error_msg(const char *fmt, ...)
 {
     va_list ap;
 
-    HDva_start(ap, fmt);
+    va_start(ap, fmt);
     FLUSHSTREAM(rawattrstream);
     FLUSHSTREAM(rawdatastream);
     FLUSHSTREAM(rawoutstream);
-    HDfprintf(rawerrorstream, "%s error: ", h5tools_getprogname());
-    HDvfprintf(rawerrorstream, fmt, ap);
+    fprintf(rawerrorstream, "%s error: ", h5tools_getprogname());
+    vfprintf(rawerrorstream, fmt, ap);
 
-    HDva_end(ap);
+    va_end(ap);
 }
 
 /*-------------------------------------------------------------------------
  * Function: warn_msg
  *
- * Purpose:  Print a nicely formatted warning message to stderr flushing
+ * Purpose:  Print a nicely formatted warning message to stderr stream flushing
  *              the stdout stream first.
  *
  * Return:   Nothing
@@ -137,13 +133,13 @@ warn_msg(const char *fmt, ...)
 {
     va_list ap;
 
-    HDva_start(ap, fmt);
+    va_start(ap, fmt);
     FLUSHSTREAM(rawattrstream);
     FLUSHSTREAM(rawdatastream);
     FLUSHSTREAM(rawoutstream);
-    HDfprintf(rawerrorstream, "%s warning: ", h5tools_getprogname());
-    HDvfprintf(rawerrorstream, fmt, ap);
-    HDva_end(ap);
+    fprintf(rawerrorstream, "%s warning: ", h5tools_getprogname());
+    vfprintf(rawerrorstream, fmt, ap);
+    va_end(ap);
 }
 
 /*-------------------------------------------------------------------------
@@ -157,8 +153,8 @@ warn_msg(const char *fmt, ...)
 void
 help_ref_msg(FILE *output)
 {
-    HDfprintf(output, "Try '-h' or '--help' for more information or ");
-    HDfprintf(output, "see the <%s> entry in the 'HDF5 Reference Manual'.\n", h5tools_getprogname());
+    fprintf(output, "Try '-h' or '--help' for more information or ");
+    fprintf(output, "see the <%s> entry in the 'HDF5 Reference Manual'.\n", h5tools_getprogname());
 }
 
 /*-------------------------------------------------------------------------
@@ -191,7 +187,7 @@ parse_hsize_list(const char *h_list, subset_d *d)
     H5TOOLS_START_DEBUG(" - h_list:%s", h_list);
     /* count how many integers do we have */
     for (ptr = h_list; ptr && *ptr && *ptr != ';' && *ptr != ']'; ptr++)
-        if (HDisdigit(*ptr)) {
+        if (isdigit(*ptr)) {
             if (!last_digit)
                 /* the last read character wasn't a digit */
                 size_count++;
@@ -209,15 +205,15 @@ parse_hsize_list(const char *h_list, subset_d *d)
     H5TOOLS_DEBUG("Number integers to read=%ld", size_count);
 
     /* allocate an array for the integers in the list */
-    if ((p_list = (hsize_t *)HDcalloc(size_count, sizeof(hsize_t))) == NULL)
+    if ((p_list = (hsize_t *)calloc(size_count, sizeof(hsize_t))) == NULL)
         H5TOOLS_INFO("Unable to allocate space for subset data");
 
     for (ptr = h_list; i < size_count && ptr && *ptr && *ptr != ';' && *ptr != ']'; ptr++)
-        if (HDisdigit(*ptr)) {
+        if (isdigit(*ptr)) {
             /* we should have an integer now */
-            p_list[i++] = (hsize_t)HDstrtoull(ptr, NULL, 0);
+            p_list[i++] = (hsize_t)strtoull(ptr, NULL, 0);
 
-            while (HDisdigit(*ptr))
+            while (isdigit(*ptr))
                 /* scroll to end of integer */
                 ptr++;
         }
@@ -245,13 +241,13 @@ parse_subset_params(const char *dset)
     H5TOOLS_START_DEBUG(" - dset:%s", dset);
     /* if dset name is quoted wait till after second quote to look for subset brackets */
     if (*dset == '"')
-        q_dset = HDstrchr(dset, '"');
+        q_dset = strchr(dset, '"');
     else
         q_dset = dset;
-    if ((brace = HDstrrchr(q_dset, '[')) != NULL) {
+    if ((brace = strrchr(q_dset, '[')) != NULL) {
         *brace++ = '\0';
 
-        s = (struct subset_t *)HDcalloc(1, sizeof(struct subset_t));
+        s = (struct subset_t *)calloc(1, sizeof(struct subset_t));
         parse_hsize_list(brace, &s->start);
 
         while (*brace && *brace != ';')
@@ -283,167 +279,6 @@ parse_subset_params(const char *dset)
     return s;
 }
 
-/*-------------------------------------------------------------------------
- * Function: get_option
- *
- * Purpose:  Determine the command-line options a user specified. We can
- *           accept both short and long type command-lines.
- *
- * Return:  Success:    The short valued "name" of the command line
- *                      parameter or EOF if there are no more
- *                      parameters to process.
- *
- *          Failure:    A question mark.
- *-------------------------------------------------------------------------
- */
-int
-get_option(int argc, const char *const *argv, const char *opts, const struct long_options *l_opts)
-{
-    static int sp      = 1;   /* character index in current token */
-    int        optchar = '?'; /* option character passed back to user */
-
-    if (sp == 1) {
-        /* check for more flag-like tokens */
-        if (opt_ind >= argc || argv[opt_ind][0] != '-' || argv[opt_ind][1] == '\0') {
-            return EOF;
-        }
-        else if (HDstrcmp(argv[opt_ind], "--") == 0) {
-            opt_ind++;
-            return EOF;
-        }
-    }
-
-    if (sp == 1 && argv[opt_ind][0] == '-' && argv[opt_ind][1] == '-') {
-        /* long command line option */
-        int        i;
-        const char ch      = '=';
-        char      *arg     = HDstrdup(&argv[opt_ind][2]);
-        size_t     arg_len = 0;
-
-        opt_arg = strchr(&argv[opt_ind][2], ch);
-        arg_len = HDstrlen(&argv[opt_ind][2]);
-        if (opt_arg) {
-            arg_len -= HDstrlen(opt_arg);
-            opt_arg++; /* skip the equal sign */
-        }
-        arg[arg_len] = 0;
-
-        for (i = 0; l_opts && l_opts[i].name; i++) {
-            if (HDstrcmp(arg, l_opts[i].name) == 0) {
-                /* we've found a matching long command line flag */
-                optchar = l_opts[i].shortval;
-
-                if (l_opts[i].has_arg != no_arg) {
-                    if (opt_arg == NULL) {
-                        if (l_opts[i].has_arg != optional_arg) {
-                            if (opt_ind < (argc - 1))
-                                if (argv[opt_ind + 1][0] != '-')
-                                    opt_arg = argv[++opt_ind];
-                        }
-                        else if (l_opts[i].has_arg == require_arg) {
-                            if (opt_err)
-                                HDfprintf(rawerrorstream, "%s: option required for \"--%s\" flag\n", argv[0],
-                                          arg);
-
-                            optchar = '?';
-                        }
-                    }
-                }
-                else {
-                    if (opt_arg) {
-                        if (opt_err)
-                            HDfprintf(rawerrorstream, "%s: no option required for \"%s\" flag\n", argv[0],
-                                      arg);
-
-                        optchar = '?';
-                    }
-                }
-                break;
-            }
-        }
-
-        if (l_opts[i].name == NULL) {
-            /* exhausted all of the l_opts we have and still didn't match */
-            if (opt_err)
-                HDfprintf(rawerrorstream, "%s: unknown option \"%s\"\n", argv[0], arg);
-
-            optchar = '?';
-        }
-
-        opt_ind++;
-        sp = 1;
-
-        HDfree(arg);
-    }
-    else {
-        char *cp; /* pointer into current token */
-
-        /* short command line option */
-        optchar = argv[opt_ind][sp];
-
-        if (optchar == ':' || (cp = HDstrchr(opts, optchar)) == 0) {
-            if (opt_err)
-                HDfprintf(rawerrorstream, "%s: unknown option \"%c\"\n", argv[0], optchar);
-
-            /* if no chars left in this token, move to next token */
-            if (argv[opt_ind][++sp] == '\0') {
-                opt_ind++;
-                sp = 1;
-            }
-            return '?';
-        }
-
-        if (*++cp == ':') {
-            /* if a value is expected, get it */
-            if (argv[opt_ind][sp + 1] != '\0') {
-                /* flag value is rest of current token */
-                opt_arg = &argv[opt_ind++][sp + 1];
-            }
-            else if (++opt_ind >= argc) {
-                if (opt_err)
-                    HDfprintf(rawerrorstream, "%s: value expected for option \"%c\"\n", argv[0], optchar);
-
-                optchar = '?';
-            }
-            else {
-                /* flag value is next token */
-                opt_arg = argv[opt_ind++];
-            }
-
-            sp = 1;
-        }
-        /* wildcard argument */
-        else if (*cp == '*') {
-            /* check the next argument */
-            opt_ind++;
-            /* we do have an extra argument, check if not last */
-            if ((opt_ind + 1) < argc) {
-                if (argv[opt_ind][0] != '-') {
-                    opt_arg = argv[opt_ind++];
-                }
-                else {
-                    opt_arg = NULL;
-                }
-            }
-            else {
-                opt_arg = NULL;
-            }
-        }
-        else {
-            /* set up to look at next char in token, next time */
-            if (argv[opt_ind][++sp] == '\0') {
-                /* no more in current token, so setup next token */
-                opt_ind++;
-                sp = 1;
-            }
-            opt_arg = NULL;
-        }
-    }
-
-    /* return the current flag character found */
-    return optchar;
-}
-
 /*****************************************************************************
  *
  * Function: parse_tuple()
@@ -502,9 +337,6 @@ get_option(int argc, const char *const *argv, const char *opts, const struct lon
  *                 NOTE: `cpy_out` string is malloc'd by function,
  *                       and should be freed when done.
  *
- * Programmer: Jacob Smith
- *             2017-11-10
- *
  *****************************************************************************
  */
 herr_t
@@ -548,7 +380,7 @@ parse_tuple(const char *start, int sep, char **cpy_out, unsigned *nelems, char *
 
     /* create list
      */
-    elems = (char **)HDmalloc(sizeof(char *) * (init_slots + 1));
+    elems = (char **)malloc(sizeof(char *) * (init_slots + 1));
     if (elems == NULL) {
         ret_value = FAIL;
         goto done;
@@ -556,8 +388,8 @@ parse_tuple(const char *start, int sep, char **cpy_out, unsigned *nelems, char *
 
     /* create destination string
      */
-    start++;                                                  /* advance past opening paren '(' */
-    cpy = (char *)HDmalloc(sizeof(char) * (HDstrlen(start))); /* no +1; less '(' */
+    start++;                                              /* advance past opening paren '(' */
+    cpy = (char *)malloc(sizeof(char) * (strlen(start))); /* no +1; less '(' */
     if (cpy == NULL) {
         ret_value = FAIL;
         goto done;
@@ -673,8 +505,8 @@ indentation(unsigned x)
             PRINTVALSTREAM(rawoutstream, " ");
     }
     else {
-        HDfprintf(rawerrorstream, "error: the indentation exceeds the number of cols.\n");
-        HDexit(1);
+        fprintf(rawerrorstream, "error: the indentation exceeds the number of cols.\n");
+        exit(1);
     }
 }
 
@@ -706,12 +538,12 @@ print_version(const char *progname)
 static void
 init_table(hid_t fid, table_t **tbl)
 {
-    table_t *table = (table_t *)HDmalloc(sizeof(table_t));
+    table_t *table = (table_t *)malloc(sizeof(table_t));
 
     table->fid   = fid;
     table->size  = 20;
     table->nobjs = 0;
-    table->objs  = (obj_t *)HDmalloc(table->size * sizeof(obj_t));
+    table->objs  = (obj_t *)malloc(table->size * sizeof(obj_t));
 
     *tbl = table;
 }
@@ -733,10 +565,10 @@ free_table(table_t *table)
     /* Free the names for the objects in the table */
     for (u = 0; u < table->nobjs; u++)
         if (table->objs[u].objname)
-            HDfree(table->objs[u].objname);
+            free(table->objs[u].objname);
 
-    HDfree(table->objs);
-    HDfree(table);
+    free(table->objs);
+    free(table);
 }
 
 #ifdef H5DUMP_DEBUG
@@ -757,12 +589,12 @@ dump_table(hid_t fid, char *tablename, table_t *table)
 
     PRINTSTREAM(rawoutstream, "%s: # of entries = %d\n", tablename, table->nobjs);
     for (u = 0; u < table->nobjs; u++) {
-        H5VLconnector_token_to_str(fid, table->objs[u].obj_token, &obj_tok_str);
+        H5Otoken_to_str(fid, &table->objs[u].obj_token, &obj_tok_str);
 
         PRINTSTREAM(rawoutstream, "%s %s %d %d\n", obj_tok_str, table->objs[u].objname,
                     table->objs[u].displayed, table->objs[u].recorded);
 
-        H5VLfree_token_str(fid, obj_tok_str);
+        H5free_memory(obj_tok_str);
     }
 }
 
@@ -828,7 +660,7 @@ find_objs_cb(const char *name, const H5O_info2_t *oinfo, const char *already_see
     switch (oinfo->type) {
         case H5O_TYPE_GROUP:
             if (NULL == already_seen)
-                add_obj(info->group_table, &oinfo->token, name, TRUE);
+                add_obj(info->group_table, &oinfo->token, name, true);
             break;
 
         case H5O_TYPE_DATASET:
@@ -836,7 +668,7 @@ find_objs_cb(const char *name, const H5O_info2_t *oinfo, const char *already_see
                 hid_t dset = H5I_INVALID_HID;
 
                 /* Add the dataset to the list of objects */
-                add_obj(info->dset_table, &oinfo->token, name, TRUE);
+                add_obj(info->dset_table, &oinfo->token, name, true);
 
                 /* Check for a dataset that uses a named datatype */
                 if ((dset = H5Dopen2(info->fid, name, H5P_DEFAULT)) >= 0) {
@@ -847,7 +679,7 @@ find_objs_cb(const char *name, const H5O_info2_t *oinfo, const char *already_see
 
                         H5Oget_info3(type, &type_oinfo, H5O_INFO_BASIC);
                         if (search_obj(info->type_table, &type_oinfo.token) == NULL)
-                            add_obj(info->type_table, &type_oinfo.token, name, FALSE);
+                            add_obj(info->type_table, &type_oinfo.token, name, false);
                     } /* end if */
 
                     H5Tclose(type);
@@ -863,14 +695,14 @@ find_objs_cb(const char *name, const H5O_info2_t *oinfo, const char *already_see
                 obj_t *found_obj;
 
                 if ((found_obj = search_obj(info->type_table, &oinfo->token)) == NULL)
-                    add_obj(info->type_table, &oinfo->token, name, TRUE);
+                    add_obj(info->type_table, &oinfo->token, name, true);
                 else {
                     /* Use latest version of name */
-                    HDfree(found_obj->objname);
-                    found_obj->objname = HDstrdup(name);
+                    free(found_obj->objname);
+                    found_obj->objname = strdup(name);
 
                     /* Mark named datatype as having valid name */
-                    found_obj->recorded = TRUE;
+                    found_obj->recorded = true;
                 } /* end else */
             }     /* end if */
             break;
@@ -912,7 +744,7 @@ init_objs(hid_t fid, find_objs_t *info, table_t **group_table, table_t **dset_ta
     info->dset_table  = *dset_table;
 
     /* Find all shared objects */
-    if ((ret_value = h5trav_visit(fid, "/", TRUE, TRUE, find_objs_cb, NULL, info, H5O_INFO_BASIC)) < 0)
+    if ((ret_value = h5trav_visit(fid, "/", true, true, find_objs_cb, NULL, info, H5O_INFO_BASIC)) < 0)
         H5TOOLS_GOTO_ERROR(FAIL, "finding shared objects failed");
 
 done:
@@ -938,22 +770,22 @@ done:
  *-------------------------------------------------------------------------
  */
 static void
-add_obj(table_t *table, const H5O_token_t *obj_token, const char *objname, hbool_t record)
+add_obj(table_t *table, const H5O_token_t *obj_token, const char *objname, bool record)
 {
     size_t u;
 
     /* See if we need to make table larger */
     if (table->nobjs == table->size) {
         table->size *= 2;
-        table->objs = (struct obj_t *)HDrealloc(table->objs, table->size * sizeof(table->objs[0]));
+        table->objs = (struct obj_t *)realloc(table->objs, table->size * sizeof(table->objs[0]));
     } /* end if */
 
     /* Increment number of objects in table */
     u = table->nobjs++;
 
     /* Set information about object */
-    HDmemcpy(&table->objs[u].obj_token, obj_token, sizeof(H5O_token_t));
-    table->objs[u].objname   = HDstrdup(objname);
+    memcpy(&table->objs[u].obj_token, obj_token, sizeof(H5O_token_t));
+    table->objs[u].objname   = strdup(objname);
     table->objs[u].recorded  = record;
     table->objs[u].displayed = 0;
 }
@@ -999,7 +831,7 @@ tmpfile(void)
  *-------------------------------------------------------------------------*/
 int
 H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t *link_info,
-                         hbool_t get_obj_type)
+                         bool get_obj_type)
 {
     htri_t      l_ret;
     H5O_info2_t trg_oinfo;
@@ -1011,7 +843,7 @@ H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t
     link_info->trg_type = H5O_TYPE_UNKNOWN;
 
     /* if path is root, return group type */
-    if (!HDstrcmp(linkpath, "/")) {
+    if (!strcmp(linkpath, "/")) {
         link_info->trg_type = H5O_TYPE_GROUP;
         H5TOOLS_GOTO_DONE(2);
     }
@@ -1035,7 +867,7 @@ H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t
         H5TOOLS_GOTO_DONE(2);
 
     /* trg_path must be freed out of this function when finished using */
-    if ((link_info->trg_path = (char *)HDcalloc(link_info->linfo.u.val_size, sizeof(char))) == NULL) {
+    if ((link_info->trg_path = (char *)calloc(link_info->linfo.u.val_size, sizeof(char))) == NULL) {
         if (link_info->opt.msg_mode == 1)
             parallel_print("Warning: unable to allocate buffer for <%s>\n", linkpath);
         H5TOOLS_GOTO_DONE(FAIL);
@@ -1073,7 +905,7 @@ H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t
         l_ret = H5Oexists_by_name(file_id, linkpath, lapl);
 
         /* detect dangling link */
-        if (l_ret == FALSE) {
+        if (l_ret == false) {
             H5TOOLS_GOTO_DONE(0);
         }
         else if (l_ret < 0) { /* function failed */
@@ -1095,7 +927,7 @@ H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t
         } /* end if */
 
         /* set target obj type to return */
-        HDmemcpy(&link_info->obj_token, &trg_oinfo.token, sizeof(H5O_token_t));
+        memcpy(&link_info->obj_token, &trg_oinfo.token, sizeof(H5O_token_t));
         link_info->trg_type = trg_oinfo.type;
         link_info->fileno   = trg_oinfo.fileno;
     } /* end if */
@@ -1162,9 +994,9 @@ h5tools_getenv_update_hyperslab_bufsize(void)
     int         ret_value = 1;
 
     /* check if environment variable is set for the hyperslab buffer size */
-    if (NULL != (env_str = HDgetenv("H5TOOLS_BUFSIZE"))) {
+    if (NULL != (env_str = getenv("H5TOOLS_BUFSIZE"))) {
         errno                = 0;
-        hyperslab_bufsize_mb = HDstrtol(env_str, (char **)NULL, 10);
+        hyperslab_bufsize_mb = strtol(env_str, (char **)NULL, 10);
         if (errno != 0 || hyperslab_bufsize_mb <= 0)
             H5TOOLS_GOTO_ERROR(FAIL, "hyperslab buffer size failed");
 
@@ -1193,9 +1025,9 @@ done:
  *----------------------------------------------------------------------------
  */
 herr_t
-h5tools_parse_ros3_fapl_tuple(const char *tuple_str, int delim, H5FD_ros3_fapl_t *fapl_config_out)
+h5tools_parse_ros3_fapl_tuple(const char *tuple_str, int delim, H5FD_ros3_fapl_ext_t *fapl_config_out)
 {
-    const char *ccred[3];
+    const char *ccred[4];
     unsigned    nelems     = 0;
     char       *s3cred_src = NULL;
     char      **s3cred     = NULL;
@@ -1206,21 +1038,27 @@ h5tools_parse_ros3_fapl_tuple(const char *tuple_str, int delim, H5FD_ros3_fapl_t
         H5TOOLS_GOTO_ERROR(FAIL, "failed to parse S3 VFD info tuple");
 
     /* Sanity-check tuple count */
-    if (nelems != 3)
+    if (nelems != 3 && nelems != 4)
         H5TOOLS_GOTO_ERROR(FAIL, "invalid S3 VFD credentials");
 
-    ccred[0] = (const char *)s3cred[0];
-    ccred[1] = (const char *)s3cred[1];
-    ccred[2] = (const char *)s3cred[2];
+    ccred[0] = (const char *)s3cred[0]; /* aws_region */
+    ccred[1] = (const char *)s3cred[1]; /* aws_access_key_id */
+    ccred[2] = (const char *)s3cred[2]; /* aws_secret_access_key */
+    if (nelems == 3) {
+        ccred[3] = "";
+    }
+    else {
+        ccred[3] = (const char *)s3cred[3]; /* aws_session_token */
+    }
 
-    if (0 == h5tools_populate_ros3_fapl(fapl_config_out, ccred))
+    if (FAIL == h5tools_populate_ros3_fapl(fapl_config_out, ccred, 4))
         H5TOOLS_GOTO_ERROR(FAIL, "failed to populate S3 VFD FAPL config");
 
 done:
     if (s3cred)
-        HDfree(s3cred);
+        free(s3cred);
     if (s3cred_src)
-        HDfree(s3cred_src);
+        free(s3cred_src);
 
     return ret_value;
 }
@@ -1241,11 +1079,11 @@ done:
  *     {   aws_region,
  *         secret_id,
  *         secret_key,
+ *         session_token (optional)
  *     }
- *     If all three strings are empty (""), the default fapl will be default.
- *     Both aws_region and secret_id values must be both empty or both
- *         populated. If
- *     Only secret_key is allowed to be empty (the empty string, "").
+ *     If all three (or four) strings are empty (""), the default fapl will be
+ *     default. The aws_region and secret_id values must be both empty or both
+ *     populated. Only secret_key is allowed to be empty (the empty string, "").
  *     All values are checked against overflow as defined in the ros3 vfd
  *     header file; if a value overruns the permitted space, FAIL is returned
  *     and the function aborts without resetting the fapl to values initially
@@ -1253,148 +1091,108 @@ done:
  *
  * Return:
  *
- *     0 (failure) if...
+ *     FAIL if...
  *         * Read-Only S3 VFD is not enabled.
  *         * NULL fapl pointer: (NULL, {...} )
  *         * Warning: In all cases below, fapl will be set as "default"
  *                    before error occurs.
- *         * NULL value strings: (&fa, {NULL?, NULL? NULL?, ...})
+ *         * NULL value strings: (&fa, {NULL?, NULL? NULL?, NULL?, ...})
  *         * Incomplete fapl info:
- *             * empty region, non-empty id, key either way
- *                 * (&fa, {"", "...", "?"})
- *             * empty id, non-empty region, key either way
- *                 * (&fa, {"...", "", "?"})
- *             * "non-empty key and either id or region empty
- *                 * (&fa, {"",    "",    "...")
- *                 * (&fa, {"",    "...", "...")
- *                 * (&fa, {"...", "",    "...")
+ *             * empty region, non-empty id, key either way, token either way
+ *                 * (&fa, token, {"", "...", "?", "?"})
+ *             * non-empty region, empty id, key either way, token either way
+ *                 * (&fa, token,  {"...", "", "?", "?"})
+ *             * "non-empty key, token either way and either id or region empty
+ *                 * (&fa, token, {"",    "",    "...", "?")
+ *                 * (&fa, token, {"",    "...", "...", "?")
+ *                 * (&fa, token, {"...", "",    "...", "?")
  *             * Any string would overflow allowed space in fapl definition.
  *     or
- *     1 (success)
+ *     SUCCEED
  *         * Sets components in fapl_t pointer, copying strings as appropriate.
  *         * "Default" fapl (valid version, authenticate->False, empty strings)
  *             * `values` pointer is NULL
- *                 * (&fa, NULL)
- *             * first three strings in `values` are empty ("")
- *                 * (&fa, {"", "", "", ...}
+ *                 * (&fa, token, NULL)
+ *             * first four strings in `values` are empty ("")
+ *                 * (&fa, token,  {"", "", "", "", ...})
  *         * Authenticating fapl
- *             * region, id, and optional key provided
- *                 * (&fa, {"...", "...", ""})
- *                 * (&fa, {"...", "...", "..."})
+ *             * region, id, optional key and option session token provided
+ *                 * (&fa, token, {"...", "...", "", ""})
+ *                 * (&fa, token, {"...", "...", "...", ""})
+ *                 * (&fa, token, {"...", "...", "...", "..."})
  *
- * Programmer: Jacob Smith
- *             2017-11-13
+ * Return:   SUCCEED/FAIL
  *
  *----------------------------------------------------------------------------
  */
-int
-h5tools_populate_ros3_fapl(H5FD_ros3_fapl_t *fa, const char **values)
+herr_t
+h5tools_populate_ros3_fapl(H5FD_ros3_fapl_ext_t *fa, const char **values, size_t num_values)
 {
-    int show_progress = 0; /* set to 1 for debugging */
-    int ret_value     = 1; /* 1 for success, 0 for failure           */
-                           /* e.g.? if (!populate()) { then failed } */
+    herr_t ret_value = SUCCEED;
 
-    if (show_progress) {
-        HDprintf("called h5tools_populate_ros3_fapl\n");
-    }
+    H5TOOLS_START_DEBUG("");
 
-    if (fa == NULL) {
-        if (show_progress) {
-            HDprintf("  ERROR: null pointer to fapl_t\n");
-        }
-        ret_value = 0;
-        goto done;
-    }
+    if (fa == NULL)
+        H5TOOLS_GOTO_ERROR(FAIL, "ERROR: null pointer to fapl_t\n");
+    if (values && (num_values < 3))
+        H5TOOLS_GOTO_ERROR(FAIL, "ERROR: too few values (< 3) provided\n");
 
-    if (show_progress) {
-        HDprintf("  preset fapl with default values\n");
-    }
-    fa->version       = H5FD_CURR_ROS3_FAPL_T_VERSION;
-    fa->authenticate  = FALSE;
-    *(fa->aws_region) = '\0';
-    *(fa->secret_id)  = '\0';
-    *(fa->secret_key) = '\0';
+    H5TOOLS_DEBUG("  preset fapl with default values\n");
+    fa->fa.version       = H5FD_CURR_ROS3_FAPL_T_VERSION;
+    fa->fa.authenticate  = false;
+    *(fa->fa.aws_region) = '\0';
+    *(fa->fa.secret_id)  = '\0';
+    *(fa->fa.secret_key) = '\0';
+    *(fa->token)         = '\0';
 
-    /* sanity-check supplied values
-     */
+    /* sanity-check supplied values */
     if (values != NULL) {
-        if (values[0] == NULL) {
-            if (show_progress) {
-                HDprintf("  ERROR: aws_region value cannot be NULL\n");
-            }
-            ret_value = 0;
-            goto done;
-        }
-        if (values[1] == NULL) {
-            if (show_progress) {
-                HDprintf("  ERROR: secret_id value cannot be NULL\n");
-            }
-            ret_value = 0;
-            goto done;
-        }
-        if (values[2] == NULL) {
-            if (show_progress) {
-                HDprintf("  ERROR: secret_key value cannot be NULL\n");
-            }
-            ret_value = 0;
-            goto done;
-        }
+        if (values[0] == NULL)
+            H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: aws_region value cannot be NULL\n");
+        if (values[1] == NULL)
+            H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: secret_id value cannot be NULL\n");
+        if (values[2] == NULL)
+            H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: secret_key value cannot be NULL\n");
+        if ((num_values > 3) && (values[3] == NULL))
+            H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: token value cannot be NULL\n");
 
         /* if region and ID are supplied (key optional), write to fapl...
          * fail if value would overflow
          */
         if (*values[0] != '\0' && *values[1] != '\0') {
-            if (HDstrlen(values[0]) > H5FD_ROS3_MAX_REGION_LEN) {
-                if (show_progress) {
-                    HDprintf("  ERROR: aws_region value too long\n");
-                }
-                ret_value = 0;
-                goto done;
-            }
-            HDmemcpy(fa->aws_region, values[0], (HDstrlen(values[0]) + 1));
-            if (show_progress) {
-                HDprintf("  aws_region set\n");
+            if (strlen(values[0]) > H5FD_ROS3_MAX_REGION_LEN)
+                H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: aws_region value too long\n");
+            memcpy(fa->fa.aws_region, values[0], (strlen(values[0]) + 1));
+            H5TOOLS_DEBUG("  aws_region set\n");
+
+            if (strlen(values[1]) > H5FD_ROS3_MAX_SECRET_ID_LEN)
+                H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: secret_id value too long\n");
+            memcpy(fa->fa.secret_id, values[1], (strlen(values[1]) + 1));
+            H5TOOLS_DEBUG("  secret_id set\n");
+
+            if (strlen(values[2]) > H5FD_ROS3_MAX_SECRET_KEY_LEN)
+                H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: secret_key value too long\n");
+            memcpy(fa->fa.secret_key, values[2], (strlen(values[2]) + 1));
+            H5TOOLS_DEBUG("  secret_key set\n");
+
+            if (num_values > 3) {
+                if (strlen(values[3]) > H5FD_ROS3_MAX_SECRET_TOK_LEN)
+                    H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: token value too long\n");
+                memcpy(fa->token, values[3], (strlen(values[3]) + 1));
+                H5TOOLS_DEBUG("  token set\n");
             }
 
-            if (HDstrlen(values[1]) > H5FD_ROS3_MAX_SECRET_ID_LEN) {
-                if (show_progress) {
-                    HDprintf("  ERROR: secret_id value too long\n");
-                }
-                ret_value = 0;
-                goto done;
-            }
-            HDmemcpy(fa->secret_id, values[1], (HDstrlen(values[1]) + 1));
-            if (show_progress) {
-                HDprintf("  secret_id set\n");
-            }
-
-            if (HDstrlen(values[2]) > H5FD_ROS3_MAX_SECRET_KEY_LEN) {
-                if (show_progress) {
-                    HDprintf("  ERROR: secret_key value too long\n");
-                }
-                ret_value = 0;
-                goto done;
-            }
-            HDmemcpy(fa->secret_key, values[2], (HDstrlen(values[2]) + 1));
-            if (show_progress) {
-                HDprintf("  secret_key set\n");
-            }
-
-            fa->authenticate = TRUE;
-            if (show_progress) {
-                HDprintf("  set to authenticate\n");
-            }
+            fa->fa.authenticate = true;
+            H5TOOLS_DEBUG("  set to authenticate\n");
         }
-        else if (*values[0] != '\0' || *values[1] != '\0' || *values[2] != '\0') {
-            if (show_progress) {
-                HDprintf("  ERROR: invalid assortment of empty/non-empty values\n");
-            }
-            ret_value = 0;
-            goto done;
+        else if (*values[0] != '\0' || *values[1] != '\0' || *values[2] != '\0' ||
+                 ((num_values > 3) && (*values[3] != '\0'))) {
+            H5TOOLS_GOTO_ERROR(FAIL, "  ERROR: invalid assortment of empty/non-empty values\n");
         }
     } /* values != NULL */
 
 done:
+    H5TOOLS_ENDDEBUG("");
     return ret_value;
 } /* h5tools_populate_ros3_fapl */
 #endif /* H5_HAVE_ROS3_VFD */
@@ -1432,23 +1230,23 @@ h5tools_parse_hdfs_fapl_tuple(const char *tuple_str, int delim, H5FD_hdfs_fapl_t
      * WARNING: No error-checking is done on length of input strings...
      *          Silent overflow is possible, albeit unlikely.
      */
-    if (HDstrncmp(props[0], "", 1)) {
-        HDstrncpy(fapl_config_out->namenode_name, (const char *)props[0], HDstrlen(props[0]));
+    if (strncmp(props[0], "", 1)) {
+        strncpy(fapl_config_out->namenode_name, (const char *)props[0], strlen(props[0]));
     }
-    if (HDstrncmp(props[1], "", 1)) {
+    if (strncmp(props[1], "", 1)) {
         k = strtoul((const char *)props[1], NULL, 0);
         if (errno == ERANGE)
             H5TOOLS_GOTO_ERROR(FAIL, "supposed port number wasn't");
         fapl_config_out->namenode_port = (int32_t)k;
     }
-    if (HDstrncmp(props[2], "", 1)) {
-        HDstrncpy(fapl_config_out->kerberos_ticket_cache, (const char *)props[2], HDstrlen(props[2]));
+    if (strncmp(props[2], "", 1)) {
+        strncpy(fapl_config_out->kerberos_ticket_cache, (const char *)props[2], strlen(props[2]));
     }
-    if (HDstrncmp(props[3], "", 1)) {
-        HDstrncpy(fapl_config_out->user_name, (const char *)props[3], HDstrlen(props[3]));
+    if (strncmp(props[3], "", 1)) {
+        strncpy(fapl_config_out->user_name, (const char *)props[3], strlen(props[3]));
     }
-    if (HDstrncmp(props[4], "", 1)) {
-        k = HDstrtoul((const char *)props[4], NULL, 0);
+    if (strncmp(props[4], "", 1)) {
+        k = strtoul((const char *)props[4], NULL, 0);
         if (errno == ERANGE)
             H5TOOLS_GOTO_ERROR(FAIL, "supposed buffersize number wasn't");
         fapl_config_out->stream_buffer_size = (int32_t)k;
@@ -1456,9 +1254,9 @@ h5tools_parse_hdfs_fapl_tuple(const char *tuple_str, int delim, H5FD_hdfs_fapl_t
 
 done:
     if (props)
-        HDfree(props);
+        free(props);
     if (props_src)
-        HDfree(props_src);
+        free(props_src);
 
     return ret_value;
 }
