@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -67,11 +67,11 @@ copy_objects(const char *fnamein, const char *fnameout, pack_opt_t *options)
     trav_table_t         *travt   = NULL;
     hsize_t               ub_size = 0;     /* size of user block */
     H5F_fspace_strategy_t set_strategy;    /* Strategy to be set in output file */
-    hbool_t               set_persist;     /* Persist free-space status to be set in output file */
+    bool                  set_persist;     /* Persist free-space status to be set in output file */
     hsize_t               set_threshold;   /* Free-space section threshold to be set in output file */
     hsize_t               set_pagesize;    /* File space page size to be set in output file */
     H5F_fspace_strategy_t in_strategy;     /* Strategy from input file */
-    hbool_t               in_persist;      /* Persist free-space status from input file */
+    bool                  in_persist;      /* Persist free-space status from input file */
     hsize_t               in_threshold;    /* Free-space section threshold from input file */
     hsize_t               in_pagesize;     /* File space page size from input file */
     unsigned              crt_order_flags; /* group creation order flag */
@@ -82,7 +82,7 @@ copy_objects(const char *fnamein, const char *fnameout, pack_opt_t *options)
      *-------------------------------------------------------------------------
      */
     if ((fidin = h5tools_fopen(fnamein, H5F_ACC_RDONLY, options->fin_fapl,
-                               (options->fin_fapl == H5P_DEFAULT) ? FALSE : TRUE, NULL, (size_t)0)) < 0)
+                               (options->fin_vol || options->fin_vfd), NULL, (size_t)0)) < 0)
         H5TOOLS_GOTO_ERROR((-1), "h5tools_fopen failed <%s>: %s", fnamein, H5FOPENERROR);
 
     /* get user block size and file space strategy/persist/threshold */
@@ -274,7 +274,7 @@ copy_objects(const char *fnamein, const char *fnameout, pack_opt_t *options)
     if (options->fs_persist == -1) /* A default "persist" is specified by user */
         set_persist = FS_PERSIST_DEF;
     else if (options->fs_persist != 0) /* Set "persist" as specified by user */
-        set_persist = (hbool_t)options->fs_persist;
+        set_persist = (bool)options->fs_persist;
 
     if (options->fs_threshold == -1) /* A "0" threshold is specified by user */
         set_threshold = (hsize_t)0;
@@ -299,7 +299,7 @@ copy_objects(const char *fnamein, const char *fnameout, pack_opt_t *options)
      *-------------------------------------------------------------------------
      */
     if (options->verbose > 0)
-        HDprintf("Making new file ...\n");
+        printf("Making new file ...\n");
 
     if ((fidout = H5Fcreate(fnameout, H5F_ACC_TRUNC, fcpl, options->fout_fapl)) < 0)
         H5TOOLS_GOTO_ERROR((-1), "H5Fcreate could not create file <%s>:", fnameout);
@@ -368,7 +368,7 @@ copy_objects(const char *fnamein, const char *fnameout, pack_opt_t *options)
      *-------------------------------------------------------------------------
      */
 
-    if (options->ublock_size > 0) {
+    if (options->ublock_filename != NULL && options->ublock_size > 0) {
         if (copy_user_block(options->ublock_filename, fnameout, options->ublock_size) < 0)
             H5TOOLS_GOTO_ERROR((-1), "Could not copy user block. Exiting...");
     }
@@ -390,7 +390,7 @@ done:
             H5Fclose(fidout);
             H5Fclose(fidin);
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     }
     if (travt)
         trav_table_free(travt);
@@ -416,7 +416,7 @@ done:
  *   * hslab_nbytes_p : [OUT] total byte of the hyperslab
  *
  * Update:
- *   The hyperslab calculation would be depend on if the dataset is chunked
+ *   The hyperslab calculation would depend on if the dataset is chunked
  *   or not.
  *
  *   There care 3 conditions to cover:
@@ -653,12 +653,13 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
     int                ifil;
     int                is_ref = 0;
     htri_t             is_named;
-    hbool_t            limit_maxdims;
+    htri_t             is_vlen = 0;
+    bool               limit_maxdims;
     hsize_t            size_dset;
     int                ret_value = 0;
 
     /* init linkinfo struct */
-    HDmemset(&linkinfo, 0, sizeof(h5tool_link_info_t));
+    memset(&linkinfo, 0, sizeof(h5tool_link_info_t));
 
     /*-------------------------------------------------------------------------
      * copy the supplied object list
@@ -667,14 +668,14 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
     if (options->verbose > 0) {
         if (options->verbose == 2) {
-            HDprintf("-----------------------------------------------------------------\n");
-            HDprintf(" Type     Filter (Compression)        Timing read/write    Name\n");
-            HDprintf("-----------------------------------------------------------------\n");
+            printf("-----------------------------------------------------------------\n");
+            printf(" Type     Filter (Compression)        Timing read/write    Name\n");
+            printf("-----------------------------------------------------------------\n");
         }
         else {
-            HDprintf("-----------------------------------------\n");
-            HDprintf(" Type     Filter (Compression)     Name\n");
-            HDprintf("-----------------------------------------\n");
+            printf("-----------------------------------------\n");
+            printf(" Type     Filter (Compression)     Name\n");
+            printf("-----------------------------------------\n");
         }
     }
 
@@ -682,7 +683,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
         for (i = 0; i < travt->nobjs; i++) {
             /* init variables per obj */
             buf           = NULL;
-            limit_maxdims = FALSE;
+            limit_maxdims = false;
 
             switch (travt->objs[i].type) {
                 case H5TRAV_TYPE_UNKNOWN:
@@ -695,9 +696,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                 case H5TRAV_TYPE_GROUP:
                     if (options->verbose > 0) {
                         if (options->verbose == 2)
-                            HDprintf(FORMAT_OBJ_NOTIME, "group", travt->objs[i].name);
+                            printf(FORMAT_OBJ_NOTIME, "group", travt->objs[i].name);
                         else
-                            HDprintf(FORMAT_OBJ, "group", travt->objs[i].name);
+                            printf(FORMAT_OBJ, "group", travt->objs[i].name);
                     }
 
                     /* open input group */
@@ -724,7 +725,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                      * and copy its attributes using that ID
                      *-------------------------------------------------------------------------
                      */
-                    if (HDstrcmp(travt->objs[i].name, "/") == 0) {
+                    if (strcmp(travt->objs[i].name, "/") == 0) {
                         if ((grp_out = H5Gopen2(fidout, "/", H5P_DEFAULT)) < 0)
                             H5TOOLS_GOTO_ERROR((-1), "H5Gopen2 failed");
                     }
@@ -762,7 +763,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                  *-------------------------------------------------------------------------
                  */
                 case H5TRAV_TYPE_DATASET: {
-                    hbool_t use_h5ocopy;
+                    bool use_h5ocopy;
 
                     read_time  = 0.0;
                     write_time = 0.0;
@@ -777,7 +778,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                     /* check if filters were requested for individual objects */
                     if (options->op_tbl->objs) {
                         for (u = 0; u < options->op_tbl->nelems; u++) {
-                            if (HDstrcmp(travt->objs[i].name, options->op_tbl->objs[u].path) == 0)
+                            if (strcmp(travt->objs[i].name, options->op_tbl->objs[u].path) == 0)
                                 for (ifil = 0; ifil < options->op_tbl->objs[ifil].nfilters; ifil++) {
                                     if (options->op_tbl->objs[u].filter[ifil].filtn > 0)
                                         req_filter = 1;
@@ -806,6 +807,14 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                     if (H5T_REFERENCE == H5Tget_class(ftype_id))
                         is_ref = 1;
 
+                    /* early detection of variable-length types */
+                    if ((is_vlen = H5Tdetect_class(ftype_id, H5T_VLEN)) < 0)
+                        H5TOOLS_GOTO_ERROR((-1), "H5Tdetect_class failed");
+                    if (!is_vlen) {
+                        if ((is_vlen = H5Tis_variable_str(ftype_id)) < 0)
+                            H5TOOLS_GOTO_ERROR((-1), "H5Tis_variable_str failed");
+                    }
+
                     /* Check if the datatype is committed */
                     if ((is_named = H5Tcommitted(ftype_id)) < 0)
                         H5TOOLS_GOTO_ERROR((-1), "H5Tcommitted failed");
@@ -823,10 +832,16 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                      * check if we should use H5Ocopy or not
                      * if there is a request for filters/layout, we read/write the object
                      * otherwise we do a copy using H5Ocopy
+                     *
+                     * Note that H5Ocopy is currently unsafe to use for objects that reside in
+                     * or interact with global heaps, such as variable-length datatypes. This
+                     * appears to be due to H5Ocopy not correctly translating in the case where
+                     * these objects move to different global heap addresses in the repacked
+                     * file.
                      *-------------------------------------------------------------------------
                      */
                     use_h5ocopy = !(options->op_tbl->nelems || options->all_filter == 1 ||
-                                    options->all_layout == 1 || is_ref || is_named);
+                                    options->all_layout == 1 || is_ref || is_vlen || is_named);
 
                     /*
                      * Check if we are using different source and destination VOL connectors.
@@ -834,7 +849,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                      * doesn't support this.
                      */
                     if (use_h5ocopy &&
-                        (options->fin_fapl != H5P_DEFAULT || options->fout_fapl != H5P_DEFAULT)) {
+                        (options->fin_vol || options->fout_vol || options->fin_vfd || options->fout_vfd)) {
                         hid_t in_vol_id;
                         hid_t out_vol_id;
                         hid_t default_vol_id;
@@ -852,7 +867,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                             H5TOOLS_GOTO_ERROR((-1), "H5Pget_vol_id failed");
 
                         if (in_vol_id != out_vol_id)
-                            use_h5ocopy = FALSE;
+                            use_h5ocopy = false;
 
                         if (in_vol_id != default_vol_id)
                             if (H5VLclose(in_vol_id) < 0)
@@ -877,7 +892,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                             H5TOOLS_GOTO_ERROR((-1), "H5Dget_create_plist failed");
                         if ((rank = H5Sget_simple_extent_ndims(f_space_id)) < 0)
                             H5TOOLS_GOTO_ERROR((-1), "H5Sget_simple_extent_ndims failed");
-                        HDmemset(dims, 0, sizeof dims);
+                        memset(dims, 0, sizeof dims);
                         if (H5Sget_simple_extent_dims(f_space_id, dims, NULL) < 0)
                             H5TOOLS_GOTO_ERROR((-1), "H5Sget_simple_extent_dims failed");
                         if (H5Dget_space_status(dset_in, &space_status) < 0)
@@ -964,15 +979,15 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                         if (options->op_tbl->nelems > 0) {
                                             /* if current obj match specified obj */
                                             if (options_get_object(travt->objs[i].name, options->op_tbl))
-                                                limit_maxdims = TRUE;
+                                                limit_maxdims = true;
                                         }
                                         else /* no dataset is specified */
-                                            limit_maxdims = TRUE;
+                                            limit_maxdims = true;
 
                                         /* if convert to COMPACT */
                                         if (options->layout_g == H5D_COMPACT)
                                             if (size_dset > MAX_COMPACT_DSIZE)
-                                                limit_maxdims = FALSE;
+                                                limit_maxdims = false;
 
                                         /* unset unlimited max dims */
                                         if (limit_maxdims)
@@ -991,9 +1006,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                 if (dset_out == H5I_INVALID_HID) {
                                     H5TOOLS_INFO("H5Dcreate2 failed");
                                     if (options->verbose > 0)
-                                        HDprintf(" warning: could not create dataset <%s>. Applying original "
-                                                 "settings\n",
-                                                 travt->objs[i].name);
+                                        printf(" warning: could not create dataset <%s>. Applying original "
+                                               "settings\n",
+                                               travt->objs[i].name);
 
                                     if ((dset_out =
                                              H5Dcreate2(fidout, travt->objs[i].name, wtype_id, f_space_id,
@@ -1012,12 +1027,12 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                     /* have to read the whole dataset if there is only one element in the
                                      * dataset */
                                     if (need < H5TOOLS_MALLOCSIZE)
-                                        buf = HDmalloc(need);
+                                        buf = malloc(need);
 
                                     /* Set up collective write if using filters in parallel */
                                     {
 #ifdef H5_HAVE_PARALLEL
-                                        hbool_t parallel = (H5FD_MPIO == H5Pget_driver(options->fout_fapl));
+                                        bool parallel = (H5FD_MPIO == H5Pget_driver(options->fout_fapl));
 
                                         if (parallel && apply_s && apply_f) {
                                             if ((dxpl_id = H5Pcreate(H5P_DATASET_XFER)) < 0)
@@ -1055,13 +1070,13 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
                                         /* Check if we have VL data in the dataset's
                                          * datatype that must be reclaimed */
-                                        if (TRUE == H5Tdetect_class(wtype_id, H5T_VLEN))
+                                        if (true == H5Tdetect_class(wtype_id, H5T_VLEN))
                                             if (H5Treclaim(wtype_id, f_space_id, H5P_DEFAULT, buf) < 0)
                                                 H5TOOLS_GOTO_ERROR((-1), "H5Treclaim failed");
 
                                         if (buf != NULL) { /* TODO: is buf potentially released by
                                                               H5Dvlen_reclaim()? */
-                                            HDfree(buf);
+                                            free(buf);
                                             buf = NULL;
                                         }
                                     }
@@ -1089,8 +1104,8 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                             H5I_INVALID_HID; /* dataset creation property list ID */
 
                                         /* check if we have VL data in the dataset's datatype */
-                                        if (H5Tdetect_class(wtype_id, H5T_VLEN) == TRUE)
-                                            vl_data = TRUE;
+                                        if (H5Tdetect_class(wtype_id, H5T_VLEN) == true)
+                                            vl_data = true;
 
                                         /* check first if writing dataset is chunked,
                                          * if so use its chunk layout for better performance. */
@@ -1108,7 +1123,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                                           &hslab_nbytes) < 0)
                                             H5TOOLS_GOTO_ERROR((-1), "get_hyperslab failed");
 
-                                        hslab_buf = HDmalloc((size_t)hslab_nbytes);
+                                        hslab_buf = malloc((size_t)hslab_nbytes);
                                         if (hslab_buf == NULL)
                                             H5TOOLS_GOTO_ERROR((-1), "can't allocate space for hyperslab");
 
@@ -1116,8 +1131,8 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                         hslab_space  = H5Screate_simple(1, &hslab_nelmts, NULL);
 
                                         /* the hyperslab selection loop */
-                                        HDmemset(hs_sel_offset, 0, sizeof hs_sel_offset);
-                                        HDmemset(zero, 0, sizeof zero);
+                                        memset(hs_sel_offset, 0, sizeof hs_sel_offset);
+                                        memset(zero, 0, sizeof zero);
 
                                         for (elmtno = 0; elmtno < p_nelmts; elmtno += hs_select_nelmts) {
                                             if (rank > 0) {
@@ -1189,7 +1204,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
                                         H5Sclose(hslab_space);
                                         if (hslab_buf != NULL) {
-                                            HDfree(hslab_buf);
+                                            free(hslab_buf);
                                             hslab_buf = NULL;
                                         }
                                     } /* end if reading/writing by hyperslab */
@@ -1221,13 +1236,13 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                                      * (in case there was a filter)
                                      */
                                     if (has_filter && apply_s == 0)
-                                        HDprintf(" <warning: filter not applied to %s. dataset smaller than "
-                                                 "%d bytes>\n",
-                                                 travt->objs[i].name, (int)options->min_comp);
+                                        printf(" <warning: filter not applied to %s. dataset smaller than "
+                                               "%d bytes>\n",
+                                               travt->objs[i].name, (int)options->min_comp);
 
                                     if (has_filter && apply_f == 0)
-                                        HDprintf(" <warning: could not apply the filter to %s>\n",
-                                                 travt->objs[i].name);
+                                        printf(" <warning: could not apply the filter to %s>\n",
+                                               travt->objs[i].name);
                                 } /* end if verbose (print compression) */
 
                                 /*-------------------------------------------------------------------------
@@ -1310,9 +1325,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
                         if (options->verbose > 0) {
                             if (options->verbose == 2)
-                                HDprintf(FORMAT_OBJ_TIME, "dset", 0.0, write_time, travt->objs[i].name);
+                                printf(FORMAT_OBJ_TIME, "dset", 0.0, write_time, travt->objs[i].name);
                             else
-                                HDprintf(FORMAT_OBJ, "dset", travt->objs[i].name);
+                                printf(FORMAT_OBJ, "dset", travt->objs[i].name);
                         }
 
                     } /* end whether we have request for filter/chunking */
@@ -1327,9 +1342,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                 case H5TRAV_TYPE_NAMED_DATATYPE:
                     if (options->verbose > 0) {
                         if (options->verbose == 2)
-                            HDprintf(FORMAT_OBJ_NOTIME, "type", travt->objs[i].name);
+                            printf(FORMAT_OBJ_NOTIME, "type", travt->objs[i].name);
                         else
-                            HDprintf(FORMAT_OBJ, "type", travt->objs[i].name);
+                            printf(FORMAT_OBJ, "type", travt->objs[i].name);
                     }
 
                     if ((type_in = H5Topen2(fidin, travt->objs[i].name, H5P_DEFAULT)) < 0)
@@ -1371,9 +1386,9 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                 case H5TRAV_TYPE_UDLINK:
                     if (options->verbose > 0) {
                         if (options->verbose == 2)
-                            HDprintf(FORMAT_OBJ_NOTIME, "link", travt->objs[i].name);
+                            printf(FORMAT_OBJ_NOTIME, "link", travt->objs[i].name);
                         else
-                            HDprintf(FORMAT_OBJ, "link", travt->objs[i].name);
+                            printf(FORMAT_OBJ, "link", travt->objs[i].name);
                     }
 
                     /* Check -X option. */
@@ -1381,7 +1396,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                         if (H5tools_get_symlink_info(fidin, travt->objs[i].name, &linkinfo, 1) == 0) {
                             /* dangling link */
                             if (options->prune) {
-                                HDprintf("Pruned %s.\n", travt->objs[i].name);
+                                printf("Pruned %s.\n", travt->objs[i].name);
                             }
                             else {
                                 if (H5Lcopy(fidin, travt->objs[i].name, fidout, travt->objs[i].name,
@@ -1405,7 +1420,7 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
                             }
 
                             /* Set flag for intermediate group creation */
-                            if (H5Pset_create_intermediate_group(lcpl_id, TRUE) < 0)
+                            if (H5Pset_create_intermediate_group(lcpl_id, true) < 0)
                                 H5TOOLS_GOTO_ERROR((-1), "H5Pset_create_intermediate_group failed");
 
                             if (H5Ocopy(fidin, travt->objs[i].name, fidout, travt->objs[i].name, ocpl_id,
@@ -1421,12 +1436,12 @@ do_copy_objects(hid_t fidin, hid_t fidout, trav_table_t *travt, pack_opt_t *opti
 
                         /* free link info path */
                         if (linkinfo.trg_path)
-                            HDfree(linkinfo.trg_path);
+                            free(linkinfo.trg_path);
                         linkinfo.trg_path = NULL;
                     } /* options->merge */
                     else {
                         if (options->prune) {
-                            HDprintf("Pruned %s.\n", travt->objs[i].name);
+                            printf("Pruned %s.\n", travt->objs[i].name);
                         }
                         else {
                             if (H5Lcopy(fidin, travt->objs[i].name, fidout, travt->objs[i].name, H5P_DEFAULT,
@@ -1455,12 +1470,12 @@ done:
         {
             named_datatype_free(&named_dt_head, 1);
         }
-        H5E_END_TRY;
+        H5E_END_TRY
     }
 
     /* free link info path */
     if (linkinfo.trg_path)
-        HDfree(linkinfo.trg_path);
+        free(linkinfo.trg_path);
 
     H5E_BEGIN_TRY
     {
@@ -1480,13 +1495,13 @@ done:
         H5Tclose(type_in);
         H5Tclose(type_out);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
     /* free */
     if (buf != NULL)
-        HDfree(buf);
+        free(buf);
     if (hslab_buf != NULL)
-        HDfree(hslab_buf);
+        free(hslab_buf);
 
     return ret_value;
 } /* end do_copy_objects() */
@@ -1505,15 +1520,15 @@ print_dataset_info(hid_t dcpl_id, char *objname, double ratio, int pr, pack_opt_
 #if defined(PRINT_DEBUG)
     char temp[255];
 #endif
-    int          nfilters;       /* number of filters */
-    unsigned     filt_flags;     /* filter flags */
-    H5Z_filter_t filtn;          /* filter identification number */
-    unsigned     cd_values[20];  /* filter client data values */
-    size_t       cd_nelmts;      /* filter client number of values */
-    char         f_objname[256]; /* filter objname */
+    int          nfilters;                    /* number of filters */
+    unsigned     filt_flags;                  /* filter flags */
+    H5Z_filter_t filtn;                       /* filter identification number */
+    unsigned     cd_values[DEFAULT_CDELEMTS]; /* filter client data values */
+    size_t       cd_nelmts;                   /* filter client number of values */
+    char         f_objname[256];              /* filter objname */
     int          i;
 
-    HDstrcpy(strfilter, "\0");
+    strcpy(strfilter, "\0");
 
     /* get information about input filters */
     if ((nfilters = H5Pget_nfilters(dcpl_id)) < 0)
@@ -1524,85 +1539,85 @@ print_dataset_info(hid_t dcpl_id, char *objname, double ratio, int pr, pack_opt_
 
         if ((filtn = H5Pget_filter2(dcpl_id, (unsigned)i, &filt_flags, &cd_nelmts, cd_values,
                                     sizeof(f_objname), f_objname, NULL)) < 0) {
-            HDstrcat(strfilter, "ERROR ");
+            strcat(strfilter, "ERROR ");
             continue;
         }
 
         switch (filtn) {
             case H5Z_FILTER_NONE:
-                HDstrcat(strfilter, "NONE ");
+                strcat(strfilter, "NONE ");
                 break;
 
             case H5Z_FILTER_DEFLATE:
-                HDstrcat(strfilter, "GZIP ");
+                strcat(strfilter, "GZIP ");
 
 #if defined(PRINT_DEBUG)
                 {
                     unsigned level = cd_values[0];
 
-                    HDsprintf(temp, "(%d)", level);
-                    HDstrcat(strfilter, temp);
+                    snprintf(temp, sizeof(temp), "(%d)", level);
+                    strcat(strfilter, temp);
                 }
 #endif
                 break;
 
             case H5Z_FILTER_SZIP:
-                HDstrcat(strfilter, "SZIP ");
+                strcat(strfilter, "SZIP ");
 
 #if defined(PRINT_DEBUG)
                 {
                     unsigned options_mask = cd_values[0]; /* from dcpl, not filt*/
                     unsigned ppb          = cd_values[1];
 
-                    HDsprintf(temp, "(%d,", ppb);
-                    HDstrcat(strfilter, temp);
+                    snprintf(temp, sizeof(temp), "(%d,", ppb);
+                    strcat(strfilter, temp);
                     if (options_mask & H5_SZIP_EC_OPTION_MASK)
-                        HDstrcpy(temp, "EC) ");
+                        strcpy(temp, "EC) ");
                     else if (options_mask & H5_SZIP_NN_OPTION_MASK)
-                        HDstrcpy(temp, "NN) ");
+                        strcpy(temp, "NN) ");
                 }
-                HDstrcat(strfilter, temp);
+                strcat(strfilter, temp);
 #endif
                 break;
 
             case H5Z_FILTER_SHUFFLE:
-                HDstrcat(strfilter, "SHUF ");
+                strcat(strfilter, "SHUF ");
                 break;
 
             case H5Z_FILTER_FLETCHER32:
-                HDstrcat(strfilter, "FLET ");
+                strcat(strfilter, "FLET ");
                 break;
 
             case H5Z_FILTER_NBIT:
-                HDstrcat(strfilter, "NBIT ");
+                strcat(strfilter, "NBIT ");
                 break;
 
             case H5Z_FILTER_SCALEOFFSET:
-                HDstrcat(strfilter, "SCALEOFFSET ");
+                strcat(strfilter, "SCALEOFFSET ");
                 break;
 
             default:
-                HDstrcat(strfilter, "UD ");
+                strcat(strfilter, "UD ");
                 break;
         } /* end switch */
     }     /* end for each filter */
 
     if (!pr)
         if (options->verbose == 2)
-            HDprintf(FORMAT_OBJ_TIME, "dset", read_time, write_time, objname);
+            printf(FORMAT_OBJ_TIME, "dset", read_time, write_time, objname);
         else
-            HDprintf(FORMAT_OBJ, "dset", objname);
+            printf(FORMAT_OBJ, "dset", objname);
     else {
         char str[512], temp[512];
 
-        HDstrcpy(str, "dset     ");
-        HDstrcat(str, strfilter);
-        HDsprintf(temp, "  (%.3f:1)", ratio);
-        HDstrcat(str, temp);
+        strcpy(str, "dset     ");
+        strcat(str, strfilter);
+        snprintf(temp, sizeof(temp), "  (%.3f:1)", ratio);
+        strcat(str, temp);
         if (options->verbose == 2)
-            HDprintf(FORMAT_OBJ_TIME, str, read_time, write_time, objname);
+            printf(FORMAT_OBJ_TIME, str, read_time, write_time, objname);
         else
-            HDprintf(FORMAT_OBJ, str, objname);
+            printf(FORMAT_OBJ, str, objname);
     }
 } /* end print_dataset_info() */
 
@@ -1654,13 +1669,13 @@ copy_user_block(const char *infile, const char *outfile, hsize_t size)
             } while (-1 == nwritten && EINTR == errno);
             if (-1 == nwritten) /* error */
                 H5TOOLS_GOTO_ERROR((-1), "HDwrite failed");
-            HDassert(nwritten > 0);
-            HDassert(nwritten <= nbytes);
+            assert(nwritten > 0);
+            assert(nwritten <= nbytes);
 
             /* Update # of bytes left & offset in buffer */
             nbytes -= nwritten;
             wbuf += nwritten;
-            HDassert(nbytes == 0 || wbuf < (rbuf + USERBLOCK_XFER_SIZE));
+            assert(nbytes == 0 || wbuf < (rbuf + USERBLOCK_XFER_SIZE));
         } /* end while */
 
         /* Update size of userblock left to transfer */
@@ -1728,9 +1743,9 @@ print_user_block(const char *filename, hid_t fid)
 
         for (i = 0; i < nread; i++) {
 
-            HDprintf("%c ", rbuf[i]);
+            printf("%c ", rbuf[i]);
         }
-        HDprintf("\n");
+        printf("\n");
 
         if (nread < 0) {
             H5TOOLS_GOTO_ERROR((-1), "nread < 0");
