@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -21,53 +21,72 @@ static int  parse_command_line(int argc, const char *const *argv, pack_opt_t *op
 static void leave(int ret) H5_ATTR_NORETURN;
 
 /* module-scoped variables */
-static int  has_i   = 0;
-static int  has_o   = 0;
-const char *infile  = NULL;
-const char *outfile = NULL;
+static int         has_i   = 0;
+static int         has_o   = 0;
+static const char *infile  = NULL;
+static const char *outfile = NULL;
 
 /*
  * Command-line options: The user can specify short or long-named
  * parameters.
  */
-static const char         *s_opts   = "a:b:c:d:e:f:hi:j:k:l:m:no:q:s:t:u:v*z:E*G:LM:P:S:T:VXW";
-static struct long_options l_opts[] = {{"alignment", require_arg, 'a'},
-                                       {"block", require_arg, 'b'},
-                                       {"compact", require_arg, 'c'},
-                                       {"indexed", require_arg, 'd'},
-                                       {"file", require_arg, 'e'},
-                                       {"filter", require_arg, 'f'},
-                                       {"help", no_arg, 'h'},
-                                       {"infile", require_arg, 'i'}, /* for backward compatibility */
-                                       {"low", require_arg, 'j'},
-                                       {"high", require_arg, 'k'},
-                                       {"layout", require_arg, 'l'},
-                                       {"minimum", require_arg, 'm'},
-                                       {"native", no_arg, 'n'},
-                                       {"outfile", require_arg, 'o'}, /* for backward compatibility */
-                                       {"sort_by", require_arg, 'q'},
-                                       {"ssize", require_arg, 's'},
-                                       {"threshold", require_arg, 't'},
-                                       {"ublock", require_arg, 'u'},
-                                       {"verbose", optional_arg, 'v'},
-                                       {"sort_order", require_arg, 'z'},
-                                       {"enable-error-stack", optional_arg, 'E'},
-                                       {"fs_pagesize", require_arg, 'G'},
-                                       {"latest", no_arg, 'L'},
-                                       {"metadata_block_size", require_arg, 'M'},
-                                       {"fs_persist", require_arg, 'P'},
-                                       {"fs_strategy", require_arg, 'S'},
-                                       {"fs_threshold", require_arg, 'T'},
-                                       {"version", no_arg, 'V'},
-                                       {"merge", no_arg, 'X'},
-                                       {"prune", no_arg, 'W'},
-                                       {"src-vol-value", require_arg, '1'},
-                                       {"src-vol-name", require_arg, '2'},
-                                       {"src-vol-info", require_arg, '3'},
-                                       {"dst-vol-value", require_arg, '4'},
-                                       {"dst-vol-name", require_arg, '5'},
-                                       {"dst-vol-info", require_arg, '6'},
-                                       {NULL, 0, '\0'}};
+static const char *s_opts =
+    "a:b:c:d:e:f:hi:j:k:l:m:no:q:s:t:u:v*z:E*G:K:LM:P:S:T:VXWY:Z:1:2:3:4:5:6:7:8:9:0:";
+static struct h5_long_options l_opts[] = {{"alignment", require_arg, 'a'},
+                                          {"block", require_arg, 'b'},
+                                          {"compact", require_arg, 'c'},
+                                          {"indexed", require_arg, 'd'},
+                                          {"file", require_arg, 'e'},
+                                          {"filter", require_arg, 'f'},
+                                          {"help", no_arg, 'h'},
+                                          {"infile", require_arg, 'i'}, /* for backward compatibility */
+                                          {"low", require_arg, 'j'},
+                                          {"high", require_arg, 'k'},
+                                          {"layout", require_arg, 'l'},
+                                          {"minimum", require_arg, 'm'},
+                                          {"native", no_arg, 'n'},
+                                          {"outfile", require_arg, 'o'}, /* for backward compatibility */
+                                          {"sort_by", require_arg, 'q'},
+                                          {"ssize", require_arg, 's'},
+                                          {"threshold", require_arg, 't'},
+                                          {"ublock", require_arg, 'u'},
+                                          {"verbose", optional_arg, 'v'},
+                                          {"sort_order", require_arg, 'z'},
+                                          {"enable-error-stack", optional_arg, 'E'},
+                                          {"fs_pagesize", require_arg, 'G'},
+                                          {"page-buffer-size", require_arg, 'K'},
+                                          {"latest", no_arg, 'L'},
+                                          {"metadata_block_size", require_arg, 'M'},
+                                          {"fs_persist", require_arg, 'P'},
+                                          {"fs_strategy", require_arg, 'S'},
+                                          {"fs_threshold", require_arg, 'T'},
+                                          {"version", no_arg, 'V'},
+                                          {"merge", no_arg, 'X'},
+                                          {"prune", no_arg, 'W'},
+                                          {"src-vol-value", require_arg, '1'},
+                                          {"src-vol-name", require_arg, '2'},
+                                          {"src-vol-info", require_arg, '3'},
+                                          {"dst-vol-value", require_arg, '4'},
+                                          {"dst-vol-name", require_arg, '5'},
+                                          {"dst-vol-info", require_arg, '6'},
+                                          {"src-vfd-value", require_arg, '7'},
+                                          {"src-vfd-name", require_arg, '8'},
+                                          {"src-vfd-info", require_arg, '9'},
+                                          {"dst-vfd-value", require_arg, '0'},
+                                          {"dst-vfd-name", require_arg, 'Y'},
+                                          {"dst-vfd-info", require_arg, 'Z'},
+                                          {NULL, 0, '\0'}};
+
+static H5FD_onion_fapl_info_t onion_fa_in_g = {
+    H5FD_ONION_FAPL_INFO_VERSION_CURR,
+    H5P_DEFAULT,                   /* backing_fapl_id                */
+    32,                            /* page_size                      */
+    H5FD_ONION_STORE_TARGET_ONION, /* store_target                   */
+    H5FD_ONION_FAPL_INFO_REVISION_ID_LATEST,
+    0,            /* force_write_open               */
+    0,            /* creation_flags                 */
+    "input file", /* comment                        */
+};
 
 /*-------------------------------------------------------------------------
  * Function: usage
@@ -96,6 +115,8 @@ usage(const char *prog)
     PRINTVALSTREAM(rawoutstream, "      N - is an integer greater than 1, 2 displays read/write timing\n");
     PRINTVALSTREAM(rawoutstream, "   -V, --version           Print version number and exit\n");
     PRINTVALSTREAM(rawoutstream, "   -n, --native            Use a native HDF5 type when repacking\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --page-buffer-size=N    Set the page buffer cache size, N=non-negative integers\n");
     PRINTVALSTREAM(rawoutstream,
                    "   --src-vol-value         Value (ID) of the VOL connector to use for opening the\n");
     PRINTVALSTREAM(rawoutstream, "                           input HDF5 file specified\n");
@@ -114,6 +135,24 @@ usage(const char *prog)
     PRINTVALSTREAM(rawoutstream,
                    "   --dst-vol-info          VOL-specific info to pass to the VOL connector used for\n");
     PRINTVALSTREAM(rawoutstream, "                           opening the output HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --src-vfd-value         Value (ID) of the VFL driver to use for opening the\n");
+    PRINTVALSTREAM(rawoutstream, "                           input HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --src-vfd-name          Name of the VFL driver to use for opening the input\n");
+    PRINTVALSTREAM(rawoutstream, "                           HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --src-vfd-info          VFD-specific info to pass to the VFL driver used for\n");
+    PRINTVALSTREAM(rawoutstream, "                           opening the input HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --dst-vfd-value         Value (ID) of the VFL driver to use for opening the\n");
+    PRINTVALSTREAM(rawoutstream, "                           output HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --dst-vfd-name          Name of the VFL driver to use for opening the output\n");
+    PRINTVALSTREAM(rawoutstream, "                           HDF5 file specified\n");
+    PRINTVALSTREAM(rawoutstream,
+                   "   --dst-vfd-info          VFD-specific info to pass to the VFL driver used for\n");
+    PRINTVALSTREAM(rawoutstream, "                           opening the output HDF5 file specified\n");
     PRINTVALSTREAM(rawoutstream, "   -L, --latest            Use latest version of file format\n");
     PRINTVALSTREAM(rawoutstream,
                    "                           This option will take precedence over the options\n");
@@ -189,8 +228,9 @@ usage(const char *prog)
     PRINTVALSTREAM(rawoutstream, "        2: This is H5F_LIBVER_V110 in H5F_libver_t struct\n");
     PRINTVALSTREAM(rawoutstream, "        3: This is H5F_LIBVER_V112 in H5F_libver_t struct\n");
     PRINTVALSTREAM(rawoutstream, "        4: This is H5F_LIBVER_V114 in H5F_libver_t struct\n");
+    PRINTVALSTREAM(rawoutstream, "        5: This is H5F_LIBVER_V200 in H5F_libver_t struct\n");
     PRINTVALSTREAM(rawoutstream,
-                   "           (H5F_LIBVER_LATEST is aliased to H5F_LIBVER_V114 for this release\n");
+                   "           (H5F_LIBVER_LATEST is aliased to H5F_LIBVER_V200 for this release\n");
     PRINTVALSTREAM(rawoutstream, "\n");
     PRINTVALSTREAM(rawoutstream, "    FS_STRATEGY is a string indicating the file space strategy used:\n");
     PRINTVALSTREAM(rawoutstream, "        FSM_AGGR:\n");
@@ -335,7 +375,7 @@ static void
 leave(int ret)
 {
     h5tools_close();
-    HDexit(ret);
+    exit(ret);
 }
 
 /*-------------------------------------------------------------------------
@@ -356,7 +396,7 @@ read_info(const char *filename, pack_opt_t *options)
     int   i;
     int   ret_value = EXIT_SUCCESS;
 
-    if (NULL == (fp = HDfopen(filename, "r"))) {
+    if (NULL == (fp = fopen(filename, "r"))) {
         error_msg("cannot open options file %s\n", filename);
         h5tools_setstatus(EXIT_FAILURE);
         ret_value = EXIT_FAILURE;
@@ -365,11 +405,11 @@ read_info(const char *filename, pack_opt_t *options)
 
     /* cycle until end of file reached */
     while (1) {
-        if (EOF == HDfscanf(fp, "%9s", stype))
+        if (EOF == fscanf(fp, "%9s", stype))
             break;
 
         /* Info indicator must be for layout or filter */
-        if (HDstrcmp(stype, "-l") != 0 && HDstrcmp(stype, "-f") != 0) {
+        if (strcmp(stype, "-l") != 0 && strcmp(stype, "-f") != 0) {
             error_msg("bad file format for %s", filename);
             h5tools_setstatus(EXIT_FAILURE);
             ret_value = EXIT_FAILURE;
@@ -380,33 +420,33 @@ read_info(const char *filename, pack_opt_t *options)
         i = 0;
         c = '0';
         while (c != ' ') {
-            if (HDfscanf(fp, "%c", &c) < 0 && HDferror(fp)) {
+            if (fscanf(fp, "%c", &c) < 0 && ferror(fp)) {
                 error_msg("fscanf error\n");
                 h5tools_setstatus(EXIT_FAILURE);
                 ret_value = EXIT_FAILURE;
                 goto done;
             }
-            if (HDfeof(fp))
+            if (feof(fp))
                 break;
         }
         c = '0';
         /* go until end */
         while (c != ' ') {
-            if (HDfscanf(fp, "%c", &c) < 0 && HDferror(fp)) {
+            if (fscanf(fp, "%c", &c) < 0 && ferror(fp)) {
                 error_msg("fscanf error\n");
                 h5tools_setstatus(EXIT_FAILURE);
                 ret_value = EXIT_FAILURE;
                 goto done;
             }
             comp_info[i++] = c;
-            if (HDfeof(fp))
+            if (feof(fp))
                 break;
             if (c == 10 /*eol*/)
                 break;
         }
         comp_info[i - 1] = '\0'; /*cut the last " */
 
-        if (!HDstrcmp(stype, "-l")) {
+        if (!strcmp(stype, "-l")) {
             if (h5repack_addlayout(comp_info, options) == -1) {
                 error_msg("could not add chunk option\n");
                 h5tools_setstatus(EXIT_FAILURE);
@@ -426,7 +466,7 @@ read_info(const char *filename, pack_opt_t *options)
 
 done:
     if (fp)
-        HDfclose(fp);
+        fclose(fp);
 
     return ret_value;
 }
@@ -446,9 +486,9 @@ set_sort_by(const char *form)
 {
     H5_index_t idx_type = H5_INDEX_UNKNOWN;
 
-    if (!HDstrcmp(form, "name"))
+    if (!strcmp(form, "name"))
         idx_type = H5_INDEX_NAME;
-    else if (!HDstrcmp(form, "creation_order"))
+    else if (!strcmp(form, "creation_order"))
         idx_type = H5_INDEX_CRT_ORDER;
 
     return idx_type;
@@ -469,9 +509,9 @@ set_sort_order(const char *form)
 {
     H5_iter_order_t iter_order = H5_ITER_UNKNOWN;
 
-    if (!HDstrcmp(form, "ascending"))
+    if (!strcmp(form, "ascending"))
         iter_order = H5_ITER_INC;
-    else if (!HDstrcmp(form, "descending"))
+    else if (!strcmp(form, "descending"))
         iter_order = H5_ITER_DEC;
 
     return iter_order;
@@ -488,29 +528,32 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 {
     h5tools_vol_info_t in_vol_info;
     h5tools_vol_info_t out_vol_info;
-    hbool_t            custom_in_fapl  = FALSE;
-    hbool_t            custom_out_fapl = FALSE;
-    hid_t              tmp_fapl        = H5I_INVALID_HID;
+    h5tools_vfd_info_t in_vfd_info;
+    h5tools_vfd_info_t out_vfd_info;
+    hid_t              tmp_fapl   = H5I_INVALID_HID;
+    size_t             page_cache = 0;
     int                bound, opt;
     int                ret_value = 0;
 
     /* Initialize fapl info structs */
-    HDmemset(&in_vol_info, 0, sizeof(h5tools_vol_info_t));
-    HDmemset(&out_vol_info, 0, sizeof(h5tools_vol_info_t));
+    memset(&in_vol_info, 0, sizeof(h5tools_vol_info_t));
+    memset(&out_vol_info, 0, sizeof(h5tools_vol_info_t));
+    memset(&in_vfd_info, 0, sizeof(h5tools_vfd_info_t));
+    memset(&out_vfd_info, 0, sizeof(h5tools_vfd_info_t));
 
     /* parse command line options */
-    while (EOF != (opt = get_option(argc, argv, s_opts, l_opts))) {
+    while (EOF != (opt = H5_get_option(argc, argv, s_opts, l_opts))) {
         switch ((char)opt) {
 
             /* -i for backward compatibility */
             case 'i':
-                infile = opt_arg;
+                infile = H5_optarg;
                 has_i++;
                 break;
 
             /* -o for backward compatibility */
             case 'o':
-                outfile = opt_arg;
+                outfile = H5_optarg;
                 has_o++;
                 break;
 
@@ -527,8 +570,8 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 goto done;
 
             case 'v':
-                if (opt_arg != NULL) {
-                    if (2 == HDatoi(opt_arg))
+                if (H5_optarg != NULL) {
+                    if (2 == atoi(H5_optarg))
                         options->verbose = 2;
                 }
                 else
@@ -537,7 +580,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 
             case 'f':
                 /* parse the -f filter option */
-                if (h5repack_addfilter(opt_arg, options) < 0) {
+                if (h5repack_addfilter(H5_optarg, options) < 0) {
                     error_msg("in parsing filter\n");
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
@@ -547,7 +590,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 
             case 'l':
                 /* parse the -l layout option */
-                if (h5repack_addlayout(opt_arg, options) < 0) {
+                if (h5repack_addlayout(H5_optarg, options) < 0) {
                     error_msg("in parsing layout\n");
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
@@ -556,9 +599,9 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'm':
-                options->min_comp = HDstrtoull(opt_arg, NULL, 0);
+                options->min_comp = strtoull(H5_optarg, NULL, 0);
                 if ((int)options->min_comp <= 0) {
-                    error_msg("invalid minimum compress size <%s>\n", opt_arg);
+                    error_msg("invalid minimum compress size <%s>\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -566,8 +609,8 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'e':
-                if ((ret_value = read_info(opt_arg, options)) < 0) {
-                    error_msg("failed to read from repack options file <%s>\n", opt_arg);
+                if ((ret_value = read_info(H5_optarg, options)) < 0) {
+                    error_msg("failed to read from repack options file <%s>\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -579,11 +622,11 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'L':
-                options->latest = TRUE;
+                options->latest = true;
                 break;
 
             case 'j':
-                bound = HDatoi(opt_arg);
+                bound = atoi(H5_optarg);
                 if (bound < H5F_LIBVER_EARLIEST || bound > H5F_LIBVER_LATEST) {
                     error_msg("in parsing low bound\n");
                     h5tools_setstatus(EXIT_FAILURE);
@@ -594,7 +637,7 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'k':
-                bound = HDatoi(opt_arg);
+                bound = atoi(H5_optarg);
                 if (bound < H5F_LIBVER_EARLIEST || bound > H5F_LIBVER_LATEST) {
                     error_msg("in parsing high bound\n");
                     h5tools_setstatus(EXIT_FAILURE);
@@ -605,74 +648,74 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'X':
-                options->merge = TRUE;
+                options->merge = true;
                 break;
 
             case 'W':
-                options->prune = TRUE;
+                options->prune = true;
                 break;
 
             case 'c':
-                options->grp_compact = HDatoi(opt_arg);
+                options->grp_compact = atoi(H5_optarg);
                 if (options->grp_compact > 0)
-                    options->latest = TRUE; /* must use latest format */
+                    options->latest = true; /* must use latest format */
                 break;
 
             case 'd':
-                options->grp_indexed = HDatoi(opt_arg);
+                options->grp_indexed = atoi(H5_optarg);
                 if (options->grp_indexed > 0)
-                    options->latest = TRUE; /* must use latest format */
+                    options->latest = true; /* must use latest format */
                 break;
 
             case 's': {
                 int   idx       = 0;
                 int   ssize     = 0;
-                char *msgPtr    = HDstrchr(opt_arg, ':');
-                options->latest = TRUE; /* must use latest format */
+                char *msgPtr    = strchr(H5_optarg, ':');
+                options->latest = true; /* must use latest format */
                 if (msgPtr == NULL) {
-                    ssize = HDatoi(opt_arg);
+                    ssize = atoi(H5_optarg);
                     for (idx = 0; idx < 5; idx++)
                         options->msg_size[idx] = ssize;
                 }
                 else {
                     char msgType[10];
 
-                    HDstrcpy(msgType, msgPtr + 1);
+                    strcpy(msgType, msgPtr + 1);
                     msgPtr[0] = '\0';
-                    ssize     = HDatoi(opt_arg);
-                    if (!HDstrncmp(msgType, "dspace", 6))
+                    ssize     = atoi(H5_optarg);
+                    if (!strncmp(msgType, "dspace", 6))
                         options->msg_size[0] = ssize;
-                    else if (!HDstrncmp(msgType, "dtype", 5))
+                    else if (!strncmp(msgType, "dtype", 5))
                         options->msg_size[1] = ssize;
-                    else if (!HDstrncmp(msgType, "fill", 4))
+                    else if (!strncmp(msgType, "fill", 4))
                         options->msg_size[2] = ssize;
-                    else if (!HDstrncmp(msgType, "pline", 5))
+                    else if (!strncmp(msgType, "pline", 5))
                         options->msg_size[3] = ssize;
-                    else if (!HDstrncmp(msgType, "attr", 4))
+                    else if (!strncmp(msgType, "attr", 4))
                         options->msg_size[4] = ssize;
                 }
             } break;
 
             case 'u':
-                options->ublock_filename = opt_arg;
+                options->ublock_filename = H5_optarg;
                 break;
 
             case 'b':
-                options->ublock_size = (hsize_t)HDatol(opt_arg);
+                options->ublock_size = (hsize_t)atol(H5_optarg);
                 break;
 
             case 'M':
-                options->meta_block_size = (hsize_t)HDatol(opt_arg);
+                options->meta_block_size = (hsize_t)atol(H5_optarg);
                 break;
 
             case 't':
-                options->threshold = (hsize_t)HDatol(opt_arg);
+                options->threshold = (hsize_t)atol(H5_optarg);
                 break;
 
             case 'a':
-                options->alignment = HDstrtoull(opt_arg, NULL, 0);
+                options->alignment = strtoull(H5_optarg, NULL, 0);
                 if (options->alignment < 1) {
-                    error_msg("invalid alignment size\n", opt_arg);
+                    error_msg("invalid alignment size `%s`\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -682,17 +725,17 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
             case 'S': {
                 char strategy[MAX_NC_NAME];
 
-                HDstrcpy(strategy, opt_arg);
-                if (!HDstrcmp(strategy, "FSM_AGGR"))
+                strcpy(strategy, H5_optarg);
+                if (!strcmp(strategy, "FSM_AGGR"))
                     options->fs_strategy = H5F_FSPACE_STRATEGY_FSM_AGGR;
-                else if (!HDstrcmp(strategy, "PAGE"))
+                else if (!strcmp(strategy, "PAGE"))
                     options->fs_strategy = H5F_FSPACE_STRATEGY_PAGE;
-                else if (!HDstrcmp(strategy, "AGGR"))
+                else if (!strcmp(strategy, "AGGR"))
                     options->fs_strategy = H5F_FSPACE_STRATEGY_AGGR;
-                else if (!HDstrcmp(strategy, "NONE"))
+                else if (!strcmp(strategy, "NONE"))
                     options->fs_strategy = H5F_FSPACE_STRATEGY_NONE;
                 else {
-                    error_msg("invalid file space management strategy\n", opt_arg);
+                    error_msg("invalid file space management strategy `%s`\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -703,29 +746,33 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
             } break;
 
             case 'P':
-                options->fs_persist = HDatoi(opt_arg);
+                options->fs_persist = atoi(H5_optarg);
                 if (options->fs_persist == 0)
                     /* To distinguish the "specified" zero value */
                     options->fs_persist = -1;
                 break;
 
             case 'T':
-                options->fs_threshold = HDatol(opt_arg);
+                options->fs_threshold = atol(H5_optarg);
                 if (options->fs_threshold == 0)
                     /* To distinguish the "specified" zero value */
                     options->fs_threshold = -1;
                 break;
 
             case 'G':
-                options->fs_pagesize = HDstrtoll(opt_arg, NULL, 0);
+                options->fs_pagesize = strtoll(H5_optarg, NULL, 0);
                 if (options->fs_pagesize == 0)
                     /* To distinguish the "specified" zero value */
                     options->fs_pagesize = -1;
                 break;
 
+            case 'K':
+                page_cache = strtoul(H5_optarg, NULL, 0);
+                break;
+
             case 'q':
-                if (H5_INDEX_UNKNOWN == (sort_by = set_sort_by(opt_arg))) {
-                    error_msg("failed to set sort by form <%s>\n", opt_arg);
+                if (H5_INDEX_UNKNOWN == (sort_by = set_sort_by(H5_optarg))) {
+                    error_msg("failed to set sort by form <%s>\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -733,8 +780,8 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'z':
-                if (H5_ITER_UNKNOWN == (sort_order = set_sort_order(opt_arg))) {
-                    error_msg("failed to set sort order form <%s>\n", opt_arg);
+                if (H5_ITER_UNKNOWN == (sort_order = set_sort_order(H5_optarg))) {
+                    error_msg("failed to set sort order form <%s>\n", H5_optarg);
                     h5tools_setstatus(EXIT_FAILURE);
                     ret_value = -1;
                     goto done;
@@ -742,42 +789,74 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
                 break;
 
             case 'E':
-                if (opt_arg != NULL)
-                    enable_error_stack = HDatoi(opt_arg);
+                if (H5_optarg != NULL)
+                    enable_error_stack = atoi(H5_optarg);
                 else
                     enable_error_stack = 1;
                 break;
 
             case '1':
                 in_vol_info.type    = VOL_BY_VALUE;
-                in_vol_info.u.value = (H5VL_class_value_t)HDatoi(opt_arg);
-                custom_in_fapl      = TRUE;
+                in_vol_info.u.value = (H5VL_class_value_t)atoi(H5_optarg);
+                options->fin_vol    = true;
                 break;
 
             case '2':
                 in_vol_info.type   = VOL_BY_NAME;
-                in_vol_info.u.name = opt_arg;
-                custom_in_fapl     = TRUE;
+                in_vol_info.u.name = H5_optarg;
+                options->fin_vol   = true;
                 break;
 
             case '3':
-                in_vol_info.info_string = opt_arg;
+                in_vol_info.info_string = H5_optarg;
                 break;
 
             case '4':
                 out_vol_info.type    = VOL_BY_VALUE;
-                out_vol_info.u.value = (H5VL_class_value_t)HDatoi(opt_arg);
-                custom_out_fapl      = TRUE;
+                out_vol_info.u.value = (H5VL_class_value_t)atoi(H5_optarg);
+                options->fout_vol    = true;
                 break;
 
             case '5':
                 out_vol_info.type   = VOL_BY_NAME;
-                out_vol_info.u.name = opt_arg;
-                custom_out_fapl     = TRUE;
+                out_vol_info.u.name = H5_optarg;
+                options->fout_vol   = true;
                 break;
 
             case '6':
-                out_vol_info.info_string = opt_arg;
+                out_vol_info.info_string = H5_optarg;
+                break;
+
+            case '7':
+                in_vfd_info.type    = VFD_BY_VALUE;
+                in_vfd_info.u.value = (H5FD_class_value_t)atoi(H5_optarg);
+                options->fin_vfd    = true;
+                break;
+
+            case '8':
+                in_vfd_info.type   = VFD_BY_NAME;
+                in_vfd_info.u.name = H5_optarg;
+                options->fin_vfd   = true;
+                break;
+
+            case '9':
+                in_vfd_info.info = (const void *)H5_optarg;
+                break;
+
+            case '0':
+                out_vfd_info.type    = VFD_BY_VALUE;
+                out_vfd_info.u.value = (H5FD_class_value_t)atoi(H5_optarg);
+                options->fout_vfd    = true;
+                break;
+
+            case 'Y':
+                out_vfd_info.type   = VFD_BY_NAME;
+                out_vfd_info.u.name = H5_optarg;
+                options->fout_vfd   = true;
+                break;
+
+            case 'Z':
+                out_vfd_info.info = (const void *)H5_optarg;
                 break;
 
             default:
@@ -787,11 +866,11 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
 
     /* If neither -i nor -o given, get in and out files positionally */
     if (0 == (has_i + has_o)) {
-        if (argv[opt_ind] != NULL && argv[opt_ind + 1] != NULL) {
-            infile  = argv[opt_ind];
-            outfile = argv[opt_ind + 1];
+        if (argv[H5_optind] != NULL && argv[H5_optind + 1] != NULL) {
+            infile  = argv[H5_optind];
+            outfile = argv[H5_optind + 1];
 
-            if (!HDstrcmp(infile, outfile)) {
+            if (!strcmp(infile, outfile)) {
                 error_msg("file names cannot be the same\n");
                 usage(h5tools_getprogname());
                 h5tools_setstatus(EXIT_FAILURE);
@@ -812,46 +891,86 @@ parse_command_line(int argc, const char *const *argv, pack_opt_t *options)
         ret_value = -1;
     }
 
+    /* If the input file uses the onion VFD, get the revision number */
+    if (in_vfd_info.u.name && !strcmp(in_vfd_info.u.name, "onion")) {
+        if (in_vfd_info.info) {
+            errno                      = 0;
+            onion_fa_in_g.revision_num = strtoull(in_vfd_info.info, NULL, 10);
+            if (errno == ERANGE) {
+                printf("Invalid onion revision specified for the input file\n");
+                usage(h5tools_getprogname());
+                exit(EXIT_FAILURE);
+            }
+        }
+        else
+            onion_fa_in_g.revision_num = 0;
+
+        in_vfd_info.info = &onion_fa_in_g;
+    }
+
     /* Setup FAPL for input and output file accesses */
-    if (custom_in_fapl) {
-        if ((tmp_fapl = h5tools_get_fapl(options->fin_fapl, &in_vol_info, NULL)) < 0) {
-            error_msg("failed to setup FAPL for input file\n");
+    if ((tmp_fapl = h5tools_get_new_fapl(options->fin_fapl)) < 0) {
+        error_msg("unable to create FAPL for file access for input file\n");
+        h5tools_setstatus(EXIT_FAILURE);
+        ret_value = -1;
+        goto done;
+    }
+    /* Set non-default VOL connector, if requested */
+    if (options->fin_vol) {
+        if (h5tools_set_fapl_vol(tmp_fapl, &in_vol_info) < 0) {
+            error_msg("unable to set VOL on fapl for input file\n");
             h5tools_setstatus(EXIT_FAILURE);
             ret_value = -1;
             goto done;
         }
-
-        /* Close old FAPL */
-        if (options->fin_fapl != H5P_DEFAULT)
-            if (H5Pclose(options->fin_fapl) < 0) {
-                error_msg("failed to close FAPL\n");
-                h5tools_setstatus(EXIT_FAILURE);
-                ret_value = -1;
-                goto done;
-            }
-
-        options->fin_fapl = tmp_fapl;
     }
-
-    if (custom_out_fapl) {
-        if ((tmp_fapl = h5tools_get_fapl(options->fout_fapl, &out_vol_info, NULL)) < 0) {
-            error_msg("failed to setup FAPL for output file\n");
+    /* Set non-default virtual file driver, if requested */
+    if (options->fin_vfd) {
+        if (h5tools_set_fapl_vfd(tmp_fapl, &in_vfd_info) < 0) {
+            error_msg("unable to set VFD on fapl for input file\n");
             h5tools_setstatus(EXIT_FAILURE);
             ret_value = -1;
             goto done;
         }
-
-        /* Close old FAPL */
-        if (options->fout_fapl != H5P_DEFAULT)
-            if (H5Pclose(options->fout_fapl) < 0) {
-                error_msg("failed to close FAPL\n");
-                h5tools_setstatus(EXIT_FAILURE);
-                ret_value = -1;
-                goto done;
-            }
-
-        options->fout_fapl = tmp_fapl;
     }
+    if (page_cache > 0) {
+        if (H5Pset_page_buffer_size(tmp_fapl, page_cache, 0, 0) < 0) {
+            error_msg("unable to set page buffer cache size for input file\n");
+            h5tools_setstatus(EXIT_FAILURE);
+            ret_value = -1;
+            goto done;
+        }
+    }
+
+    options->fin_fapl = tmp_fapl;
+
+    /* Setup FAPL for input and output file accesses */
+    if ((tmp_fapl = h5tools_get_new_fapl(options->fout_fapl)) < 0) {
+        error_msg("unable to create FAPL for file access for output file\n");
+        h5tools_setstatus(EXIT_FAILURE);
+        ret_value = -1;
+        goto done;
+    }
+    /* Set non-default VOL connector, if requested */
+    if (options->fout_vol) {
+        if (h5tools_set_fapl_vol(tmp_fapl, &out_vol_info) < 0) {
+            error_msg("unable to set VOL on fapl for output file\n");
+            h5tools_setstatus(EXIT_FAILURE);
+            ret_value = -1;
+            goto done;
+        }
+    }
+    /* Set non-default virtual file driver, if requested */
+    if (options->fout_vfd) {
+        if (h5tools_set_fapl_vfd(tmp_fapl, &out_vfd_info) < 0) {
+            error_msg("unable to set VFD on fapl for output file\n");
+            h5tools_setstatus(EXIT_FAILURE);
+            ret_value = -1;
+            goto done;
+        }
+    }
+
+    options->fout_fapl = tmp_fapl;
 
 done:
     return ret_value;
@@ -870,10 +989,11 @@ done:
 int
 main(int argc, char **argv)
 {
-    pack_opt_t options; /*the global options */
-    int        parse_ret;
+    pack_opt_t *options = NULL; /*the global options */
+    int         parse_ret;
 
-    HDmemset(&options, 0, sizeof(pack_opt_t));
+    if (NULL == (options = (pack_opt_t *)calloc(1, sizeof(pack_opt_t))))
+        goto done;
 
     /* Initialize h5tools lib */
     h5tools_init();
@@ -883,14 +1003,14 @@ main(int argc, char **argv)
 
     /* update hyperslab buffer size from H5TOOLS_BUFSIZE env if exist */
     if (h5tools_getenv_update_hyperslab_bufsize() < 0) {
-        HDprintf("Error occurred while retrieving H5TOOLS_BUFSIZE value\n");
+        printf("Error occurred while retrieving H5TOOLS_BUFSIZE value\n");
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
     }
 
     /* initialize options  */
-    if (h5repack_init(&options, 0, FALSE) < 0) {
-        HDprintf("Error occurred while initializing repack options\n");
+    if (h5repack_init(options, 0, false) < 0) {
+        printf("Error occurred while initializing repack options\n");
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
     }
@@ -898,9 +1018,9 @@ main(int argc, char **argv)
     /* Initialize default indexing options */
     sort_by = H5_INDEX_CRT_ORDER;
 
-    parse_ret = parse_command_line(argc, (const char *const *)argv, &options);
+    parse_ret = parse_command_line(argc, (const char *const *)argv, options);
     if (parse_ret < 0) {
-        HDprintf("Error occurred while parsing command-line options\n");
+        printf("Error occurred while parsing command-line options\n");
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
     }
@@ -914,8 +1034,8 @@ main(int argc, char **argv)
     h5tools_error_report();
 
     /* pack it */
-    if (h5repack(infile, outfile, &options) < 0) {
-        HDprintf("Error occurred while repacking\n");
+    if (h5repack(infile, outfile, options) < 0) {
+        printf("Error occurred while repacking\n");
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
     }
@@ -923,13 +1043,17 @@ main(int argc, char **argv)
     h5tools_setstatus(EXIT_SUCCESS);
 
 done:
-    if (options.fin_fapl >= 0 && options.fin_fapl != H5P_DEFAULT)
-        H5Pclose(options.fin_fapl);
-    if (options.fout_fapl >= 0 && options.fout_fapl != H5P_DEFAULT)
-        H5Pclose(options.fout_fapl);
+    if (options) {
+        if (options->fin_fapl >= 0 && options->fin_fapl != H5P_DEFAULT)
+            H5Pclose(options->fin_fapl);
+        if (options->fout_fapl >= 0 && options->fout_fapl != H5P_DEFAULT)
+            H5Pclose(options->fout_fapl);
 
-    /* free tables */
-    h5repack_end(&options);
+        /* free tables */
+        h5repack_end(options);
+
+        free(options);
+    }
 
     leave(h5tools_getstatus());
 }
