@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -23,8 +23,8 @@
  * parameters. The long-named ones can be partially spelled. When
  * adding more, make sure that they don't clash with each other.
  */
-static const char         *s_opts   = "h";
-static struct long_options l_opts[] = {{"help", no_arg, 'h'}, {"hel", no_arg, 'h'}, {NULL, 0, '\0'}};
+static const char            *s_opts   = "h";
+static struct h5_long_options l_opts[] = {{"help", no_arg, 'h'}, {"hel", no_arg, 'h'}, {NULL, 0, '\0'}};
 
 /*-------------------------------------------------------------------------
  * Function:    usage
@@ -37,11 +37,11 @@ static struct long_options l_opts[] = {{"help", no_arg, 'h'}, {"hel", no_arg, 'h
 static void
 usage(const char *prog)
 {
-    HDfflush(stdout);
-    HDfprintf(stdout, "usage: %s h5_file\n", prog);
-    HDfprintf(stdout, "           Check that h5_fil is HDF5 file and print size of user block \n");
-    HDfprintf(stdout, "       %s -h\n", prog);
-    HDfprintf(stdout, "           Print a usage message and exit\n");
+    fflush(stdout);
+    fprintf(stdout, "usage: %s h5_file\n", prog);
+    fprintf(stdout, "           Check that h5_fil is HDF5 file and print size of user block \n");
+    fprintf(stdout, "       %s -h\n", prog);
+    fprintf(stdout, "           Print a usage message and exit\n");
 } /* end usage() */
 
 /*-------------------------------------------------------------------------
@@ -60,7 +60,7 @@ parse_command_line(int argc, const char *const *argv)
     int opt;
 
     /* parse command line options */
-    while ((opt = get_option(argc, argv, s_opts, l_opts)) != EOF) {
+    while ((opt = H5_get_option(argc, argv, s_opts, l_opts)) != EOF) {
         switch ((char)opt) {
             case 'h':
                 usage(h5tools_getprogname());
@@ -74,7 +74,7 @@ parse_command_line(int argc, const char *const *argv)
     }
 
     /* check for file name to be processed */
-    if (argc <= opt_ind) {
+    if (argc <= H5_optind) {
         error_msg("missing file name\n");
         usage(h5tools_getprogname());
         h5tools_setstatus(EXIT_FAILURE);
@@ -85,7 +85,7 @@ static void
 leave(int ret)
 {
     h5tools_close();
-    HDexit(ret);
+    exit(ret);
 }
 
 /*-------------------------------------------------------------------------
@@ -117,14 +117,14 @@ main(int argc, char *argv[])
     /* enable error reporting if command line option */
     h5tools_error_report();
 
-    if (argc <= (opt_ind)) {
+    if (argc <= (H5_optind)) {
         error_msg("missing file name\n");
         usage(h5tools_getprogname());
         h5tools_setstatus(EXIT_FAILURE);
         goto done;
     }
 
-    ifname = HDstrdup(argv[opt_ind]);
+    ifname = strdup(argv[H5_optind]);
 
     testval = H5Fis_accessible(ifname, H5P_DEFAULT);
 
@@ -156,12 +156,13 @@ main(int argc, char *argv[])
         goto done;
     }
 
-    HDprintf("%ld\n", (long)usize);
+    printf("%ld\n", (long)usize);
 
 done:
     H5Pclose(plist);
     if (ifile >= 0)
         H5Fclose(ifile);
+    free(ifname);
 
     leave(h5tools_getstatus());
 } /* end main() */
