@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -18,9 +18,9 @@ static void usage(void);
 static void
 usage(void)
 {
-    HDfprintf(stdout, "\n");
-    HDfprintf(stdout, "Usage error!\n");
-    HDfprintf(stdout, "Usage: clear_open_chk filename\n");
+    fprintf(stdout, "\n");
+    fprintf(stdout, "Usage error!\n");
+    fprintf(stdout, "Usage: clear_open_chk filename\n");
 } /* usage() */
 
 /*-------------------------------------------------------------------------
@@ -32,8 +32,6 @@ usage(void)
  * Return:    0 on success
  *        1 on failure
  *
- * Programmer:    Vailin Choi; July 2013
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -45,26 +43,26 @@ main(int argc, char *argv[])
     /* Check the # of arguments */
     if (argc != 2) {
         usage();
-        HDexit(EXIT_FAILURE);
+        exit(EXIT_FAILURE);
     }
 
     /* Get the file name */
-    fname = HDstrdup(argv[1]);
+    fname = strdup(argv[1]);
 
     /* Try opening the file */
-    if ((fid = h5tools_fopen(fname, H5F_ACC_RDONLY, H5P_DEFAULT, FALSE, NULL, (size_t)0)) < 0) {
-        HDfprintf(stderr, "clear_open_chk: unable to open the file\n");
-        HDfree(fname);
-        HDexit(EXIT_FAILURE);
+    if ((fid = h5tools_fopen(fname, H5F_ACC_RDONLY, H5P_DEFAULT, false, NULL, (size_t)0)) < 0) {
+        fprintf(stderr, "clear_open_chk: unable to open the file\n");
+        free(fname);
+        exit(EXIT_FAILURE);
     }
-    HDfree(fname);
+    free(fname);
 
     /* Close the file */
     if (H5Fclose(fid) < 0) {
-        HDfprintf(stderr, "clear_open_chk: cannot close the file\n");
-        HDexit(EXIT_FAILURE);
+        fprintf(stderr, "clear_open_chk: cannot close the file\n");
+        exit(EXIT_FAILURE);
     }
 
     /* Return success */
-    HDexit(EXIT_SUCCESS);
+    exit(EXIT_SUCCESS);
 } /* main() */
