@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -13,7 +13,7 @@
 #include "h5test.h"
 
 /* The HDF5 test files */
-const char *FILENAME[] = {
+static const char *FILENAME[] = {
     "h5clear_sec2_v3.h5", /* 0 -- sec2 file with superblock version 3 */
     "h5clear_log_v3.h5",  /* 1 -- log file with superblock version 3 */
     "h5clear_sec2_v0.h5", /* 2 -- sec2 file with superblock version 0 */
@@ -48,31 +48,31 @@ const char *FILENAME_ENHANCE[] = {
  * Return:      Success:    0
  *              Failure:    1
  *
- * Programmer:    Vailin Choi; March 2017
- *
  *-------------------------------------------------------------------------
  */
 static int
 gen_cache_image_file(const char *fname)
 {
-    hid_t                     fid = H5I_INVALID_HID;           /* File ID */
-    hid_t                     did = -1, sid = H5I_INVALID_HID; /* Dataset ID, dataspace ID */
-    hid_t                     fapl = H5I_INVALID_HID;          /* File access property list */
-    hid_t                     dcpl = H5I_INVALID_HID;          /* Dataset creation property list */
-    hsize_t                   dims[2];                         /* Dimension sizes */
-    hsize_t                   chunks[2];                       /* Chunked dimension sizes */
-    int                       i, j;                            /* Local index variables */
-    int                     **buf                = NULL;       /* Buffer for data to write */
-    H5AC_cache_image_config_t cache_image_config =             /* Cache image input configuration */
-        {H5AC__CURR_CACHE_IMAGE_CONFIG_VERSION, TRUE, FALSE, H5AC__CACHE_IMAGE__ENTRY_AGEOUT__NONE};
+    hid_t   fid = H5I_INVALID_HID;           /* File ID */
+    hid_t   did = -1, sid = H5I_INVALID_HID; /* Dataset ID, dataspace ID */
+    hid_t   fapl = H5I_INVALID_HID;          /* File access property list */
+    hid_t   dcpl = H5I_INVALID_HID;          /* Dataset creation property list */
+    hsize_t dims[2];                         /* Dimension sizes */
+    hsize_t chunks[2];                       /* Chunked dimension sizes */
+    int     i, j;                            /* Local index variables */
+    struct {
+        int arr[50][100];
+    }                        *buf;                 /* Buffer for data to write */
+    H5AC_cache_image_config_t cache_image_config = /* Cache image input configuration */
+        {H5AC__CURR_CACHE_IMAGE_CONFIG_VERSION, true, false, H5AC__CACHE_IMAGE__ENTRY_AGEOUT__NONE};
 
     /* Create and fill array */
-    H5TEST_ALLOCATE_2D_ARRAY(buf, int, 50, 100);
+    buf = malloc(sizeof(*buf));
     if (NULL == buf)
         goto error;
     for (i = 0; i < 50; i++)
         for (j = 0; j < 100; j++)
-            buf[i][j] = i * j;
+            buf->arr[i][j] = i * j;
 
     /* Create a copy of file access property list */
     if ((fapl = H5Pcreate(H5P_FILE_ACCESS)) < 0)
@@ -107,7 +107,7 @@ gen_cache_image_file(const char *fname)
         goto error;
 
     /* Write to the dataset */
-    if (H5Dwrite(did, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, buf[0]) < 0)
+    if (H5Dwrite(did, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, buf) < 0)
         goto error;
 
     /* Closing */
@@ -122,7 +122,7 @@ gen_cache_image_file(const char *fname)
     if (H5Fclose(fid) < 0)
         goto error;
 
-    HDfree(buf);
+    free(buf);
 
     return 0;
 
@@ -136,9 +136,9 @@ error:
         H5Pclose(fapl);
         H5Pclose(dcpl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
 
-    HDfree(buf);
+    free(buf);
 
     return 1;
 } /* gen_cache_image_file() */
@@ -165,12 +165,10 @@ error:
  * Return:      Success:    0
  *              Failure:    1
  *
- * Programmer:    Vailin Choi; March 2017
- *
  *-------------------------------------------------------------------------
  */
 static int
-gen_enhance_files(hbool_t user)
+gen_enhance_files(bool user)
 {
     hid_t    fid  = H5I_INVALID_HID; /* File ID */
     hid_t    fcpl = H5I_INVALID_HID; /* File creation property list */
@@ -195,7 +193,7 @@ gen_enhance_files(hbool_t user)
     }
 
     /* Set file space strategy and persisting free-space */
-    if (H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_FSM_AGGR, TRUE, (hsize_t)1) < 0)
+    if (H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_FSM_AGGR, true, (hsize_t)1) < 0)
         goto error;
 
     /*
@@ -276,7 +274,7 @@ gen_enhance_files(hbool_t user)
         }
 
         /* location of "end of file address" */
-        if (lseek(fd, (off_t)(28 + (user ? USERBLOCK : 0)), SEEK_SET) < 0)
+        if (lseek(fd, (HDoff_t)(28 + (user ? USERBLOCK : 0)), SEEK_SET) < 0)
             goto error;
 
         /* Write the bad eoa value to the file */
@@ -284,7 +282,7 @@ gen_enhance_files(hbool_t user)
             goto error;
 
         /* location of "superblock checksum" */
-        if (lseek(fd, (off_t)(44 + (user ? USERBLOCK : 0)), SEEK_SET) < 0)
+        if (lseek(fd, (HDoff_t)(44 + (user ? USERBLOCK : 0)), SEEK_SET) < 0)
             goto error;
 
         /* Write the chksum value to the file */
@@ -311,7 +309,7 @@ error:
         H5Fclose(fid);
         H5Pclose(fcpl);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 } /* gen_enhance_files() */
 
@@ -364,8 +362,6 @@ error:
  * Return:    Success:    0
  *            Failure:    1
  *
- * Programmer:    Vailin Choi; July 2013
- *
  *-------------------------------------------------------------------------
  */
 int
@@ -387,9 +383,9 @@ main(void)
         goto error;
 
     /* Generate the first 6 files in FILENAME_ENHANCE[]  */
-    if (gen_enhance_files(FALSE) < 0)
+    if (gen_enhance_files(false) < 0)
         goto error;
-    if (gen_enhance_files(TRUE) < 0)
+    if (gen_enhance_files(true) < 0)
         goto error;
 
     /*
@@ -411,7 +407,7 @@ main(void)
      *      --FILENAME[0]: "h5clear_sec2_v3.h5", "latest_h5clear_sec2_v3.h5"
      *      --FILENAME[1]: "h5clear_log_v3.h5", "latest_h5clear_log_v3.h5"
      */
-    for (new_format = FALSE; new_format <= TRUE; new_format++) {
+    for (new_format = false; new_format <= true; new_format++) {
         hid_t fapl2, my_fapl; /* File access property lists */
 
         /* Set to use the appropriate file access property list */
@@ -425,7 +421,7 @@ main(void)
         if ((my_fapl = H5Pcopy(fapl2)) < 0)
             goto error;
         /* Create the file */
-        HDsnprintf(fname, sizeof(fname), "%s%s", new_format ? "latest_" : "", FILENAME[0]);
+        snprintf(fname, sizeof(fname), "%s%s", new_format ? "latest_" : "", FILENAME[0]);
         if ((fid = H5Fcreate(fname, H5F_ACC_TRUNC | (new_format ? 0 : H5F_ACC_SWMR_WRITE), H5P_DEFAULT,
                              my_fapl)) < 0)
             goto error;
@@ -450,7 +446,7 @@ main(void)
             goto error;
 
         /* Create the file */
-        HDsnprintf(fname, sizeof(fname), "%s%s", new_format ? "latest_" : "", FILENAME[1]);
+        snprintf(fname, sizeof(fname), "%s%s", new_format ? "latest_" : "", FILENAME[1]);
         if ((fid = H5Fcreate(fname, H5F_ACC_TRUNC | (new_format ? 0 : H5F_ACC_SWMR_WRITE), H5P_DEFAULT,
                              my_fapl)) < 0)
             goto error;
@@ -563,7 +559,7 @@ main(void)
         goto error;
 
     /* Set file space strategy and persisting free-space */
-    if (H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_FSM_AGGR, TRUE, (hsize_t)1) < 0)
+    if (H5Pset_file_space_strategy(fcpl, H5F_FSPACE_STRATEGY_FSM_AGGR, true, (hsize_t)1) < 0)
         goto error;
 
     /* Create the file with the set file space info */
@@ -598,10 +594,10 @@ main(void)
     fflush(stderr);
 
     /* Not going through library closing by calling _exit(0) with success */
-    HD_exit(0);
+    _exit(0);
 
 error:
 
     /* Exit with failure */
-    HD_exit(1);
+    _exit(1);
 }
