@@ -4,23 +4,19 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
 
 /*
- * Programmer:  Robb Matzke
- *              Thursday, May 14, 1998
- *
  * Purpose:	Checks the effect of various I/O request sizes and raw data
  *		cache sizes.  Performance depends on the amount of data read
  *		from disk and we use a filter to get that number.
  */
 
 /* See H5private.h for how to include headers */
-#undef NDEBUG
 #include "hdf5.h"
 
 #include <assert.h>
@@ -28,8 +24,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-/* Solaris Studio defines attribute, but for the attributes we need */
-#if !defined(H5_HAVE_ATTRIBUTE) || defined __cplusplus || defined(__SUNPRO_C)
+#if !defined(H5_HAVE_ATTRIBUTE) || defined __cplusplus
 #undef __attribute__
 #define __attribute__(X) /*void*/
 #define H5_ATTR_UNUSED   /*void*/
@@ -76,7 +71,7 @@ static size_t counter(unsigned H5_ATTR_UNUSED flags, size_t cd_nelmts, const uns
                       size_t nbytes, size_t *buf_size, void **buf);
 
 /* This message derives from H5Z */
-const H5Z_class2_t H5Z_COUNTER[1] = {{
+static const H5Z_class2_t H5Z_COUNTER[1] = {{
     H5Z_CLASS_T_VERS, /* H5Z_class_t version		*/
     FILTER_COUNTER,   /* Filter id number		*/
     1, 1,             /* Encoding and decoding enabled */
@@ -95,11 +90,6 @@ const H5Z_class2_t H5Z_COUNTER[1] = {{
  *
  *		Failure:	never fails
  *
- * Programmer:	Robb Matzke
- *              Thursday, May 14, 1998
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static size_t
@@ -121,11 +111,6 @@ counter(unsigned H5_ATTR_UNUSED flags, size_t H5_ATTR_UNUSED cd_nelmts,
  *
  * Return:	void
  *
- * Programmer:	Robb Matzke
- *              Thursday, May 14, 1998
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static void
@@ -173,11 +158,6 @@ create_dataset(void)
  *
  * Return:	Efficiency: data requested divided by data actually read.
  *
- * Programmer:	Robb Matzke
- *              Thursday, May 14, 1998
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static double
@@ -245,11 +225,6 @@ test_rowmaj(int op, size_t cache_size, size_t io_size)
  *
  * Return:	Efficiency.
  *
- * Programmer:	Robb Matzke
- *              Friday, May 15, 1998
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 static double
@@ -316,11 +291,6 @@ test_diag(int op, size_t cache_size, size_t io_size, size_t offset)
  *
  *		Failure:
  *
- * Programmer:	Robb Matzke
- *              Thursday, May 14, 1998
- *
- * Modifications:
- *
  *-------------------------------------------------------------------------
  */
 int
