@@ -4,7 +4,7 @@
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
- * the COPYING file, which can be found at the root of the source code       *
+ * the LICENSE file, which can be found at the root of the source code       *
  * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
@@ -18,44 +18,41 @@
 #include "hdf5.h"
 
 #ifdef H5_HAVE_FILTER_DEFLATE
-#include <zlib.h>
+#if defined(H5_HAVE_ZLIB_H) && !defined(H5_ZLIB_HEADER)
+#define H5_ZLIB_HEADER "zlib.h"
+#endif
+#if defined(H5_ZLIB_HEADER)
+#include H5_ZLIB_HEADER /* "zlib.h" */
+#endif
 
 #if !defined(WIN32) && !defined(__MINGW32__)
 
-#include <math.h>
-
-#ifdef H5_STDC_HEADERS
 #include <errno.h>
 #include <fcntl.h>
+#include <math.h>
 #include <stdio.h>
 #include <stdlib.h>
-#endif
-
-#ifdef H5_HAVE_UNISTD_H
+#include <time.h>
 #include <sys/types.h>
-#include <unistd.h>
-#endif
 
 #ifdef H5_HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
 
-#if defined(H5_TIME_WITH_SYS_TIME)
+#ifdef H5_HAVE_SYS_TIME_H
 #include <sys/time.h>
-#include <time.h>
-#elif defined(H5_HAVE_SYS_TIME_H)
-#include <sys/time.h>
-#else
-#include <time.h>
 #endif
 
-const char *FILENAME[] = {"direct_write", "unix.raw", NULL};
+#ifdef H5_HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+
+static const char *FILENAME[] = {"direct_write", "unix.raw", NULL};
 
 /*
  * Print the current location on the standard output stream.
  */
-#define FUNC __func__
-#define AT() printf("   at %s:%d in %s()...\n", __FILE__, __LINE__, FUNC);
+#define AT() printf("   at %s:%d in %s()...\n", __FILE__, __LINE__, __func__);
 #define H5_FAILED()                                                                                          \
     {                                                                                                        \
         puts("*FAILED*");                                                                                    \
@@ -247,7 +244,11 @@ create_file(hid_t fapl_id)
         z_dst     = (Bytef *)outbuf[i];
 
         /* Perform compression from the source to the destination buffer */
+#if defined(H5_HAVE_ZLIBNG_H)
+        ret = zng_compress2(z_dst, &z_dst_nbytes, z_src, z_src_nbytes, aggression);
+#else
         ret = compress2(z_dst, &z_dst_nbytes, z_src, z_src_nbytes, aggression);
+#endif
 
         data_size[i] = (size_t)z_dst_nbytes;
         total_size += data_size[i];
@@ -277,7 +278,7 @@ error:
         H5Pclose(cparms);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -343,7 +344,7 @@ error:
         H5Pclose(dxpl);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -408,7 +409,7 @@ error:
         H5Pclose(dxpl);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -500,7 +501,7 @@ error:
         H5Pclose(dxpl);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -592,7 +593,7 @@ error:
         H5Pclose(dxpl);
         H5Fclose(file);
     }
-    H5E_END_TRY;
+    H5E_END_TRY
     return 1;
 }
 
@@ -698,7 +699,7 @@ main(void)
 int
 main(void)
 {
-    HDfprintf(stdout, "No compression IO performance because zlib was not configured\n");
+    fprintf(stdout, "No compression IO performance because zlib was not configured\n");
     return EXIT_SUCCESS;
 }
 
